@@ -2,7 +2,7 @@
 
 require 'erb'
 require 'yaml'
-require 'pathname'
+require_relative 'cache_config'
 require_relative 'config_finder'
 
 module RuboCop
@@ -25,47 +25,65 @@ module RuboCop
 
       attr_accessor :debug, :ignore_parent_exclusion, :disable_pending_cops, :enable_pending_cops,
                     :ignore_unrecognized_cops
-      attr_writer :default_configuration
-      attr_reader :loaded_features
+      attr_writer :default_configuration, :cache_root
+      attr_reader :loaded_plugins, :loaded_features
 
       alias debug? debug
       alias ignore_parent_exclusion? ignore_parent_exclusion
 
+      def cache_root(cache_root_override = nil)
+        @cache_root ||= CacheConfig.root_dir_from_toplevel_config(cache_root_override)
+      end
+
       def clear_options
         @debug = nil
+        @loaded_plugins = Set.new
         @loaded_features = Set.new
+        @disable_pending_cops = nil
+        @enable_pending_cops = nil
+        @ignore_parent_exclusion = nil
+        @ignore_unrecognized_cops = nil
+        @cache_root = nil
         FileFinder.root_level = nil
       end
 
+      # rubocop:disable Metrics/AbcSize
       def load_file(file, check: true)
         path = file_path(file)
 
         hash = load_yaml_configuration(path)
 
-        # Resolve requires first in case they define additional cops
+        rubocop_config = Config.create(hash, path, check: false)
+        plugins = hash.delete('plugins')
+        loaded_plugins = resolver.resolve_plugins(rubocop_config, plugins)
+        add_loaded_plugins(loaded_plugins)
+
         loaded_features = resolver.resolve_requires(path, hash)
         add_loaded_features(loaded_features)
 
-        add_missing_namespaces(path, hash)
-
-        resolver.override_department_setting_for_cops({}, hash)
         resolver.resolve_inheritance_from_gems(hash)
         resolver.resolve_inheritance(path, hash, file, debug?)
-
         hash.delete('inherit_from')
 
+        # Adding missing namespaces only after resolving requires & inheritance,
+        # since both can introduce new cops that need to be considered here.
+        add_missing_namespaces(path, hash)
+
         Config.create(hash, path, check: check)
       end
+      # rubocop:enable Metrics/AbcSize
 
       def load_yaml_configuration(absolute_path)
         file_contents = read_file(absolute_path)
         yaml_code = Dir.chdir(File.dirname(absolute_path)) { ERB.new(file_contents).result }
-        check_duplication(yaml_code, absolute_path)
-        hash = yaml_safe_load(yaml_code, absolute_path) || {}
+        yaml_tree = check_duplication(yaml_code, absolute_path)
+        hash = yaml_tree_to_hash(yaml_tree) || {}
 
         puts "configuration from #{absolute_path}" if debug?
 
-        raise(TypeError, "Malformed configuration in #{absolute_path}") unless hash.is_a?(Hash)
+        unless hash.is_a?(Hash)
+          raise(ValidationError, "Malformed configuration in #{absolute_path}")
+        end
 
         hash
       end
@@ -73,8 +91,12 @@ module RuboCop
       def add_missing_namespaces(path, hash)
         # Using `hash.each_key` will cause the
         # `can't add a new key into hash during iteration` error
+        obsoletion = ConfigObsoletion.new(hash)
+
         hash_keys = hash.keys
         hash_keys.each do |key|
+          next if obsoletion.deprecated_cop_name?(key)
+
           q = Cop::Registry.qualified_cop_name(key, path)
           next if q == key
 
@@ -110,14 +132,7 @@ module RuboCop
           add_excludes_from_files(config, config_file)
         end
 
-        merge_with_default(config, config_file).tap do |merged_config|
-          warn_on_pending_cops(merged_config.pending_cops) unless possible_new_cops?(merged_config)
-        end
-      end
-
-      def possible_new_cops?(config)
-        disable_pending_cops || enable_pending_cops ||
-          config.disabled_new_cops? || config.enabled_new_cops?
+        merge_with_default(config, config_file)
       end
 
       def add_excludes_from_files(config, config_file)
@@ -137,11 +152,32 @@ module RuboCop
         end
       end
 
+      # This API is primarily intended for testing and documenting plugins.
+      # When testing a plugin using `rubocop/rspec/support`, the plugin is loaded automatically,
+      # so this API is usually not needed. It is intended to be used only when implementing tests
+      # that do not use `rubocop/rspec/support`.
+      def inject_defaults!(config_yml_path)
+        if Pathname(config_yml_path).directory?
+          warn Rainbow(<<~MESSAGE).yellow, uplevel: 1
+            Use config YAML file path instead of project root directory.
+            e.g., `path/to/config/default.yml`
+          MESSAGE
+          raise ArgumentError,
+                'Passing a project root directory to `inject_defaults!` is no longer supported.'
+        end
+
+        path = config_yml_path.to_s
+        hash = ConfigLoader.load_yaml_configuration(path)
+        config = Config.new(hash, path).tap(&:make_excludes_absolute)
+
+        @default_configuration = ConfigLoader.merge_with_default(config, path)
+      end
+
       # Returns the path RuboCop inferred as the root of the project. No file
       # searches will go past this directory.
       # @deprecated Use `RuboCop::ConfigFinder.project_root` instead.
       def project_root
-        warn Rainbow(<<~WARNING).yellow
+        warn Rainbow(<<~WARNING).yellow, uplevel: 1
           `RuboCop::ConfigLoader.project_root` is deprecated and will be removed in RuboCop 2.0. \
           Use `RuboCop::ConfigFinder.project_root` instead.
         WARNING
@@ -149,36 +185,18 @@ module RuboCop
         ConfigFinder.project_root
       end
 
-      PENDING_BANNER = <<~BANNER
-        The following cops were added to RuboCop, but are not configured. Please set Enabled to either `true` or `false` in your `.rubocop.yml` file.
-
-        Please also note that you can opt-in to new cops by default by adding this to your config:
-          AllCops:
-            NewCops: enable
-      BANNER
-
-      def warn_on_pending_cops(pending_cops)
-        return if pending_cops.empty?
-
-        warn Rainbow(PENDING_BANNER).yellow
-
-        pending_cops.each { |cop| warn_pending_cop cop }
-
-        warn Rainbow('For more information: https://docs.rubocop.org/rubocop/versioning.html').yellow
-      end
-
-      def warn_pending_cop(cop)
-        version = cop.metadata['VersionAdded'] || 'N/A'
-
-        warn Rainbow("#{cop.name}: # new in #{version}").yellow
-        warn Rainbow('  Enabled: true').yellow
-      end
-
       # Merges the given configuration with the default one.
       def merge_with_default(config, config_file, unset_nil: true)
         resolver.merge_with_default(config, config_file, unset_nil: unset_nil)
       end
 
+      # @api private
+      # Used to add plugins that were required inside a config or from
+      # the CLI using `--plugin`.
+      def add_loaded_plugins(loaded_plugins)
+        @loaded_plugins.merge(Array(loaded_plugins))
+      end
+
       # @api private
       # Used to add features that were required inside a config or from
       # the CLI using `--require`.
@@ -222,8 +240,8 @@ module RuboCop
         raise ConfigNotFoundError, "Configuration file not found: #{absolute_path}"
       end
 
-      def yaml_safe_load(yaml_code, filename)
-        yaml_safe_load!(yaml_code, filename)
+      def yaml_tree_to_hash(yaml_tree)
+        yaml_tree_to_hash!(yaml_tree)
       rescue ::StandardError
         if defined?(::SafeYAML)
           raise 'SafeYAML is unmaintained, no longer needed and should be removed'
@@ -232,18 +250,16 @@ module RuboCop
         raise
       end
 
-      if Gem::Version.new(Psych::VERSION) >= Gem::Version.new('3.1.0')
-        def yaml_safe_load!(yaml_code, filename)
-          YAML.safe_load(yaml_code,
-                         permitted_classes: [Regexp, Symbol],
-                         permitted_symbols: [],
-                         aliases: true,
-                         filename: filename)
-        end
-      else # Ruby < 2.6
-        def yaml_safe_load!(yaml_code, filename)
-          YAML.safe_load(yaml_code, [Regexp, Symbol], [], true, filename)
-        end
+      def yaml_tree_to_hash!(yaml_tree)
+        return nil unless yaml_tree
+
+        # Optimization: Because we checked for duplicate keys, we already have the
+        # yaml tree and don't need to parse it again.
+        # Also see https://github.com/ruby/psych/blob/v5.1.2/lib/psych.rb#L322-L336
+        class_loader = YAML::ClassLoader::Restricted.new(%w[Regexp Symbol], [])
+        scanner = YAML::ScalarScanner.new(class_loader)
+        visitor = YAML::Visitors::ToRuby.new(scanner, class_loader)
+        visitor.accept(yaml_tree)
       end
     end
 
