@@ -121,14 +121,16 @@ module RuboCop
           return if case_node.single_line?
           return if enforced_style_end? && end_and_last_conditional_same_line?(case_node)
 
-          case_node.each_when { |when_node| check_when(when_node, 'when') }
+          case_node.when_branches.each { |when_node| check_when(when_node, 'when') }
         end
 
         def on_case_match(case_match_node)
           return if case_match_node.single_line?
           return if enforced_style_end? && end_and_last_conditional_same_line?(case_match_node)
 
-          case_match_node.each_in_pattern { |in_pattern_node| check_when(in_pattern_node, 'in') }
+          case_match_node.in_pattern_branches.each do |in_pattern_node|
+            check_when(in_pattern_node, 'in')
+          end
         end
 
         private
