@@ -6,10 +6,13 @@ module RuboCop
       # Checks for duplicated instance (or singleton) method
       # definitions.
       #
+      # NOTE: Aliasing a method to itself is allowed, as it indicates that
+      # the developer intends to suppress Ruby's method redefinition warnings.
+      # See https://bugs.ruby-lang.org/issues/13574.
+      #
       # @example
       #
       #   # bad
-      #
       #   def foo
       #     1
       #   end
@@ -18,20 +21,14 @@ module RuboCop
       #     2
       #   end
       #
-      # @example
-      #
       #   # bad
-      #
       #   def foo
       #     1
       #   end
       #
       #   alias foo bar
       #
-      # @example
-      #
       #   # good
-      #
       #   def foo
       #     1
       #   end
@@ -40,37 +37,109 @@ module RuboCop
       #     2
       #   end
       #
-      # @example
-      #
       #   # good
-      #
       #   def foo
       #     1
       #   end
       #
       #   alias bar foo
-      class DuplicateMethods < Base
+      #
+      #   # good
+      #   alias foo foo
+      #   def foo
+      #     1
+      #   end
+      #
+      #   # good
+      #   alias_method :foo, :foo
+      #   def foo
+      #     1
+      #   end
+      #
+      #   # bad
+      #   class MyClass
+      #     extend Forwardable
+      #
+      #     # or with: `def_instance_delegator`, `def_delegators`, `def_instance_delegators`
+      #     def_delegator :delegation_target, :delegated_method_name
+      #
+      #     def delegated_method_name
+      #     end
+      #   end
+      #
+      #   # good
+      #   class MyClass
+      #     extend Forwardable
+      #
+      #     def_delegator :delegation_target, :delegated_method_name
+      #
+      #     def non_duplicated_delegated_method_name
+      #     end
+      #   end
+      #
+      # @example AllCops:ActiveSupportExtensionsEnabled: false (default)
+      #
+      #   # good
+      #   def foo
+      #     1
+      #   end
+      #
+      #   delegate :foo, to: :bar
+      #
+      # @example AllCops:ActiveSupportExtensionsEnabled: true
+      #
+      #   # bad
+      #   def foo
+      #     1
+      #   end
+      #
+      #   delegate :foo, to: :bar
+      #
+      #   # good
+      #   def foo
+      #     1
+      #   end
+      #
+      #   delegate :baz, to: :bar
+      #
+      #   # good - delegate with splat arguments is ignored
+      #   def foo
+      #     1
+      #   end
+      #
+      #   delegate :foo, **options
+      #
+      #   # good - delegate inside a condition is ignored
+      #   def foo
+      #     1
+      #   end
+      #
+      #   if cond
+      #     delegate :foo, to: :bar
+      #   end
+      #
+      class DuplicateMethods < Base # rubocop:disable Metrics/ClassLength
         MSG = 'Method `%<method>s` is defined at both %<defined>s and %<current>s.'
-        RESTRICT_ON_SEND = %i[alias_method attr_reader attr_writer attr_accessor attr].freeze
-        DEF_TYPES = %i[def defs].freeze
+        RESTRICT_ON_SEND = %i[alias_method attr_reader attr_writer attr_accessor attr
+                              delegate def_delegator def_instance_delegator def_delegators
+                              def_instance_delegators].freeze
 
         def initialize(config = nil, options = nil)
           super
           @definitions = {}
+          @scopes = Hash.new { |hash, key| hash[key] = [] }
         end
 
         def on_def(node)
           # if a method definition is inside an if, it is very likely
           # that a different definition is used depending on platform, etc.
-          return if node.ancestors.any?(&:if_type?)
-          return if possible_dsl?(node)
+          return if node.each_ancestor.any?(&:if_type?)
 
           found_instance_method(node, node.method_name)
         end
 
         def on_defs(node)
-          return if node.ancestors.any?(&:if_type?)
-          return if possible_dsl?(node)
+          return if node.each_ancestor.any?(&:if_type?)
 
           if node.receiver.const_type?
             _, const_name = *node.receiver
@@ -82,32 +151,74 @@ module RuboCop
 
         # @!method method_alias?(node)
         def_node_matcher :method_alias?, <<~PATTERN
-          (alias (sym $_name) sym)
+          (alias (sym $_name) (sym $_original_name))
         PATTERN
 
         def on_alias(node)
-          return unless (name = method_alias?(node))
+          name, original_name = method_alias?(node)
+          return unless name && original_name
+          return if name == original_name
           return if node.ancestors.any?(&:if_type?)
-          return if possible_dsl?(node)
 
           found_instance_method(node, name)
         end
 
         # @!method alias_method?(node)
         def_node_matcher :alias_method?, <<~PATTERN
-          (send nil? :alias_method (sym $_name) _)
+          (send nil? :alias_method (sym $_name) (sym $_original_name))
+        PATTERN
+
+        # @!method delegate_method?(node)
+        def_node_matcher :delegate_method?, <<~PATTERN
+          (send nil? :delegate
+            ({sym str} $_)+
+            (hash <(pair (sym :to) {sym str}) ...>)
+          )
+        PATTERN
+
+        # @!method delegator?(node)
+        def_node_matcher :delegator?, <<~PATTERN
+          (send nil? {:def_delegator :def_instance_delegator}
+            {
+              {sym str} ({sym str} $_) |
+              {sym str} {sym str} ({sym str} $_)
+            }
+          )
+        PATTERN
+
+        # @!method delegators?(node)
+        def_node_matcher :delegators?, <<~PATTERN
+          (send nil? {:def_delegators :def_instance_delegators}
+            {sym str}
+            ({sym str} $_)+
+          )
         PATTERN
 
         # @!method sym_name(node)
         def_node_matcher :sym_name, '(sym $_name)'
-        def on_send(node)
-          if (name = alias_method?(node))
-            return if node.ancestors.any?(&:if_type?)
-            return if possible_dsl?(node)
+
+        def on_send(node) # rubocop:disable Metrics/AbcSize, Metrics/CyclomaticComplexity, Metrics/MethodLength, Metrics/PerceivedComplexity
+          name, original_name = alias_method?(node)
+
+          if name && original_name
+            return if name == original_name
+            return if inside_condition?(node)
 
             found_instance_method(node, name)
           elsif (attr = node.attribute_accessor?)
             on_attr(node, *attr)
+          elsif active_support_extensions_enabled? && (names = delegate_method?(node))
+            return if inside_condition?(node)
+
+            on_delegate(node, names)
+          elsif (name = delegator?(node))
+            return if inside_condition?(node)
+
+            found_instance_method(node, name)
+          elsif (names = delegators?(node))
+            return if inside_condition?(node)
+
+            names.each { |name| found_instance_method(node, name) }
           end
         end
 
@@ -127,11 +238,41 @@ module RuboCop
           found_method(node, "#{enclosing}.#{name}")
         end
 
+        def inside_condition?(node)
+          node.ancestors.any?(&:if_type?)
+        end
+
         def message_for_dup(node, method_name, key)
           format(MSG, method: method_name, defined: source_location(@definitions[key]),
                       current: source_location(node))
         end
 
+        def on_delegate(node, method_names)
+          name_prefix = delegate_prefix(node)
+
+          method_names.each do |name|
+            name = "#{name_prefix}_#{name}" if name_prefix
+
+            found_instance_method(node, name)
+          end
+        end
+
+        def delegate_prefix(node)
+          kwargs_node = node.last_argument
+
+          return unless (prefix = hash_value(kwargs_node, :prefix))
+
+          if prefix.true_type?
+            hash_value(kwargs_node, :to).value
+          elsif prefix.type?(:sym, :str)
+            prefix.value
+          end
+        end
+
+        def hash_value(node, key)
+          node.pairs.find { |pair| pair.key.value == key }&.value
+        end
+
         def found_instance_method(node, name)
           return found_sclass_method(node, name) unless (scope = node.parent_module_name)
 
@@ -157,29 +298,39 @@ module RuboCop
 
         def found_method(node, method_name)
           key = method_key(node, method_name)
+          scope = node.each_ancestor(:rescue, :ensure).first&.type
 
           if @definitions.key?(key)
-            loc = if DEF_TYPES.include?(node.type)
-                    node.loc.keyword.join(node.loc.name)
-                  else
-                    node.loc.expression
-                  end
+            if scope && !@scopes[scope].include?(key)
+              @definitions[key] = node
+              @scopes[scope] << key
+              return
+            end
+
             message = message_for_dup(node, method_name, key)
 
-            add_offense(loc, message: message)
+            add_offense(location(node), message: message)
           else
             @definitions[key] = node
           end
         end
 
         def method_key(node, method_name)
-          if (ancestor_def = node.each_ancestor(*DEF_TYPES).first)
+          if (ancestor_def = node.each_ancestor(:any_def).first)
             "#{ancestor_def.method_name}.#{method_name}"
           else
             method_name
           end
         end
 
+        def location(node)
+          if node.any_def_type?
+            node.loc.keyword.join(node.loc.name)
+          else
+            node.source_range
+          end
+        end
+
         def on_attr(node, attr_name, args)
           case attr_name
           when :attr
@@ -236,18 +387,8 @@ module RuboCop
           end
         end
 
-        def possible_dsl?(node)
-          # DSL methods may evaluate a block in the context of a newly created
-          # class or module
-          # Assume that if a method definition is inside any block call which
-          # we can't identify, it could be a DSL
-          node.each_ancestor(:block).any? do |ancestor|
-            ancestor.method_name != :class_eval && !ancestor.class_constructor?
-          end
-        end
-
         def source_location(node)
-          range = node.location.expression
+          range = node.source_range
           path = smart_path(range.source_buffer.name)
           "#{path}:#{range.line}"
         end
