@@ -3,25 +3,31 @@
 module RuboCop
   module Cop
     module Lint
-      # This cop checks to make sure `#to_json` includes an optional argument.
+      # Checks to make sure `#to_json` includes an optional argument.
       # When overriding `#to_json`, callers may invoke JSON
-      # generation via `JSON.generate(your_obj)`.  Since `JSON#generate` allows
+      # generation via `JSON.generate(your_obj)`. Since `JSON#generate` allows
       # for an optional argument, your method should too.
       #
       # @example
-      #   # bad
+      #   # bad - incorrect arity
       #   def to_json
+      #     JSON.generate([x, y])
       #   end
       #
-      #   # good
+      #   # good - preserving args
+      #   def to_json(*args)
+      #     JSON.generate([x, y], *args)
+      #   end
+      #
+      #   # good - discarding args
       #   def to_json(*_args)
+      #     JSON.generate([x, y])
       #   end
       #
       class ToJSON < Base
         extend AutoCorrector
 
-        MSG = ' `#to_json` requires an optional argument to be parsable ' \
-          'via JSON.generate(obj).'
+        MSG = '`#to_json` requires an optional argument to be parsable via JSON.generate(obj).'
 
         def on_def(node)
           return unless node.method?(:to_json) && node.arguments.empty?
