@@ -30,12 +30,13 @@ module RuboCop
       end
 
       alias on_numblock on_block
+      alias on_itblock on_block
 
       private
 
       # @!method define_method?(node)
       def_node_matcher :define_method?, <<~PATTERN
-        ({block numblock}
+        (any_block
          (send nil? :define_method ({sym str} $_)) _ _)
       PATTERN
 
@@ -49,22 +50,33 @@ module RuboCop
 
         return unless complexity > max
 
-        msg = format(self.class::MSG,
-                     method: method_name,
-                     complexity: complexity,
-                     abc_vector: abc_vector,
-                     max: max)
+        msg = format(
+          self.class::MSG,
+          method: method_name, complexity: complexity, abc_vector: abc_vector, max: max
+        )
+        location = location(node)
 
-        add_offense(node, message: msg) { self.max = complexity.ceil }
+        add_offense(location, message: msg) { self.max = complexity.ceil }
       end
 
       def complexity(body)
-        body.each_node(:lvasgn, *self.class::COUNTED_NODES).reduce(1) do |score, node|
+        score = 1
+        body.each_node(:lvasgn, *self.class::COUNTED_NODES) do |node|
           if node.lvasgn_type?
             reset_on_lvasgn(node)
-            next score
+          else
+            score += complexity_score_for(node)
           end
-          score + complexity_score_for(node)
+        end
+        score
+      end
+
+      def location(node)
+        if LSP.enabled?
+          end_range = node.loc?(:name) ? node.loc.name : node.loc.begin
+          node.source_range.begin.join(end_range)
+        else
+          node.source_range
         end
       end
     end
