@@ -21,22 +21,20 @@ module RuboCop
         include RangeHelp
         extend AutoCorrector
 
-        NON_MODIFIER_THEN = /then\s*(#.*)?$/.freeze
-
         MSG = 'Do not use `then` for multi-line `%<keyword>s`.'
 
         def on_normal_if_unless(node)
           return unless non_modifier_then?(node)
 
           add_offense(node.loc.begin, message: format(MSG, keyword: node.keyword)) do |corrector|
-            corrector.remove(range_with_surrounding_space(range: node.loc.begin, side: :left))
+            corrector.remove(range_with_surrounding_space(node.loc.begin, side: :left))
           end
         end
 
         private
 
         def non_modifier_then?(node)
-          NON_MODIFIER_THEN.match?(node.loc.begin&.source_line)
+          node.then? && node.loc.begin.line != node.if_branch&.loc&.line
         end
       end
     end
