@@ -1,7 +1,5 @@
 # frozen_string_literal: true
 
-require 'tsort'
-
 module RuboCop
   module Cop
     module Style
@@ -16,7 +14,7 @@ module RuboCop
       #
       #   # good
       #   one, two = *foo
-      #   a, b = foo()
+      #   a, b = foo
       #   a, b = b, a
       #
       #   a = 1
@@ -28,25 +26,29 @@ module RuboCop
 
         MSG = 'Do not use parallel assignment.'
 
-        def on_masgn(node)
-          lhs, rhs = *node
-          lhs_elements = *lhs
+        def on_masgn(node) # rubocop:disable Metrics/AbcSize
+          return if part_of_ignored_node?(node)
+
+          rhs = node.rhs
+          rhs = rhs.body if rhs.rescue_type?
           rhs_elements = Array(rhs).compact # edge case for one constant
 
-          return if allowed_lhs?(lhs) || allowed_rhs?(rhs) ||
-                    allowed_masign?(lhs_elements, rhs_elements)
+          return if allowed_lhs?(node.assignments) || allowed_rhs?(rhs) ||
+                    allowed_masign?(node.assignments, rhs_elements)
 
-          add_offense(node) { |corrector| autocorrect(corrector, node) }
+          range = node.source_range.begin.join(rhs.source_range.end)
+
+          add_offense(range) do |corrector|
+            autocorrect(corrector, node, rhs)
+          end
+          ignore_node(node)
         end
 
         private
 
-        def autocorrect(corrector, node)
-          left, right = *node
-          left_elements = *left
-          right_elements = Array(right).compact
-          order = find_valid_order(left_elements, right_elements)
-          correction = assignment_corrector(node, order)
+        def autocorrect(corrector, node, rhs)
+          order = find_valid_order(node.assignments, Array(rhs).compact)
+          correction = assignment_corrector(node, rhs, order)
 
           corrector.replace(correction.correction_range, correction.correction)
         end
@@ -57,9 +59,7 @@ module RuboCop
                               add_self_to_getters(rhs_elements))
         end
 
-        def allowed_lhs?(node)
-          elements = *node
-
+        def allowed_lhs?(elements)
           # Account for edge cases using one variable with a comma
           # E.g.: `foo, = *bar`
           elements.one? || elements.any?(&:splat_type?)
@@ -70,36 +70,31 @@ module RuboCop
           elements = Array(node).compact
 
           # Account for edge case of `Constant::CONSTANT`
-          !node.array_type? || return_of_method_call?(node) || elements.any?(&:splat_type?)
+          !node.array_type? || elements.any?(&:splat_type?)
         end
 
-        def return_of_method_call?(node)
-          node.block_type? || node.send_type?
-        end
-
-        def assignment_corrector(node, order)
-          _assignment, modifier = *node.parent
-          if modifier_statement?(node.parent)
-            ModifierCorrector.new(node, config, order)
-          elsif rescue_modifier?(modifier)
-            RescueCorrector.new(node, config, order)
+        def assignment_corrector(node, rhs, order)
+          if node.parent&.rescue_type?
+            _assignment, modifier = *node.parent
           else
-            GenericCorrector.new(node, config, order)
+            _assignment, modifier = *rhs.parent
+          end
+
+          if modifier_statement?(node.parent)
+            ModifierCorrector.new(node, rhs, modifier, config, order)
+          elsif rescue_modifier?(modifier)
+            RescueCorrector.new(node, rhs, modifier, config, order)
+          else
+            GenericCorrector.new(node, rhs, modifier, config, order)
           end
         end
 
         def find_valid_order(left_elements, right_elements)
           # arrange left_elements in an order such that no corresponding right
           # element refers to a left element earlier in the sequence
-          # this can be done using an algorithm called a "topological sort"
-          # fortunately for us, Ruby's stdlib contains an implementation
           assignments = left_elements.zip(right_elements)
 
-          begin
-            AssignmentSorter.new(assignments).tsort
-          rescue TSort::Cyclic
-            nil
-          end
+          AssignmentSorter.new(assignments).tsort
         end
 
         # Converts (send nil :something) nodes to (send (:self) :something).
@@ -114,10 +109,9 @@ module RuboCop
         # @!method implicit_self_getter?(node)
         def_node_matcher :implicit_self_getter?, '(send nil? $_)'
 
-        # Helper class necessitated by silly design of TSort prior to Ruby 2.1
-        # Newer versions have a better API, but that doesn't help us
+        # Topologically sorts the assignments with Kahn's algorithm.
+        # https://en.wikipedia.org/wiki/Topological_sorting#Kahn's_algorithm
         class AssignmentSorter
-          include TSort
           extend RuboCop::NodePattern::Macros
 
           # @!method var_name(node)
@@ -133,21 +127,39 @@ module RuboCop
             @assignments = assignments
           end
 
-          def tsort_each_node(&block)
-            @assignments.each(&block)
+          def tsort
+            dependencies = @assignments.to_h do |assignment|
+              [assignment, dependencies_for_assignment(assignment)]
+            end
+            result = []
+
+            while (matched_node, = dependencies.find { |_node, edges| edges.empty? })
+              dependencies.delete(matched_node)
+              result.push(matched_node)
+
+              dependencies.each do |node, edges|
+                dependencies[node].delete(matched_node) if edges.include?(matched_node)
+              end
+            end
+            # Cyclic dependency
+            return nil if dependencies.any?
+
+            result
           end
 
-          def tsort_each_child(assignment)
-            # yield all the assignments which must come after `assignment`
-            # (due to dependencies on the previous value of the assigned var)
+          # Returns all the assignments which must come after `assignment`
+          # (due to dependencies on the previous value of the assigned var)
+          def dependencies_for_assignment(assignment)
             my_lhs, _my_rhs = *assignment
 
-            @assignments.each do |other|
-              _other_lhs, other_rhs = *other
+            @assignments.filter_map do |other|
+              # Exclude self, there are no dependencies in cases such as `a, b = a, b`.
+              next if other == assignment
 
+              _other_lhs, other_rhs = *other
               next unless dependency?(my_lhs, other_rhs)
 
-              yield other
+              other
             end
           end
 
@@ -172,17 +184,21 @@ module RuboCop
         end
 
         def modifier_statement?(node)
-          node && %i[if while until].include?(node.type) && node.modifier_form?
+          return false unless node
+
+          node.basic_conditional? && node.modifier_form?
         end
 
         # An internal class for correcting parallel assignment
         class GenericCorrector
           include Alignment
 
-          attr_reader :config, :node
+          attr_reader :node, :rhs, :rescue_result, :config
 
-          def initialize(node, config, new_elements)
+          def initialize(node, rhs, modifier, config, new_elements)
             @node = node
+            @rhs = rhs
+            _, _, @rescue_result = *modifier
             @config = config
             @new_elements = new_elements
           end
@@ -198,15 +214,16 @@ module RuboCop
           protected
 
           def assignment
-            @new_elements.map { |lhs, rhs| "#{lhs.source} = #{source(rhs)}" }
+            @new_elements.map { |lhs, rhs| "#{lhs.source} = #{source(rhs, rhs.loc)}" }
           end
 
           private
 
-          def source(node)
-            if node.str_type? && node.loc.begin.nil?
+          def source(node, loc)
+            # __FILE__ is treated as a StrNode but has no begin
+            if node.str_type? && loc.respond_to?(:begin) && loc.begin.nil?
               "'#{node.source}'"
-            elsif node.sym_type? && node.loc.begin.nil?
+            elsif node.sym_type? && !node.loc?(:begin)
               ":#{node.source}"
             else
               node.source
@@ -226,13 +243,10 @@ module RuboCop
         # protected by rescue
         class RescueCorrector < GenericCorrector
           def correction
-            _node, rescue_clause = *node.parent
-            _, _, rescue_result = *rescue_clause
-
             # If the parallel assignment uses a rescue modifier and it is the
             # only contents of a method, then we want to make use of the
             # implicit begin
-            if node.parent.parent&.def_type?
+            if rhs.parent.parent.parent&.def_type?
               super + def_correction(rescue_result)
             else
               begin_correction(rescue_result)
@@ -240,7 +254,7 @@ module RuboCop
           end
 
           def correction_range
-            node.parent.source_range
+            rhs.parent.parent.source_range
           end
 
           private
@@ -279,9 +293,7 @@ module RuboCop
           private
 
           def modifier_range(node)
-            Parser::Source::Range.new(node.source_range.source_buffer,
-                                      node.loc.keyword.begin_pos,
-                                      node.source_range.end_pos)
+            node.loc.keyword.join(node.source_range.end)
           end
         end
       end
