@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Style
-      # This cop checks for `when;` uses in `case` expressions.
+      # Checks for `when;` uses in `case` expressions.
       #
       # @example
       #   # bad
@@ -17,17 +17,17 @@ module RuboCop
       #   when 1 then 'baz'
       #   when 2 then 'bar'
       #   end
-      class WhenThen < Cop
-        MSG = 'Do not use `when x;`. Use `when x then` instead.'
+      class WhenThen < Base
+        extend AutoCorrector
+
+        MSG = 'Do not use `when %<expression>s;`. Use `when %<expression>s then` instead.'
 
         def on_when(node)
           return if node.multiline? || node.then? || !node.body
 
-          add_offense(node, location: :begin)
-        end
+          message = format(MSG, expression: node.conditions.map(&:source).join(', '))
 
-        def autocorrect(node)
-          lambda do |corrector|
+          add_offense(node.loc.begin, message: message) do |corrector|
             corrector.replace(node.loc.begin, ' then')
           end
         end
