@@ -9,7 +9,10 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
 
   let(:rubocop) { "#{RuboCop::ConfigLoader::RUBOCOP_HOME}/exe/rubocop" }
 
-  before { RuboCop::ConfigLoader.default_configuration = nil }
+  before do
+    RuboCop::ConfigLoader.default_configuration = nil
+    RuboCop::ConfigLoader.clear_options
+  end
 
   describe '--parallel' do
     if RuboCop::Platform.windows?
@@ -31,9 +34,8 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
         it 'fails with an error message' do
           cli.run %w[-P]
           expect($stderr.string)
-            .to include('-P/--parallel uses caching to speed up execution, ' \
-                        'so combining with AllCops: UseCache: false is not ' \
-                        'allowed.')
+            .to include('-P/--parallel uses caching to speed up execution, so ' \
+                        'combining with AllCops: UseCache: false is not allowed.')
         end
       end
 
@@ -173,14 +175,14 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       end
 
       describe '--server-status' do
-        context 'when server is not runnning' do
+        context 'when server is not running' do
           it 'displays server status' do
             output = `ruby -I . "#{rubocop}" --server-status`
             expect(output).to match(/RuboCop server is not running./)
           end
         end
 
-        context 'when server is runnning' do
+        context 'when server is running' do
           before do
             `ruby -I . "#{rubocop}" --start-server`
           end
@@ -199,7 +201,7 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
   else
     context 'when not supporting server' do
       describe 'no server options' do
-        it 'displays an warning message' do
+        it 'displays a warning message' do
           stdout, stderr, status = Open3.capture3("ruby -I . \"#{rubocop}\"")
           expect(stdout).to eq(<<~RESULT)
             Inspecting 0 files
@@ -213,7 +215,7 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       end
 
       describe '--start-server' do
-        it 'displays an warning message' do
+        it 'displays a warning message' do
           stdout, stderr, status = Open3.capture3("ruby -I . \"#{rubocop}\" --start-server")
           expect(stdout).to eq ''
           expect(stderr).to include("RuboCop server is not supported by this Ruby.\n")
@@ -227,12 +229,12 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
     context 'when there are no files' do
       it 'prints nothing with -L' do
         cli.run ['-L']
-        expect($stdout.string.empty?).to be(true)
+        expect($stdout.string).to be_empty
       end
 
       it 'prints nothing with --list-target-files' do
         cli.run ['--list-target-files']
-        expect($stdout.string.empty?).to be(true)
+        expect($stdout.string).to be_empty
       end
     end
 
@@ -294,12 +296,13 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       expect($stdout.string).to include(RuboCop::Version::STRING)
       expect($stdout.string).to match(/Parser \d+\.\d+\.\d+/)
       expect($stdout.string).to match(/rubocop-ast \d+\.\d+\.\d+/)
+      expect($stdout.string).to match(/analyzing as Ruby #{RuboCop::TargetRuby::DEFAULT_VERSION}/o)
     end
 
     context 'when requiring extension cops' do
       before do
         create_file('.rubocop.yml', <<~YAML)
-          require:
+          plugins:
             - rubocop-performance
             - rubocop-rspec
         YAML
@@ -320,13 +323,13 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
     context 'when requiring extension cops in multiple layers' do
       before do
         create_file('.rubocop-parent.yml', <<~YAML)
-          require:
+          plugins:
             - rubocop-performance
         YAML
 
         create_file('.rubocop.yml', <<~YAML)
           inherit_from: ./.rubocop-parent.yml
-          require:
+          plugins:
             - rubocop-rspec
         YAML
       end
@@ -346,12 +349,12 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
     context 'when requiring redundant extension cop' do
       before do
         create_file('ext.yml', <<~YAML)
-          require:
+          plugins:
             - rubocop-rspec
         YAML
         create_file('.rubocop.yml', <<~YAML)
           inherit_from: ext.yml
-          require:
+          plugins:
             - rubocop-performance
             - rubocop-rspec
         YAML
@@ -408,6 +411,34 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
         expect(output).not_to include(pending_cop_warning)
       end
     end
+
+    context 'when the config contains erb' do
+      before do
+        create_file('.rubocop.yml', <<~YAML)
+          <% if true %>
+          <% end %>
+        YAML
+      end
+
+      it 'exits cleanly' do
+        expect(cli.run(['-V'])).to eq(0)
+        expect($stdout.string).to include(RuboCop::Version::STRING)
+      end
+    end
+
+    context 'when run in a subfolder with `.rubocop.yml` specifying `TargetRubyVersion`' do
+      before do
+        create_file('subdir/.rubocop.yml', <<~YAML)
+          AllCops:
+            TargetRubyVersion: 3.0
+        YAML
+      end
+
+      it 'shows that Ruby version in the output' do
+        Dir.chdir('subdir') { cli.run ['-V'] }
+        expect($stdout.string).to match(/analyzing as Ruby 3\.0/)
+      end
+    end
   end
 
   describe '--only' do
@@ -450,6 +481,14 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
         expect($stderr.string).to include('Unrecognized cop or department: .')
       end
 
+      it '`Lint/Syntax` must be enabled even if `--only` is given `Style/StringLiterals` only' do
+        create_file('example.rb', '1 /// 2')
+        expect(cli.run(['--only', 'Style/StringLiterals', 'example.rb'])).to eq(1)
+        expect(
+          $stdout.string
+        ).to include('example.rb:1:7: F: Lint/Syntax: unexpected token tINTEGER')
+      end
+
       %w[Syntax Lint/Syntax].each do |name|
         it "only checks syntax if #{name} is given" do
           create_file('example.rb', 'x ')
@@ -567,7 +606,8 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
               remaining_range = pending_cop_warning.length..-(inspected_output.length + 1)
               pending_cops = output[remaining_range]
 
-              expect(pending_cops).to include("Style/SomeCop: # new in 0.80\n  Enabled: true")
+              expect(pending_cops)
+                .to include("Style/SomeCop: # new in 0.80\n  Enabled: true")
 
               manual_url = output[remaining_range].split("\n").last
 
@@ -585,7 +625,8 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
               remaining_range = pending_cop_warning.length..-(inspected_output.length + 1)
               pending_cops = output[remaining_range]
 
-              expect(pending_cops).to include("Style/SomeCop: # new in N/A\n  Enabled: true")
+              expect(pending_cops)
+                .to include("Style/SomeCop: # new in N/A\n  Enabled: true")
 
               manual_url = output[remaining_range].split("\n").last
 
@@ -661,6 +702,8 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
                 Enabled: false
               Security:
                 Enabled: false
+              Metrics:
+                Enabled: false
 
               Style/SomeCop:
                 Description: Something
@@ -674,6 +717,30 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
         end
       end
 
+      context 'when specifying disabled `Layout/LineLength` cop' do
+        let(:line) { "Object::#{'A' * 100}".inspect }
+
+        it 'enables the given cop' do
+          create_file('example.rb', [line])
+
+          create_file('.rubocop.yml', <<~YAML)
+            Layout/LineLength:
+              Enabled: false
+              Max: 80
+          YAML
+
+          expect(cli.run(['--format', 'simple',
+                          '--only', 'Layout/LineLength',
+                          'example.rb'])).to be_zero
+          expect($stderr.string).to eq('')
+          expect($stdout.string)
+            .to eq(<<~RESULT)
+
+              1 file inspected, no offenses detected
+            RESULT
+        end
+      end
+
       context 'without using namespace' do
         it 'runs just one cop' do
           create_file('example.rb', ['if x== 0 ', "\ty", 'end'])
@@ -753,9 +820,9 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
               == example.rb ==
               C:  1:  5: [Correctable] Layout/SpaceAroundOperators: Surrounding space missing for operator ==.
               C:  2:  1: [Correctable] Layout/IndentationStyle: Tab detected in indentation.
-              W:  2:  2: Lint/UselessAssignment: Useless assignment to variable - y.
+              W:  2:  2: [Correctable] Lint/UselessAssignment: Useless assignment to variable - y.
 
-              1 file inspected, 3 offenses detected, 2 offenses autocorrectable
+              1 file inspected, 3 offenses detected, 3 offenses autocorrectable
             RESULT
         end
       end
@@ -767,12 +834,12 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
         expect(cli.run(%w[-f offenses --only Layout example.rb])).to eq(1)
         expect($stdout.string).to eq(<<~RESULT)
 
-          1  Layout/CommentIndentation
-          1  Layout/IndentationStyle
-          1  Layout/IndentationWidth
-          1  Layout/LineLength
-          1  Layout/SpaceAroundOperators
-          1  Layout/TrailingWhitespace
+          1  Layout/CommentIndentation [Safe Correctable]
+          1  Layout/IndentationStyle [Safe Correctable]
+          1  Layout/IndentationWidth [Safe Correctable]
+          1  Layout/LineLength [Safe Correctable]
+          1  Layout/SpaceAroundOperators [Safe Correctable]
+          1  Layout/TrailingWhitespace [Safe Correctable]
           --
           6  Total in 1 files
 
@@ -791,13 +858,13 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
         expect($stdout.string)
           .to eq(<<~RESULT)
 
-            1  Layout/CommentIndentation
-            1  Layout/IndentationStyle
-            1  Layout/IndentationWidth
-            1  Layout/LineLength
-            1  Layout/TrailingWhitespace
-            1  Style/FrozenStringLiteralComment
-            1  Style/NumericLiterals
+            1  Layout/CommentIndentation [Safe Correctable]
+            1  Layout/IndentationStyle [Safe Correctable]
+            1  Layout/IndentationWidth [Safe Correctable]
+            1  Layout/LineLength [Safe Correctable]
+            1  Layout/TrailingWhitespace [Safe Correctable]
+            1  Style/FrozenStringLiteralComment [Unsafe Correctable]
+            1  Style/NumericLiterals [Safe Correctable]
             --
             7  Total in 1 files
 
@@ -807,7 +874,7 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
 
     context 'when a cop name is not specified' do
       it 'displays how to use `--only` option' do
-        expect(cli.run(%w[--except -a Lint/NumberConverion])).to eq(2)
+        expect(cli.run(%w[--except -a Lint/NumberConversion])).to eq(2)
         expect($stderr.string).to eq(<<~MESSAGE)
           --except argument should be [COP1,COP2,...].
         MESSAGE
@@ -916,27 +983,50 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       end
     end
 
-    context 'when one cop plus one namespace are given' do
+    context 'when two cop plus one namespace are given' do
       it 'runs all cops except the given' do
         # The disable comment should not be reported as unnecessary (even if
         # it is) since --except overrides configuration.
         create_file('example.rb', ['# rubocop:disable LineLength', 'if x== 0 ', "\ty = 3", 'end'])
         expect(cli.run(['--format', 'offenses',
-                        '--except', 'Style/IfUnlessModifier,Lint',
+                        '--except', 'Style/IfUnlessModifier,Lint/UselessAssignment,Layout',
                         'example.rb'])).to eq(1)
         # NOTE: No Lint/UselessAssignment offense.
         expect($stdout.string)
           .to eq(<<~RESULT)
 
-            1  Layout/IndentationStyle
-            1  Layout/IndentationWidth
-            1  Layout/SpaceAroundOperators
-            1  Layout/TrailingWhitespace
-            1  Migration/DepartmentName
-            1  Style/FrozenStringLiteralComment
-            1  Style/NumericPredicate
+            1  Lint/MissingCopEnableDirective
+            1  Lint/RedundantCopDisableDirective [Safe Correctable]
+            1  Migration/DepartmentName [Safe Correctable]
+            1  Style/FrozenStringLiteralComment [Unsafe Correctable]
+            1  Style/NumericPredicate [Unsafe Correctable]
             --
-            7  Total in 1 files
+            5  Total in 1 files
+
+          RESULT
+      end
+    end
+
+    context 'when one cop plus `Lint/RedundantCopDisableDirective` are given' do
+      it 'runs all cops except the given' do
+        create_file('example.rb', ['# rubocop:disable LineLength', 'if x== 0 ', "\ty = 3", 'end'])
+        expect(cli.run(['--format', 'offenses',
+                        '--except', 'Style/IfUnlessModifier,Lint/RedundantCopDisableDirective',
+                        'example.rb'])).to eq(1)
+        expect($stdout.string)
+          .to eq(<<~RESULT)
+
+            1  Layout/IndentationStyle [Safe Correctable]
+            1  Layout/IndentationWidth [Safe Correctable]
+            1  Layout/SpaceAroundOperators [Safe Correctable]
+            1  Layout/TrailingWhitespace [Safe Correctable]
+            1  Lint/MissingCopEnableDirective
+            1  Lint/UselessAssignment [Safe Correctable]
+            1  Migration/DepartmentName [Safe Correctable]
+            1  Style/FrozenStringLiteralComment [Unsafe Correctable]
+            1  Style/NumericPredicate [Unsafe Correctable]
+            --
+            9  Total in 1 files
 
           RESULT
       end
@@ -954,7 +1044,7 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
 
         expect($stderr.string).to eq('')
         expect(without_option.split($RS) - with_option.split($RS))
-          .to eq(['1  Style/IfUnlessModifier', '7  Total in 1 files'])
+          .to eq(['1  Style/IfUnlessModifier [Safe Correctable]', '7  Total in 1 files'])
       end
     end
 
@@ -976,10 +1066,10 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
           expect($stdout.string)
             .to eq(<<~RESULT)
 
-              1  Layout/IndentationWidth
-              1  Layout/TrailingWhitespace
-              1  Style/FrozenStringLiteralComment
-              1  Style/NumericLiterals
+              1  Layout/IndentationWidth [Safe Correctable]
+              1  Layout/TrailingWhitespace [Safe Correctable]
+              1  Style/FrozenStringLiteralComment [Unsafe Correctable]
+              1  Style/NumericLiterals [Safe Correctable]
               --
               4  Total in 1 files
 
@@ -1011,9 +1101,9 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       expect($stdout.string)
         .to eq(<<~RESULT)
           == example.rb ==
-          W:  1:  4: Lint/LiteralAsCondition: Literal 0 appeared as a condition.
+          W:  1:  4: [Correctable] Lint/LiteralAsCondition: Literal 0 appeared as a condition.
 
-          1 file inspected, 1 offense detected
+          1 file inspected, 1 offense detected, 1 offense autocorrectable
         RESULT
     end
   end
@@ -1025,9 +1115,9 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       create_file('example1.rb', "\tputs 0")
       expect(cli.run(['--debug', 'example1.rb'])).to eq(1)
       home = File.dirname(File.dirname(File.dirname(File.dirname(__FILE__))))
-      expect($stdout.string.lines.grep(/configuration/).map(&:chomp))
-        .to eq(["For #{abs('')}: " \
-                "Default configuration from #{home}/config/default.yml"])
+      expect($stdout.string)
+        .to include("For #{abs('')}: " \
+                    "Default configuration from #{home}/config/default.yml")
     end
 
     it 'shows cop names' do
@@ -1035,9 +1125,9 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       file = abs('example1.rb')
 
       expect(cli.run(['--format', 'emacs', '--debug', 'example1.rb'])).to eq(1)
-      expect($stdout.string.lines.to_a[-1])
-        .to eq("#{file}:1:7: C: [Correctable] Layout/TrailingWhitespace: Trailing " \
-               "whitespace detected.\n")
+      expect($stdout.string)
+        .to include("#{file}:1:7: C: [Correctable] Layout/TrailingWhitespace: Trailing " \
+                    "whitespace detected.\n")
     end
   end
 
@@ -1048,13 +1138,15 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
 
     context 'without --display-time' do
       it 'does not display elapsed time in seconds' do
-        expect(`rubocop example1.rb`).not_to match(regex)
+        expect(cli.run(['example1.rb'])).to eq(0)
+        expect($stdout.string).not_to match(regex)
       end
     end
 
     context 'with --display-time' do
       it 'displays elapsed time in seconds' do
-        expect(`rubocop --display-time example1.rb`).to match(regex)
+        expect(cli.run(['--display-time', 'example1.rb'])).to eq(0)
+        expect($stdout.string).to match(regex)
       end
     end
   end
@@ -1153,12 +1245,13 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
     it 'shows reference entry' do
       create_file('example1.rb', "JSON.load('{}')")
       file = abs('example1.rb')
-      url = 'https://ruby-doc.org/stdlib-2.7.0/libdoc/json/rdoc/JSON.html#method-i-load'
+      urls = 'https://ruby-doc.org/stdlib-2.7.0/libdoc/json/rdoc/JSON.html#method-i-load, ' \
+             'https://bugs.ruby-lang.org/issues/19528'
 
       expect(cli.run(['--format', 'emacs', '--display-style-guide', 'example1.rb'])).to eq(1)
 
       output = "#{file}:1:6: C: [Correctable] Security/JSONLoad: " \
-               "Prefer `JSON.parse` over `JSON.load`. (#{url})"
+               "Prefer `JSON.parse` over `JSON.load`. (#{urls})"
       expect($stdout.string.lines.to_a[-1]).to eq([output, ''].join("\n"))
     end
 
@@ -1186,8 +1279,8 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
                          else
                            YAML.load(out.join) # rubocop:disable Security/YAMLLoad
                          end
-        cop_names = (arguments[0] || '').split(',')
-        cop_names.each do |cop_name|
+
+        expected_cop_names.each do |cop_name|
           global_conf[cop_name].each do |key, value|
             printed_value = printed_config[cop_name][key]
             expect(printed_value).to eq(value)
@@ -1196,6 +1289,8 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       end
     end
 
+    let(:expected_cop_names) { (arguments[0] || '').split(',') }
+
     let(:cops) { RuboCop::Cop::Registry.all }
     let(:registry) { RuboCop::Cop::Registry.global }
 
@@ -1240,14 +1335,16 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
 
       it 'prints all available cops and their description' do
         cops.each do |cop|
-          expect(stdout).to include cop.cop_name
+          expect(stdout).to include(cop.cop_name)
           # Because of line breaks, we will only find the beginning.
-          expect(stdout).to include short_description_of_cop(cop)[0..60]
+          expect(stdout).to include(short_description_of_cop(cop)[0..60])
         end
       end
 
       it 'prints all departments' do
-        registry.departments.each { |department| expect(stdout).to include(department.to_s) }
+        registry.departments.each do |department|
+          expect(stdout).to include(department.to_s)
+        end
       end
 
       it 'prints all cops in their right department listing' do
@@ -1258,19 +1355,19 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
 
           # all cops in their department listing
           registry.with_department(current).each do |cop|
-            expect(slice.any? { |l| l.include? cop.cop_name }).to be_truthy
+            expect(slice).to be_any { |l| l.include? cop.cop_name }
           end
 
           # no cop in wrong department listing
           departments.each do |department|
             registry.with_department(department).each do |cop|
-              expect(slice.any? { |l| l.include? cop.cop_name }).to be_falsey
+              expect(slice).not_to be_any { |l| l.include? cop.cop_name }
             end
           end
         end
       end
 
-      include_examples 'prints config'
+      it_behaves_like 'prints config'
     end
 
     context 'with one cop given' do
@@ -1289,7 +1386,7 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
         )
       end
 
-      include_examples 'prints config'
+      it_behaves_like 'prints config'
     end
 
     context 'with one cop given and inherit_mode set in its local configuration' do
@@ -1302,7 +1399,7 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
            '  Description: Checks for deprecated constants.',
            '  Enabled: pending',
            /^  VersionAdded: '[0-9.]+'$/,
-           /^  VersionChanged: '[0-9.]+'$/,
+           /^  VersionChanged: ('[0-9.]+'|"<<next>>")$/,
            '  DeprecatedConstants:',
            '    NIL:',
            '      Alternative: nil',
@@ -1319,6 +1416,12 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
            '    Random::DEFAULT:',
            '      Alternative: Random.new',
            "      DeprecatedVersion: '3.0'",
+           '    Struct::Group:',
+           '      Alternative: Etc::Group',
+           "      DeprecatedVersion: '3.0'",
+           '    Struct::Passwd:',
+           '      Alternative: Etc::Passwd',
+           "      DeprecatedVersion: '3.0'",
            '    MY_CONST:',
            '      Alternative: MyConst',
            "      DeprecatedVersion: '2.7'",
@@ -1329,10 +1432,19 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       end
     end
 
+    context 'with a cop containing a wildcard' do
+      let(:arguments) { ['Layout/Indentation*'] }
+      let(:expected_cop_names) do
+        ['Layout/IndentationConsistency', 'Layout/IndentationStyle', 'Layout/IndentationWidth']
+      end
+
+      it_behaves_like 'prints config'
+    end
+
     context 'with two cops given' do
       let(:arguments) { ['Layout/IndentationStyle,Layout/LineLength'] }
 
-      include_examples 'prints config'
+      it_behaves_like 'prints config'
     end
 
     context 'with one of the cops misspelled' do
@@ -1429,6 +1541,38 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
           RESULT
         end
       end
+
+      context 'with a custom cop without DocumentationBaseURL specified' do
+        let(:arguments) { ['Layout/IndentationStyle,Test/AlignmentDirective'] }
+
+        it 'skips the cop without documentation url' do
+          cmd
+          expect(stdout).to eq(<<~RESULT)
+            https://docs.rubocop.org/rubocop/cops_layout.html#layoutindentationstyle
+
+          RESULT
+        end
+      end
+
+      context 'with a custom cop with DocumentationBaseURL specified' do
+        let(:arguments) { ['Layout/IndentationStyle,Test/AlignmentDirective'] }
+
+        before do
+          create_file('.rubocop.yml', <<~YAML)
+            Test:
+              DocumentationBaseURL: https://example.com
+          YAML
+        end
+
+        it 'builds the doc urls' do
+          cmd
+          expect(stdout).to eq(<<~RESULT)
+            https://docs.rubocop.org/rubocop/cops_layout.html#layoutindentationstyle
+            https://example.com/cops_test.html#testalignmentdirective
+
+          RESULT
+        end
+      end
     end
   end
 
@@ -1441,14 +1585,13 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       context 'when simple format is specified' do
         it 'outputs with simple format' do
           cli.run(['--format', 'simple', 'example.rb'])
-          expect($stdout.string)
-            .to include(<<~RESULT)
-              == #{target_file} ==
-              C:  1:  1: [Correctable] Style/FrozenStringLiteralComment: Missing frozen string literal comment.
-              C:  1:121: Layout/LineLength: Line is too long. [130/120]
+          expect($stdout.string).to include(<<~RESULT)
+            == #{target_file} ==
+            C:  1:  1: [Correctable] Style/FrozenStringLiteralComment: Missing frozen string literal comment.
+            C:  1:121: Layout/LineLength: Line is too long. [130/120]
 
-              1 file inspected, 2 offenses detected, 1 offense autocorrectable
-            RESULT
+            1 file inspected, 2 offenses detected, 1 offense autocorrectable
+          RESULT
         end
       end
 
@@ -1560,7 +1703,7 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
             'example2.rb:3:2: C: [Correctable] Layout/InitialIndentation: ' \
             'Indentation of first line in file detected.',
             "\tx",
-            ' ^',
+            "\t^",
             'example2.rb:4:1: C: [Correctable] Layout/IndentationConsistency: ' \
             'Inconsistent indentation detected.',
             'def a ...',
@@ -1625,7 +1768,14 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       context 'when unknown format name is specified' do
         it 'aborts with error message' do
           expect(cli.run(['--format', 'unknown', 'example.rb'])).to eq(2)
-          expect($stderr.string).to include('No formatter for "unknown"')
+          expect($stderr.string).to include('Formatter "unknown" not found')
+        end
+      end
+
+      context 'when wrong similar format name is specified' do
+        it 'aborts with error message' do
+          expect(cli.run(['--format', 'quite', 'example.rb'])).to eq(2)
+          expect($stderr.string).to include('Formatter "quite" not found. Did you mean? "quiet"')
         end
       end
     end
@@ -1633,27 +1783,29 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
     describe 'custom formatter' do
       let(:target_file) { abs('example.rb') }
 
+      before do
+        stub_const('MyTool::RuboCopFormatter',
+                   Class.new(RuboCop::Formatter::BaseFormatter) do
+                     def started(all_files)
+                       output.puts "started: #{all_files.join(',')}"
+                     end
+
+                     def file_started(file, _options)
+                       output.puts "file_started: #{file}"
+                     end
+
+                     def file_finished(file, _offenses)
+                       output.puts "file_finished: #{file}"
+                     end
+
+                     def finished(processed_files)
+                       output.puts "finished: #{processed_files.join(',')}"
+                     end
+                   end)
+      end
+
       context 'when a class name is specified' do
         it 'uses the class as a formatter' do
-          stub_const('MyTool::RuboCopFormatter',
-                     Class.new(RuboCop::Formatter::BaseFormatter) do
-                       def started(all_files)
-                         output.puts "started: #{all_files.join(',')}"
-                       end
-
-                       def file_started(file, _options)
-                         output.puts "file_started: #{file}"
-                       end
-
-                       def file_finished(file, _offenses)
-                         output.puts "file_finished: #{file}"
-                       end
-
-                       def finished(processed_files)
-                         output.puts "finished: #{processed_files.join(',')}"
-                       end
-                     end)
-
           cli.run(['--format', 'MyTool::RuboCopFormatter', 'example.rb'])
           expect($stdout.string).to eq(<<~RESULT)
             started: #{target_file}
@@ -1662,6 +1814,16 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
             finished: #{target_file}
           RESULT
         end
+
+        it 'accepts fully qualified class name' do
+          cli.run(['--format', '::MyTool::RuboCopFormatter', 'example.rb'])
+          expect($stdout.string).to eq(<<~RESULT)
+            started: #{target_file}
+            file_started: #{target_file}
+            file_finished: #{target_file}
+            finished: #{target_file}
+          RESULT
+        end
       end
 
       context 'when unknown class name is specified' do
@@ -1728,7 +1890,7 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
     def expect_offense_detected
       expect($stderr.string).to eq('')
       expect($stdout.string).to include('1 file inspected, 1 offense detected')
-      expect($stdout.string).to include 'Layout/IndentationWidth'
+      expect($stdout.string).to include('Layout/IndentationWidth')
     end
 
     it 'fails when option is less than the severity level' do
@@ -1753,6 +1915,29 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       expect_offense_detected
     end
 
+    context 'when the cop has the "info" severity' do
+      before do
+        create_file(target_file, <<~RUBY)
+          some_object.some_method.another_method.yet_another_method
+        RUBY
+
+        create_file('.rubocop.yml', <<~YAML)
+          Layout/LineLength:
+            Max: 10
+            Severity: info
+        YAML
+      end
+
+      it 'succeeds when option is autocorrect and the offense is not autocorrectable' do
+        expect(cli.run(['--fail-level', 'autocorrect',
+                        '--only', 'Layout/LineLength',
+                        target_file])).to eq(0)
+        expect($stderr.string).to eq('')
+        expect($stdout.string).to include('1 file inspected, 1 offense detected')
+        expect($stdout.string).to include('Layout/LineLength')
+      end
+    end
+
     context 'with --display-only-fail-level-offenses' do
       it 'outputs offense message when fail-level is less than the severity' do
         expect(cli.run(['--fail-level', 'refactor',
@@ -1780,7 +1965,7 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
                         target_file])).to eq 0
         expect($stderr.string).to eq('')
         expect($stdout.string).to include('1 file inspected, no offenses detected')
-        expect($stdout.string).not_to include 'Layout/IndentationWidth'
+        expect($stdout.string).not_to include('Layout/IndentationWidth')
       end
 
       context 'with disabled line' do
@@ -1796,8 +1981,8 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
                           target_file])).to eq 0
           expect($stderr.string).to eq('')
           expect($stdout.string).to include('1 file inspected, no offenses detected')
-          expect($stdout.string).not_to include 'Layout/IndentationWidth'
-          expect($stdout.string).not_to include 'Lint/RedundantCopDisableDirective'
+          expect($stdout.string).not_to include('Layout/IndentationWidth')
+          expect($stdout.string).not_to include('Lint/RedundantCopDisableDirective')
         end
 
         it "still checks unprinted offense if they're a redundant disable" do
@@ -1812,7 +1997,7 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
                           target_file])).to eq 1
           expect($stderr.string).to eq('')
           expect($stdout.string).to include('1 file inspected, 1 offense detected')
-          expect($stdout.string).to include 'RedundantCopDisableDirective'
+          expect($stdout.string).to include('RedundantCopDisableDirective')
         end
       end
     end
@@ -1899,11 +2084,10 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
           a = "Hello"
         RUBY
 
-        expect(cli.run(['--autocorrect', '--format', 'simple', target_file])).to eq(1)
+        expect(cli.run(['--autocorrect', '--format', 'simple', target_file])).to eq(0)
 
         expect($stdout.string.lines.to_a.last)
-          .to eq('1 file inspected, 2 offenses detected, 1 offense corrected' \
-                 "\n")
+          .to eq("1 file inspected, 3 offenses detected, 3 offenses corrected\n")
       end
     end
 
@@ -1939,11 +2123,11 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       end
     end
 
-    context 'when setting `AutoCorrect: false` for `Style/StringLiterals`' do
+    context 'when setting `AutoCorrect: disabled` for `Style/StringLiterals`' do
       before do
         create_file('.rubocop.yml', <<~YAML)
           Style/StringLiterals:
-            AutoCorrect: false
+            AutoCorrect: disabled
         YAML
       end
 
@@ -1955,7 +2139,9 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
         RUBY
 
         expect(cli.run(['--autocorrect', '--format', 'simple', target_file])).to eq(1)
-        expect($stdout.string.lines.to_a.last).to eq("1 file inspected, 2 offenses detected\n")
+        expect($stdout.string.lines.to_a.last).to eq(
+          "1 file inspected, 2 offenses detected, 1 offense corrected\n"
+        )
       end
     end
   end
@@ -2160,6 +2346,76 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
     end
   end
 
+  describe '--editor-mode' do
+    let(:target_file) { 'example.rb' }
+
+    before do
+      create_file(target_file, <<~RUBY)
+        def empty_method
+        end
+      RUBY
+
+      create_file('.rubocop.yml', <<~YAML)
+        AllCops:
+          SuggestExtensions: false
+
+        Layout/EmptyLineAfterMagicComment:
+          AutoCorrect: contextual
+      YAML
+    end
+
+    after { RuboCop::LSP.disable }
+
+    context 'when using `--editor-mode`' do
+      it 'registers an offense, but does not correct for `Layout/EmptyLineAfterMagicComment` with `AutoCorrect: contextual`' do
+        status_code = cli.run(['--editor-mode', '-a', '--only', 'Style/EmptyMethod', target_file])
+
+        expect(status_code).to eq(1)
+        expect($stderr.string).to eq('')
+        expect(File.read('example.rb')).to eq(<<~RUBY)
+          def empty_method
+          end
+        RUBY
+        expect($stdout.string).to eq(<<~RESULT)
+          Inspecting 1 file
+          C
+
+          Offenses:
+
+          example.rb:1:1: C: Style/EmptyMethod: Put empty method definitions on a single line.
+          def empty_method ...
+          ^^^^^^^^^^^^^^^^
+
+          1 file inspected, 1 offense detected
+        RESULT
+      end
+    end
+
+    context 'when not using `--editor-mode`' do
+      it 'registers an offense and corrects for `Layout/EmptyLineAfterMagicComment` with `AutoCorrect: contextual`' do
+        status_code = cli.run(['-a', '--only', 'Style/EmptyMethod', target_file])
+
+        expect(status_code).to eq(0)
+        expect($stderr.string).to eq('')
+        expect(File.read('example.rb')).to eq(<<~RUBY)
+          def empty_method; end
+        RUBY
+        expect($stdout.string).to eq(<<~RESULT)
+          Inspecting 1 file
+          C
+
+          Offenses:
+
+          example.rb:1:1: C: [Corrected] Style/EmptyMethod: Put empty method definitions on a single line.
+          def empty_method ...
+          ^^^^^^^^^^^^^^^^
+
+          1 file inspected, 1 offense detected, 1 offense corrected
+        RESULT
+      end
+    end
+  end
+
   describe '--require', :restore_registry do
     context 'when adding an extension' do
       before do
@@ -2208,4 +2464,52 @@ RSpec.describe 'RuboCop::CLI options', :isolated_environment do # rubocop:disabl
       RESULT
     end
   end
+
+  describe 'option is ambiguous' do
+    it 'suggests to use the --help flag' do
+      ambiguous_option = '--no'
+
+      expect(cli.run([ambiguous_option])).to eq(2)
+      expect($stderr.string).to eq(<<~RESULT)
+        ambiguous option: #{ambiguous_option}
+        For usage information, use --help
+      RESULT
+    end
+  end
+
+  describe 'argument is needless' do
+    it 'suggests to use the --help flag' do
+      option = '--help=yes'
+
+      expect(cli.run([option])).to eq(2)
+      expect($stderr.string).to eq(<<~RESULT)
+        needless argument: #{option}
+        For usage information, use --help
+      RESULT
+    end
+  end
+
+  describe 'argument is missing' do
+    it 'suggests to use the --help flag' do
+      option = '--exclude-limit'
+
+      expect(cli.run([option])).to eq(2)
+      expect($stderr.string).to eq(<<~RESULT)
+        missing argument: #{option}
+        For usage information, use --help
+      RESULT
+    end
+  end
+
+  describe 'argument is invalid' do
+    it 'suggests to use the --help flag' do
+      option = '--fail-level=Z'
+
+      expect(cli.run([option])).to eq(2)
+      expect($stderr.string).to eq(<<~RESULT)
+        invalid argument: #{option}
+        For usage information, use --help
+      RESULT
+    end
+  end
 end
