@@ -27,9 +27,9 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
         Dir.chdir('other') { expect(cli.run(['--format', 'simple', checked_path])).to eq(1) }
         expect($stdout.string).to eq(<<~RESULT)
           == #{abs('Rakefile')} ==
-          W:  3:  1: Lint/UselessAssignment: Useless assignment to variable - x.
+          W:  3:  1: [Correctable] Lint/UselessAssignment: Useless assignment to variable - x.
 
-          1 file inspected, 1 offense detected
+          1 file inspected, 1 offense detected, 1 offense autocorrectable
         RESULT
       end
     end
@@ -37,25 +37,25 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
     context 'and the directory is absolute' do
       let(:checked_path) { abs('..') }
 
-      include_examples 'checks Rakefile'
+      it_behaves_like 'checks Rakefile'
     end
 
     context 'and the directory is relative' do
       let(:checked_path) { '..' }
 
-      include_examples 'checks Rakefile'
+      it_behaves_like 'checks Rakefile'
     end
 
     context 'and the Rakefile path is absolute' do
       let(:checked_path) { abs('../Rakefile') }
 
-      include_examples 'checks Rakefile'
+      it_behaves_like 'checks Rakefile'
     end
 
     context 'and the Rakefile path is relative' do
       let(:checked_path) { '../Rakefile' }
 
-      include_examples 'checks Rakefile'
+      it_behaves_like 'checks Rakefile'
     end
   end
 
@@ -86,6 +86,24 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
     end
   end
 
+  context 'when using an invalid encoding string' do
+    it 'does not crash and reports an offense' do
+      create_file('example.rb', <<~'RUBY')
+        "\xE3\xD3\x8B\xE3\x83\xBC\x83\xE3\x83\xE3\x82\xB3\xA3\x82\x99"
+      RUBY
+      result = cli.run(['--format', 'simple', 'example.rb'])
+      expect(result).to eq(1)
+      expect($stdout.string)
+        .to eq(<<~RESULT)
+          == example.rb ==
+          C:  1:  1: [Correctable] Style/FrozenStringLiteralComment: Missing frozen string literal comment.
+
+          1 file inspected, 1 offense detected, 1 offense autocorrectable
+      RESULT
+      expect($stderr.string).to eq ''
+    end
+  end
+
   context 'when checking a correct file' do
     it 'returns 0' do
       create_file('example.rb', <<~RUBY)
@@ -149,8 +167,8 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
     expect(cli.run(['--format', 'emacs', 'example.rb'])).to eq(1)
     expect($stderr.string).to eq ''
     expect($stdout.string)
-      .to eq(["#{abs('example.rb')}:3:1: E: Lint/Syntax: unexpected " \
-              'token $end (Using Ruby 2.6 parser; configure using ' \
+      .to eq(["#{abs('example.rb')}:3:1: F: Lint/Syntax: unexpected " \
+              'token $end (Using Ruby 2.7 parser; configure using ' \
               '`TargetRubyVersion` parameter, under `AllCops`)',
               ''].join("\n"))
   end
@@ -170,8 +188,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
                 "if it's surely a splat operator, or add a whitespace to the " \
                 'right of the `*` if it should be a multiplication.',
                 "#{abs('example.rb')}:4:1: C: [Correctable] Style/OneLineConditional: " \
-                'Favor the ternary operator (`?:`) or multi-line constructs over ' \
-                'single-line `if/then/else/end` constructs.',
+                'Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.',
                 ''].join("\n"))
     end
   end
@@ -202,7 +219,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
     #       In other words, even if no option is specified, it will be parallelized by default.
     describe 'when parallel static by default' do
       context 'when specifying `--debug` option only`' do
-        it 'fails with an error message' do
+        it 'uses parallel inspection' do
           create_file('example1.rb', <<~RUBY)
             # frozen_string_literal: true
 
@@ -213,6 +230,19 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
         end
       end
 
+      context 'when specifying configuration file' do
+        it 'uses parallel inspection' do
+          create_file('example1.rb', <<~RUBY)
+            # frozen_string_literal: true
+
+            puts 'hello'
+          RUBY
+          create_empty_file('.rubocop.yml')
+          expect(cli.run(['--debug', '--config', '.rubocop.yml'])).to eq(0)
+          expect($stdout.string).to include('Use parallel by default.')
+        end
+      end
+
       context 'when specifying `--debug` and `-a` options`' do
         it 'uses parallel inspection when correcting the file' do
           create_file('example1.rb', <<~RUBY)
@@ -231,7 +261,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       end
 
       context 'when setting `UseCache: true`' do
-        it 'fails with an error message' do
+        it 'uses parallel inspection' do
           create_file('example.rb', <<~RUBY)
             # frozen_string_literal: true
 
@@ -247,7 +277,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       end
 
       context 'when setting `UseCache: false`' do
-        it 'fails with an error message' do
+        it 'does not use parallel inspection' do
           create_file('example.rb', <<~RUBY)
             # frozen_string_literal: true
 
@@ -279,7 +309,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
   end
 
   describe 'for a disabled cop' do
-    it 'reports no offense when enabled on part of a file' do
+    it 'reports an offense when explicitly enabled on part of a file' do
       create_file('.rubocop.yml', <<~YAML)
         AllCops:
           SuggestExtensions: false
@@ -292,18 +322,129 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
 
         a = 1
         # rubocop:enable Lint/UselessAssignment
-        b = a
-        b += 1
+        b = 2
         # rubocop:disable Lint/UselessAssignment
-        c = 2
+        c = 3
       RUBY
 
-      expect(cli.run(['--format', 'offenses', 'example.rb'])).to eq(0)
+      expect(cli.run(['--format', 'simple', 'example.rb'])).to eq(1)
       expect($stdout.string).to eq(<<~RESULT)
+        == example.rb ==
+        W:  5:  1: [Correctable] Lint/UselessAssignment: Useless assignment to variable - b.
 
-        --
-        0  Total in 0 files
+        1 file inspected, 1 offense detected, 1 offense autocorrectable
+      RESULT
+    end
 
+    it '`Lint/Syntax` must be enabled when `Lint` is given `Enabled: false`' do
+      create_file('.rubocop.yml', <<~YAML)
+        Lint:
+          Enabled: false
+      YAML
+
+      create_file('example.rb', <<~RUBY)
+        1 /// 2
+      RUBY
+
+      expect(cli.run(['--format', 'simple', 'example.rb'])).to eq(1)
+      expect($stdout.string).to include('F:  1:  7: Lint/Syntax: unexpected token tINTEGER')
+    end
+
+    it '`Lint/Syntax` must be enabled when `DisabledByDefault: true`' do
+      create_file('.rubocop.yml', <<~YAML)
+        AllCops:
+          DisabledByDefault: true
+      YAML
+
+      create_file('example.rb', <<~RUBY)
+        1 /// 2
+      RUBY
+
+      expect(cli.run(['--format', 'simple', 'example.rb'])).to eq(1)
+      expect($stdout.string).to include('F:  1:  7: Lint/Syntax: unexpected token tINTEGER')
+    end
+
+    it '`Lint/Syntax` must be enabled when disabled by directive comment' do
+      create_file('example.rb', <<~RUBY)
+        # rubocop:disable Lint/Syntax
+        1 /// 2
+      RUBY
+
+      expect(cli.run(['--format', 'simple', 'example.rb'])).to eq(1)
+      expect($stdout.string).to include('F:  2:  7: Lint/Syntax: unexpected token tINTEGER')
+    end
+
+    it '`Lint/Syntax` must be enabled when disabled by directive department comment' do
+      create_file('example.rb', <<~RUBY)
+        # rubocop:disable Lint
+        1 /// 2
+      RUBY
+
+      expect(cli.run(['--format', 'simple', 'example.rb'])).to eq(1)
+      expect($stdout.string).to include('F:  2:  7: Lint/Syntax: unexpected token tINTEGER')
+    end
+
+    it '`Lint/Syntax` must be enabled when disabled by directive all comment' do
+      create_file('example.rb', <<~RUBY)
+        # rubocop:disable all
+        1 /// 2
+      RUBY
+
+      expect(cli.run(['--format', 'simple', 'example.rb'])).to eq(1)
+      expect($stdout.string).to include('F:  2:  7: Lint/Syntax: unexpected token tINTEGER')
+    end
+
+    it '`Naming/FileName` must be disabled for global offenses' do
+      create_file('Example.rb', <<~RUBY)
+        # rubocop:disable Naming/FileName
+      RUBY
+
+      expect(cli.run(['--format', 'simple', 'Example.rb'])).to eq(1)
+      expect($stdout.string).not_to include('Naming/FileName:')
+    end
+
+    it '`Naming/FileName` must be enabled if directive comment is on unrelated line' do
+      create_file('Example.rb', <<~RUBY)
+        # Prelude
+        # rubocop:disable Naming/FileName
+      RUBY
+
+      expect(cli.run(['--format', 'simple', 'Example.rb'])).to eq(1)
+      expect($stdout.string).to include('C:  1:  1: Naming/FileName:')
+    end
+  end
+
+  describe 'for a cop enabled only for a subset of files' do
+    it "doesn't enable the cop for all files when department disables are present" do
+      create_file('.rubocop.yml', <<~YAML)
+        AllCops:
+          DisabledByDefault: true
+
+        Style/HashSyntax:
+          Enabled: true
+          Exclude:
+            - example1.rb
+      YAML
+
+      source = <<~RUBY
+        { :a => :b }
+        # rubocop:disable Style
+        { :a => :b }
+        # rubocop:enable Style
+        # rubocop:disable all
+        { :a => :b }
+        # rubocop:enable all
+      RUBY
+
+      create_file('example1.rb', source)
+      create_file('example2.rb', source)
+
+      expect(cli.run(['--format', 'simple', 'example1.rb', 'example2.rb'])).to eq(1)
+      expect($stdout.string).to eq(<<~RESULT)
+        == example2.rb ==
+        C:  1:  3: [Correctable] Style/HashSyntax: Use the new Ruby 1.9 hash syntax.
+
+        2 files inspected, 1 offense detected, 1 offense autocorrectable
       RESULT
     end
   end
@@ -374,7 +515,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
         expect(cli.run(['--format', 'offenses', '-A', 'example.rb'])).to eq(0)
         expect($stdout.string).to eq(<<~RESULT)
 
-          1  Style/FrozenStringLiteralComment
+          1  Style/FrozenStringLiteralComment [Unsafe Correctable]
           --
           1  Total in 1 files
 
@@ -407,7 +548,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       expect(cli.run(['--format', 'emacs', 'example.rb'])).to eq(1)
       expect($stderr.string)
         .to eq(['example.rb: Style/LineLength has the wrong ' \
-                'namespace - should be Layout',
+                'namespace - replace it with Layout/LineLength',
                 ''].join("\n"))
       # 2 real cops were disabled, and 1 that was incorrect
       # 2 real cops was enabled, but only 1 had been disabled correctly
@@ -421,7 +562,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
     it 'can disable all cops on a single line' do
       create_file('example.rb', 'y("123", 123456) # rubocop:disable all')
       expect(cli.run(['--format', 'emacs', 'example.rb'])).to eq(0)
-      expect($stdout.string.empty?).to be(true)
+      expect($stdout.string).to be_empty
     end
 
     it 'can disable selected cops on a single line' do
@@ -550,22 +691,22 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
         end
       end
 
-      include_examples 'RedundantCopDisableDirective not run',
-                       'individually disabled', <<~YAML
-                         Lint/RedundantCopDisableDirective:
-                           Enabled: false
-                       YAML
-      include_examples 'RedundantCopDisableDirective not run',
-                       'individually excluded', <<~YAML
-                         Lint/RedundantCopDisableDirective:
-                           Exclude:
-                             - example.rb
-                       YAML
-      include_examples 'RedundantCopDisableDirective not run',
-                       'disabled through department', <<~YAML
-                         Lint:
-                           Enabled: false
-                       YAML
+      it_behaves_like 'RedundantCopDisableDirective not run',
+                      'individually disabled', <<~YAML
+                        Lint/RedundantCopDisableDirective:
+                          Enabled: false
+                      YAML
+      it_behaves_like 'RedundantCopDisableDirective not run',
+                      'individually excluded', <<~YAML
+                        Lint/RedundantCopDisableDirective:
+                          Exclude:
+                            - example.rb
+                      YAML
+      it_behaves_like 'RedundantCopDisableDirective not run',
+                      'disabled through department', <<~YAML
+                        Lint:
+                          Enabled: false
+                      YAML
     end
   end
 
@@ -668,7 +809,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
 
             expect($stdout.string).to eq(<<~RESULT)
 
-              1  Style/AndOr
+              1  Style/AndOr [Unsafe Correctable]
               --
               1  Total in 1 files
 
@@ -684,8 +825,8 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
 
             expect($stdout.string).to eq(<<~RESULT)
 
-              3  Layout/LineLength
-              1  Style/AndOr
+              3  Layout/LineLength [Safe Correctable]
+              1  Style/AndOr [Unsafe Correctable]
               --
               4  Total in 1 files
 
@@ -705,7 +846,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
 
             expect($stdout.string).to eq(<<~RESULT)
 
-              3  Layout/LineLength
+              3  Layout/LineLength [Safe Correctable]
               --
               3  Total in 1 files
 
@@ -721,8 +862,8 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
 
             expect($stdout.string).to eq(<<~RESULT)
 
-              3  Layout/LineLength
-              1  Style/AndOr
+              3  Layout/LineLength [Safe Correctable]
+              1  Style/AndOr [Unsafe Correctable]
               --
               4  Total in 1 files
 
@@ -811,7 +952,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       end
 
       %w[class module].each do |parent|
-        it "registers offense for normal indentation in #{parent}" do
+        it "registers an offense for normal indentation in #{parent}" do
           create_file('.rubocop.yml', <<~YAML)
             Layout/IndentationConsistency:
               EnforcedStyle: indented_internal_methods
@@ -865,10 +1006,8 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
               - "="
         YAML
         expect(cli.run([])).to eq(2)
-        expect($stderr.string).to include('obsolete parameter ' \
-                                          '`MultiSpaceAllowedForOperators` ' \
-                                          '(for `Layout/SpaceAroundOperators`) ' \
-                                          'found')
+        expect($stderr.string).to include('obsolete parameter `MultiSpaceAllowedForOperators` ' \
+                                          '(for `Layout/SpaceAroundOperators`) found')
       end
     end
 
@@ -908,6 +1047,27 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       end
     end
 
+    context 'when Naming/PredicatePrefix has predicate prefix forbidden which is not listed in NamePrefix' do
+      it 'fails with an error message' do
+        create_file('example.rb', 'puts 1')
+        create_file('.rubocop.yml', <<~YAML)
+          Naming/PredicatePrefix:
+            NamePrefix:
+              - is_
+              - has_
+            ForbiddenPrefixes:
+              - is_
+              - has_
+              - seems_to_be_
+        YAML
+        expect(cli.run(['example.rb'])).to eq(2)
+        expect($stderr.string.strip).to eq(
+          'Error: The `Naming/PredicatePrefix` cop is misconfigured. Prefix seems_to_be_ must be ' \
+          'included in NamePrefix because it is included in ForbiddenPrefixes.'
+        )
+      end
+    end
+
     it 'allows the default configuration file as the -c argument' do
       create_file('example.rb', <<~RUBY)
         # frozen_string_literal: true
@@ -944,13 +1104,25 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       context 'when no config file specified' do
         let(:args) { %w[--format simple --force-default-config] }
 
-        include_examples 'ignores config file'
+        it_behaves_like 'ignores config file'
       end
 
       context 'when config file specified with -c' do
         let(:args) { %w[--format simple --force-default-config -c .rubocop.yml] }
 
-        include_examples 'ignores config file'
+        it_behaves_like 'ignores config file'
+      end
+
+      context 'when config file has invalid inherit_from' do
+        it 'ignores config file with invalid inherit_from' do
+          create_file('example.rb', ['# frozen_string_literal: true', '', 'x = 0', 'puts x'])
+          create_file('.rubocop.yml', <<~YAML)
+            inherit_from: config/nonexistent.yml
+          YAML
+
+          expect(cli.run(%w[--format simple --force-default-config])).to eq(0)
+          expect($stdout.string).to include('1 file inspected, no offenses detected')
+        end
       end
     end
 
@@ -1016,7 +1188,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       expect($stdout.string)
         .to eq(<<~RESULT)
 
-          1  Layout/TrailingWhitespace
+          1  Layout/TrailingWhitespace [Safe Correctable]
           --
           1  Total in 1 files
 
@@ -1027,7 +1199,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       create_file('file.rb', 'x=0') # Included by default
       create_file('example', 'x=0')
       create_file('regexp', 'x=0')
-      create_file('vendor/bundle/ruby/2.6.0/gems/backports-3.6.8/.irbrc', 'x=0')
+      create_file('vendor/bundle/ruby/2.7.0/gems/backports-3.6.8/.irbrc', 'x=0')
       create_file('.dot1/file.rb', 'x=0') # Hidden but explicitly included
       create_file('.dot2/file.rb', 'x=0') # Hidden, excluded by default
       create_file('.dot3/file.rake', 'x=0') # Hidden, not included by wildcard
@@ -1051,6 +1223,31 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
                                                     abs('regexp')])
     end
 
+    context 'when a .rubocop.yml is included from an ancestor directory' do
+      before do
+        create_file('child/grandkid/.rubocop.yml', <<~YAML)
+          inherit_from:
+            - ../../.rubocop.yml
+        YAML
+      end
+
+      context 'and it specifies an Include pattern' do
+        before do
+          create_file('.rubocop.yml', <<~YAML)
+            AllCops:
+              Include:
+                - "**/*.rbi"
+          YAML
+        end
+
+        it 'finds files included through inheritance' do
+          create_file('child/grandkid/file.rbi', 'x=0')
+          Dir.chdir('child/grandkid') { expect(cli.run(['-L'])).to eq(0) }
+          expect($stdout.string).to eq("file.rbi\n")
+        end
+      end
+    end
+
     it 'ignores excluded files' do
       create_file('example.rb', ['x = 0', 'puts x'])
       create_file('regexp.rb', ['x = 0', 'puts x'])
@@ -1066,6 +1263,23 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       expect($stdout.string).to eq(['', '0 files inspected, no offenses detected', ''].join("\n"))
     end
 
+    it 'works when `AllCops:Exclude` is empty' do
+      create_file('example.rb', ['x = 0', 'puts x'])
+      create_file('.rubocop.yml', <<~YAML)
+        AllCops:
+          Exclude:
+      YAML
+
+      expect(cli.run(%w[--format simple])).to eq(1)
+      expect($stdout.string).to eq(<<~STDOUT)
+        == example.rb ==
+        C:  1:  1: [Correctable] Style/FrozenStringLiteralComment: Missing frozen string literal comment.
+
+        1 file inspected, 1 offense detected, 1 offense autocorrectable
+      STDOUT
+      expect($stderr.string).to eq ''
+    end
+
     it 'only reads configuration in explicitly included hidden directories' do
       create_file('.hidden/example.rb', 'x=0')
       # This file contains configuration for an unknown cop. This would cause a
@@ -1097,9 +1311,9 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       expect($stdout.string)
         .to eq(<<~RESULT)
           == .other/example.rb ==
-          W:  3:  1: Lint/UselessAssignment: Useless assignment to variable - x.
+          W:  3:  1: [Correctable] Lint/UselessAssignment: Useless assignment to variable - x.
 
-          1 file inspected, 1 offense detected
+          1 file inspected, 1 offense detected, 1 offense autocorrectable
         RESULT
     end
 
@@ -1160,7 +1374,6 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
           Exclude:
             - ignored/**
       YAML
-      expect(File).not_to receive(:open).with(%r{/ignored/})
       expect(cli.run(%w[--format simple example])).to eq(0)
       expect($stdout.string).to eq(<<~OUTPUT)
 
@@ -1231,7 +1444,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
           Enabled: false
       YAML
       expect(cli.run(['--format', 'emacs', 'example.rb'])).to eq(2)
-      expect($stderr.string).to include('Error: configuration for Syntax cop found')
+      expect($stderr.string).to include('Error: configuration for Lint/Syntax cop found')
       expect($stderr.string).to include('It\'s not possible to disable this cop.')
     end
 
@@ -1457,7 +1670,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
 
     # Being immune to bad configuration files in excluded directories has
     # become important due to a bug in rubygems
-    # (https://github.com/rubygems/rubygems/issues/680) that makes
+    # (https://github.com/ruby/rubygems/issues/680) that makes
     # installations of, for example, RuboCop lack their .rubocop.yml in the
     # root directory.
     it 'can exclude a vendor directory with an erroneous config file' do
@@ -1563,30 +1776,60 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
         OUTPUT
     end
 
-    it 'prints a warning for an unrecognized configuration parameter' do
+    it 'prints a warning for an unrecognized configuration parameter, ignoring permitted ones' do
       create_file('example/example1.rb', '#' * 90)
 
       create_file('example/.rubocop.yml', <<~YAML)
+        # Default config includes none of Min, References, or StyleGuide
+        Layout/AssignmentIndentation:
+          Enabled: true
+          Min: 10
+          StyleGuide: '#assignment-indentation'
+
+        # Default config includes StyleGuide, but neither Min nor Reference nor References
         Layout/LineLength:
           Enabled: true
           Min: 10
+          Reference:
+            - 'https://example.com#layout-line-length-decision-log'
+          References:
+            - 'https://example.com#layout-line-length-decision-log'
+
+        # Default config includes References and StyleGuide, but not Min
+        Style/GlobalVars:
+          Enabled: true
+          Min: 10
       YAML
 
       expect(cli.run(%w[--format simple example])).to eq(1)
 
-      expect($stderr.string).to eq(<<-RESULT.strip_margin('|'))
-        |Warning: Layout/LineLength does not support Min parameter.
-        |
-        |Supported parameters are:
-        |
-        |  - Enabled
-        |  - Max
-        |  - AllowHeredoc
-        |  - AllowURI
-        |  - URISchemes
-        |  - IgnoreCopDirectives
-        |  - AllowedPatterns
-        |  - IgnoredPatterns
+      expect($stderr.string).to eq(<<~RESULT)
+        Warning: Layout/AssignmentIndentation does not support Min parameter.
+
+        Supported parameters are:
+
+          - Enabled
+          - IndentationWidth
+        Warning: Layout/LineLength does not support Min parameter.
+
+        Supported parameters are:
+
+          - Enabled
+          - Max
+          - AllowHeredoc
+          - AllowURI
+          - AllowQualifiedName
+          - URISchemes
+          - AllowRBSInlineAnnotation
+          - AllowCopDirectives
+          - AllowedPatterns
+          - SplitStrings
+        Warning: Style/GlobalVars does not support Min parameter.
+
+        Supported parameters are:
+
+          - Enabled
+          - AllowedVariables
       RESULT
     end
 
@@ -1662,8 +1905,8 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       end
     end
 
-    include_examples 'specified Severity', 'Layout/LineLength'
-    include_examples 'specified Severity', 'Layout'
+    it_behaves_like 'specified Severity', 'Layout/LineLength'
+    it_behaves_like 'specified Severity', 'Layout'
 
     it 'fails when a configuration file specifies an invalid Severity' do
       create_file('example/example1.rb', '#' * 130)
@@ -1681,9 +1924,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
                 ''].join("\n"))
     end
 
-    # FIXME: Remove `broken_on: jruby`, which works around a JRuby 9.2.13.0 regression:
-    # https://github.com/jruby/jruby/issues/6365
-    it 'fails when a configuration file has invalid YAML syntax', broken_on: :jruby do
+    it 'fails when a configuration file has invalid YAML syntax' do
       create_file('example/.rubocop.yml', <<~YAML)
         AllCops:
           Exclude:
@@ -1694,7 +1935,7 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       # MRI and JRuby return slightly different error messages.
       expect($stderr.string)
         .to match(%r{^\(\S+example/\.rubocop\.yml\):\ (did\ not\ find\ )?
-                  expected\ alphabetic\ or \ numeric\ character}x)
+                  (expected\ alphabetic\ or \ numeric\ character|unexpected\ character)}x)
     end
 
     context 'when a file inherits from a higher level' do
@@ -1745,6 +1986,29 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
   end
 
   describe 'configuration of `AutoCorrect`' do
+    context 'when setting `AutoCorrect: disabled` for `Style/StringLiterals`' do
+      before do
+        create_file('.rubocop.yml', <<~YAML)
+          Style/StringLiterals:
+            AutoCorrect: disabled
+        YAML
+      end
+
+      it 'does not suggest `1 offense autocorrectable` for `Style/StringLiterals`' do
+        create_file('example.rb', <<~RUBY)
+          # frozen_string_literal: true
+
+          a = "Hello"
+        RUBY
+
+        expect(cli.run(['--format', 'simple', 'example.rb'])).to eq(1)
+        expect($stdout.string.lines.to_a.last).to eq(
+          "1 file inspected, 2 offenses detected, 1 offense autocorrectable\n"
+        )
+      end
+    end
+
+    # For backward compatibility, `false` is treated the same as `'disabled'`.
     context 'when setting `AutoCorrect: false` for `Style/StringLiterals`' do
       before do
         create_file('.rubocop.yml', <<~YAML)
@@ -1761,7 +2025,9 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
         RUBY
 
         expect(cli.run(['--format', 'simple', 'example.rb'])).to eq(1)
-        expect($stdout.string.lines.to_a.last).to eq("1 file inspected, 2 offenses detected\n")
+        expect($stdout.string.lines.to_a.last).to eq(
+          "1 file inspected, 2 offenses detected, 1 offense autocorrectable\n"
+        )
       end
     end
   end
@@ -1771,14 +2037,19 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
       it 'fails with an error message' do
         create_file('.rubocop.yml', <<~YAML)
           AllCops:
-            TargetRubyVersion: 4.0
+            TargetRubyVersion: 5.0
         YAML
         expect(cli.run([])).to eq(2)
         expect($stderr.string.strip).to start_with(
-          'Error: RuboCop found unknown Ruby version 4.0 in `TargetRubyVersion`'
+          'Error: RuboCop found unknown Ruby version 5.0 in `TargetRubyVersion`'
         )
         expect($stderr.string.strip).to match(
-          /Supported versions: 2.0, 2.1, 2.2, 2.3, 2.4, 2.5, 2.6, 2.7, 3.0, 3.1, 3.2/
+          Regexp.new(<<~MESSAGE.chomp.tr("\n", ' '))
+            Supported versions:
+            2.0, 2.1, 2.2, 2.3, 2.4, 2.5, 2.6, 2.7,
+            3.0, 3.1, 3.2, 3.3, 3.4,
+            4.0, 4.1
+          MESSAGE
         )
       end
     end
@@ -1812,14 +2083,34 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
           require: unknownlibrary
         YAML
 
-        regexp =
-          if RUBY_ENGINE == 'jruby'
-            /no such file to load -- unknownlibrary/
-          else
-            /cannot load such file -- unknownlibrary/
-          end
         expect(cli.run([])).to eq(2)
-        expect($stderr.string).to match(regexp)
+        expect($stderr.string).to match(/cannot load such file -- unknownlibrary/)
+      end
+    end
+
+    context 'when using `plugins` to enable a plugin' do
+      it 'exits with 0 without warning' do
+        create_file('.rubocop.yml', <<~YAML)
+          plugins:
+            - rubocop-internal_affairs
+        YAML
+
+        expect(cli.run([])).to eq(0)
+        expect($stderr.string).to be_blank
+      end
+    end
+
+    context 'when using `require` to enable a plugin' do
+      it 'exits with 0 with warning' do
+        create_file('.rubocop.yml', <<~YAML)
+          require:
+            - rubocop/cop/internal_affairs
+        YAML
+
+        expect(cli.run([])).to eq(0)
+        expect($stderr.string).to start_with(
+          'rubocop/cop/internal_affairs extension supports plugin'
+        )
       end
     end
   end
@@ -1950,8 +2241,179 @@ RSpec.describe RuboCop::CLI, :isolated_environment do
 
       it 'is an invalid configuration' do
         expect(cli.run(['--format', 'simple', 'test.rb'])).to eq(2)
-        expect($stderr.string)
-          .to include('Error: configuration for Syntax cop found in .rubocop.yml')
+        expect(
+          $stderr.string
+        ).to include('Error: configuration for Lint/Syntax cop found in .rubocop.yml')
+      end
+    end
+
+    context 'when `Lint` is given `Severity: info`' do
+      let(:code) do
+        <<~RUBY
+          1 /// 2
+        RUBY
+      end
+
+      before do
+        create_file('.rubocop.yml', <<~YAML)
+          Lint:
+            Severity: info
+        YAML
+      end
+
+      it '`Lint/Syntax` severity `fatal` cannot be changed by configuration' do
+        expect(cli.run(['--format', 'simple', 'test.rb'])).to eq(1)
+        expect($stdout.string).to include('F:  1:  7: Lint/Syntax: unexpected token tINTEGER')
+      end
+    end
+  end
+
+  describe '--display-only-correctable' do
+    it 'returns 0 if there are no offenses shown' do
+      create_file('.rubocop.yml', <<~YAML)
+        AllCops:
+          SuggestExtensions: false
+      YAML
+      create_file('example.rb', <<~RUBY)
+        # frozen_string_literal: true
+
+        @@var = 0
+      RUBY
+      expect(cli.run(['--display-only-correctable', 'example.rb'])).to eq(0)
+      expect($stderr.string).to eq('')
+      expect($stdout.string).to eq(<<~RESULT)
+        Inspecting 1 file
+        .
+
+        1 file inspected, no offenses detected
+      RESULT
+    end
+  end
+
+  describe '--display-only-safe-correctable' do
+    it 'returns 0 if there are no offenses shown' do
+      create_file('.rubocop.yml', <<~YAML)
+        AllCops:
+          SuggestExtensions: false
+      YAML
+      create_file('example.rb', <<~RUBY)
+        # frozen_string_literal: true
+
+        a.foo..b.bar # Lint/AmbiguousRange offense is not safe correctable
+      RUBY
+      expect(cli.run(['--display-only-safe-correctable', 'example.rb'])).to eq(0)
+      expect($stderr.string).to eq('')
+      expect($stdout.string).to eq(<<~RESULT)
+        Inspecting 1 file
+        .
+
+        1 file inspected, no offenses detected
+      RESULT
+    end
+  end
+
+  if RUBY_ENGINE == 'ruby' && !RuboCop::Platform.windows?
+    describe 'profiling' do
+      let(:cpu_profile) { File.join('tmp', 'rubocop-stackprof.dump') }
+      let(:memory_profile) { File.join('tmp', 'rubocop-memory_profiler.txt') }
+
+      before do
+        # Force reload of project root
+        RuboCop::ConfigFinder.project_root = nil
+
+        FileUtils.rm_f(cpu_profile)
+        FileUtils.rm_f(memory_profile)
+
+        create_file('example1.rb', <<~RUBY)
+          # frozen_string_literal: true
+
+          'string'
+        RUBY
+        create_empty_file('Gemfile')
+      end
+
+      after do
+        # Don't leak project root change
+        RuboCop::ConfigFinder.project_root = nil
+      end
+
+      it 'does not create profile files by default' do
+        expect(cli.run(['example1.rb'])).to eq(0)
+        expect($stdout.string).not_to include('Profile report generated')
+        expect(File).not_to exist(cpu_profile)
+      end
+
+      it 'creates cpu profile file' do
+        expect(cli.run(['--profile', 'example1.rb'])).to eq(0)
+        expect($stdout.string).to include('Profile report generated')
+        expect(File).to exist(cpu_profile)
+      end
+
+      it 'creates memory profile file' do
+        expect(cli.run(['--profile', '--memory', 'example1.rb'])).to eq(0)
+        expect($stdout.string).to include('Building memory report...')
+        expect(File).to exist(memory_profile)
+      end
+    end
+  end
+
+  describe 'cache root warning' do
+    let(:warning) { 'Warning: Remote configuration cache files were stored' }
+
+    before do
+      create_file('example.rb', ['# frozen_string_literal: true', '', 'puts 1'])
+    end
+
+    context 'when cache roots match' do
+      it 'does not print a warning when using default cache root without overrides' do
+        create_file('.rubocop.yml', <<~YAML)
+          AllCops:
+            DisabledByDefault: true
+        YAML
+
+        expect(cli.run(['example.rb'])).to eq(0)
+        expect($stderr.string).not_to include(warning)
+      end
+
+      context 'when --cache-root is given' do
+        it 'does not print a warning with no CacheRootDirectory in the configuration file' do
+          create_file('.rubocop.yml', <<~YAML)
+            AllCops:
+              DisabledByDefault: true
+          YAML
+
+          expect(cli.run(['--cache-root', '/tmp/.rubocop_cache', 'example.rb'])).to eq(0)
+          expect($stderr.string).not_to include(warning)
+        end
+
+        it 'does not print a warning with different CacheRootDirectory as --cache-root overrides it' do
+          create_file('.rubocop.yml', <<~YAML)
+            AllCops:
+              DisabledByDefault: true
+              CacheRootDirectory: /tmp/some-other-cache
+          YAML
+
+          expect(cli.run(['--cache-root', '/tmp/.rubocop_cache', 'example.rb'])).to eq(0)
+          expect($stderr.string).not_to include(warning)
+        end
+      end
+    end
+
+    context 'when cache roots differ' do
+      it 'prints a warning when non-default CacheRootDirectory is set in a inherited file' do
+        create_file('.rubocop.yml', <<~YAML)
+          inherit_from: inherited.yml
+          AllCops:
+            DisabledByDefault: true
+        YAML
+
+        create_file('inherited.yml', <<~YAML)
+          AllCops:
+            CacheRootDirectory: /tmp/inherited-cache
+        YAML
+
+        expect(cli.run(['example.rb'])).to eq(0)
+        expect($stderr.string).to include(warning)
       end
     end
   end
