@@ -9,12 +9,14 @@ RSpec.describe RuboCop::ConfigLoader do
     described_class.debug = true
     # Force reload of default configuration
     described_class.default_configuration = nil
+    RuboCop::ConfigFinder.project_root = nil
   end
 
   after do
     described_class.debug = false
     # Remove custom configuration
     described_class.default_configuration = nil
+    RuboCop::ConfigFinder.project_root = nil
   end
 
   let(:default_config) { described_class.default_configuration }
@@ -27,6 +29,64 @@ RSpec.describe RuboCop::ConfigLoader do
 
       before { create_empty_file('dir/example.rb') }
 
+      context 'but a config file exists in .config/.rubocop.yml of the project root' do
+        before do
+          create_empty_file('Gemfile')
+          create_empty_file('.config/.rubocop.yml')
+        end
+
+        it 'returns the path to the file in .config directory' do
+          expect(configuration_file_for).to end_with('.config/.rubocop.yml')
+        end
+      end
+
+      context 'but a config file exists in both .config/.rubocop.yml of the project root and home directory' do
+        before do
+          create_empty_file('Gemfile')
+          create_empty_file('.config/.rubocop.yml')
+          create_empty_file('~/.rubocop.yml')
+        end
+
+        it 'returns the path to the file in .config directory' do
+          expect(configuration_file_for).to end_with('.config/.rubocop.yml')
+        end
+      end
+
+      context 'but a config file exists in .config/rubocop/config.yml of the project root' do
+        before do
+          create_empty_file('Gemfile')
+          create_empty_file('.config/rubocop/config.yml')
+        end
+
+        it 'returns the path to the file in .config/rubocop directory' do
+          expect(configuration_file_for).to end_with('.config/rubocop/config.yml')
+        end
+      end
+
+      context 'but a config file exists in both .config/.rubocop.yml and .config/rubocop/config.yml of the project root' do
+        before do
+          create_empty_file('Gemfile')
+          create_empty_file('.config/.rubocop.yml')
+          create_empty_file('.config/rubocop/config.yml')
+        end
+
+        it 'returns the path to the file in .config directory' do
+          expect(configuration_file_for).to end_with('.config/.rubocop.yml')
+        end
+      end
+
+      context 'but a config file exists in both .config//rubocop/config.yml of the project root and home directory' do
+        before do
+          create_empty_file('Gemfile')
+          create_empty_file('.config/rubocop/config.yml')
+          create_empty_file('~/.rubocop.yml')
+        end
+
+        it 'returns the path to the file in .config/rubocop directory' do
+          expect(configuration_file_for).to end_with('.config/rubocop/config.yml')
+        end
+      end
+
       context 'but a config file exists in home directory' do
         before { create_empty_file('~/.rubocop.yml') }
 
@@ -384,6 +444,122 @@ RSpec.describe RuboCop::ConfigLoader do
       end
     end
 
+    context 'when ParserEngine is in base config and gemspec needs to be parsed' do
+      let(:file_path) { '.rubocop.yml' }
+
+      before do
+        # This reproduces the issue from https://github.com/rubocop/rubocop/issues/14541
+        # ParserEngine is in base file but no TargetRubyVersion is set anywhere
+        create_file('.rubocop_base.yml', <<~YAML)
+          AllCops:
+            ParserEngine: parser_prism
+        YAML
+
+        create_file('.rubocop.yml', <<~YAML)
+          inherit_from: .rubocop_base.yml
+        YAML
+
+        # The gemspec will be parsed to detect Ruby version since TargetRubyVersion is not set
+        create_file('test.gemspec', <<~RUBY)
+          Gem::Specification.new do |s|
+            s.name = 'test'
+            s.required_ruby_version = '>= 2.7.0'
+          end
+        RUBY
+      end
+
+      it 'can parse gemspec without error even when parser_prism is configured' do
+        # Without the fix, this would raise:
+        # ArgumentError: RuboCop supports target Ruby versions 3.3 and above with Prism.
+        # Specified target Ruby version: 2.7
+        expect { configuration_from_file }.not_to raise_error
+        config = configuration_from_file
+        expect(config.for_all_cops['ParserEngine']).to eq('parser_prism')
+        expect(config.target_ruby_version).to eq(2.7)
+      end
+    end
+
+    context 'when TargetRubyVersion and ParserEngine are in separate inherited configs' do
+      let(:file_path) { '.rubocop.yml' }
+
+      before do
+        # When TargetRubyVersion is explicitly set, there's no issue
+        create_file('.rubocop_base.yml', <<~YAML)
+          AllCops:
+            ParserEngine: parser_prism
+        YAML
+
+        create_file('.rubocop.yml', <<~YAML)
+          inherit_from: .rubocop_base.yml
+
+          AllCops:
+            TargetRubyVersion: 3.3
+        YAML
+
+        create_file('test.gemspec', <<~RUBY)
+          Gem::Specification.new do |s|
+            s.name = 'test'
+            s.required_ruby_version = '>= 2.7.0'
+          end
+        RUBY
+      end
+
+      it 'loads configuration without error when using parser_prism' do
+        expect { configuration_from_file }.not_to raise_error
+        config = configuration_from_file
+        expect(config.for_all_cops['TargetRubyVersion']).to eq(3.3)
+        expect(config.for_all_cops['ParserEngine']).to eq('parser_prism')
+        expect(config.target_ruby_version).to eq(3.3)
+      end
+    end
+
+    context 'when a file inherits from multiple files using a glob' do
+      let(:file_path) { '.rubocop.yml' }
+
+      before do
+        create_file(file_path, <<~YAML)
+          inherit_from:
+            - packages/*/.rubocop_todo.yml
+
+          inherit_mode:
+            merge:
+              - Exclude
+
+          Style/For:
+            Exclude:
+              - spec/requests/group_invite_spec.rb
+        YAML
+
+        create_file('packages/package_one/.rubocop_todo.yml', <<~YAML)
+          Style/For:
+            Exclude:
+              - 'spec/models/group_spec.rb'
+        YAML
+
+        create_file('packages/package_two/.rubocop_todo.yml', <<~YAML)
+          Style/For:
+            Exclude:
+              - 'spec/models/expense_spec.rb'
+        YAML
+
+        create_file('packages/package_three/.rubocop_todo.yml', <<~YAML)
+          Style/For:
+            Exclude:
+              - 'spec/models/order_spec.rb'
+        YAML
+      end
+
+      it 'gets the Exclude merging the inherited one' do
+        expected = [
+          File.expand_path('packages/package_two/spec/models/expense_spec.rb'),
+          File.expand_path('packages/package_one/spec/models/group_spec.rb'),
+          File.expand_path('packages/package_three/spec/models/order_spec.rb'),
+          File.expand_path('spec/requests/group_invite_spec.rb')
+        ]
+        expect(configuration_from_file['Style/For']['Exclude']).to match_array(expected)
+      end
+    end
+
     context 'when a file inherits and overrides a hash with nil' do
       let(:file_path) { '.rubocop.yml' }
 
@@ -529,7 +705,7 @@ RSpec.describe RuboCop::ConfigLoader do
         end.not_to output(/overrides the same parameter/).to_stdout
       end
 
-      it 'overwrites the Exclude from the parent when the cop overridesthe global inherit_mode' do
+      it 'overwrites the Exclude from the parent when the cop overrides the global inherit_mode' do
         expect do
           excludes = configuration_from_file['Style/Dir']['Exclude']
           expect(excludes).to eq([File.expand_path('spec/requests/group_invite_spec.rb')])
@@ -605,6 +781,9 @@ RSpec.describe RuboCop::ConfigLoader do
               - foo.rb
             Include:
               - bar.rb
+            InheritedArraySpecifiedString:
+              - 'string in array'
+            InheritedStringSpecifiedArray: 'bare string'
         YAML
         create_file(file_path, <<~YAML)
           inherit_from:
@@ -616,12 +795,17 @@ RSpec.describe RuboCop::ConfigLoader do
                 - AllowedIdentifiers
                 - Exclude
                 - Include
+                - InheritedStringSpecifiedArray
+                - InheritedArraySpecifiedString
             AllowedIdentifiers:
               - iso2
             Exclude:
               - test.rb
             Include:
               - another_test.rb
+            InheritedArraySpecifiedString: 'bare string'
+            InheritedStringSpecifiedArray:
+              - 'string in array'
         YAML
       end
 
@@ -631,7 +815,17 @@ RSpec.describe RuboCop::ConfigLoader do
           .to contain_exactly('foo.rb', 'test.rb')
         expect(examples_configuration['Include']).to contain_exactly('bar.rb', 'another_test.rb')
         expect(examples_configuration['AllowedIdentifiers'])
-          .to contain_exactly(*%w[capture3 iso8601 rfc1123_date rfc2822 rfc3339 rfc822 iso2])
+          .to match_array(
+            %w[TLS1_1 TLS1_2 capture3 iso8601 rfc1123_date rfc2822 rfc3339 rfc822 iso2 x86_64]
+          )
+        expect(examples_configuration['InheritedArraySpecifiedString']).to contain_exactly(
+          'bare string',
+          'string in array'
+        )
+        expect(examples_configuration['InheritedStringSpecifiedArray']).to contain_exactly(
+          'bare string',
+          'string in array'
+        )
       end
     end
 
@@ -681,6 +875,12 @@ RSpec.describe RuboCop::ConfigLoader do
         it "handles EnabledByDefault: #{enabled_by_default}, " \
            "DisabledByDefault: #{disabled_by_default} with disabled #{custom_dept_to_disable}" do
           create_file('grandparent_rubocop.yml', <<~YAML)
+            Layout:
+              Enabled: false
+
+            Layout/EndOfLine:
+              Enabled: true
+
             Naming/FileName:
               Enabled: pending
 
@@ -718,6 +918,12 @@ RSpec.describe RuboCop::ConfigLoader do
               EnabledByDefault: #{enabled_by_default}
               DisabledByDefault: #{disabled_by_default}
 
+            Layout:
+              Enabled: false
+
+            Layout/LineLength:
+              Enabled: true
+
             Style:
               Enabled: false
 
@@ -739,7 +945,7 @@ RSpec.describe RuboCop::ConfigLoader do
           end
 
           if custom_dept_to_disable == 'Foo'
-            message = <<~'OUTPUT'.chomp
+            message = <<~OUTPUT.chomp
               unrecognized cop or department Foo found in parent_rubocop.yml
               Foo is not a department. Use `Foo/Bar`.
             OUTPUT
@@ -747,6 +953,15 @@ RSpec.describe RuboCop::ConfigLoader do
             next
           end
 
+          # Department disabled in grandparent config.
+          expect(enabled?('Layout/DotPosition')).to be(false)
+
+          # Enabled in grandparent config, disabled in user config.
+          expect(enabled?('Layout/EndOfLine')).to be(false)
+
+          # Department disabled in grandparent config, cop enabled in user config.
+          expect(enabled?('Layout/LineLength')).to be(true)
+
           # Department disabled in parent config, cop enabled in child.
           expect(enabled?('Metrics/MethodLength')).to be(true)
 
@@ -785,10 +1000,10 @@ RSpec.describe RuboCop::ConfigLoader do
         end
       end
 
-      include_examples 'resolves enabled/disabled for all cops', false, false, 'Foo/Bar'
-      include_examples 'resolves enabled/disabled for all cops', false, true, 'Foo/Bar'
-      include_examples 'resolves enabled/disabled for all cops', true, false, 'Foo/Bar'
-      include_examples 'resolves enabled/disabled for all cops', false, false, 'Foo'
+      it_behaves_like 'resolves enabled/disabled for all cops', false, false, 'Foo/Bar'
+      it_behaves_like 'resolves enabled/disabled for all cops', false, true, 'Foo/Bar'
+      it_behaves_like 'resolves enabled/disabled for all cops', true, false, 'Foo/Bar'
+      it_behaves_like 'resolves enabled/disabled for all cops', false, false, 'Foo'
     end
 
     context 'when a third party require defines a new gem', :restore_registry do
@@ -805,7 +1020,7 @@ RSpec.describe RuboCop::ConfigLoader do
             .to output(
               a_string_including(
                 '.rubocop.yml: Custom/Loop has the ' \
-                "wrong namespace - should be Lint\n"
+                "wrong namespace - replace it with Lint/Loop\n"
               )
             ).to_stderr
         end
@@ -887,9 +1102,11 @@ RSpec.describe RuboCop::ConfigLoader do
               'AllowHeredoc' => true,
               'AllowURI' => true,
               'URISchemes' => %w[http https],
-              'IgnoreCopDirectives' => true,
+              'AllowRBSInlineAnnotation' => false,
+              'AllowCopDirectives' => true,
               'AllowedPatterns' => [],
-              'IgnoredPatterns' => []
+              'AllowQualifiedName' => true,
+              'SplitStrings' => false
             },
             'Metrics/MethodLength' => {
               'Description' =>
@@ -904,12 +1121,10 @@ RSpec.describe RuboCop::ConfigLoader do
               'Max' => 5,
               'CountAsOne' => [],
               'AllowedMethods' => [],
-              'IgnoredMethods' => [],
-              'AllowedPatterns' => [],
-              'ExcludedMethods' => []
+              'AllowedPatterns' => []
             }
           )
-        expect { expect(configuration_from_file.to_h).to eq(config) }.to output('').to_stderr
+        expect { expect(configuration_from_file.to_h).to eq(config) }.not_to output.to_stderr
       end
     end
 
@@ -948,7 +1163,7 @@ RSpec.describe RuboCop::ConfigLoader do
                      'Max' => 200 }            # special.yml takes precedence
         expect do
           expect(configuration_from_file['Metrics/MethodLength']
-                   .to_set.superset?(expected.to_set)).to be(true)
+                   .to_set).to be_superset(expected.to_set)
         end.to output(Regexp.new(<<~OUTPUT)).to_stdout
           .rubocop.yml: Metrics/MethodLength:Enabled overrides the same parameter in special.yml
           .rubocop.yml: Metrics/MethodLength:Enabled overrides the same parameter in normal.yml
@@ -957,7 +1172,7 @@ RSpec.describe RuboCop::ConfigLoader do
       end
     end
 
-    context 'when a file inherits and overrides with non-namedspaced cops' do
+    context 'when a file inherits and overrides with non-namespaced cops' do
       let(:file_path) { '.rubocop.yml' }
 
       before do
@@ -993,9 +1208,11 @@ RSpec.describe RuboCop::ConfigLoader do
               'AllowHeredoc' => false,  # overridden in rubocop.yml
               'AllowURI' => true,
               'URISchemes' => %w[http https],
-              'IgnoreCopDirectives' => true,
+              'AllowRBSInlineAnnotation' => false,
+              'AllowCopDirectives' => true,
               'AllowedPatterns' => [],
-              'IgnoredPatterns' => []
+              'AllowQualifiedName' => true,
+              'SplitStrings' => false
             }
           )
 
@@ -1106,8 +1323,8 @@ RSpec.describe RuboCop::ConfigLoader do
                        'Max' => 200 }            # inherited from somegem
           expect do
             expect(configuration_from_file['Metrics/MethodLength']
-                    .to_set.superset?(expected.to_set)).to be(true)
-          end.to output('').to_stderr
+                    .to_set).to be_superset(expected.to_set)
+          end.not_to output.to_stderr
 
           expected = { 'Enabled' => true, # gemtwo/config/default.yml
                        'Max' => 72,              # gemtwo/config/strict.yml
@@ -1115,8 +1332,39 @@ RSpec.describe RuboCop::ConfigLoader do
                        'AllowURI' => false }     # overridden in .rubocop.yml
           expect(
             configuration_from_file['Layout/LineLength']
-              .to_set.superset?(expected.to_set)
-          ).to be(true)
+              .to_set
+          ).to be_superset(expected.to_set)
+        end
+
+        context 'bundler isolated', :isolated_bundler do
+          it 'loads' do
+            expect { configuration_from_file }.not_to raise_error
+          end
+
+          context 'when the gemfile contains an uninstalled git source' do
+            before do
+              create_file('Gemfile', <<~GEMFILE)
+                gem 'rubocop', github: 'rubocop/rubocop'
+                gem 'some_other_gem'
+              GEMFILE
+            end
+
+            it 'loads' do
+              expect { configuration_from_file }.not_to raise_error
+            end
+          end
+
+          context 'when the gemfile fails to load' do
+            before do
+              create_file('Gemfile', <<~GEMFILE)
+                eval_gemfile 'file_that_does_not_exist'
+              GEMFILE
+            end
+
+            it 'loads' do
+              expect { configuration_from_file }.not_to raise_error
+            end
+          end
         end
       end
 
@@ -1142,8 +1390,8 @@ RSpec.describe RuboCop::ConfigLoader do
                        'Max' => 200 }            # inherited from somegem
           expect do
             expect(configuration_from_file['Metrics/MethodLength']
-                    .to_set.superset?(expected.to_set)).to be(true)
-          end.to output('').to_stderr
+                    .to_set).to be_superset(expected.to_set)
+          end.not_to output.to_stderr
 
           expected = { 'Enabled' => true, # gemtwo/config/default.yml
                        'Max' => 72,              # gemtwo/config/strict.yml
@@ -1151,8 +1399,8 @@ RSpec.describe RuboCop::ConfigLoader do
                        'AllowURI' => false }     # overridden in .rubocop.yml
           expect(
             configuration_from_file['Layout/LineLength']
-              .to_set.superset?(expected.to_set)
-          ).to be(true)
+              .to_set
+          ).to be_superset(expected.to_set)
         end
       end
     end
@@ -1188,9 +1436,11 @@ RSpec.describe RuboCop::ConfigLoader do
 
     context 'when a file inherits from a url' do
       let(:file_path) { '.rubocop.yml' }
-      let(:cache_file) { '.rubocop-http---example-com-rubocop-yml' }
+      let(:cache_file) { 'rubocop-e32e465e27910f2bc7262515eebe6b63.yml' }
 
       before do
+        described_class.cache_root = Dir.pwd
+
         stub_request(:get, /example.com/)
           .to_return(status: 200, body: <<~YAML)
             Style/Encoding:
@@ -1210,18 +1460,20 @@ RSpec.describe RuboCop::ConfigLoader do
         FileUtils.rm_rf cache_file
       end
 
-      it 'creates the cached file alongside the owning file' do
-        expect { configuration_from_file }.to output('').to_stderr
-        expect(File.exist?(cache_file)).to be true
+      it 'creates the cached file at the cache root' do
+        expect { configuration_from_file }.not_to output.to_stderr
+        expect(File).to exist(cache_file)
       end
     end
 
     context 'when a file inherits from a url inheriting from another file' do
       let(:file_path) { '.rubocop.yml' }
-      let(:cache_file) { '.rubocop-http---example-com-rubocop-yml' }
-      let(:cache_file2) { '.rubocop-http---example-com-inherit-yml' }
+      let(:cache_file) { 'inherit-1e2eaf67d5bc989f4bc3c5a900039224.yml' }
+      let(:cache_file2) { 'rubocop-e32e465e27910f2bc7262515eebe6b63.yml' }
 
       before do
+        described_class.cache_root = Dir.pwd
+
         stub_request(:get, %r{example.com/rubocop})
           .to_return(status: 200, body: "inherit_from:\n    - inherit.yml")
 
@@ -1239,8 +1491,52 @@ RSpec.describe RuboCop::ConfigLoader do
 
       it 'downloads the inherited file from the same url and caches it' do
         configuration_from_file
-        expect(File.exist?(cache_file)).to be true
-        expect(File.exist?(cache_file2)).to be true
+        expect(File).to exist(cache_file)
+        expect(File).to exist(cache_file2)
+      end
+    end
+
+    context 'with early cache_root computation' do
+      around do |example|
+        original_rubocop_cache_root = ENV.fetch('RUBOCOP_CACHE_ROOT', nil)
+        original_xdg_cache_home = ENV.fetch('XDG_CACHE_HOME', nil)
+        ENV['RUBOCOP_CACHE_ROOT'] = nil
+        ENV['XDG_CACHE_HOME'] = nil
+        example.run
+        ENV['RUBOCOP_CACHE_ROOT'] = original_rubocop_cache_root
+        ENV['XDG_CACHE_HOME'] = original_xdg_cache_home
+      end
+
+      before do
+        described_class.cache_root = nil
+      end
+
+      context 'when a file inherits from a URL without explicit cache_root', :isolated_environment do
+        let(:file_path) { '.rubocop.yml' }
+        let(:cache_file) { 'rubocop-e32e465e27910f2bc7262515eebe6b63.yml' }
+
+        before do
+          stub_request(:get, %r{example.com/rubocop.yml})
+            .to_return(status: 200, body: <<~YAML)
+              Style/Encoding:
+                Enabled: true
+            YAML
+
+          create_file(file_path, <<~YAML)
+            inherit_from: http://example.com/rubocop.yml
+          YAML
+        end
+
+        it 'caches remote config in early-computed cache directory, not Dir.pwd' do
+          expect(File).not_to exist(File.join(Dir.home, '.cache', 'rubocop_cache', cache_file))
+
+          configuration_from_file
+
+          pwd_cache_files = Dir.glob('**/*', File::FNM_DOTMATCH).select { |f| File.file?(f) && f.include?('.yml') && f != '.rubocop.yml' }
+
+          expect(File).to exist(File.join(Dir.home, '.cache', 'rubocop_cache', cache_file))
+          expect(pwd_cache_files).to be_empty
+        end
       end
     end
 
@@ -1623,10 +1919,10 @@ RSpec.describe RuboCop::ConfigLoader do
       expect(configuration['Style/Encoding']).to eq('Exclude' => [abs('dir/c.rb')])
     end
 
-    it 'fails with a TypeError when loading a malformed configuration file' do
+    it 'fails with a ValidationError when loading a malformed configuration file' do
       create_file(configuration_path, 'This string is not a YAML hash')
       expect { load_file }.to raise_error(
-        TypeError, /^Malformed configuration in .*\.rubocop\.yml$/
+        RuboCop::ValidationError, /^Malformed configuration in .*\.rubocop\.yml$/
       )
     end
 
@@ -1646,6 +1942,32 @@ RSpec.describe RuboCop::ConfigLoader do
       expect(configuration.to_h).to eq({})
     end
 
+    it 'rejects non-allowed yaml types' do
+      create_file(configuration_path, <<~YAML)
+        foo: !ruby/object:Rational
+          numerator: 1
+          denominator: 2
+      YAML
+
+      expect { load_file }.to raise_error(Psych::DisallowedClass, /Rational/)
+    end
+
+    it 'allows yaml anchors' do
+      create_file(configuration_path, <<~YAML)
+        Style/Alias: &anchor
+          Enabled: false
+        Style/Encoding:
+          <<: *anchor
+      YAML
+
+      expect(load_file.to_h).to eq(
+        {
+          'Style/Alias' => { 'Enabled' => false },
+          'Style/Encoding' => { 'Enabled' => false }
+        }
+      )
+    end
+
     context 'set neither true nor false to value to Enabled' do
       before do
         create_file(configuration_path, <<~YAML)
@@ -1664,6 +1986,42 @@ RSpec.describe RuboCop::ConfigLoader do
       end
     end
 
+    context 'does not set `always`, `contextual`, `disabled`, or boolean to `AutoCorrect`' do
+      before do
+        create_file(configuration_path, <<~YAML)
+          Layout/EmptyComment:
+            AutoCorrect: unknown
+        YAML
+      end
+
+      it 'gets a warning message' do
+        expect do
+          load_file
+        end.to raise_error(
+          RuboCop::ValidationError,
+          /supposed to be `always`, `contextual`, `disabled`, or a boolean and unknown is not/
+        )
+      end
+    end
+
+    context 'does not set an array to `References`' do
+      before do
+        create_file(configuration_path, <<~YAML)
+          Layout/EmptyComment:
+            References: 'https://example.com'
+        YAML
+      end
+
+      it 'gets a warning message' do
+        expect do
+          load_file
+        end.to raise_error(
+          RuboCop::ValidationError,
+          %r{supposed to be an array of strings and https://example\.com is not}
+        )
+      end
+    end
+
     context 'does not set `pending`, `disable`, or `enable` to `NewCops`' do
       before do
         create_file(configuration_path, <<~YAML)
@@ -1733,6 +2091,38 @@ RSpec.describe RuboCop::ConfigLoader do
         end
       end
     end
+
+    context 'when inheriting from a remote file' do
+      let(:remote_config_parent) { <<~YAML }
+        inherit_from: './child.yml'
+
+        AllCops:
+          TargetRubyVersion: 3.2
+      YAML
+
+      let(:remote_config_child) { <<~YAML }
+        AllCops:
+          TargetRubyVersion: 3.1
+      YAML
+
+      context 'and that file inherits another' do
+        before do
+          create_file('.rubocop.yml', <<~YAML)
+            inherit_from: "https://www.example.com/rubocop.yml"
+          YAML
+
+          stub_request(:get, 'https://www.example.com/rubocop.yml')
+            .to_return(status: 200, body: remote_config_parent)
+
+          stub_request(:get, 'https://www.example.com/child.yml')
+            .to_return(status: 200, body: remote_config_child)
+        end
+
+        it 'does not output warnings for duplicate keys' do
+          expect { load_file }.not_to output(/overrides the same parameter/).to_stdout
+        end
+      end
+    end
   end
 
   describe '.merge' do
@@ -1756,6 +2146,38 @@ RSpec.describe RuboCop::ConfigLoader do
     end
   end
 
+  describe '.inject_defaults!', :isolated_environment do
+    subject(:rubocop_config) { described_class.inject_defaults!(config_path) }
+
+    before do
+      create_empty_file('default.yml')
+    end
+
+    context 'when config path is a string' do
+      let(:config_path) { 'default.yml' }
+
+      it { expect { rubocop_config }.not_to raise_error }
+    end
+
+    context 'when config path is a `Pathname` object' do
+      let(:config_path) { Pathname('default.yml') }
+
+      it { expect { rubocop_config }.not_to raise_error }
+    end
+
+    context 'when config path is a directory' do
+      let(:config_path) { 'config' }
+
+      before do
+        FileUtils.mkdir_p(config_path)
+      end
+
+      it 'raises an ArgumentError' do
+        expect { rubocop_config }.to raise_error(ArgumentError, /project root directory/)
+      end
+    end
+  end
+
   describe 'configuration for CharacterLiteral', :isolated_environment do
     let(:dir_path) { 'test/blargh' }
 
@@ -1781,43 +2203,12 @@ RSpec.describe RuboCop::ConfigLoader do
     end
   end
 
-  describe 'when pending cops exist', :isolated_environment do
-    subject(:from_file) { described_class.configuration_from_file('.rubocop.yml') }
-
-    before do
-      create_empty_file('.rubocop.yml')
-
-      # Setup similar to https://github.com/rubocop/rubocop-rspec/blob/master/lib/rubocop/rspec/inject.rb#L16
-      # and https://github.com/runtastic/rt_rubocop_defaults/blob/master/lib/rt_rubocop_defaults/inject.rb#L21
-      config = RuboCop::Config.new(parent_config)
-      described_class.instance_variable_set(:@default_configuration, config)
-    end
-
-    context 'when NewCops is set in a required file' do
-      let(:parent_config) { { 'AllCops' => { 'NewCops' => 'enable' } } }
-
-      it 'does not print a warning' do
-        expect(described_class).not_to receive(:warn_on_pending_cops)
-        from_file
-      end
-    end
-
-    context 'when NewCops is not configured in a required file' do
-      let(:parent_config) { { 'AllCops' => { 'Exclude:' => ['coverage/**/*'] } } }
-
-      it 'prints a warning' do
-        expect(described_class).to receive(:warn_on_pending_cops)
-        from_file
-      end
-    end
-  end
-
   describe 'configuration for AssignmentInCondition' do
     describe 'AllowSafeAssignment' do
       it 'is enabled by default' do
         default_config = described_class.default_configuration
         symbol_name_config = default_config.for_cop('Lint/AssignmentInCondition')
-        expect(symbol_name_config['AllowSafeAssignment']).to be_truthy
+        expect(symbol_name_config['AllowSafeAssignment']).to be(true)
       end
     end
   end
@@ -1833,19 +2224,19 @@ RSpec.describe RuboCop::ConfigLoader do
     it 'requires the passed path' do
       config_path = described_class.configuration_file_for('.')
       described_class.configuration_from_file(config_path)
-      expect(defined?(MyClass)).to be_truthy
+      expect(defined?(MyClass)).to eq('constant')
     end
 
     it 'uses paths relative to the .rubocop.yml, not cwd' do
       config_path = described_class.configuration_file_for('.')
       Dir.chdir '..' do
         described_class.configuration_from_file(config_path)
-        expect(defined?(MyClass)).to be_truthy
+        expect(defined?(MyClass)).to eq('constant')
       end
     end
   end
 
-  describe 'when a unqualified requirement is defined', :isolated_environment do
+  describe 'when an unqualified requirement is defined', :isolated_environment do
     let(:required_file_path) { 'required_file' }
 
     before do
@@ -1858,7 +2249,7 @@ RSpec.describe RuboCop::ConfigLoader do
       $LOAD_PATH.unshift(File.dirname(config_path))
       Dir.chdir '..' do
         described_class.configuration_from_file(config_path)
-        expect(defined?(MyClass)).to be_truthy
+        expect(defined?(MyClass)).to eq('constant')
       end
     end
   end
