@@ -7,10 +7,11 @@ RSpec.describe RuboCop::ConfigObsoletion do
 
   let(:configuration) { RuboCop::Config.new(hash, loaded_path) }
   let(:loaded_path) { 'example/.rubocop.yml' }
+  let(:plugins) { [] }
   let(:requires) { [] }
 
   before do
-    allow(configuration).to receive(:loaded_features).and_return(requires)
+    allow(configuration).to receive_messages(loaded_plugins: plugins, loaded_features: requires)
     described_class.files = [described_class::DEFAULT_RULES_FILE]
   end
 
@@ -168,8 +169,6 @@ RSpec.describe RuboCop::ConfigObsoletion do
           (obsolete configuration found in example/.rubocop.yml, please update it)
           The `Style/OpMethod` cop has been renamed to `Naming/BinaryOperatorParameterName`.
           (obsolete configuration found in example/.rubocop.yml, please update it)
-          The `Style/PredicateName` cop has been moved to `Naming/PredicateName`.
-          (obsolete configuration found in example/.rubocop.yml, please update it)
           The `Style/SingleSpaceBeforeFirstArg` cop has been renamed to `Layout/SpaceBeforeFirstArg`.
           (obsolete configuration found in example/.rubocop.yml, please update it)
           The `Style/UnneededCapitalW` cop has been renamed to `Style/RedundantCapitalW`.
@@ -213,11 +212,21 @@ RSpec.describe RuboCop::ConfigObsoletion do
         OUTPUT
       end
 
+      let(:expected_warnings) do
+        [
+          <<~OUTPUT.chomp
+            The `Style/PredicateName` cop has been renamed to `Naming/PredicatePrefix`.
+            (obsolete configuration found in example/.rubocop.yml, please update it)
+          OUTPUT
+        ]
+      end
+
       it 'prints a warning message' do
         config_obsoletion.reject_obsolete!
         raise 'Expected a RuboCop::ValidationError'
       rescue RuboCop::ValidationError => e
         expect(e.message).to eq(expected_message)
+        expect(config_obsoletion.warnings).to eq(expected_warnings)
       end
     end
 
@@ -231,6 +240,32 @@ RSpec.describe RuboCop::ConfigObsoletion do
         }
       end
 
+      context 'when the plugin extensions are loaded' do
+        let(:plugins) { %w[rubocop-rails rubocop-performance] }
+
+        it 'does not print a warning message' do
+          expect { config_obsoletion.reject_obsolete! }.not_to raise_error
+        end
+      end
+
+      context 'when only one plugin extension is loaded' do
+        let(:plugins) { %w[rubocop-performance] }
+
+        let(:expected_message) do
+          <<~OUTPUT.chomp
+            `Rails` cops have been extracted to the `rubocop-rails` gem.
+            (obsolete configuration found in example/.rubocop.yml, please update it)
+          OUTPUT
+        end
+
+        it 'prints a warning message' do
+          config_obsoletion.reject_obsolete!
+          raise 'Expected a RuboCop::ValidationError'
+        rescue RuboCop::ValidationError => e
+          expect(e.message).to eq(expected_message)
+        end
+      end
+
       context 'when the extensions are loaded' do
         let(:requires) { %w[rubocop-rails rubocop-performance] }
 
@@ -277,6 +312,8 @@ RSpec.describe RuboCop::ConfigObsoletion do
     end
 
     context 'when the extensions are loaded via inherit_gem', :restore_registry do
+      include_context 'mock console output'
+
       let(:resolver) { RuboCop::ConfigLoaderResolver.new }
       let(:gem_root) { File.expand_path('gems') }
 
@@ -391,7 +428,7 @@ RSpec.describe RuboCop::ConfigObsoletion do
         OUTPUT
       end
 
-      it 'prints a error message' do
+      it 'prints an error message' do
         config_obsoletion.reject_obsolete!
         raise 'Expected a RuboCop::ValidationError'
       rescue RuboCop::ValidationError => e
@@ -399,6 +436,45 @@ RSpec.describe RuboCop::ConfigObsoletion do
       end
     end
 
+    context 'when the configuration includes deprecated parameters for the TargetRubyVersion' do
+      let(:hash) do
+        {
+          'AllCops' => { 'TargetRubyVersion' => target_ruby_version },
+          **cop_config
+        }
+      end
+      let(:warning_message) { config_obsoletion.warnings.join("\n") }
+
+      context 'with Style/ArgumentsForwarding AllowOnlyRestArgument' do
+        let(:cop_config) do
+          { 'Style/ArgumentsForwarding' => { 'AllowOnlyRestArgument' => false } }
+        end
+
+        context 'with TargetRubyVersion 3.2' do
+          let(:target_ruby_version) { 3.2 }
+
+          it 'prints a warning message' do
+            expected_message = <<~OUTPUT.chomp
+              obsolete parameter `AllowOnlyRestArgument` (for `Style/ArgumentsForwarding`) found in example/.rubocop.yml
+              `AllowOnlyRestArgument` has no effect with TargetRubyVersion >= 3.2.
+            OUTPUT
+
+            expect { config_obsoletion.reject_obsolete! }.not_to raise_error
+            expect(warning_message).to eq(expected_message)
+          end
+        end
+
+        context 'with TargetRubyVersion 3.1' do
+          let(:target_ruby_version) { 3.1 }
+
+          it 'does not print a warning message' do
+            expect { config_obsoletion.reject_obsolete! }.not_to raise_error
+            expect(warning_message).to eq('')
+          end
+        end
+      end
+    end
+
     context 'when the configuration includes any deprecated parameters' do
       let(:hash) do
         {
@@ -505,7 +581,7 @@ RSpec.describe RuboCop::ConfigObsoletion do
         }
       end
 
-      let(:file1) do
+      let(:file_with_renamed_config) do
         create_file('obsoletions1.yml', <<~YAML)
           renamed:
             Foo/Bar: Foo/Baz
@@ -513,7 +589,7 @@ RSpec.describe RuboCop::ConfigObsoletion do
         YAML
       end
 
-      let(:file2) do
+      let(:file_with_removed_and_split_config) do
         create_file('obsoletions2.yml', <<~YAML)
           removed:
             Legacy/Test:
@@ -528,6 +604,12 @@ RSpec.describe RuboCop::ConfigObsoletion do
         YAML
       end
 
+      let(:file_with_comments_only) do
+        create_file('obsoletions3.yml', <<~YAML)
+          # Placeholder for eventual obsoletions, so we can hook up the file regardless
+        YAML
+      end
+
       let(:expected_message) do
         <<~OUTPUT.chomp
           The `Style/FlipFlop` cop has been moved to `Lint/FlipFlop`.
@@ -544,8 +626,9 @@ RSpec.describe RuboCop::ConfigObsoletion do
       end
 
       it 'includes obsoletions from all sources' do
-        described_class.files << file1
-        described_class.files << file2
+        described_class.files << file_with_renamed_config
+        described_class.files << file_with_removed_and_split_config
+        described_class.files << file_with_comments_only
 
         begin
           config_obsoletion.reject_obsolete!
@@ -594,4 +677,52 @@ RSpec.describe RuboCop::ConfigObsoletion do
       end
     end
   end
+
+  describe '.deprecated_cop_name?' do
+    RSpec::Matchers.alias_matcher(:have_deprecated_cop_name, :be_deprecated_cop_name)
+
+    it 'returns true for a cop name that is deprecated' do
+      expect(described_class).to have_deprecated_cop_name('Layout/AlignArguments')
+    end
+
+    it 'returns true for a cop name that is not deprecated' do
+      expect(described_class).not_to have_deprecated_cop_name('Layout/ArgumentAlignment')
+    end
+
+    it 'returns true for a cop name that is unknown' do
+      expect(described_class).not_to have_deprecated_cop_name('Foo/Bar')
+    end
+  end
+
+  describe '.deprecated_names_for', :isolated_environment, :mock_obsoletion do
+    before do
+      create_file(obsoletion_configuration_path, <<~YAML)
+        renamed:
+          Layout/AlignArguments: Layout/ArgumentAlignment
+          Style/PredicateName: Naming/PredicatePrefix
+          Naming/PredicateName: Naming/PredicatePrefix
+      YAML
+    end
+
+    context 'when a cop has been moved once' do
+      it 'returns the deprecated name for a cop' do
+        described_class.deprecated_names_for('Layout/ArgumentAlignment')
+        expect(described_class.deprecated_names_for('Layout/ArgumentAlignment'))
+          .to contain_exactly('Layout/AlignArguments')
+      end
+    end
+
+    context 'when a cop has been moved multiple times' do
+      it 'returns the deprecated names for a cop' do
+        expect(described_class.deprecated_names_for('Naming/PredicatePrefix'))
+          .to contain_exactly('Style/PredicateName', 'Naming/PredicateName')
+      end
+    end
+
+    context 'when a cop has not been moved' do
+      it 'returns an empty array' do
+        expect(described_class.deprecated_names_for('Foo/Bar')).to be_empty
+      end
+    end
+  end
 end
