@@ -10,7 +10,7 @@ RSpec.describe RuboCop::ConfigStore do
       # dir/.rubocop.yml
       # dir/file2
       # dir/subdir/file3
-      "#{/dir/.match?(arg) ? 'dir' : '.'}/.rubocop.yml"
+      "#{arg.include?('dir') ? 'dir' : '.'}/.rubocop.yml"
     end
     allow(RuboCop::ConfigLoader).to receive(:configuration_from_file) { |arg| arg }
     allow(RuboCop::ConfigLoader).to receive(:load_file) { |arg| RuboCop::Config.new(arg) }
@@ -21,8 +21,9 @@ RSpec.describe RuboCop::ConfigStore do
 
   describe '.for' do
     it 'always uses config specified in command line' do
-      config_store.options_config = { options_config: true }
-      expect(config_store.for('file1')).to eq('merged {:options_config=>true}')
+      config = { options_config: true }
+      config_store.options_config = config
+      expect(config_store.for('file1')).to eq("merged #{config}")
     end
 
     context 'when no config specified in command line' do
