@@ -64,7 +64,7 @@ RSpec.describe RuboCop::Cop::Bundler::GemComment, :config do
 
     context 'and a gem has no comment' do
       it 'registers an offense' do
-        expect_offense(<<-RUBY, 'Gemfile')
+        expect_offense(<<~RUBY, 'Gemfile')
           gem 'rubocop'
           ^^^^^^^^^^^^^ Missing gem description comment.
         RUBY
@@ -88,15 +88,15 @@ RSpec.describe RuboCop::Cop::Bundler::GemComment, :config do
 
         context 'when a gem is uncommented and has no version specified' do
           it 'does not register an offense' do
-            expect_no_offenses(<<-RUBY, 'Gemfile')
-            gem 'rubocop'
+            expect_no_offenses(<<~RUBY, 'Gemfile')
+              gem 'rubocop'
             RUBY
           end
         end
 
         context 'when a gem is uncommented and has options but no version specifiers' do
           it 'does not register an offense' do
-            expect_no_offenses(<<-RUBY, 'Gemfile')
+            expect_no_offenses(<<~RUBY, 'Gemfile')
               gem 'rubocop', group: development
             RUBY
           end
@@ -104,25 +104,25 @@ RSpec.describe RuboCop::Cop::Bundler::GemComment, :config do
 
         context 'when a gem is uncommented and has a version specifier' do
           it 'registers an offense' do
-            expect_offense(<<-RUBY, 'Gemfile')
-                gem 'rubocop', '~> 12.0'
-                ^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
+            expect_offense(<<~RUBY, 'Gemfile')
+              gem 'rubocop', '~> 12.0'
+              ^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
             RUBY
           end
         end
 
         context 'when a gem is uncommented and has multiple version specifiers' do
           it 'registers an offense' do
-            expect_offense(<<-RUBY, 'Gemfile')
-                gem 'rubocop', '~> 12.0', '>= 11.0'
-                ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
+            expect_offense(<<~RUBY, 'Gemfile')
+              gem 'rubocop', '~> 12.0', '>= 11.0'
+              ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
             RUBY
           end
         end
 
         context 'when a gem is uncommented and has a version specifier along with other options' do
           it 'registers an offense' do
-            expect_offense(<<-RUBY, 'Gemfile')
+            expect_offense(<<~RUBY, 'Gemfile')
               gem 'rubocop', '~> 12.0', required: true
               ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
             RUBY
@@ -144,15 +144,15 @@ RSpec.describe RuboCop::Cop::Bundler::GemComment, :config do
 
         context 'when a gem is uncommented and has no version specified' do
           it 'does not register an offense' do
-            expect_no_offenses(<<-RUBY, 'Gemfile')
-            gem 'rubocop'
+            expect_no_offenses(<<~RUBY, 'Gemfile')
+              gem 'rubocop'
             RUBY
           end
         end
 
         context 'when a gem is uncommented and has options but no version specifiers' do
           it 'does not register an offense' do
-            expect_no_offenses(<<-RUBY, 'Gemfile')
+            expect_no_offenses(<<~RUBY, 'Gemfile')
               gem 'rubocop', group: development
             RUBY
           end
@@ -160,7 +160,7 @@ RSpec.describe RuboCop::Cop::Bundler::GemComment, :config do
 
         context 'when a gem is uncommented and has only a minimum version specifier' do
           it 'does not register an offense' do
-            expect_no_offenses(<<-RUBY, 'Gemfile')
+            expect_no_offenses(<<~RUBY, 'Gemfile')
               gem 'rubocop', '>= 12.0'
             RUBY
           end
@@ -168,52 +168,52 @@ RSpec.describe RuboCop::Cop::Bundler::GemComment, :config do
 
         context 'when a gem is uncommented and has a non-minimum version specifier with a leading space' do
           it 'registers an offense' do
-            expect_offense(<<-RUBY, 'Gemfile')
-                gem 'rubocop', ' ~> 12.0'
-                ^^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
+            expect_offense(<<~RUBY, 'Gemfile')
+              gem 'rubocop', ' ~> 12.0'
+              ^^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
             RUBY
           end
         end
 
         context 'when a gem is uncommented and has a version specifier without operator' do
           it 'registers an offense' do
-            expect_offense(<<-RUBY, 'Gemfile')
-                gem 'rubocop', '12.0'
-                ^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
+            expect_offense(<<~RUBY, 'Gemfile')
+              gem 'rubocop', '12.0'
+              ^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
             RUBY
           end
         end
 
         context 'when a gem is uncommented and has a frozen version specifier' do
           it 'registers an offense' do
-            expect_offense(<<-RUBY, 'Gemfile')
-                gem 'rubocop', '= 12.0'
-                ^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
+            expect_offense(<<~RUBY, 'Gemfile')
+              gem 'rubocop', '= 12.0'
+              ^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
             RUBY
           end
         end
 
         context 'when a gem is uncommented and has a pessimistic version specifier' do
           it 'registers an offense' do
-            expect_offense(<<-RUBY, 'Gemfile')
-                gem 'rubocop', '~> 12.0'
-                ^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
+            expect_offense(<<~RUBY, 'Gemfile')
+              gem 'rubocop', '~> 12.0'
+              ^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
             RUBY
           end
         end
 
         context 'when a gem is uncommented and has both minimum and non-minimum version specifier' do
           it 'registers an offense' do
-            expect_offense(<<-RUBY, 'Gemfile')
-                gem 'rubocop', '~> 12.0', '>= 11.0'
-                ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
+            expect_offense(<<~RUBY, 'Gemfile')
+              gem 'rubocop', '~> 12.0', '>= 11.0'
+              ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
             RUBY
           end
         end
 
         context 'when a gem is uncommented and has a version specifier along with other options' do
           it 'registers an offense' do
-            expect_offense(<<-RUBY, 'Gemfile')
+            expect_offense(<<~RUBY, 'Gemfile')
               gem 'rubocop', '~> 12.0', required: true
               ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
             RUBY
@@ -226,7 +226,7 @@ RSpec.describe RuboCop::Cop::Bundler::GemComment, :config do
 
         context 'when a gem is uncommented and has one of the specified options' do
           it 'registers an offense' do
-            expect_offense(<<-RUBY, 'Gemfile')
+            expect_offense(<<~RUBY, 'Gemfile')
               gem 'rubocop', github: 'some_user/some_fork'
               ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Missing gem description comment.
             RUBY
@@ -235,7 +235,7 @@ RSpec.describe RuboCop::Cop::Bundler::GemComment, :config do
 
         context 'when a gem is uncommented and has a version specifier but none of the specified options' do
           it 'does not register an offense' do
-            expect_no_offenses(<<-RUBY, 'Gemfile')
+            expect_no_offenses(<<~RUBY, 'Gemfile')
               gem 'rubocop', '~> 12.0'
             RUBY
           end
@@ -243,7 +243,7 @@ RSpec.describe RuboCop::Cop::Bundler::GemComment, :config do
 
         context 'when a gem is uncommented and contains only options not specified' do
           it 'does not register an offense' do
-            expect_no_offenses(<<-RUBY, 'Gemfile')
+            expect_no_offenses(<<~RUBY, 'Gemfile')
               gem 'rubocop', group: development
             RUBY
           end
