@@ -65,6 +65,10 @@ RSpec.describe RuboCop::Cop::Corrector do
       expect { |corrector| corrector.remove_trailing(operator, 2) }.to rewrite_to 'true a false'
     end
 
+    it 'allows swapping sources of two nodes' do
+      expect { |corrector| corrector.swap(node.lhs, node.rhs) }.to rewrite_to 'false and true'
+    end
+
     it 'accepts a node instead of a range' do
       expect { |corrector| corrector.replace(node.rhs, 'maybe') }.to rewrite_to 'true and maybe'
     end
