@@ -78,11 +78,17 @@ RSpec.describe RuboCop::Cop::Generator do
                   (send nil? :bad_method ...)
                 PATTERN
 
+                # Called on every `send` node (method call) while walking the AST.
+                # TODO: remove this method if inspecting `send` nodes is unneeded for your cop.
+                # By default, this is aliased to `on_csend` as well to handle method calls
+                # with safe navigation, remove the alias if this is unnecessary.
+                # If kept, ensure your tests cover safe navigation as well!
                 def on_send(node)
                   return unless bad_method?(node)
 
                   add_offense(node)
                 end
+                alias on_csend on_send
               end
             end
           end
@@ -346,7 +352,8 @@ RSpec.describe RuboCop::Cop::Generator do
       expect(File).to receive(:write).with('spec/rubocop/cop/plugin/style/fake_cop_spec.rb',
                                            an_instance_of(String))
       generator.write_spec
-      expect(stdout.string).to include("[create] spec/rubocop/cop/plugin/style/fake_cop_spec.rb\n")
+      expect(stdout.string)
+        .to include("[create] spec/rubocop/cop/plugin/style/fake_cop_spec.rb\n")
     end
   end
 
@@ -358,12 +365,7 @@ RSpec.describe RuboCop::Cop::Generator do
       RuboCop::Cop::Registry.with_temporary_global(new_global) { example.run }
     end
 
-    let(:config) do
-      config = RuboCop::ConfigStore.new
-      path = File.join(RuboCop::ConfigLoader::RUBOCOP_HOME, RuboCop::ConfigFinder::DOTFILE)
-      config.options_config = path
-      config
-    end
+    let(:config) { RuboCop::ConfigStore.new }
     let(:options) { { formatters: [] } }
     let(:runner) { RuboCop::Runner.new(options, config) }
 
