@@ -3,33 +3,33 @@
 RSpec.describe RuboCop::Cop::Layout::BeginEndAlignment, :config do
   let(:cop_config) { { 'EnforcedStyleAlignWith' => 'begin' } }
 
-  include_examples 'aligned', 'begin', '', 'end'
+  it_behaves_like 'aligned', 'begin', '', 'end'
 
-  include_examples 'misaligned', <<~RUBY, false
+  it_behaves_like 'misaligned', <<~RUBY, false
     begin
       end
       ^^^ `end` at 2, 2 is not aligned with `begin` at 1, 0.
   RUBY
 
-  include_examples 'aligned', 'puts 1; begin', '', '        end'
+  it_behaves_like 'aligned', 'puts 1; begin', '', '        end'
 
   context 'when EnforcedStyleAlignWith is start_of_line' do
     let(:cop_config) { { 'EnforcedStyleAlignWith' => 'start_of_line' } }
 
-    include_examples 'aligned', 'puts 1; begin', '', 'end'
+    it_behaves_like 'aligned', 'puts 1; begin', '', 'end'
 
-    include_examples 'misaligned', <<~RUBY, false
+    it_behaves_like 'misaligned', <<~RUBY, false
       begin
         end
         ^^^ `end` at 2, 2 is not aligned with `begin` at 1, 0.
     RUBY
 
-    include_examples 'misaligned', <<~RUBY, :begin
+    it_behaves_like 'misaligned', <<~RUBY, :begin
       var << begin
              end
              ^^^ `end` at 2, 7 is not aligned with `var << begin` at 1, 0.
     RUBY
 
-    include_examples 'aligned', 'var = begin', '', 'end'
+    it_behaves_like 'aligned', 'var = begin', '', 'end'
   end
 end
