@@ -114,7 +114,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
       RUBY
     end
 
-    it 'registers an offenses for mismatched end alignment' do
+    it 'registers an offense for mismatched end alignment' do
       expect_offense(<<~RUBY)
         variable =
           a_long_method_that_dont_fit_on_the_line do |v|
@@ -390,6 +390,12 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
         end)
         ^^^ `end` at 3, 2 is not aligned with `arr.all? do |o|` at 1, 7 or `expect(arr.all? do |o|` at 1, 0.
     RUBY
+
+    expect_correction(<<~RUBY)
+      expect(arr.all? do |o|
+        o.valid?
+      end)
+    RUBY
   end
 
   it 'accepts end aligned with an op-asgn (+=, -=)' do
@@ -407,6 +413,12 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
         end
         ^^^ `end` at 3, 2 is not aligned with `rb` at 1, 0.
     RUBY
+
+    expect_correction(<<~RUBY)
+      rb += files.select do |file|
+        file << something
+      end
+    RUBY
   end
 
   it 'accepts end aligned with an and-asgn (&&=)' do
@@ -422,6 +434,11 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
         end
         ^^^ `end` at 2, 2 is not aligned with `variable &&= test do |ala|` at 1, 0.
     RUBY
+
+    expect_correction(<<~RUBY)
+      variable &&= test do |ala|
+      end
+    RUBY
   end
 
   it 'accepts end aligned with an or-asgn (||=)' do
@@ -437,6 +454,11 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
         end
         ^^^ `end` at 2, 2 is not aligned with `variable ||= test do |ala|` at 1, 0.
     RUBY
+
+    expect_correction(<<~RUBY)
+      variable ||= test do |ala|
+      end
+    RUBY
   end
 
   it 'accepts end aligned with a mass assignment' do
@@ -462,6 +484,12 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
         end
         ^^^ `end` at 3, 2 is not aligned with `var1, var2` at 1, 0.
     RUBY
+
+    expect_correction(<<~RUBY)
+      var1, var2 = lambda do |test|
+        [1, 2]
+      end
+    RUBY
   end
 
   context 'when multiple similar-looking blocks have misaligned ends' do
@@ -474,6 +502,13 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
          end
          ^^^ `end` at 4, 1 is not aligned with `b = test do` at 3, 0.
       RUBY
+
+      expect_correction(<<~RUBY)
+        a = test do
+        end
+        b = test do
+        end
+      RUBY
     end
   end
 
@@ -502,7 +537,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
         def get_gems_by_name
           @gems ||= Hash[*get_latest_gems.map { |gem|
                            [gem.name, gem, gem.full_name, gem]
-                         }.flatten]
+          }.flatten]
         end
       RUBY
     end
@@ -533,7 +568,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
         def abc
           @abc ||= A[~xyz { |x|
                        x
-                     }.flatten]
+          }.flatten]
         end
       RUBY
     end
@@ -564,7 +599,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
         def abc
           @abc ||= A[!xyz { |x|
                        x
-                     }.flatten]
+          }.flatten]
         end
       RUBY
     end
@@ -595,7 +630,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
         def abc
           @abc ||= A[-xyz { |x|
                        x
-                     }.flatten]
+          }.flatten]
         end
       RUBY
     end
@@ -616,7 +651,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
     end
   end
 
-  context 'when configured to align with start_of_line' do
+  context 'with `EnforcedStyle: start_of_line`' do
     let(:cop_config) { { 'EnforcedStyleAlignWith' => 'start_of_line' } }
 
     it 'allows when start_of_line aligned' do
@@ -644,9 +679,137 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
         end
       RUBY
     end
+
+    context 'inside a non-endless method' do
+      it 'does not register an offense when `end` is aligned with the block start' do
+        expect_no_offenses(<<~RUBY)
+          def foo
+            bar do
+              baz
+            end
+          end
+        RUBY
+      end
+
+      it 'registers an offense and corrects when `end` is aligned with the method start' do
+        expect_offense(<<~RUBY)
+          def foo
+            bar do
+              baz
+          end
+          ^^^ `end` at 4, 0 is not aligned with `bar do` at 2, 2.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def foo
+            bar do
+              baz
+            end
+          end
+        RUBY
+      end
+    end
+
+    context 'inside a non-endless singleton method' do
+      it 'does not register an offense when `end` is aligned with the block start' do
+        expect_no_offenses(<<~RUBY)
+          def self.foo
+            bar do
+              baz
+            end
+          end
+        RUBY
+      end
+
+      it 'registers an offense and corrects when `end` is aligned with the method start' do
+        expect_offense(<<~RUBY)
+          def self.foo
+            bar do
+              baz
+          end
+          ^^^ `end` at 4, 0 is not aligned with `bar do` at 2, 2.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def self.foo
+            bar do
+              baz
+            end
+          end
+        RUBY
+      end
+    end
+
+    context 'with endless methods', :ruby30 do
+      it 'does not register an offense when `end` is aligned with the start of the method definition' do
+        expect_no_offenses(<<~RUBY)
+          def foo = bar do
+            baz
+          end
+        RUBY
+      end
+
+      it 'does not register an offense when `end` is aligned with the start of a multiline method definition' do
+        expect_no_offenses(<<~RUBY)
+          def foo = bar(123,
+                        456) do
+            baz
+          end
+        RUBY
+      end
+
+      it 'registers an offense when `end` is not aligned with the start of the method definition' do
+        expect_offense(<<~RUBY)
+          def foo = bar do
+            baz
+              end
+              ^^^ `end` at 3, 4 is not aligned with `def foo = bar do` at 1, 0.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def foo = bar do
+            baz
+          end
+        RUBY
+      end
+
+      it 'does not register an offense when `end` is aligned with the start of a singleton method definition' do
+        expect_no_offenses(<<~RUBY)
+          def self.foo = bar do
+            baz
+          end
+        RUBY
+      end
+
+      it 'does not register an offense when `end` is aligned with the start of a multiline singleton method definition' do
+        expect_no_offenses(<<~RUBY)
+          def self.foo = bar(123,
+                             456) do
+            baz
+          end
+        RUBY
+      end
+
+      it 'registers an offense when `end` is not aligned with the start of a singleton method definition' do
+        expect_offense(<<~RUBY)
+          def self.foo = bar do
+            baz
+              end
+              ^^^ `end` at 3, 4 is not aligned with `def self.foo = bar do` at 1, 0.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def self.foo = bar do
+            baz
+          end
+        RUBY
+      end
+    end
   end
 
-  context 'when configured to align with do' do
+  context 'with `EnforcedStyle: start_of_block`' do
     let(:cop_config) { { 'EnforcedStyleAlignWith' => 'start_of_block' } }
 
     it 'allows when do aligned' do
@@ -674,6 +837,150 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
           end
       RUBY
     end
+
+    context 'inside a non-endless method' do
+      it 'does not register an offense when `end` is aligned with the block start' do
+        expect_no_offenses(<<~RUBY)
+          def foo
+            bar do
+              baz
+            end
+          end
+        RUBY
+      end
+
+      it 'registers an offense and corrects when `end` is aligned with the method start' do
+        expect_offense(<<~RUBY)
+          def foo
+            bar do
+              baz
+          end
+          ^^^ `end` at 4, 0 is not aligned with `bar do` at 2, 2.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def foo
+            bar do
+              baz
+            end
+          end
+        RUBY
+      end
+    end
+
+    context 'inside a non-endless singleton method' do
+      it 'does not register an offense when `end` is aligned with the block start' do
+        expect_no_offenses(<<~RUBY)
+          def self.foo
+            bar do
+              baz
+            end
+          end
+        RUBY
+      end
+
+      it 'registers an offense and corrects when `end` is aligned with the method start' do
+        expect_offense(<<~RUBY)
+          def self.foo
+            bar do
+              baz
+          end
+          ^^^ `end` at 4, 0 is not aligned with `bar do` at 2, 2.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def self.foo
+            bar do
+              baz
+            end
+          end
+        RUBY
+      end
+    end
+
+    context 'with endless methods', :ruby30 do
+      it 'does not register an offense when `end` is aligned with the start of the method definition' do
+        expect_no_offenses(<<~RUBY)
+          def foo = bar do
+            baz
+          end
+        RUBY
+      end
+
+      it 'registers an offense when `end` is aligned with the start of a multiline method definition' do
+        expect_offense(<<~RUBY)
+          def foo = bar(123,
+                        456) do
+            baz
+          end
+          ^^^ `end` at 4, 0 is not aligned with `456) do` at 2, 14.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def foo = bar(123,
+                        456) do
+            baz
+                        end
+        RUBY
+      end
+
+      it 'registers an offense when `end` is not aligned with the start of the method definition' do
+        expect_offense(<<~RUBY)
+          def foo = bar do
+            baz
+              end
+              ^^^ `end` at 3, 4 is not aligned with `def foo = bar do` at 1, 0.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def foo = bar do
+            baz
+          end
+        RUBY
+      end
+
+      it 'does not register an offense when `end` is aligned with the start of a singleton method definition' do
+        expect_no_offenses(<<~RUBY)
+          def self.foo = bar do
+            baz
+          end
+        RUBY
+      end
+
+      it 'registers an offense when `end` is aligned with the start of a multiline singleton method definition' do
+        expect_offense(<<~RUBY)
+          def self.foo = bar(123,
+                             456) do
+            baz
+          end
+          ^^^ `end` at 4, 0 is not aligned with `456) do` at 2, 19.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def self.foo = bar(123,
+                             456) do
+            baz
+                             end
+        RUBY
+      end
+
+      it 'registers an offense when `end` is not aligned with the start of a singleton method definition' do
+        expect_offense(<<~RUBY)
+          def self.foo = bar do
+            baz
+              end
+              ^^^ `end` at 3, 4 is not aligned with `def self.foo = bar do` at 1, 0.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def self.foo = bar do
+            baz
+          end
+        RUBY
+      end
+    end
   end
 
   context 'Ruby 2.7', :ruby27 do
@@ -694,4 +1001,14 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
       RUBY
     end
   end
+
+  context 'Ruby 3.4', :ruby34 do
+    it 'accepts end aligned with a call chain left hand side' do
+      expect_no_offenses(<<~RUBY)
+        parser.diagnostics.consumer = lambda do
+          it << diagnostic
+        end
+      RUBY
+    end
+  end
 end
