@@ -41,7 +41,7 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
 
   context 'when the first line ends with a comment' do
     it 'reports an offense and swaps the lines' do
-      expect_offense <<-RUBY
+      expect_offense <<~RUBY
         class GridTask
           DESC = 'Grid Task' # grid task name OID, subclasses should set this
           extend Helpers::MakeFromFile
@@ -49,7 +49,7 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
         end
       RUBY
 
-      expect_correction <<-RUBY
+      expect_correction <<~RUBY
         class GridTask
           extend Helpers::MakeFromFile
           DESC = 'Grid Task' # grid task name OID, subclasses should set this
@@ -60,7 +60,7 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
 
   context 'with a complete ordered example' do
     it 'does not create offense' do
-      expect_no_offenses <<-RUBY
+      expect_no_offenses <<~RUBY
         class Person
           # extend and include go first
           extend SomeModule
@@ -136,8 +136,25 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
     end
   end
 
+  it 'registers an offense and corrects when public instance method is before class method' do
+    expect_offense(<<~RUBY)
+      class Foo
+        def instance_method; end
+        def self.class_method; end
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^ `public_class_methods` is supposed to appear before `public_methods`.
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      class Foo
+        def self.class_method; end
+        def instance_method; end
+      end
+    RUBY
+  end
+
   context 'with protected methods declared before private' do
-    let(:code) { <<-RUBY }
+    let(:code) { <<~RUBY }
       class MyClass
         def public_method
         end
@@ -165,7 +182,7 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
   end
 
   context 'with attribute macros before after validations' do
-    let(:code) { <<-RUBY }
+    let(:code) { <<~RUBY }
       class Person
         include AnotherModule
         extend SomeModule
@@ -211,7 +228,7 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
   end
 
   context 'constant is not a literal' do
-    it 'registers offense but does not autocorrect' do
+    it 'registers an offense but does not autocorrect' do
       expect_offense <<~RUBY
         class Person
           def name; end
@@ -252,14 +269,45 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
 
         LIMIT = 10
         ^^^^^^^^^^ `constants` is supposed to appear before `public_methods`.
+        CONST = 'wrong place'.freeze
+        RECURSIVE_BASIC_LITERALS_CONST = [1, 2].freeze
+        DYNAMIC_CONST = foo.freeze
       end
     RUBY
 
     expect_correction(<<~RUBY)
       class Foo
         LIMIT = 10
+        CONST = 'wrong place'.freeze
+        RECURSIVE_BASIC_LITERALS_CONST = [1, 2].freeze
         def name; end
 
+        DYNAMIC_CONST = foo.freeze
+      end
+    RUBY
+  end
+
+  it 'ignores misplaced private constants' do
+    expect_offense(<<~RUBY)
+      class Foo
+        def name; end
+
+        PRIVATE_CONST1 = 1
+        PRIVATE_CONST2 = 2
+        private_constant :PRIVATE_CONST1, :PRIVATE_CONST2
+        PUBLIC_CONST = 'public'
+        ^^^^^^^^^^^^^^^^^^^^^^^ `constants` is supposed to appear before `public_methods`.
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      class Foo
+        PUBLIC_CONST = 'public'
+        def name; end
+
+        PRIVATE_CONST1 = 1
+        PRIVATE_CONST2 = 2
+        private_constant :PRIVATE_CONST1, :PRIVATE_CONST2
       end
     RUBY
   end
@@ -315,7 +363,7 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
   end
 
   it 'registers an offense and corrects when xstr heredoc constant is defined after public method' do
-    expect_offense(<<~'RUBY')
+    expect_offense(<<~RUBY)
       class Foo
         def do_something
         end
@@ -327,7 +375,7 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
       end
     RUBY
 
-    expect_correction(<<~'RUBY')
+    expect_correction(<<~RUBY)
       class Foo
         CONSTANT = <<~`EOS`
           str
@@ -339,6 +387,37 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
     RUBY
   end
 
+  it 'registers an offense and corrects when public class method with heredoc after instance method' do
+    expect_offense(<<~RUBY)
+      class Foo
+        def instance_method
+          'instance method'
+        end
+
+        def self.class_method
+        ^^^^^^^^^^^^^^^^^^^^^ `public_class_methods` is supposed to appear before `public_methods`.
+          <<~EOS
+            class method
+          EOS
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      class Foo
+        def self.class_method
+          <<~EOS
+            class method
+          EOS
+        end
+        def instance_method
+          'instance method'
+        end
+
+      end
+    RUBY
+  end
+
   context 'when def modifier is used' do
     it 'registers an offense and corrects public method with modifier declared after private method with modifier' do
       expect_offense(<<~RUBY)
@@ -356,9 +435,9 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
         class A
           public def bar
           end
-
           private def foo
           end
+
         end
       RUBY
     end
@@ -379,9 +458,37 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
         class A
           def bar
           end
-
           private def foo
           end
+
+        end
+      RUBY
+    end
+
+    it 'registers an offense and corrects when definitions that need to be sorted are defined alternately' do
+      expect_offense(<<~RUBY)
+        class A
+          private def foo; end
+
+          def bar; end
+          ^^^^^^^^^^^^ `public_methods` is supposed to appear before `private_methods`.
+
+          private def baz; end
+
+          def qux; end
+          ^^^^^^^^^^^^ `public_methods` is supposed to appear before `private_methods`.
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        class A
+          def bar; end
+          def qux; end
+          private def foo; end
+
+
+          private def baz; end
+
         end
       RUBY
     end
@@ -403,10 +510,10 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
         class A
           def bar
           end
-
           def foo
           end
           private :foo
+
         end
       RUBY
     end
@@ -438,4 +545,65 @@ RSpec.describe RuboCop::Cop::Layout::ClassStructure, :config do
       RUBY
     end
   end
+
+  context 'when singleton class' do
+    context 'simple example' do
+      specify do
+        expect_offense <<~RUBY
+          class << self
+            CONST = 'wrong place'
+            include AnotherModule
+            ^^^^^^^^^^^^^^^^^^^^^ `module_inclusion` is supposed to appear before `constants`.
+            extend SomeModule
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          class << self
+            include AnotherModule
+            extend SomeModule
+            CONST = 'wrong place'
+          end
+        RUBY
+      end
+    end
+  end
+
+  context 'when constants is in the Categories' do
+    let(:config) do
+      RuboCop::Config.new(
+        'Layout/ClassStructure' => {
+          'ExpectedOrder' => %w[
+            all_constants
+            attribute_macros
+          ],
+          'Categories' => {
+            'all_constants' => %w[
+              constants
+            ],
+            'attribute_macros' => %w[
+              attr_accessor
+            ]
+          }
+        }
+      )
+    end
+
+    it 'registers an offense and corrects when attribute macros after constant' do
+      expect_offense(<<~RUBY)
+        class Foo
+          attr_accessor :foo
+          CONST = 'wrong place'
+          ^^^^^^^^^^^^^^^^^^^^^ `all_constants` is supposed to appear before `attribute_macros`.
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        class Foo
+          CONST = 'wrong place'
+          attr_accessor :foo
+        end
+      RUBY
+    end
+  end
 end
