@@ -45,8 +45,8 @@ RSpec.describe RuboCop::Cop::Layout::CommentIndentation, :config do
         | ^^^^^^^^^ Incorrect indentation detected (column 1 instead of 0).
         RUBY
 
-        expect_correction(<<-RUBY.strip_margin('|'))
-        |# comment
+        expect_correction(<<~RUBY)
+          # comment
         RUBY
       end
 
@@ -56,8 +56,8 @@ RSpec.describe RuboCop::Cop::Layout::CommentIndentation, :config do
         |  ^^^^^^^^^ Incorrect indentation detected (column 2 instead of 0).
         RUBY
 
-        expect_correction(<<-RUBY.strip_margin('|'))
-        |# comment
+        expect_correction(<<~RUBY)
+          # comment
         RUBY
       end
 
@@ -113,6 +113,13 @@ RSpec.describe RuboCop::Cop::Layout::CommentIndentation, :config do
               b
             end
             # this is accepted
+            case a
+            # this is accepted
+            in 0
+              #
+              b
+            end
+            # this is accepted
           rescue
           # this is accepted
           ensure
@@ -164,7 +171,6 @@ RSpec.describe RuboCop::Cop::Layout::CommentIndentation, :config do
     end
 
     it 'registers an offense and corrects' do
-      # FIXME
       expect_offense(<<~RUBY)
          # comment 1
          # comment 2
@@ -197,6 +203,19 @@ RSpec.describe RuboCop::Cop::Layout::CommentIndentation, :config do
              #
              ^ Incorrect indentation detected (column 5 instead of 4).
             b
+          when 2
+            # this is also accepted
+          end
+          case a
+          # this is accepted
+          in 0
+            # so is this
+          in 1
+          #
+          ^ Incorrect indentation detected (column 2 instead of 4).
+            b
+          in 2
+            # this is also accepted
           end
       RUBY
 
@@ -226,6 +245,18 @@ RSpec.describe RuboCop::Cop::Layout::CommentIndentation, :config do
           when 1
             #
             b
+          when 2
+            # this is also accepted
+          end
+          case a
+          # this is accepted
+          in 0
+            # so is this
+          in 1
+            #
+            b
+          in 2
+            # this is also accepted
           end
       RUBY
     end
@@ -234,7 +265,7 @@ RSpec.describe RuboCop::Cop::Layout::CommentIndentation, :config do
   context 'when allow_for_alignment is false' do
     let(:allow_for_alignment) { false }
 
-    include_examples 'any allow_for_alignment'
+    it_behaves_like 'any allow_for_alignment'
 
     it 'registers an offense for comments with extra indentation' do
       expect_offense(<<~RUBY)
@@ -266,7 +297,7 @@ RSpec.describe RuboCop::Cop::Layout::CommentIndentation, :config do
   context 'when allow_for_alignment is true' do
     let(:allow_for_alignment) { true }
 
-    include_examples 'any allow_for_alignment'
+    it_behaves_like 'any allow_for_alignment'
 
     it 'accepts comments with extra indentation if aligned with comment on previous line' do
       expect_no_offenses(<<~RUBY)
@@ -292,4 +323,54 @@ RSpec.describe RuboCop::Cop::Layout::CommentIndentation, :config do
       RUBY
     end
   end
+
+  context 'when `Layout/AccessModifierIndentation EnforcedStyle: outdent`' do
+    let(:indentation_width) { 2 }
+    let(:config) do
+      RuboCop::Config.new(
+        'Layout/AccessModifierIndentation' => {
+          'Enabled' => true,
+          'EnforcedStyle' => 'outdent'
+        },
+        'Layout/CommentIndentation' => {
+          'Enabled' => true
+        },
+        'Layout/IndentationWidth' => {
+          'Width' => indentation_width
+        }
+      )
+    end
+
+    it 'does not register an offense with indentation if aligned with code on previous line' do
+      expect_no_offenses(<<~RUBY)
+        class A
+          # rubocop:disable
+          def foo
+          end
+          # rubocop:enable
+
+        private
+
+          def bar
+          end
+        end
+      RUBY
+    end
+
+    it 'registers an offense with indentation if aligned with access modifier on next line' do
+      expect_offense(<<~RUBY)
+        class A
+          # rubocop:disable
+          def foo
+          end
+        # rubocop:enable
+        ^^^^^^^^^^^^^^^^ Incorrect indentation detected (column 0 instead of 2).
+        private
+
+          def bar
+          end
+        end
+      RUBY
+    end
+  end
 end
