@@ -210,6 +210,28 @@ RSpec.describe RuboCop::Cop::Layout::DotPosition, :config do
         end
       end
 
+      context 'with an xstr heredoc' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            my_method.
+                     ^ Place the . on the next line, together with the method name.
+              something(<<~`HERE`).
+                                  ^ Place the . on the next line, together with the method name.
+                ls -la
+              HERE
+              somethingelse
+          RUBY
+
+          expect_correction(<<~RUBY)
+            my_method
+              .something(<<~`HERE`)
+                ls -la
+              HERE
+              .somethingelse
+          RUBY
+        end
+      end
+
       context 'as the first argument' do
         it 'registers an offense' do
           expect_offense(<<~'RUBY')
@@ -234,7 +256,7 @@ RSpec.describe RuboCop::Cop::Layout::DotPosition, :config do
 
       context 'with multiple heredocs' do
         it 'registers an offense' do
-          expect_offense(<<~'RUBY')
+          expect_offense(<<~RUBY)
             my_method.
                      ^ Place the . on the next line, together with the method name.
               something(<<~HERE, <<~THERE).
@@ -246,7 +268,7 @@ RSpec.describe RuboCop::Cop::Layout::DotPosition, :config do
               somethingelse
           RUBY
 
-          expect_correction(<<~'RUBY')
+          expect_correction(<<~RUBY)
             my_method
               .something(<<~HERE, <<~THERE)
                 something
@@ -287,6 +309,25 @@ RSpec.describe RuboCop::Cop::Layout::DotPosition, :config do
         RUBY
       end
     end
+
+    context 'when the receiver is an `xstr` heredoc' do
+      it 'registers an offense' do
+        expect_offense(<<~RUBY)
+          <<~`HEREDOC`.
+                      ^ Place the . on the next line, together with the method name.
+            ls -la
+          HEREDOC
+            method_name
+        RUBY
+
+        expect_correction(<<~RUBY)
+          <<~`HEREDOC`
+            ls -la
+          HEREDOC
+            .method_name
+        RUBY
+      end
+    end
   end
 
   context 'Trailing dots style' do
@@ -416,6 +457,28 @@ RSpec.describe RuboCop::Cop::Layout::DotPosition, :config do
         end
       end
 
+      context 'with an `xstr` heredoc' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            my_method
+              .something(<<~`HERE`)
+              ^ Place the . on the previous line, together with the method call receiver.
+                ls -la
+              HERE
+              .somethingelse
+              ^ Place the . on the previous line, together with the method call receiver.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            my_method.
+              something(<<~`HERE`).
+                ls -la
+              HERE
+              somethingelse
+          RUBY
+        end
+      end
+
       context 'as the first argument' do
         it 'registers an offense' do
           expect_offense(<<~'RUBY')
@@ -440,7 +503,7 @@ RSpec.describe RuboCop::Cop::Layout::DotPosition, :config do
 
       context 'with multiple heredocs' do
         it 'registers an offense' do
-          expect_offense(<<~'RUBY')
+          expect_offense(<<~RUBY)
             my_method
               .something(<<~HERE, <<~THERE)
               ^ Place the . on the previous line, together with the method call receiver.
@@ -452,7 +515,7 @@ RSpec.describe RuboCop::Cop::Layout::DotPosition, :config do
               ^ Place the . on the previous line, together with the method call receiver.
           RUBY
 
-          expect_correction(<<~'RUBY')
+          expect_correction(<<~RUBY)
             my_method.
               something(<<~HERE, <<~THERE).
                 something
@@ -494,6 +557,25 @@ RSpec.describe RuboCop::Cop::Layout::DotPosition, :config do
       end
     end
 
+    context 'when the receiver is an `xstr` heredoc' do
+      it 'registers an offense' do
+        expect_offense(<<~RUBY)
+          <<~`HEREDOC`
+            ls -la
+          HEREDOC
+            .method_name
+            ^ Place the . on the previous line, together with the method call receiver.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          <<~`HEREDOC`.
+            ls -la
+          HEREDOC
+            method_name
+        RUBY
+      end
+    end
+
     context 'when there is a heredoc with a following method' do
       it 'does not register an offense for a heredoc' do
         expect_no_offenses(<<~RUBY)
