@@ -25,22 +25,24 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLineAfterGuardClause, :config do
     RUBY
   end
 
-  it 'registers an offense and corrects `next` guard clause not followed by empty line' do
-    expect_offense(<<~RUBY)
-      def foo
-        next unless need_next? # comment
-        ^^^^^^^^^^^^^^^^^^^^^^ Add empty line after guard clause.
-        foobar
-      end
-    RUBY
+  context 'Ruby <= 3.2', :ruby32, unsupported_on: :prism do
+    it 'registers an offense and corrects `next` guard clause not followed by empty line' do
+      expect_offense(<<~RUBY)
+        def foo
+          next unless need_next? # comment
+          ^^^^^^^^^^^^^^^^^^^^^^ Add empty line after guard clause.
+          foobar
+        end
+      RUBY
 
-    expect_correction(<<~RUBY)
-      def foo
-        next unless need_next? # comment
+      expect_correction(<<~RUBY)
+        def foo
+          next unless need_next? # comment
 
-        foobar
-      end
-    RUBY
+          foobar
+        end
+      RUBY
+    end
   end
 
   it 'registers an offense and corrects a guard clause is before `begin`' do
@@ -116,8 +118,7 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLineAfterGuardClause, :config do
   end
 
   it 'registers an offense and corrects a next guard clause not followed by ' \
-     'empty line when guard clause is after heredoc ' \
-     'including string interpolation' do
+     'empty line when guard clause is after heredoc including string interpolation' do
     expect_offense(<<~'RUBY')
       raise(<<-FAIL) unless true
         #{1 + 1}
@@ -137,7 +138,7 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLineAfterGuardClause, :config do
 
   it 'accepts a `raise` guard clause not followed by empty line when guard ' \
      'clause is after condition without method invocation' do
-    expect_no_offenses(<<~'RUBY')
+    expect_no_offenses(<<~RUBY)
       def foo
         raise unless $1 == o
 
@@ -327,6 +328,18 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLineAfterGuardClause, :config do
     RUBY
   end
 
+  it 'accepts using guard clause is after `:nocov:` comment' do
+    expect_no_offenses(<<~RUBY)
+      def foo
+        # :nocov:
+        return if condition
+        # :nocov:
+
+        bar
+      end
+    RUBY
+  end
+
   it 'accepts a guard clause inside oneliner block' do
     expect_no_offenses(<<~RUBY)
       def foo
@@ -336,6 +349,44 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLineAfterGuardClause, :config do
     RUBY
   end
 
+  it 'registers a guard clause outside difference line block' do
+    expect_offense(<<~RUBY)
+      return if condition
+      ^^^^^^^^^^^^^^^^^^^ Add empty line after guard clause.
+      foo do
+        bar
+      end
+      baz
+    RUBY
+
+    expect_correction(<<~RUBY)
+      return if condition
+
+      foo do
+        bar
+      end
+      baz
+    RUBY
+  end
+
+  it 'accepts a guard clause outside oneliner block' do
+    expect_no_offenses(<<~RUBY)
+      return if condition; foo do
+        bar
+      end
+      baz
+    RUBY
+  end
+
+  it 'accepts a guard clause outside oneliner numbered block' do
+    expect_no_offenses(<<~RUBY)
+      return if condition; foo do
+        bar(_1)
+      end
+      baz
+    RUBY
+  end
+
   it 'accepts multiple guard clauses' do
     expect_no_offenses(<<~RUBY)
       def foo
@@ -470,6 +521,43 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLineAfterGuardClause, :config do
     RUBY
   end
 
+  it 'accepts a guard clause that is after a multiline heredoc with parenthesized method call' do
+    expect_no_offenses(<<~RUBY)
+      def foo
+        raise ArgumentError, (<<~END.squish) unless guard
+          A multiline message
+          that will be squished.
+        END
+
+        return_value
+      end
+    RUBY
+  end
+
+  it 'does not register an offense when using `return` before guard condition with heredoc' do
+    expect_no_offenses(<<~RUBY)
+      def foo
+        return true if <<~TEXT.length > bar
+          hi
+        TEXT
+
+        false
+      end
+    RUBY
+  end
+
+  it 'does not register an offense when using `raise` before guard condition with heredoc' do
+    expect_no_offenses(<<~RUBY)
+      def foo
+        raise if <<~TEXT.length > bar
+          hi
+        TEXT
+
+        baz
+      end
+    RUBY
+  end
+
   it 'registers an offense and corrects a guard clause that is a ternary operator' do
     expect_offense(<<~RUBY)
       def foo
@@ -495,15 +583,15 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLineAfterGuardClause, :config do
   it 'registers an offense and corrects a method starting with end_' do
     expect_offense(<<~RUBY)
       def foo
-        next unless need_next?
-        ^^^^^^^^^^^^^^^^^^^^^^ Add empty line after guard clause.
+        return unless need_next?
+        ^^^^^^^^^^^^^^^^^^^^^^^^ Add empty line after guard clause.
         end_this!
       end
     RUBY
 
     expect_correction(<<~RUBY)
       def foo
-        next unless need_next?
+        return unless need_next?
 
         end_this!
       end
@@ -513,17 +601,17 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLineAfterGuardClause, :config do
   it 'registers an offense and corrects only the last guard clause' do
     expect_offense(<<~RUBY)
       def foo
-        next if foo?
-        next if bar?
-        ^^^^^^^^^^^^ Add empty line after guard clause.
+        return if foo?
+        return if bar?
+        ^^^^^^^^^^^^^^ Add empty line after guard clause.
         foobar
       end
     RUBY
 
     expect_correction(<<~RUBY)
       def foo
-        next if foo?
-        next if bar?
+        return if foo?
+        return if bar?
 
         foobar
       end
@@ -593,6 +681,12 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLineAfterGuardClause, :config do
     RUBY
   end
 
+  it 'does not register an offense when calling a method on the result of a single-line `if` with `return`' do
+    expect_no_offenses(<<~RUBY)
+      if cond then return end.then { 42 }
+    RUBY
+  end
+
   it 'does not register an offense when the clause ends with a semicolon but is followed by a newline' do
     expect_no_offenses(<<~RUBY)
       def foo(item)
