@@ -334,6 +334,156 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundAccessModifier, :config do
           #{access_modifier}
         RUBY
       end
+
+      it 'accepts when an access modifier and an expression are on the same line' do
+        expect_no_offenses(<<~RUBY)
+          #{access_modifier}; foo
+          .bar
+        RUBY
+      end
+
+      context 'inside an implicit `begin` node' do
+        it 'registers an offense and corrects' do
+          expect_offense(<<~RUBY, access_modifier: access_modifier)
+            foo
+            %{access_modifier}
+            ^{access_modifier} Keep a blank line before and after `%{access_modifier}`.
+            bar
+          RUBY
+
+          expect_correction(<<~RUBY)
+            foo
+
+            #{access_modifier}
+
+            bar
+          RUBY
+        end
+      end
+
+      context 'when `Layout/EmptyLinesAroundBlockBody` is configured with `EnforcedStyle: no_empty_lines`' do
+        let(:other_cops) do
+          { 'Layout/EmptyLinesAroundBlockBody' => { 'EnforcedStyle' => 'no_empty_lines' } }
+        end
+
+        context 'access modifier is the only child of the block' do
+          it 'registers an offense but does not correct' do
+            expect_offense(<<~RUBY, access_modifier: access_modifier)
+              Module.new do
+                %{access_modifier}
+                ^{access_modifier} Keep a blank line after `%{access_modifier}`.
+              end
+            RUBY
+
+            expect_no_corrections
+          end
+        end
+
+        context 'access modifier is the first child of the block' do
+          it 'registers an offense and corrects' do
+            expect_offense(<<~RUBY, access_modifier: access_modifier)
+              Module.new do
+                %{access_modifier}
+                ^{access_modifier} Keep a blank line after `%{access_modifier}`.
+                foo
+              end
+            RUBY
+
+            expect_correction(<<~RUBY)
+              Module.new do
+                #{access_modifier}
+
+                foo
+              end
+            RUBY
+          end
+        end
+
+        context 'access modifier is the last child of the block' do
+          it 'registers an offense and partially corrects' do
+            expect_offense(<<~RUBY, access_modifier: access_modifier)
+              Module.new do
+                foo
+                %{access_modifier}
+                ^{access_modifier} Keep a blank line before and after `%{access_modifier}`.
+              end
+            RUBY
+
+            expect_correction(<<~RUBY)
+              Module.new do
+                foo
+
+                #{access_modifier}
+              end
+            RUBY
+          end
+        end
+      end
+
+      context 'when `Layout/EmptyLinesAroundBlockBody` is configured with `EnforcedStyle: empty_lines`' do
+        let(:other_cops) do
+          { 'Layout/EmptyLinesAroundBlockBody' => { 'EnforcedStyle' => 'empty_lines' } }
+        end
+
+        context 'access modifier is the only child of the block' do
+          it 'registers an offense and corrects' do
+            expect_offense(<<~RUBY, access_modifier: access_modifier)
+              Module.new do
+                %{access_modifier}
+                ^{access_modifier} Keep a blank line after `%{access_modifier}`.
+              end
+            RUBY
+
+            expect_correction(<<~RUBY)
+              Module.new do
+                #{access_modifier}
+
+              end
+            RUBY
+          end
+        end
+
+        context 'access modifier is the first child of the block' do
+          it 'registers an offense and corrects' do
+            expect_offense(<<~RUBY, access_modifier: access_modifier)
+              Module.new do
+                %{access_modifier}
+                ^{access_modifier} Keep a blank line after `%{access_modifier}`.
+                foo
+              end
+            RUBY
+
+            expect_correction(<<~RUBY)
+              Module.new do
+                #{access_modifier}
+
+                foo
+              end
+            RUBY
+          end
+        end
+
+        context 'access modifier is the last child of the block' do
+          it 'registers an offense and corrects' do
+            expect_offense(<<~RUBY, access_modifier: access_modifier)
+              Module.new do
+                foo
+                %{access_modifier}
+                ^{access_modifier} Keep a blank line before and after `%{access_modifier}`.
+              end
+            RUBY
+
+            expect_correction(<<~RUBY)
+              Module.new do
+                foo
+
+                #{access_modifier}
+
+              end
+            RUBY
+          end
+        end
+      end
     end
   end
 
@@ -416,6 +566,12 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundAccessModifier, :config do
           end
         RUBY
       end
+
+      it 'does not register an offense when modifier is on the last line' do
+        expect_no_offenses(<<~RUBY)
+          #{access_modifier}
+        RUBY
+      end
     end
   end
 
@@ -451,4 +607,37 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundAccessModifier, :config do
       end
     end
   end
+
+  context 'Ruby 3.4', :ruby34 do
+    %w[private protected public module_function].each do |access_modifier|
+      it "registers an offense for missing around line before #{access_modifier}" do
+        expect_offense(<<~RUBY)
+          included do
+            it
+            #{access_modifier}
+            #{'^' * access_modifier.size} Keep a blank line before and after `#{access_modifier}`.
+            def test; end
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          included do
+            it
+
+            #{access_modifier}
+
+            def test; end
+          end
+        RUBY
+      end
+
+      it "ignores #{access_modifier} with itblock argument" do
+        expect_no_offenses(<<~RUBY)
+          def foo
+            #{access_modifier} { it }
+          end
+        RUBY
+      end
+    end
+  end
 end
