@@ -202,7 +202,7 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundArguments, :config do
       end
     end
 
-    it 'registers autocorrects empty line whetn args start on definition line' do
+    it 'registers autocorrects empty line when args start on definition line' do
       expect_offense(<<~RUBY)
         bar(qux,
 
@@ -300,6 +300,14 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundArguments, :config do
       RUBY
     end
 
+    it 'ignores a multiline string with only whitespace on one line and []-style method call after' do
+      expect_no_offenses(<<~RUBY)
+        format('%d
+
+        ', 1)[0]
+      RUBY
+    end
+
     context 'with one argument' do
       it 'ignores empty lines inside of method arguments' do
         expect_no_offenses(<<~RUBY)
