@@ -72,6 +72,28 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundClassBody, :config do
         end
       RUBY
     end
+
+    it 'registers an offense when a class body starts with a blank line and defines a multiline superclass' do
+      expect_offense(<<~RUBY)
+        class SomeClass < Struct.new(
+          :attr,
+          keyword_init: true
+        )
+
+        ^{} #{extra_begin}
+          do_something
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        class SomeClass < Struct.new(
+          :attr,
+          keyword_init: true
+        )
+          do_something
+        end
+      RUBY
+    end
   end
 
   context 'when EnforcedStyle is empty_lines' do
@@ -161,7 +183,7 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundClassBody, :config do
         RUBY
       end
 
-      it 'registers offense for namespace body starting with a blank' do
+      it 'registers an offense for namespace body starting with a blank' do
         expect_offense(<<~RUBY)
           class Parent
 
@@ -175,7 +197,7 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundClassBody, :config do
         RUBY
       end
 
-      it 'registers offense for namespace body ending with a blank' do
+      it 'registers an offense for namespace body ending with a blank' do
         expect_offense(<<~RUBY)
           class Parent
             class Child
@@ -251,7 +273,7 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundClassBody, :config do
         RUBY
       end
 
-      it 'registers offense for namespace body starting with a blank' do
+      it 'registers an offense for namespace body starting with a blank' do
         expect_offense(<<~RUBY)
           class Parent
 
@@ -263,7 +285,7 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundClassBody, :config do
         RUBY
       end
 
-      it 'registers offense for namespace body ending with a blank' do
+      it 'registers an offense for namespace body ending with a blank' do
         expect_offense(<<~RUBY)
           class Parent
             module Child
@@ -375,5 +397,5 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLinesAroundClassBody, :config do
     end
   end
 
-  include_examples 'empty_lines_around_class_or_module_body', 'class'
+  it_behaves_like 'empty_lines_around_class_or_module_body', 'class'
 end
