@@ -132,6 +132,50 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
         RUBY
       end
 
+      it 'registers an offense and corrects over-indented first arguments in nested method calls' do
+        expect_offense(<<~RUBY)
+          foo
+            .bar(
+            baz(
+            ^^^^ Indent the first argument one step more than the start of the previous line.
+                qux
+                ^^^ Bad indentation of the first argument.
+              )
+            )
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo
+            .bar(
+              baz(
+                qux
+                )
+            )
+        RUBY
+      end
+
+      it 'registers an offense and corrects over-indented first arguments in nested method calls with hash arguments' do
+        expect_offense(<<~RUBY)
+          foo
+            .bar(
+            bar(
+            ^^^^ Indent the first argument one step more than the start of the previous line.
+                key: value
+                ^^^^^^^^^^ Bad indentation of the first argument.
+              )
+            )
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo
+            .bar(
+              bar(
+                key: value
+                )
+            )
+        RUBY
+      end
+
       context 'when using safe navigation operator' do
         it 'registers an offense and corrects an under-indented 1st argument' do
           expect_offense(<<~RUBY)
@@ -358,7 +402,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
     let(:style) { 'special_for_inner_method_call' }
     let(:indentation_width) { 2 }
 
-    include_examples 'common behavior'
+    it_behaves_like 'common behavior'
 
     context 'for method calls within method calls' do
       context 'with outer parentheses' do
@@ -374,6 +418,23 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
                         bar: 3))
           RUBY
         end
+
+        it 'corrects only the first argument in a method chain, not the entire chain' do
+          expect_offense(<<~RUBY)
+            run(:foo, Diagnostic.where(
+                          'limit >= 10',
+                          ^^^^^^^^^^^^^ Indent the first argument one step more than the start of the previous line.
+                        )
+                        .ids)
+          RUBY
+
+          expect_correction(<<~RUBY)
+            run(:foo, Diagnostic.where(
+              'limit >= 10',
+                        )
+                        .ids)
+          RUBY
+        end
       end
 
       context 'without outer parentheses' do
@@ -383,6 +444,79 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
                         bar: 3)
           RUBY
         end
+
+        it 'corrects only the first argument in a method chain, not the entire chain' do
+          expect_offense(<<~RUBY)
+            run :foo, Diagnostic.where(
+                          'limit >= 10',
+                          ^^^^^^^^^^^^^ Indent the first argument one step more than the start of the previous line.
+                        )
+                        .ids
+          RUBY
+
+          expect_correction(<<~RUBY)
+            run :foo, Diagnostic.where(
+              'limit >= 10',
+                        )
+                        .ids
+          RUBY
+        end
+      end
+    end
+
+    context 'for method chains' do
+      it 'corrects only the first argument, not the entire method chain' do
+        expect_offense(<<~RUBY)
+          sequences = CourseSequence
+            .includes(
+                course_sequence_memberships: {
+                ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Indent the first argument one step more than the start of the previous line.
+                  course: :course_components
+                }
+              )
+            .joins(:courses)
+        RUBY
+
+        expect_correction(<<~RUBY)
+          sequences = CourseSequence
+            .includes(
+              course_sequence_memberships: {
+                course: :course_components
+              }
+              )
+            .joins(:courses)
+        RUBY
+      end
+
+      it 'corrects an under-indented first argument in a method chain' do
+        expect_offense(<<~RUBY)
+          result = Foo
+            .bar(
+          x: 1
+          ^^^^ Indent the first argument one step more than the start of the previous line.
+            )
+            .baz
+        RUBY
+
+        expect_correction(<<~RUBY)
+          result = Foo
+            .bar(
+              x: 1
+            )
+            .baz
+        RUBY
+      end
+
+      it 'accepts properly indented first argument in a method chain' do
+        expect_no_offenses(<<~RUBY)
+          sequences = CourseSequence
+            .includes(
+              course_sequence_memberships: {
+                course: :course_components
+              }
+            )
+            .joins(:courses)
+        RUBY
       end
     end
   end
@@ -391,7 +525,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
     let(:style) { 'special_for_inner_method_call_in_parentheses' }
     let(:indentation_width) { 2 }
 
-    include_examples 'common behavior'
+    it_behaves_like 'common behavior'
 
     context 'for method calls within method calls' do
       context 'with outer parentheses' do
@@ -441,6 +575,77 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
                                a))
           RUBY
         end
+
+        it 'corrects the entire method call when closing parenthesis is on a separate line' do
+          expect_offense(<<~RUBY)
+            instance_variable_set(
+              "@diagnostics",
+              Diagnostic.where(
+                          'limit >= 10 and limit < 100',
+                          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Indent the first argument one step more than `Diagnostic.where(`.
+                        )
+            )
+          RUBY
+
+          expect_correction(<<~RUBY)
+            instance_variable_set(
+              "@diagnostics",
+              Diagnostic.where(
+                'limit >= 10 and limit < 100',
+              )
+            )
+          RUBY
+        end
+
+        it 'corrects the entire method call with multiple arguments' do
+          expect_offense(<<~RUBY)
+            instance_variable_set(
+              "@diagnostics",
+              Diagnostic.where(
+                    'limit >= ? and limit < ?',
+                    ^^^^^^^^^^^^^^^^^^^^^^^^^^ Indent the first argument one step more than `Diagnostic.where(`.
+                    LIMITS[:lowest_value], LIMITS[:highest_value]
+                  )
+            )
+          RUBY
+
+          expect_correction(<<~RUBY)
+            instance_variable_set(
+              "@diagnostics",
+              Diagnostic.where(
+                'limit >= ? and limit < ?',
+                LIMITS[:lowest_value], LIMITS[:highest_value]
+              )
+            )
+          RUBY
+        end
+
+        it 'corrects the entire method call chain' do
+          expect_offense(<<~RUBY)
+            instance_variable_set(
+              "@diagnostic_ids",
+              Diagnostic.where(
+                    'limit >= ? and limit < ?',
+                    ^^^^^^^^^^^^^^^^^^^^^^^^^^ Indent the first argument one step more than the start of the previous line.
+                    LIMITS[:lowest_value], LIMITS[:highest_value]
+                  )
+                  .where(id: 1)
+                  .ids,
+            )
+          RUBY
+
+          expect_correction(<<~RUBY)
+            instance_variable_set(
+              "@diagnostic_ids",
+              Diagnostic.where(
+                'limit >= ? and limit < ?',
+                LIMITS[:lowest_value], LIMITS[:highest_value]
+              )
+              .where(id: 1)
+              .ids,
+            )
+          RUBY
+        end
       end
 
       context 'without outer parentheses' do
@@ -450,6 +655,60 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
               bar: 3)
           RUBY
         end
+
+        it 'corrects only the first argument in a method chain, not the entire chain' do
+          expect_offense(<<~RUBY)
+            run :foo, Diagnostic.where(
+                          'limit >= 10',
+                          ^^^^^^^^^^^^^ Indent the first argument one step more than the start of the previous line.
+                        )
+                        .ids
+          RUBY
+
+          expect_correction(<<~RUBY)
+            run :foo, Diagnostic.where(
+              'limit >= 10',
+                        )
+                        .ids
+          RUBY
+        end
+      end
+    end
+
+    context 'for method chains' do
+      it 'corrects only the first argument when not inside a parenthesized call' do
+        expect_offense(<<~RUBY)
+          sequences = CourseSequence
+            .includes(
+                course_sequence_memberships: {
+                ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Indent the first argument one step more than the start of the previous line.
+                  course: :course_components
+                }
+              )
+            .joins(:courses)
+        RUBY
+
+        expect_correction(<<~RUBY)
+          sequences = CourseSequence
+            .includes(
+              course_sequence_memberships: {
+                course: :course_components
+              }
+              )
+            .joins(:courses)
+        RUBY
+      end
+
+      it 'accepts properly indented first argument in a method chain' do
+        expect_no_offenses(<<~RUBY)
+          sequences = CourseSequence
+            .includes(
+              course_sequence_memberships: {
+                course: :course_components
+              }
+            )
+            .joins(:courses)
+        RUBY
       end
     end
   end
@@ -458,7 +717,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
     let(:style) { 'consistent' }
     let(:indentation_width) { 2 }
 
-    include_examples 'common behavior'
+    it_behaves_like 'common behavior'
 
     context 'for method calls within method calls' do
       it 'registers an offense and corrects an over-indented first argument' do
@@ -480,6 +739,100 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
             :error, :token, { :token => name }, location))
         RUBY
       end
+
+      context 'with outer parentheses' do
+        it 'corrects only the first argument in a method chain, not the entire chain' do
+          expect_offense(<<~RUBY)
+            run(:foo, Diagnostic.where(
+                          'limit >= 10',
+                          ^^^^^^^^^^^^^ Indent the first argument one step more than the start of the previous line.
+                        )
+                        .ids)
+          RUBY
+
+          expect_correction(<<~RUBY)
+            run(:foo, Diagnostic.where(
+              'limit >= 10',
+                        )
+                        .ids)
+          RUBY
+        end
+      end
+
+      context 'without outer parentheses' do
+        it 'corrects only the first argument in a method chain, not the entire chain' do
+          expect_offense(<<~RUBY)
+            run :foo, Diagnostic.where(
+                          'limit >= 10',
+                          ^^^^^^^^^^^^^ Indent the first argument one step more than the start of the previous line.
+                        )
+                        .ids
+          RUBY
+
+          expect_correction(<<~RUBY)
+            run :foo, Diagnostic.where(
+              'limit >= 10',
+                        )
+                        .ids
+          RUBY
+        end
+      end
+    end
+
+    context 'for method chains' do
+      it 'corrects only the first argument, not the entire method chain' do
+        expect_offense(<<~RUBY)
+          sequences = CourseSequence
+            .includes(
+                course_sequence_memberships: {
+                ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Indent the first argument one step more than the start of the previous line.
+                  course: :course_components
+                }
+              )
+            .joins(:courses)
+        RUBY
+
+        expect_correction(<<~RUBY)
+          sequences = CourseSequence
+            .includes(
+              course_sequence_memberships: {
+                course: :course_components
+              }
+              )
+            .joins(:courses)
+        RUBY
+      end
+
+      it 'corrects an under-indented first argument in a method chain' do
+        expect_offense(<<~RUBY)
+          result = Foo
+            .bar(
+          x: 1
+          ^^^^ Indent the first argument one step more than the start of the previous line.
+            )
+            .baz
+        RUBY
+
+        expect_correction(<<~RUBY)
+          result = Foo
+            .bar(
+              x: 1
+            )
+            .baz
+        RUBY
+      end
+
+      it 'accepts properly indented first argument in a method chain' do
+        expect_no_offenses(<<~RUBY)
+          sequences = CourseSequence
+            .includes(
+              course_sequence_memberships: {
+                course: :course_components
+              }
+            )
+            .joins(:courses)
+        RUBY
+      end
     end
   end
 
@@ -545,7 +898,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
       end
 
       context 'for assignment' do
-        it 'register an offense and corrects a correctly indented first ' \
+        it 'registers an offense and corrects a correctly indented first ' \
            'argument and does not care about the second argument' do
           expect_offense(<<~RUBY)
             x = run(
@@ -718,6 +1071,62 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
               ).freeze
         RUBY
       end
+
+      context 'for method chains' do
+        it 'corrects only the first argument, not the entire method chain' do
+          expect_offense(<<~RUBY)
+            sequences = CourseSequence
+              .includes(
+                  course_sequence_memberships: {
+                  ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Indent the first argument one step more than the start of the previous line.
+                    course: :course_components
+                  }
+                )
+              .joins(:courses)
+          RUBY
+
+          expect_correction(<<~RUBY)
+            sequences = CourseSequence
+              .includes(
+                course_sequence_memberships: {
+                  course: :course_components
+                }
+                )
+              .joins(:courses)
+          RUBY
+        end
+
+        it 'corrects an under-indented first argument in a method chain' do
+          expect_offense(<<~RUBY)
+            result = Foo
+              .bar(
+            x: 1
+            ^^^^ Indent the first argument one step more than the start of the previous line.
+              )
+              .baz
+          RUBY
+
+          expect_correction(<<~RUBY)
+            result = Foo
+              .bar(
+                x: 1
+              )
+              .baz
+          RUBY
+        end
+
+        it 'accepts properly indented first argument in a method chain' do
+          expect_no_offenses(<<~RUBY)
+            sequences = CourseSequence
+              .includes(
+                course_sequence_memberships: {
+                  course: :course_components
+                }
+              )
+              .joins(:courses)
+          RUBY
+        end
+      end
     end
 
     context 'when IndentationWidth:Width is 4' do
@@ -808,6 +1217,23 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
                         )
           RUBY
         end
+
+        it 'corrects only the first argument in a method chain, not the entire chain' do
+          expect_offense(<<~RUBY)
+            run(:foo, Diagnostic.where(
+                          'limit >= 10',
+                          ^^^^^^^^^^^^^ Indent the first argument one step more than `Diagnostic.where(`.
+                        )
+                        .ids)
+          RUBY
+
+          expect_correction(<<~RUBY)
+            run(:foo, Diagnostic.where(
+                        'limit >= 10',
+                        )
+                        .ids)
+          RUBY
+        end
       end
 
       context 'without outer parentheses' do
@@ -830,6 +1256,23 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
                                   bar: 3))
           RUBY
         end
+
+        it 'corrects only the first argument in a method chain, not the entire chain' do
+          expect_offense(<<~RUBY)
+            run :foo, Diagnostic.where(
+                          'limit >= 10',
+                          ^^^^^^^^^^^^^ Indent the first argument one step more than `Diagnostic.where(`.
+                        )
+                        .ids
+          RUBY
+
+          expect_correction(<<~RUBY)
+            run :foo, Diagnostic.where(
+                        'limit >= 10',
+                        )
+                        .ids
+          RUBY
+        end
       end
     end
   end
