@@ -68,7 +68,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
   context 'always inspect last argument hash' do
     let(:cop_config) { { 'EnforcedLastArgumentHashStyle' => 'always_inspect' } }
 
-    it 'registers offense and corrects misaligned keys in implicit hash' do
+    it 'registers an offense and corrects misaligned keys in implicit hash' do
       expect_offense(<<~RUBY)
         func(a: 0,
           b: 1)
@@ -81,7 +81,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers offense and corrects misaligned keys in explicit hash' do
+    it 'registers an offense and corrects misaligned keys in explicit hash' do
       expect_offense(<<~RUBY)
         func({a: 0,
           b: 1})
@@ -146,8 +146,34 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
+    it 'registers an offense and corrects misaligned keys in implicit hash for safe navigation' do
+      expect_offense(<<~RUBY)
+        foo&.bar(a: 0,
+          b: 1)
+          ^^^^ Align the keys of a hash literal if they span more than one line.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        foo&.bar(a: 0,
+                 b: 1)
+      RUBY
+    end
+
+    it 'registers an offense and corrects misaligned keys in explicit hash for safe navigation' do
+      expect_offense(<<~RUBY)
+        foo&.bar({a: 0,
+          b: 1})
+          ^^^^ Align the keys of a hash literal if they span more than one line.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        foo&.bar({a: 0,
+                  b: 1})
+      RUBY
+    end
+
     context 'when using hash value omission', :ruby31 do
-      it 'registers offense and corrects misaligned keys in implicit hash' do
+      it 'registers an offense and corrects misaligned keys in implicit hash' do
         expect_offense(<<~RUBY)
           func(a:,
             b:)
@@ -160,7 +186,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
         RUBY
       end
 
-      it 'registers offense and corrects misaligned keys in explicit hash' do
+      it 'registers an offense and corrects misaligned keys in explicit hash' do
         expect_offense(<<~RUBY)
           func({a:,
             b:})
@@ -178,7 +204,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
   context 'when `EnforcedStyle: with_fixed_indentation` of `ArgumentAlignment`' do
     let(:argument_alignment_config) { { 'EnforcedStyle' => 'with_fixed_indentation' } }
 
-    it 'register and corrects an offense' do
+    it 'registers and corrects an offense' do
       expect_offense(<<~RUBY)
         THINGS = {
           oh: :io,
@@ -219,7 +245,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
     end
 
     context 'when using hash value omission', :ruby31 do
-      it 'register and corrects an offense' do
+      it 'registers and corrects an offense' do
         expect_offense(<<~RUBY)
           THINGS = {
             oh:,
@@ -236,7 +262,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
         RUBY
       end
 
-      it 'does not register and corrects an offense when using aligned keyword arguments' do
+      it 'does not register an offense when using aligned keyword arguments' do
         expect_no_offenses(<<~RUBY)
           config.fog_credentials_as_kwargs(
             provider:,
@@ -268,6 +294,33 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
         proc.(key: value)
       RUBY
     end
+
+    it 'does not register an offense for a method with a positional argument' do
+      expect_no_offenses(<<~RUBY)
+        do_something(
+          foo, baz: true,
+          quux: false
+        )
+      RUBY
+    end
+
+    it 'does not register an offense for a method with a positional argument that spans multiple lines' do
+      expect_no_offenses(<<~RUBY)
+        do_something(
+          foo(
+            bar
+          ), baz: true,
+          quux: false
+        )
+      RUBY
+    end
+
+    it 'does not register an offense when a multiline hash starts on the same line as an implicit `call`' do
+      expect_no_offenses(<<~RUBY)
+        do_something.(foo: bar, baz: qux,
+          quux: corge)
+      RUBY
+    end
   end
 
   context 'always ignore last argument hash' do
@@ -314,6 +367,20 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
           b: 1})
       RUBY
     end
+
+    it 'accepts misaligned keys in implicit hash for safe navigation' do
+      expect_no_offenses(<<~RUBY)
+        foo&.bar(a: 0,
+          b: 1)
+      RUBY
+    end
+
+    it 'accepts misaligned keys in explicit hash for safe navigation' do
+      expect_no_offenses(<<~RUBY)
+        foo&.bar({a: 0,
+          b: 1})
+      RUBY
+    end
   end
 
   context 'ignore implicit last argument hash' do
@@ -378,6 +445,26 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
                b: 1})
       RUBY
     end
+
+    it 'accepts misaligned keys in implicit hash for safe navigation' do
+      expect_no_offenses(<<~RUBY)
+        foo&.bar(a: 0,
+          b: 1)
+      RUBY
+    end
+
+    it 'registers an offense and corrects misaligned keys in explicit hash for safe navigation' do
+      expect_offense(<<~RUBY)
+        foo&.bar({a: 0,
+          b: 1})
+          ^^^^ Align the keys of a hash literal if they span more than one line.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        foo&.bar({a: 0,
+                  b: 1})
+      RUBY
+    end
   end
 
   context 'ignore explicit last argument hash' do
@@ -464,6 +551,26 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
           b: 1})
       RUBY
     end
+
+    it 'registers an offense and corrects misaligned keys in implicit hash for safe navigation' do
+      expect_offense(<<~RUBY)
+        foo&.bar(a: 0,
+          b: 1)
+          ^^^^ Align the keys of a hash literal if they span more than one line.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        foo&.bar(a: 0,
+                 b: 1)
+      RUBY
+    end
+
+    it 'accepts misaligned keys in explicit hash for safe navigation' do
+      expect_no_offenses(<<~RUBY)
+        foo&.bar({a: 0,
+          b: 1})
+      RUBY
+    end
   end
 
   context 'with default configuration' do
@@ -718,7 +825,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
     end
   end
 
-  include_examples 'not on separate lines'
+  it_behaves_like 'not on separate lines'
 
   context 'with table alignment configuration' do
     let(:cop_config) do
@@ -728,7 +835,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       }
     end
 
-    include_examples 'not on separate lines'
+    it_behaves_like 'not on separate lines'
 
     it 'accepts aligned hash keys and values' do
       expect_no_offenses(<<~RUBY)
@@ -1000,7 +1107,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    include_examples 'not on separate lines'
+    it_behaves_like 'not on separate lines'
 
     it 'registers an offense and corrects mixed indentation and spacing' do
       expect_offense(<<~RUBY)
@@ -1268,6 +1375,23 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
           }
         RUBY
       end
+
+      it 'corrects a hash with mixed separators into table alignment' do
+        expect_offense(<<~RUBY)
+          other = {
+            foo:  1,
+            ^^^^^^^ Align the keys and values of a hash literal if they span more than one line.
+            'bar' => 2,
+          }
+        RUBY
+
+        expect_correction(<<~RUBY)
+          other = {
+            foo:     1,
+            'bar' => 2,
+          }
+        RUBY
+      end
     end
   end
 
@@ -1319,11 +1443,11 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
     end
   end
 
-  it 'register no offense for superclass call without args' do
+  it 'registers no offense for superclass call without args' do
     expect_no_offenses('super')
   end
 
-  it 'register no offense for yield without args' do
+  it 'registers no offense for yield without args' do
     expect_no_offenses('yield')
   end
 
@@ -1351,7 +1475,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
 
     context 'when using hash value omission', :ruby31 do
       context 'and aligned keys' do
-        it 'does not register an offense and corrects' do
+        it 'does not register an offense' do
           expect_no_offenses(<<~RUBY)
             foo ab: 1,
                 c:
@@ -1360,6 +1484,57 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       end
     end
 
+    context 'when using anonymous keyword rest arguments', :ruby32 do
+      context 'and forwarded keyword rest argument after a hash key' do
+        it 'registers an offense on the misaligned key and corrects' do
+          expect_offense(<<~RUBY)
+            def foo(**)
+              bar ab: 1,
+                  c: 2, **
+                  ^^^^ Align the keys and values of a hash literal if they span more than one line.
+            end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            def foo(**)
+              bar ab: 1,
+                  c:  2, **
+            end
+          RUBY
+        end
+      end
+
+      context 'and aligned keys but forwarded keyword rest argument after' do
+        it 'does not register an offense on the `forwarded_kwrestarg`' do
+          expect_no_offenses(<<~RUBY)
+            def foo(**)
+              bar a: 1,
+                  b: 2, **
+            end
+          RUBY
+        end
+      end
+
+      context 'and a misaligned forwarded keyword rest argument' do
+        it 'registers an offense and corrects' do
+          expect_offense(<<~RUBY)
+            def foo(**)
+              bar a: 1,
+                    **
+                    ^^ Align keyword splats with the rest of the hash if it spans more than one line.
+            end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            def foo(**)
+              bar a: 1,
+                  **
+            end
+          RUBY
+        end
+      end
+    end
+
     context 'when the only item is a kwsplat' do
       it 'does not register an offense' do
         expect_no_offenses(<<~RUBY)
