@@ -11,7 +11,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
     end
 
     it 'accepts when using access modifier at the top level' do
-      expect_no_offenses(<<~'RUBY')
+      expect_no_offenses(<<~RUBY)
         public
 
         def foo
@@ -21,7 +21,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
 
     it 'registers and corrects an offense when using access modifier and indented method definition ' \
        'at the top level' do
-      expect_offense(<<~'RUBY')
+      expect_offense(<<~RUBY)
         public
 
           def foo
@@ -29,7 +29,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
           end
       RUBY
 
-      expect_correction(<<~'RUBY')
+      expect_correction(<<~RUBY)
         public
 
         def foo
