@@ -7,7 +7,8 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
       'Layout/AccessModifierIndentation' => access_modifier_config,
       'Layout/IndentationConsistency' => consistency_config,
       'Layout/EndAlignment' => end_alignment_config,
-      'Layout/DefEndAlignment' => def_end_alignment_config
+      'Layout/DefEndAlignment' => def_end_alignment_config,
+      'Layout/IndentationStyle' => indentation_style_config
     )
   end
   let(:access_modifier_config) { { 'EnforcedStyle' => 'indent' } }
@@ -16,9 +17,21 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
   let(:def_end_alignment_config) do
     { 'Enabled' => true, 'EnforcedStyleAlignWith' => 'start_of_line' }
   end
+  let(:indentation_style_config) { { 'EnforcedStyle' => 'spaces' } }
+  let(:width) { 2 }
+  let(:enforced_style_align_with) { 'start_of_line' }
+  let(:allowed_patterns) { [] }
+  let(:cop_config) do
+    {
+      'Width' => width,
+      'EnforcedStyleAlignWith' => enforced_style_align_with,
+      'SupportedStylesAlignWith' => %w[start_of_line relative_to_receiver],
+      'AllowedPatterns' => allowed_patterns
+    }
+  end
 
   context 'with Width set to 4' do
-    let(:cop_config) { { 'Width' => 4 } }
+    let(:width) { 4 }
 
     context 'for a file with byte order mark' do
       let(:bom) { "\xef\xbb\xbf" }
@@ -34,12 +47,8 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
     end
 
     context 'with ignored patterns set' do
-      let(:cop_config) do
-        {
-          'Width' => 4,
-          'AllowedPatterns' => ['^\s*module', '^\s*(els)?if.*[A-Z][a-z]+']
-        }
-      end
+      let(:width) { 4 }
+      let(:allowed_patterns) { ['^\s*module', '^\s*(els)?if.*[A-Z][a-z]+'] }
 
       it 'accepts unindented lines for those keywords' do
         expect_no_offenses(<<~RUBY)
@@ -71,6 +80,62 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
       end
     end
 
+    context 'with tabs indentation' do
+      let(:indentation_style_config) { { 'EnforcedStyle' => 'tabs' } }
+
+      it 'accepts correctly indented code with tabs' do
+        expect_no_offenses(<<-RUBY.gsub(/^      /, ''))
+        class A
+        \tdef test
+        \t\tputs 'hello'
+        \tend
+        end
+        RUBY
+      end
+
+      it 'accepts correctly indented if statement with tabs' do
+        expect_no_offenses(<<-RUBY.gsub(/^      /, ''))
+        if cond
+        \tfunc
+        end
+        RUBY
+      end
+
+      it 'detects excessive tab indentation in if statement' do
+        expect_offense(<<-RUBY.gsub(/^        /, ''))
+        if cond
+        \t\tfunc
+        ^^ Use 1 (not 2) tabs for indentation.
+        end
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'detects insufficient tab indentation in class' do
+        expect_offense(<<-RUBY.gsub(/^        /, ''))
+        class A
+        def test
+        ^{} Use 1 (not 0) tabs for indentation.
+        end
+        end
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'detects excessive tab indentation' do
+        expect_offense(<<-RUBY.gsub(/^        /, ''))
+        def test
+        \t\t\tputs 'hello'
+        ^^^ Use 1 (not 3) tabs for indentation.
+        end
+        RUBY
+
+        expect_no_corrections
+      end
+    end
+
     it 'registers and corrects offense for bad indentation' do
       expect_offense(<<~RUBY)
         if a1
@@ -100,7 +165,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
   end
 
   context 'with Width set to 2' do
-    let(:cop_config) { { 'Width' => 2 } }
+    let(:width) { 2 }
 
     context 'with if statement' do
       it 'registers an offense for bad indentation of an if body' do
@@ -161,7 +226,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
         RUBY
       end
 
-      it 'registers offense for bad indentation of ternary inside else' do
+      it 'registers an offense for bad indentation of ternary inside else' do
         expect_offense(<<~RUBY)
           if a
             b
@@ -172,7 +237,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
         RUBY
       end
 
-      it 'registers offense for bad indentation of modifier if in else' do
+      it 'registers an offense for bad indentation of modifier if in else' do
         expect_offense(<<~RUBY)
           if a
             b
@@ -637,7 +702,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
             { 'Enabled' => true, 'EnforcedStyleAlignWith' => 'variable' }
           end
 
-          include_examples 'assignment with if statement'
+          it_behaves_like 'assignment with if statement'
         end
 
         context 'when alignment style is start_of_line' do
@@ -645,7 +710,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
             { 'Enabled' => true, 'EnforcedStyleAlignWith' => 'start_of_line' }
           end
 
-          include_examples 'assignment with if statement'
+          it_behaves_like 'assignment with if statement'
         end
 
         context 'when alignment style is keyword' do
@@ -905,7 +970,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
       end
 
       it 'accepts aligned values in `in` clause' do
-        expect_no_offenses(<<~'RUBY')
+        expect_no_offenses(<<~RUBY)
           case condition
           in [42]
             foo
@@ -916,7 +981,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
       end
 
       it 'accepts aligned value in `in` clause and `else` is empty' do
-        expect_no_offenses(<<~'RUBY')
+        expect_no_offenses(<<~RUBY)
           case x
           in 42
             foo
@@ -1064,7 +1129,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
           { 'Enabled' => true, 'EnforcedStyleAlignWith' => 'start_of_line' }
         end
 
-        include_examples 'without modifier on the same line'
+        it_behaves_like 'without modifier on the same line'
 
         context 'when modifier and def are on the same line' do
           it 'accepts a correctly aligned body' do
@@ -1162,7 +1227,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
           { 'Enabled' => true, 'EnforcedStyleAlignWith' => 'def' }
         end
 
-        include_examples 'without modifier on the same line'
+        it_behaves_like 'without modifier on the same line'
 
         context 'when modifier and def are on the same line' do
           it 'accepts a correctly aligned body' do
@@ -1533,6 +1598,14 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
             end
           RUBY
         end
+
+        it 'does not register an offense for an empty block body' do
+          expect_no_offenses(<<~RUBY)
+            some_block do
+              # intentionally left empty
+            end
+          RUBY
+        end
       end
 
       it 'registers an offense for bad indentation of a do/end body' do
@@ -1629,6 +1702,26 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
         end
       end
 
+      context 'Ruby 3.4', :ruby34 do
+        it 'registers an offense for bad indentation of a {} body' do
+          expect_offense(<<~RUBY)
+            func {
+               it&.foo
+            ^^^ Use 2 (not 3) spaces for indentation.
+            }
+          RUBY
+        end
+
+        it 'registers an offense for bad indentation of a do-end body' do
+          expect_offense(<<~RUBY)
+            func do
+               it&.foo
+            ^^^ Use 2 (not 3) spaces for indentation.
+            end
+          RUBY
+        end
+      end
+
       # The cop uses the block end/} as the base for indentation, so if it's not
       # on its own line, all bets are off.
       it 'accepts badly indented code if block end is not on separate line' do
@@ -1639,5 +1732,248 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
         RUBY
       end
     end
+
+    context 'with method chain blocks' do
+      it 'registers an offense for bad indentation in chained block' do
+        expect_offense(<<~RUBY)
+          foo
+            .bar do |x|
+          x
+          ^ Use 2 (not -2) spaces for indentation.
+          end
+        RUBY
+      end
+
+      it 'accepts correct indentation in chained block' do
+        expect_no_offenses(<<~RUBY)
+          foo
+            .bar do |x|
+              x
+            end
+        RUBY
+      end
+
+      it 'accepts block body indented relative to dot when end is at different column' do
+        expect_no_offenses(<<~RUBY)
+          out
+            .break
+            .sep_with_breaks(inner) { |v|
+              simplified_process(v)
+          }
+        RUBY
+      end
+
+      it 'accepts block body indented relative to dot with do...end' do
+        expect_no_offenses(<<~RUBY)
+          out
+            .break
+            .sep_with_breaks(inner) do |v|
+              simplified_process(v)
+          end
+        RUBY
+      end
+
+      it 'registers an offense when the chain receiver is long and body not indented relative to dot' do
+        expect_offense(<<~RUBY)
+          ::Some::Very::Long::Module::Name.active
+                                          .in_batches do |batch|
+            process(batch)
+            ^^^^^^^^^^^^^^ Use 2 (not -30) spaces for indentation.
+          end
+        RUBY
+      end
+
+      it 'accepts correct indentation when the chain receiver is long' do
+        expect_no_offenses(<<~RUBY)
+          ::Some::Very::Long::Module::Name.active
+                                          .in_batches do |batch|
+                                            process(batch)
+                                          end
+        RUBY
+      end
+
+      context 'when EnforcedStyleAlignWith is relative_to_receiver' do
+        let(:enforced_style_align_with) { 'relative_to_receiver' }
+
+        it 'registers an offense for indentation relative to line start' do
+          expect_offense(<<~RUBY)
+            foo
+              .bar do |x|
+            x
+            ^ Use 2 (not -2) spaces for indentation.
+            end
+          RUBY
+        end
+
+        it 'accepts indentation relative to receiver position' do
+          expect_no_offenses(<<~RUBY)
+            foo
+              .bar do |x|
+                x
+            end
+          RUBY
+        end
+      end
+
+      it 'accepts correct indentation for block without method chain' do
+        expect_no_offenses(<<~RUBY)
+          foo bar do
+            baz
+          end
+        RUBY
+      end
+
+      it 'accepts correct indentation when dot is on the same line as receiver' do
+        expect_no_offenses(<<~RUBY)
+          foo.bar do |x|
+            x
+          end
+        RUBY
+      end
+
+      it 'does not raise error for block without dot (e.g., super)' do
+        expect_no_offenses(<<~RUBY)
+          def foo
+            super do |x|
+              x
+            end
+          end
+        RUBY
+      end
+    end
+
+    context 'with tabs indentation' do
+      let(:indentation_style_config) { { 'EnforcedStyle' => 'tabs' } }
+
+      it 'accepts correctly indented code with tabs' do
+        expect_no_offenses(<<-RUBY.gsub(/^      /, ''))
+        class A
+        \tdef test
+        \t\tputs 'hello'
+        \tend
+        end
+        RUBY
+      end
+
+      it 'accepts correctly indented if statement with tabs' do
+        expect_no_offenses(<<-RUBY.gsub(/^      /, ''))
+        if cond
+        \tfunc
+        end
+        RUBY
+      end
+
+      it 'detects excessive tab indentation in if statement' do
+        expect_offense(<<-RUBY.gsub(/^        /, ''))
+        if cond
+        \t\tfunc
+        ^^ Use 1 (not 2) tabs for indentation.
+        end
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'detects insufficient tab indentation in class' do
+        expect_offense(<<-RUBY.gsub(/^        /, ''))
+        class A
+        def test
+        ^{} Use 1 (not 0) tabs for indentation.
+        end
+        end
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'detects excessive tab indentation' do
+        expect_offense(<<-RUBY.gsub(/^        /, ''))
+        def test
+        \t\t\tputs 'hello'
+        ^^^ Use 1 (not 3) tabs for indentation.
+        end
+        RUBY
+
+        expect_no_corrections
+      end
+    end
+
+    context 'with mixed tabs and spaces' do
+      context 'when spaces are enforced' do
+        let(:indentation_style_config) { { 'EnforcedStyle' => 'spaces' } }
+
+        it 'correctly autocorrects mixed tab and space indentation' do
+          expect_offense(<<-RUBY.gsub(/^      /, ''))
+          class Test
+            def foo
+           \t\tbar
+            ^ Use 2 (not 1) spaces for indentation.
+            end
+          end
+          RUBY
+
+          expect_correction(<<-RUBY.gsub(/^      /, ''))
+          class Test
+            def foo
+           \t\t bar
+            end
+          end
+          RUBY
+        end
+
+        it 'does not register space followed by tab in indentation' do
+          expect_no_offenses(<<-RUBY.gsub(/^      /, ''))
+          if condition
+           \tfoo
+          end
+          RUBY
+        end
+      end
+
+      context 'when tabs are enforced' do
+        let(:indentation_style_config) { { 'EnforcedStyle' => 'tabs' } }
+
+        it 'correctly autocorrects mixed tab and space indentation', pending: 'autocorrection for mixed indentation needs work' do
+          expect_offense(<<-RUBY.gsub(/^          /, ''))
+          class Test
+            def foo
+           \t\tbar
+          ^^^ Use 1 (not 1) tabs for indentation.
+            end
+          end
+          RUBY
+
+          expect_correction(<<-RUBY.gsub(/^      /, ''))
+          class Test
+            def foo
+          \tbar
+            end
+          end
+          RUBY
+        end
+
+        it 'handles space followed by tab in indentation', pending: 'autocorrection for mixed indentation needs work' do
+          expect_offense(<<-RUBY.gsub(/^          /, ''))
+          if condition
+           \tfoo
+          ^^ Use 1 (not 1) tabs for indentation.
+          end
+          RUBY
+
+          expect_correction(<<-RUBY.gsub(/^      /, ''))
+          if condition
+          \tfoo
+          end
+          RUBY
+        end
+      end
+    end
+  end
+
+  it 'does not register an offense for blocks with a very large offset' do
+    expect_no_offenses(<<~RUBY)
+      foo {
+      #{' ' * 100_001}}
+    RUBY
   end
 end
