@@ -211,7 +211,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineBlockLayout, :config do
     RUBY
   end
 
-  it 'registers an offense and corrects a do/end block with a mult-line body' do
+  it 'registers an offense and corrects a do/end block with a multi-line body' do
     expect_offense(<<~RUBY)
       test do |foo| bar
                     ^^^ Block body expression is on the same line as the block start.
@@ -349,6 +349,28 @@ RSpec.describe RuboCop::Cop::Layout::MultilineBlockLayout, :config do
     RUBY
   end
 
+  context 'when `Layout/LineLength` is disabled' do
+    let(:config) do
+      RuboCop::Config.new('Layout/LineLength' => { 'Enabled' => false })
+    end
+
+    it 'registers an offense' do
+      expect_offense(<<~RUBY)
+        test do
+        |(x, y)|
+        ^^^^^^^^ Block argument expression is not on the same line as the block start.
+          play_with(x, y)
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        test do |(x, y)|
+          play_with(x, y)
+        end
+      RUBY
+    end
+  end
+
   context 'Ruby 2.7', :ruby27 do
     it 'registers an offense and corrects for missing newline in {} block w/o params' do
       expect_offense(<<~RUBY)
@@ -378,4 +400,34 @@ RSpec.describe RuboCop::Cop::Layout::MultilineBlockLayout, :config do
       RUBY
     end
   end
+
+  context 'Ruby 3.4', :ruby34 do
+    it 'registers an offense and corrects for missing newline in {} block w/o params' do
+      expect_offense(<<~RUBY)
+        test { it
+               ^^ Block body expression is on the same line as the block start.
+        }
+      RUBY
+
+      expect_correction(<<~RUBY)
+        test {#{trailing_whitespace}
+          it
+        }
+      RUBY
+    end
+
+    it 'registers an offense and corrects for missing newline in do/end block with params' do
+      expect_offense(<<~RUBY)
+        test do it
+                ^^ Block body expression is on the same line as the block start.
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        test do#{trailing_whitespace}
+          it
+        end
+      RUBY
+    end
+  end
 end
