@@ -2,13 +2,17 @@
 
 RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
   let(:config) do
-    RuboCop::Config.new('Layout/LineLength' => { 'Max' => max_line_length },
+    RuboCop::Config.new('Layout/LineLength' => {
+                          'Enabled' => line_length_enabled, 'Max' => max_line_length
+                        },
                         'Layout/RedundantLineBreak' => { 'InspectBlocks' => inspect_blocks },
                         'Layout/SingleLineBlockChain' => {
                           'Enabled' => single_line_block_chain_enabled
                         })
   end
+  let(:line_length_enabled) { true }
   let(:max_line_length) { 31 }
+  let(:inspect_blocks) { false }
   let(:single_line_block_chain_enabled) { true }
 
   shared_examples 'common behavior' do
@@ -28,6 +32,32 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
           ^^^^^^^^^^^^^^^^^^^^^^^^ Redundant line break detected.
            .join + []
         RUBY
+
+        expect_correction(<<~RUBY)
+          e.select { |i| i.cond? }.join
+          a = e.select { |i| i.cond? }.join
+          e.select { |i| i.cond? }.join + []
+        RUBY
+      end
+
+      it 'reports an offense for a safe navigation method call chained onto a single line block' do
+        expect_offense(<<~RUBY)
+          e&.select { |i| i.cond? }
+          ^^^^^^^^^^^^^^^^^^^^^^^^^ Redundant line break detected.
+            &.join
+          a = e&.select { |i| i.cond? }
+          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Redundant line break detected.
+            &.join
+          e&.select { |i| i.cond? }
+          ^^^^^^^^^^^^^^^^^^^^^^^^^ Redundant line break detected.
+            &.join + []
+        RUBY
+
+        expect_correction(<<~RUBY)
+          e&.select { |i| i.cond? }&.join
+          a = e&.select { |i| i.cond? }&.join
+          e&.select { |i| i.cond? }&.join + []
+        RUBY
       end
     end
 
@@ -45,6 +75,28 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
            .join + []
         RUBY
       end
+
+      it 'accepts a method call chained onto a single line numbered block', :ruby27 do
+        expect_no_offenses(<<~RUBY)
+          e.select { _1.cond? }
+           .join
+          a = e.select { _1.cond? }
+           .join
+          e.select { _1.cond? }
+           .join + []
+        RUBY
+      end
+
+      it 'accepts a method call chained onto a single line `it` block', :ruby34 do
+        expect_no_offenses(<<~RUBY)
+          e.select { it.cond? }
+           .join
+          a = e.select { it.cond? }
+           .join
+          e.select { it.cond? }
+           .join + []
+        RUBY
+      end
     end
 
     context 'for an expression that fits on a single line' do
@@ -100,6 +152,14 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
         RUBY
       end
 
+      it 'accepts a modified singleton method definition' do
+        expect_no_offenses(<<~RUBY)
+          x def self.y
+              z
+            end
+        RUBY
+      end
+
       it 'accepts a method call on a single line' do
         expect_no_offenses(<<~RUBY)
           my_method(1, 2, "x")
@@ -118,6 +178,64 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
         RUBY
       end
 
+      it 'does not register an offense for index access call chained on multiple lines with backslash' do
+        expect_no_offenses(<<~RUBY)
+          hash[:foo] \\
+            [:bar]
+        RUBY
+      end
+
+      it 'registers an offense for index access call chained on multiline hash literal' do
+        expect_offense(<<~RUBY)
+          {
+          ^ Redundant line break detected.
+            key: value
+          }[key]
+        RUBY
+
+        expect_correction(<<~RUBY)
+          { key: value }[key]
+        RUBY
+      end
+
+      it 'registers an offense when using `&&` before a backslash newline' do
+        expect_offense(<<~RUBY)
+          foo && \\
+          ^^^^^^^^ Redundant line break detected.
+            bar
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo && bar
+        RUBY
+      end
+
+      it 'does not register an offense when using `&&` after a backslash newline' do
+        expect_no_offenses(<<~RUBY)
+          foo \\
+            && bar
+        RUBY
+      end
+
+      it 'registers an offense when using `||` before a backslash newline' do
+        expect_offense(<<~RUBY)
+          foo || \\
+          ^^^^^^^^ Redundant line break detected.
+            bar
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo || bar
+        RUBY
+      end
+
+      it 'does not register an offense when using `||` after a backslash newline' do
+        expect_no_offenses(<<~RUBY)
+          foo \\
+            || bar
+        RUBY
+      end
+
       context 'with LineLength Max 100' do
         let(:max_line_length) { 100 }
 
@@ -303,7 +421,7 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
           RUBY
         end
 
-        it 'registers an offense and corrects with a arguments on multiple lines' do
+        it 'registers an offense and corrects with arguments on multiple lines' do
           expect_offense(<<~RUBY)
             foo(x,
             ^^^^^^ Redundant line break detected.
@@ -341,6 +459,24 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
               .baz
           RUBY
         end
+
+        it 'does not register an offense with a line broken string argument' do
+          expect_no_offenses(<<~RUBY)
+            foo('
+              xyz
+            ')
+              .bar
+              .baz
+          RUBY
+        end
+
+        it 'does not register an offense when the `%` form string `"%\n\n"` at the end of file' do
+          expect_no_offenses("%\n\n")
+        end
+
+        it 'does not register an offense when assigning the `%` form string `"%\n\n"` to a variable at the end of file' do
+          expect_no_offenses("x = %\n\n")
+        end
       end
     end
 
@@ -356,6 +492,13 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
         RUBY
       end
 
+      it 'accepts a quoted symbol with a single newline' do
+        expect_no_offenses(<<~RUBY)
+          foo(:"
+          ")
+        RUBY
+      end
+
       context 'with a longer max line length' do
         let(:max_line_length) { 82 }
 
@@ -405,6 +548,15 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
           RUBY
         end
 
+        it 'accepts a complex method call on a multiple lines with numbered block', :ruby27 do
+          expect_no_offenses(<<~RUBY)
+            node.each_node(:dstr)
+                .select(&:heredoc?)
+                .map { _1.loc.heredoc_body }
+                .flat_map {  (_1.line..._1.last_line).to_a }
+          RUBY
+        end
+
         it 'accepts method call with a do keyword that would just surpass the max line length' do
           expect_no_offenses(<<~RUBY)
             context 'when the configuration includes ' \\
@@ -443,7 +595,7 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
   context 'when InspectBlocks is true' do
     let(:inspect_blocks) { true }
 
-    include_examples 'common behavior'
+    it_behaves_like 'common behavior'
 
     context 'for a block' do
       let(:max_line_length) { 82 }
@@ -516,7 +668,7 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
   context 'when InspectBlocks is false' do
     let(:inspect_blocks) { false }
 
-    include_examples 'common behavior'
+    it_behaves_like 'common behavior'
 
     context 'for a block' do
       let(:max_line_length) { 100 }
@@ -529,6 +681,14 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
         RUBY
       end
 
+      it 'accepts when the method call has parentheses with numbered block', :ruby27 do
+        expect_no_offenses(<<~RUBY)
+          a = Foo.do_something(arg) do
+            _1
+          end
+        RUBY
+      end
+
       it 'accepts when the method call has no arguments' do
         expect_no_offenses(<<~RUBY)
           RSpec.shared_context do
@@ -546,6 +706,14 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
             end
           RUBY
         end
+
+        it 'accepts a multiline numbered block without a chained method call', :ruby27 do
+          expect_no_offenses(<<~RUBY)
+            f do
+              foo(_1)
+            end
+          RUBY
+        end
       end
 
       context 'when Layout/SingleLineBlockChain is disabled' do
@@ -558,6 +726,14 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
           RUBY
         end
 
+        it 'accepts a multiline numbered block without a chained method call', :ruby27 do
+          expect_no_offenses(<<~RUBY)
+            f do
+              foo(_1)
+            end
+          RUBY
+        end
+
         it 'accepts a method call chained onto a multiline block' do
           expect_no_offenses(<<~RUBY)
             e.select do |i|
@@ -571,7 +747,52 @@ RSpec.describe RuboCop::Cop::Layout::RedundantLineBreak, :config do
             end.join + []
           RUBY
         end
+
+        it 'accepts a method call chained onto a multiline numbered block', :ruby27 do
+          expect_no_offenses(<<~RUBY)
+            e.select do
+              _1.cond?
+            end.join
+            a = e.select do
+              _1.cond?
+            end.join
+            e.select do
+              _1.cond?
+            end.join + []
+          RUBY
+        end
+
+        it 'accepts a method call chained onto a multiline `it` block', :ruby34 do
+          expect_no_offenses(<<~RUBY)
+            e.select do
+              it.cond?
+            end.join
+            a = e.select do
+              it.cond?
+            end.join
+            e.select do
+              it.cond?
+            end.join + []
+          RUBY
+        end
       end
     end
   end
+
+  context 'when `Layout/LineLength` is disabled' do
+    let(:line_length_enabled) { false }
+
+    it 'registers an offense for a method call on multiple lines' do
+      expect_offense(<<~RUBY)
+        my_method(1,
+        ^^^^^^^^^^^^ Redundant line break detected.
+                  2,
+                  "x")
+      RUBY
+
+      expect_correction(<<~RUBY)
+        my_method(1, 2, "x")
+      RUBY
+    end
+  end
 end
