@@ -8,7 +8,12 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
         'Layout/HashAlignment' => { 'EnforcedHashRocketStyle' => hash_style },
         'Layout/SpaceAroundOperators' => {
           'AllowForAlignment' => allow_for_alignment,
-          'EnforcedStyleForExponentOperator' => exponent_operator_style
+          'EnforcedStyleForExponentOperator' => exponent_operator_style,
+          'EnforcedStyleForRationalLiterals' => rational_literals_style
+        },
+        'Layout/ExtraSpacing' => {
+          'Enabled' => force_equal_sign_alignment,
+          'ForceEqualSignAlignment' => force_equal_sign_alignment
         }
       )
   end
@@ -16,6 +21,8 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
   let(:hash_style) { 'key' }
   let(:allow_for_alignment) { true }
   let(:exponent_operator_style) { nil }
+  let(:rational_literals_style) { nil }
+  let(:force_equal_sign_alignment) { false }
 
   it 'accepts operator surrounded by tabs' do
     expect_no_offenses("a\t+\tb")
@@ -33,6 +40,13 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
     expect_no_offenses('x = 2/3r')
   end
 
+  it 'accepts multiple spaces between an operator and a tailing comment' do
+    expect_no_offenses(<<~RUBY)
+      foo +  # comment
+        bar
+    RUBY
+  end
+
   it 'accepts scope operator' do
     expect_no_offenses('@io.class == Zlib::GzipWriter')
   end
@@ -155,6 +169,25 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
     RUBY
   end
 
+  it 'accepts vertical alignment with operator' do
+    expect_no_offenses(<<~RUBY)
+      down? && !migrated.include?(migration.version.to_i)
+      up?   &&  migrated.include?(migration.version.to_i)
+    RUBY
+  end
+
+  it 'accepts vertical alignment with different operators that end with `=`' do
+    expect_no_offenses(<<~RUBY)
+      var.foo       = a
+      var.bar      != b
+      var.quux     <= c
+      var.garply   >= d
+      var.corge    == e
+      var.fred     += f
+      var.baz     === g
+    RUBY
+  end
+
   it 'accepts an operator called with method syntax' do
     expect_no_offenses('Date.today.+(1).to_s')
   end
@@ -188,7 +221,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
     RUBY
   end
 
-  it 'registers an offenses for exponent operator with spaces' do
+  it 'registers an offense for exponent operator with spaces' do
     expect_offense(<<~RUBY)
       x = a * b ** 2
                 ^^ Space around operator `**` detected.
@@ -206,11 +239,103 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
     expect_no_offenses('x = a * b**2')
   end
 
+  it 'registers an offense for slash in rational literals with spaces' do
+    expect_offense(<<~RUBY)
+      x = a * b / 42r
+                ^ Space around operator `/` detected.
+      y = a * b/ 42r
+               ^ Space around operator `/` detected.
+    RUBY
+
+    expect_correction(<<~RUBY)
+      x = a * b/42r
+      y = a * b/42r
+    RUBY
+  end
+
+  it 'accepts slash in rational literals without spaces' do
+    expect_no_offenses('x = a * b/42r')
+  end
+
+  it 'does not register an offense for slash in non rational literals without spaces' do
+    expect_no_offenses(<<~RUBY)
+      x = a * b / 42
+    RUBY
+  end
+
+  it 'registers slash in non rational literals without spaces' do
+    expect_offense(<<~RUBY)
+      x = a * b/42
+               ^ Surrounding space missing for operator `/`.
+      y = a * b/ 42
+               ^ Surrounding space missing for operator `/`.
+    RUBY
+
+    expect_correction(<<~RUBY)
+      x = a * b / 42
+      y = a * b / 42
+    RUBY
+  end
+
   context '>= Ruby 2.7', :ruby27 do
     let(:target_ruby_version) { 2.7 }
 
+    it 'registers an offense for alternative pattern matching syntax' do
+      expect_offense(<<~RUBY)
+        case foo
+        in 0|1|2
+              ^ Surrounding space missing for operator `|`.
+            ^ Surrounding space missing for operator `|`.
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        case foo
+        in 0 | 1 | 2
+        end
+      RUBY
+    end
+
+    it 'registers an offense for as pattern matching syntax' do
+      expect_offense(<<~RUBY)
+        case foo
+        in bar=>baz
+              ^^ Surrounding space missing for operator `=>`.
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        case foo
+        in bar => baz
+        end
+      RUBY
+    end
+
+    it 'registers an offense for one-line alternative pattern matching syntax' do
+      expect_offense(<<~RUBY)
+        foo in 0|1|2
+                  ^ Surrounding space missing for operator `|`.
+                ^ Surrounding space missing for operator `|`.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        foo in 0 | 1 | 2
+      RUBY
+    end
+
+    it 'registers an offense for one-line as pattern matching syntax' do
+      expect_offense(<<~RUBY)
+        foo in bar=>baz
+                  ^^ Surrounding space missing for operator `=>`.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        foo in bar => baz
+      RUBY
+    end
+
     # NOTE: It is `Layout/SpaceAroundKeyword` cop's role to detect this offense.
-    it 'does not register an offenses for one-line pattern matching syntax (`in`)' do
+    it 'does not register an offense for one-line pattern matching syntax (`in`)' do
       expect_no_offenses(<<~RUBY)
         ""in foo
       RUBY
@@ -220,7 +345,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
   context '>= Ruby 3.0', :ruby30 do
     let(:target_ruby_version) { 3.0 }
 
-    it 'registers an offenses for one-line pattern matching syntax (`=>`)' do
+    it 'registers an offense for one-line pattern matching syntax (`=>`)' do
       expect_offense(<<~RUBY)
         ""=>foo
           ^^ Surrounding space missing for operator `=>`.
@@ -235,7 +360,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
   context 'when EnforcedStyleForExponentOperator is space' do
     let(:exponent_operator_style) { 'space' }
 
-    it 'registers an offenses for exponent operator without spaces' do
+    it 'registers an offense for exponent operator without spaces' do
       expect_offense(<<~RUBY)
         x = a * b**2
                  ^^ Surrounding space missing for operator `**`.
@@ -247,11 +372,27 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
     end
   end
 
+  context 'when EnforcedStyleForRationalLiterals is space' do
+    let(:rational_literals_style) { 'space' }
+
+    it 'registers an offense for rational literals without spaces' do
+      expect_offense(<<~RUBY)
+        x = a * b/42r
+                 ^ Surrounding space missing for operator `/`.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        x = a * b / 42r
+      RUBY
+    end
+  end
+
   it 'accepts unary operators without space' do
     expect_no_offenses(<<~RUBY)
       [].map(&:size)
       a.(b)
       -3
+      foo::~
       arr.collect { |e| -e }
       x = +2
     RUBY
@@ -431,6 +572,17 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
       RUBY
     end
 
+    it 'registers an offense and corrects a setter call with implicit array without spaces' do
+      expect_offense(<<~RUBY)
+        x.y=2,3
+           ^ Surrounding space missing for operator `=`.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        x.y = 2,3
+      RUBY
+    end
+
     context 'when a hash literal is on a single line' do
       context 'and Layout/HashAlignment:EnforcedHashRocketStyle is key' do
         let(:hash_style) { 'key' }
@@ -461,6 +613,21 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
           RUBY
         end
       end
+
+      context 'and Layout/HashAlignment:EnforcedHashRocketStyle is key, table' do
+        let(:hash_style) { %w[key table] }
+
+        it 'registers an offense and corrects a hash rocket without spaces' do
+          expect_offense(<<~RUBY)
+            { 1=>2, a: b }
+               ^^ Surrounding space missing for operator `=>`.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            { 1 => 2, a: b }
+          RUBY
+        end
+      end
     end
 
     context 'when a hash literal is on multiple lines' do
@@ -497,6 +664,19 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
           RUBY
         end
       end
+
+      context 'and Layout/HashAlignment:EnforcedHashRocketStyle is key, table' do
+        let(:hash_style) { %w[key table] }
+
+        it "doesn't register an offense for a hash rocket without spaces" do
+          expect_no_offenses(<<~RUBY)
+            {
+              1=>2,
+              a: b
+            }
+          RUBY
+        end
+      end
     end
 
     it 'registers an offense and corrects match operators without space' do
@@ -799,7 +979,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects a hash rocket with an extra spaceon multiple line' do
+    it 'registers an offense and corrects a hash rocket with an extra space on multiple line' do
       expect_offense(<<~RUBY)
         {
           1 =>  2
@@ -858,20 +1038,46 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
       RUBY
     end
 
-    it 'does not register an offenses match operators between `<<` and `+=`' do
+    it 'does not register an offense match operators between `<<` and `+=`' do
       expect_no_offenses(<<~RUBY)
         x  << foo
         yz += bar
       RUBY
     end
 
-    it 'does not register an offenses match operators between `+=` and `<<`' do
+    it 'does not register an offense match operators between `+=` and `<<`' do
       expect_no_offenses(<<~RUBY)
         x  += foo
         yz << bar
       RUBY
     end
 
+    it 'registers an offense when operator is followed by aligned << inside a string' do
+      expect_offense(<<~RUBY)
+        x   += foo
+            ^^ Operator `+=` should be surrounded by a single space.
+        'yz << bar'
+      RUBY
+
+      expect_correction(<<~RUBY)
+        x += foo
+        'yz << bar'
+      RUBY
+    end
+
+    it 'registers an offense when operator is preceded by aligned << inside a string' do
+      expect_offense(<<~RUBY)
+        'yz << bar'
+        x   += foo
+            ^^ Operator `+=` should be surrounded by a single space.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        'yz << bar'
+        x += foo
+      RUBY
+    end
+
     it 'registers an offense and corrects various assignments with too many spaces' do
       expect_offense(<<~RUBY)
         x ||=  0
@@ -971,9 +1177,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
   end
 
   describe 'when Layout/ExtraSpacing has `ForceEqualSignAlignment` configured to true' do
-    let(:other_cops) do
-      { 'Layout/ExtraSpacing' => { 'Enabled' => true, 'ForceEqualSignAlignment' => true } }
-    end
+    let(:force_equal_sign_alignment) { true }
 
     it 'allows variables to be aligned' do
       expect_no_offenses(<<~RUBY)
