@@ -14,6 +14,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeBlockBraces, :config do
             ^ Space missing to the left of {.
       RUBY
 
+      expect(cop.config_to_allow_offenses).to eq('EnforcedStyle' => 'no_space')
       expect_correction(<<~RUBY)
         each { puts }
       RUBY
@@ -26,6 +27,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeBlockBraces, :config do
         each { puts }
       RUBY
 
+      expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
       expect_correction(<<~RUBY)
         each { puts }
         each { puts }
@@ -56,6 +58,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeBlockBraces, :config do
           each { _1 }
         RUBY
 
+        expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
         expect_correction(<<~RUBY)
           each { _1 }
           each { _1 }
@@ -78,6 +81,38 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeBlockBraces, :config do
         RUBY
       end
     end
+
+    context 'Ruby 3.4', :ruby34 do
+      it 'registers an offense and corrects opposite + correct style' do
+        expect_offense(<<~RUBY)
+          each{ it }
+              ^ Space missing to the left of {.
+          each { it }
+        RUBY
+
+        expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
+        expect_correction(<<~RUBY)
+          each { it }
+          each { it }
+        RUBY
+      end
+
+      it 'registers an offense and corrects multiline block where the left ' \
+         'brace has no outer space' do
+        expect_offense(<<~RUBY)
+          foo.map{
+                 ^ Space missing to the left of {.
+            it.bar.to_s
+          }
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo.map {
+            it.bar.to_s
+          }
+        RUBY
+      end
+    end
   end
 
   context 'when EnforcedStyle is no_space' do
@@ -89,6 +124,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeBlockBraces, :config do
             ^ Space detected to the left of {.
       RUBY
 
+      expect(cop.config_to_allow_offenses).to eq('EnforcedStyle' => 'space')
       expect_correction(<<~RUBY)
         each{ puts }
       RUBY
@@ -101,6 +137,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeBlockBraces, :config do
             ^ Space detected to the left of {.
       RUBY
 
+      expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
       expect_correction(<<~RUBY)
         each{ puts }
         each{ puts }
@@ -119,6 +156,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeBlockBraces, :config do
               ^ Space detected to the left of {.
         RUBY
 
+        expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
         expect_correction(<<~RUBY)
           each{ _1 }
           each{ _1 }
@@ -164,6 +202,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeBlockBraces, :config do
           ^ Space detected to the left of {.
       RUBY
 
+      expect(cop.config_to_allow_offenses).to eq('EnforcedStyleForEmptyBraces' => 'space')
       expect_correction(<<~RUBY)
         ->{}
       RUBY
@@ -188,6 +227,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeBlockBraces, :config do
           ^ Space missing to the left of {.
       RUBY
 
+      expect(cop.config_to_allow_offenses).to eq('EnforcedStyleForEmptyBraces' => 'no_space')
       expect_correction(<<~RUBY)
         -> {}
       RUBY
