@@ -293,6 +293,146 @@ RSpec.describe RuboCop::Cop::Layout::SpaceInsideArrayLiteralBrackets, :config do
            ]
       RUBY
     end
+
+    context 'when using array pattern matching', :ruby27 do
+      it 'registers an offense when array pattern with spaces' do
+        expect_offense(<<~RUBY)
+          case foo
+          in [ bar, baz ]
+                       ^ Do not use space inside array brackets.
+              ^ Do not use space inside array brackets.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case foo
+          in [bar, baz]
+          end
+        RUBY
+      end
+
+      it 'does not register an offense when array pattern with no spaces' do
+        expect_no_offenses(<<~RUBY)
+          case foo
+          in [bar, baz]
+          end
+        RUBY
+      end
+    end
+
+    context 'when using one-line array `in` pattern matching', :ruby27 do
+      it 'registers an offense when array pattern with spaces' do
+        expect_offense(<<~RUBY)
+          foo in [ bar, baz ]
+                           ^ Do not use space inside array brackets.
+                  ^ Do not use space inside array brackets.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo in [bar, baz]
+        RUBY
+      end
+
+      it 'does not register an offense when array pattern with no spaces' do
+        expect_no_offenses(<<~RUBY)
+          foo in [bar, baz]
+        RUBY
+      end
+    end
+
+    context 'when using one-line array `=>` pattern matching', :ruby30 do
+      it 'registers an offense when array pattern with spaces' do
+        expect_offense(<<~RUBY)
+          foo => [ bar, baz ]
+                           ^ Do not use space inside array brackets.
+                  ^ Do not use space inside array brackets.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo => [bar, baz]
+        RUBY
+      end
+
+      it 'does not register an offense when array pattern with no spaces' do
+        expect_no_offenses(<<~RUBY)
+          foo => [bar, baz]
+        RUBY
+      end
+    end
+
+    context 'when using constant pattern matching', :ruby27 do
+      it 'registers an offense for empty pattern with spaces' do
+        expect_offense(<<~RUBY)
+          case value
+          in ADT[ ]
+                ^^^ #{no_space_in_empty_message}
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case value
+          in ADT[]
+          end
+        RUBY
+      end
+
+      it 'registers an offense for empty nested pattern with spaces' do
+        expect_offense(<<~RUBY)
+          case value
+          in ADT[*head, ADT[ ]]
+                           ^^^ #{no_space_in_empty_message}
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case value
+          in ADT[*head, ADT[]]
+          end
+        RUBY
+      end
+
+      it 'registers an offense for pattern with spaces' do
+        expect_offense(<<~RUBY)
+          case value
+          in ADT[ *head, tail ]
+                 ^ Do not use space inside array brackets.
+                             ^ Do not use space inside array brackets.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case value
+          in ADT[*head, tail]
+          end
+        RUBY
+      end
+
+      it 'registers an offense for nested constant with spaces' do
+        expect_offense(<<~RUBY)
+          case value
+          in ADT[ *head, ADT[ *headhead, tail ] ]
+                 ^ Do not use space inside array brackets.
+                             ^ Do not use space inside array brackets.
+                                             ^ Do not use space inside array brackets.
+                                               ^ Do not use space inside array brackets.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case value
+          in ADT[*head, ADT[*headhead, tail]]
+          end
+        RUBY
+      end
+
+      it 'does not register an offense for pattern with no spaces' do
+        expect_no_offenses(<<~RUBY)
+          case value
+          in ADT[*head, ADT[*headhead, tail]]
+          end
+        RUBY
+      end
+    end
   end
 
   shared_examples 'space inside arrays' do
@@ -436,7 +576,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceInsideArrayLiteralBrackets, :config do
       RUBY
     end
 
-    it 'register an offense and corrects when 2 arrays are on one line' do
+    it 'registers an offense and corrects when 2 arrays are on one line' do
       expect_offense(<<~RUBY)
         [ 2, 3, 4 ] - [3, 4 ]
                       ^ #{use_space_message}
@@ -448,22 +588,144 @@ RSpec.describe RuboCop::Cop::Layout::SpaceInsideArrayLiteralBrackets, :config do
     end
   end
 
+  shared_examples 'array pattern without brackets' do
+    it 'does not register an offense' do
+      expect_no_offenses(<<~RUBY)
+        case ary
+        in a, b, c, d
+        end
+      RUBY
+    end
+  end
+
   context 'when EnforcedStyle is space' do
     let(:cop_config) { { 'EnforcedStyle' => 'space' } }
 
     it_behaves_like 'space inside arrays'
+    it_behaves_like 'array pattern without brackets'
 
     it 'does not register offense for valid 2-dimensional array' do
       expect_no_offenses(<<~RUBY)
         [ 1, [ 2,3,4 ], [ 5,6,7 ] ]
       RUBY
     end
+
+    context 'when using array pattern matching', :ruby27 do
+      it 'registers an offense when array pattern with no spaces' do
+        expect_offense(<<~RUBY)
+          case foo
+          in [bar, baz]
+                      ^ Use space inside array brackets.
+             ^ Use space inside array brackets.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case foo
+          in [ bar, baz ]
+          end
+        RUBY
+      end
+
+      it 'does not register an offense when array pattern with spaces' do
+        expect_no_offenses(<<~RUBY)
+          case foo
+          in [ bar, baz ]
+          end
+        RUBY
+      end
+    end
+
+    context 'when using one-line array `in` pattern matching', :ruby27 do
+      it 'registers an offense when array pattern with no spaces' do
+        expect_offense(<<~RUBY)
+          foo in [bar, baz]
+                          ^ Use space inside array brackets.
+                 ^ Use space inside array brackets.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo in [ bar, baz ]
+        RUBY
+      end
+
+      it 'does not register an offense when array pattern with spaces' do
+        expect_no_offenses(<<~RUBY)
+          foo in [ bar, baz ]
+        RUBY
+      end
+    end
+
+    context 'when using one-line array `=>` pattern matching', :ruby30 do
+      it 'registers an offense when array pattern with no spaces' do
+        expect_offense(<<~RUBY)
+          foo => [bar, baz]
+                          ^ Use space inside array brackets.
+                 ^ Use space inside array brackets.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo => [ bar, baz ]
+        RUBY
+      end
+
+      it 'does not register an offense when array pattern with spaces' do
+        expect_no_offenses(<<~RUBY)
+          foo => [ bar, baz ]
+        RUBY
+      end
+    end
+
+    context 'when using constant pattern matching', :ruby27 do
+      it 'registers an offense for pattern with no spaces' do
+        expect_offense(<<~RUBY)
+          case value
+          in ADT[*head, tail]
+                ^ #{use_space_message}
+                            ^ #{use_space_message}
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case value
+          in ADT[ *head, tail ]
+          end
+        RUBY
+      end
+
+      it 'registers an offense for nested constant with no spaces' do
+        expect_offense(<<~RUBY)
+          case value
+          in ADT[*head, ADT[*headhead, tail]]
+                ^ #{use_space_message}
+                           ^ #{use_space_message}
+                                           ^ #{use_space_message}
+                                            ^ #{use_space_message}
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case value
+          in ADT[ *head, ADT[ *headhead, tail ] ]
+          end
+        RUBY
+      end
+
+      it 'does not register an offense for pattern with spaces' do
+        expect_no_offenses(<<~RUBY)
+          case value
+          in ADT[ *head, ADT[ *headhead, tail ] ]
+          end
+        RUBY
+      end
+    end
   end
 
   context 'when EnforcedStyle is compact' do
     let(:cop_config) { { 'EnforcedStyle' => 'compact' } }
 
     it_behaves_like 'space inside arrays'
+    it_behaves_like 'array pattern without brackets'
 
     it 'does not register offense for valid 2-dimensional array' do
       expect_no_offenses(<<~RUBY)
@@ -598,5 +860,48 @@ RSpec.describe RuboCop::Cop::Layout::SpaceInsideArrayLiteralBrackets, :config do
         [[ a, b ], [ foo, [ bar, baz ]]]
       RUBY
     end
+
+    context 'when using constant pattern matching', :ruby27 do
+      it 'registers an offense for pattern with no spaces' do
+        expect_offense(<<~RUBY)
+          case value
+          in ADT[*head, tail]
+                ^ #{use_space_message}
+                            ^ #{use_space_message}
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case value
+          in ADT[ *head, tail ]
+          end
+        RUBY
+      end
+
+      it 'registers an offense for nested constant pattern with no spaces' do
+        expect_offense(<<~RUBY)
+          case value
+          in ADT[*head, ADT[*headhead, tail]]
+                ^ #{use_space_message}
+                           ^ #{use_space_message}
+                                           ^ #{use_space_message}
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case value
+          in ADT[ *head, ADT[ *headhead, tail ]]
+          end
+        RUBY
+      end
+
+      it 'does not register an offense for pattern with spaces' do
+        expect_no_offenses(<<~RUBY)
+          case value
+          in ADT[ *head, ADT[ *headhead, tail ]]
+          end
+        RUBY
+      end
+    end
   end
 end
