@@ -104,6 +104,20 @@ RSpec.describe RuboCop::Cop::Layout::SpaceInsideBlockBraces, :config do
     end
   end
 
+  context 'Ruby >= 3.4', :ruby34 do
+    it 'registers an offense for itblocks without inner space' do
+      expect_offense(<<~RUBY)
+        [1, 2, 3].each {it * 2}
+                        ^ Space missing inside {.
+                              ^ Space missing inside }.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        [1, 2, 3].each { it * 2 }
+      RUBY
+    end
+  end
+
   it 'accepts braces surrounded by spaces' do
     expect_no_offenses('each { puts }')
   end
@@ -148,7 +162,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceInsideBlockBraces, :config do
     RUBY
   end
 
-  it 'register offenses and correct both braces without inner space' do
+  it 'registers offenses and correct both braces without inner space' do
     expect_offense(<<~RUBY)
       a {}
       b { }
@@ -329,6 +343,14 @@ RSpec.describe RuboCop::Cop::Layout::SpaceInsideBlockBraces, :config do
       expect_no_offenses('each{puts}')
     end
 
+    it 'accepts when a method call with a multiline block is used as an argument' do
+      expect_no_offenses(<<~RUBY)
+        foo bar { |arg|
+          baz(arg)
+        }
+      RUBY
+    end
+
     context 'with passed in parameters' do
       context 'and space before block parameters allowed' do
         it 'accepts left brace with inner space' do
