@@ -100,6 +100,84 @@ RSpec.describe RuboCop::Cop::Layout::SpaceInsideHashLiteralBraces, :config do
     RUBY
   end
 
+  it 'handles "{" as final hash value' do
+    expect_offense(<<~RUBY)
+      h = {a: '{'}
+                 ^ Space inside } missing.
+          ^ Space inside { missing.
+    RUBY
+
+    expect_correction(<<~RUBY)
+      h = { a: '{' }
+    RUBY
+  end
+
+  context 'when using hash pattern matching', :ruby27 do
+    it 'registers an offense when hash pattern with no spaces' do
+      expect_offense(<<~RUBY)
+        case foo
+        in {k1: 0, k2: 1}
+                        ^ Space inside } missing.
+           ^ Space inside { missing.
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        case foo
+        in { k1: 0, k2: 1 }
+        end
+      RUBY
+    end
+
+    it 'does not register an offense when hash pattern with spaces' do
+      expect_no_offenses(<<~RUBY)
+        case foo
+        in { k1: 0, k2: 1 }
+        end
+      RUBY
+    end
+  end
+
+  context 'when using one-line hash `in` pattern matching', :ruby27 do
+    it 'registers an offense when hash pattern with no spaces' do
+      expect_offense(<<~RUBY)
+        foo in {k1: 0, k2: 1}
+                            ^ Space inside } missing.
+               ^ Space inside { missing.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        foo in { k1: 0, k2: 1 }
+      RUBY
+    end
+
+    it 'does not register an offense when hash pattern with spaces' do
+      expect_no_offenses(<<~RUBY)
+        foo in { k1: 0, k2: 1 }
+      RUBY
+    end
+  end
+
+  context 'when using one-line hash `=>` pattern matching', :ruby30 do
+    it 'registers an offense when hash pattern with no spaces' do
+      expect_offense(<<~RUBY)
+        foo => {k1: 0, k2: 1}
+                            ^ Space inside } missing.
+               ^ Space inside { missing.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        foo => { k1: 0, k2: 1 }
+      RUBY
+    end
+
+    it 'does not register an offense when hash pattern with spaces' do
+      expect_no_offenses(<<~RUBY)
+        foo => { k1: 0, k2: 1 }
+      RUBY
+    end
+  end
+
   context 'when EnforcedStyle is no_space' do
     let(:cop_config) { { 'EnforcedStyle' => 'no_space' } }
 
@@ -126,6 +204,18 @@ RSpec.describe RuboCop::Cop::Layout::SpaceInsideHashLiteralBraces, :config do
       RUBY
     end
 
+    it 'handles "{" as final hash value' do
+      expect_offense(<<~RUBY)
+        h = { a: '{' }
+                    ^ Space inside } detected.
+             ^ Space inside { detected.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        h = {a: '{'}
+      RUBY
+    end
+
     it 'accepts hashes with no spaces' do
       expect_no_offenses(<<~RUBY)
         h = {a: 1, b: 2}
@@ -158,6 +248,72 @@ RSpec.describe RuboCop::Cop::Layout::SpaceInsideHashLiteralBraces, :config do
         RUBY
       end
     end
+
+    context 'when using hash pattern matching', :ruby27 do
+      it 'registers an offense when hash with spaces' do
+        expect_offense(<<~RUBY)
+          case foo
+          in { k1: 0, k2: 1 }
+                           ^ Space inside } detected.
+              ^ Space inside { detected.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case foo
+          in {k1: 0, k2: 1}
+          end
+        RUBY
+      end
+
+      it 'does not register an offense when hash pattern with no spaces' do
+        expect_no_offenses(<<~RUBY)
+          case foo
+          in {k1: 0, k2: 1}
+          end
+        RUBY
+      end
+    end
+
+    context 'when using one-line hash `in` pattern matching', :ruby27 do
+      it 'registers an offense when hash with spaces' do
+        expect_offense(<<~RUBY)
+          foo in { k1: 0, k2: 1 }
+                               ^ Space inside } detected.
+                  ^ Space inside { detected.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo in {k1: 0, k2: 1}
+        RUBY
+      end
+
+      it 'does not register an offense when hash with no spaces' do
+        expect_no_offenses(<<~RUBY)
+          foo in {k1: 0, k2: 1}
+        RUBY
+      end
+    end
+
+    context 'when using one-line hash `=>` pattern matching', :ruby30 do
+      it 'registers an offense when hash with spaces' do
+        expect_offense(<<~RUBY)
+          foo => { k1: 0, k2: 1 }
+                               ^ Space inside } detected.
+                  ^ Space inside { detected.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo => {k1: 0, k2: 1}
+        RUBY
+      end
+
+      it 'does not register an offense when hash with no spaces' do
+        expect_no_offenses(<<~RUBY)
+          foo => {k1: 0, k2: 1}
+        RUBY
+      end
+    end
   end
 
   context 'when EnforcedStyle is compact' do
