@@ -45,6 +45,28 @@ RSpec.describe RuboCop::Cop::Lint::DeprecatedOpenSSLConstant, :config do
     RUBY
   end
 
+  it 'registers an offense when the `Cipher` constant appears twice and autocorrects' do
+    expect_offense(<<~RUBY)
+      OpenSSL::Cipher::Cipher.new('AES-256-ECB')
+      ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use `OpenSSL::Cipher.new('AES-256-ECB')` instead of `OpenSSL::Cipher::Cipher.new('AES-256-ECB')`.
+    RUBY
+
+    expect_correction(<<~RUBY)
+      OpenSSL::Cipher.new('AES-256-ECB')
+    RUBY
+  end
+
+  it 'registers an offense with cipher constant and `ecb` argument and corrects' do
+    expect_offense(<<~RUBY)
+      OpenSSL::Cipher::BF.new('ecb')
+      ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use `OpenSSL::Cipher.new('bf-ecb')` instead of `OpenSSL::Cipher::BF.new('ecb')`.
+    RUBY
+
+    expect_correction(<<~RUBY)
+      OpenSSL::Cipher.new('bf-ecb')
+    RUBY
+  end
+
   it 'registers an offense with AES + blocksize constant and mode argument and corrects' do
     expect_offense(<<~RUBY)
       OpenSSL::Cipher::AES128.new(:GCM)
@@ -56,7 +78,7 @@ RSpec.describe RuboCop::Cop::Lint::DeprecatedOpenSSLConstant, :config do
     RUBY
   end
 
-  RuboCop::Cop::Lint::DeprecatedOpenSSLConstant::NO_ARG_ALGORITHM.each do |algorithm_name|
+  described_class::NO_ARG_ALGORITHM.each do |algorithm_name|
     it 'registers an offense with cipher constant and no arguments and corrects' do
       expect_offense(<<~RUBY, algorithm_name: algorithm_name)
         OpenSSL::Cipher::#{algorithm_name}.new
@@ -93,19 +115,25 @@ RSpec.describe RuboCop::Cop::Lint::DeprecatedOpenSSLConstant, :config do
     RUBY
   end
 
-  it 'does not register an offense with cipher constant and send argument is a method' do
+  it 'does not register an offense with cipher constant and argument is a method call' do
     expect_no_offenses(<<~RUBY)
       OpenSSL::Cipher::AES128.new(do_something)
     RUBY
   end
 
+  it 'does not register an offense with cipher constant and argument is a safe navigation method call' do
+    expect_no_offenses(<<~RUBY)
+      OpenSSL::Cipher::AES128.new(foo&.bar)
+    RUBY
+  end
+
   it 'does not register an offense with cipher constant and argument is a constant' do
     expect_no_offenses(<<~RUBY)
       OpenSSL::Cipher::AES128.new(MODE)
     RUBY
   end
 
-  it 'registers an offense when building an instance using an digest constant and corrects' do
+  it 'registers an offense when building an instance using a digest constant and corrects' do
     expect_offense(<<~RUBY)
       OpenSSL::Digest::SHA256.new
       ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use `OpenSSL::Digest.new('SHA256')` instead of `OpenSSL::Digest::SHA256.new`.
@@ -127,7 +155,7 @@ RSpec.describe RuboCop::Cop::Lint::DeprecatedOpenSSLConstant, :config do
     RUBY
   end
 
-  it 'registers an offense when using an digest constant with chained methods and corrects' do
+  it 'registers an offense when using a digest constant with chained methods and corrects' do
     expect_offense(<<~RUBY)
       OpenSSL::Digest::SHA256.new.digest('foo')
       ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use `OpenSSL::Digest.new('SHA256')` instead of `OpenSSL::Digest::SHA256.new`.
