@@ -10,7 +10,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction('')
+    expect_no_corrections
   end
 
   it 'registers an offense for missing `if` and `else` body' do
@@ -21,7 +21,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction('')
+    expect_no_corrections
   end
 
   it 'registers an offense for missing `if` and `else` body with some indentation' do
@@ -34,13 +34,10 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction(<<~RUBY)
-      def foo
-          end
-    RUBY
+    expect_no_corrections
   end
 
-  it 'registers an offense for missing `if` body with present `else` body' do
+  it 'registers an offense and corrects for missing `if` body with present `else` body' do
     expect_offense(<<~RUBY)
       class Foo
         if condition
@@ -60,6 +57,13 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
     RUBY
   end
 
+  # This case is registered by `Style/IfWithSemicolon` cop. Therefore, this cop does not handle it.
+  it 'does not register an offense for missing `if` body with present `else` body on single line' do
+    expect_no_offenses(<<~RUBY)
+      if condition; else do_something end
+    RUBY
+  end
+
   it 'does not register an offense for missing `if` body with a comment' do
     expect_no_offenses(<<~RUBY)
       if condition
@@ -68,6 +72,43 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
     RUBY
   end
 
+  it 'does not register an offense for missing 2nd `if` body with a comment' do
+    expect_no_offenses(<<~RUBY)
+      if condition1
+        do_something1
+      end
+      if condition2
+        # noop
+      end
+    RUBY
+  end
+
+  it 'does not register an offense for missing 2nd `elsif` body with a comment' do
+    expect_no_offenses(<<~RUBY)
+      if condition1
+        do_something1
+      elsif condition2
+        do_something2
+      elsif condition3
+        # noop
+      end
+    RUBY
+  end
+
+  it 'does not register an offense for missing 3rd `elsif` body with a comment' do
+    expect_no_offenses(<<~RUBY)
+      if condition1
+        do_something1
+      elsif condition2
+        do_something2
+      elsif condition3
+        do_something3
+      elsif condition4
+        # noop
+      end
+    RUBY
+  end
+
   it 'registers an offense for missing `elsif` body' do
     expect_offense(<<~RUBY)
       if condition
@@ -79,13 +120,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction(<<~RUBY)
-      if condition
-        do_something1
-      elsif other_condition2
-        do_something2
-      end
-    RUBY
+    expect_no_corrections
   end
 
   it 'registers an offense for missing `if` and `elsif` body' do
@@ -99,11 +134,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction(<<~RUBY)
-      if other_condition2
-        do_something
-      end
-    RUBY
+    expect_no_corrections
   end
 
   it 'registers an offense for missing all branches of `if` and `elsif` body' do
@@ -115,7 +146,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction('')
+    expect_no_corrections
   end
 
   it 'registers an offense for missing all branches of `if` and multiple `elsif` body' do
@@ -129,10 +160,10 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction('')
+    expect_no_corrections
   end
 
-  it 'registers an offense for missing `if` body with `else`' do
+  it 'registers an offense and corrects for missing `if` body with `else`' do
     expect_offense(<<~RUBY)
       if condition
       ^^^^^^^^^^^^ Avoid `if` branches without a body.
@@ -148,7 +179,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
     RUBY
   end
 
-  it 'registers an offense for missing `unless` body with `else`' do
+  it 'registers an offense and corrects for missing `unless` body with `else`' do
     expect_offense(<<~RUBY)
       unless condition
       ^^^^^^^^^^^^^^^^ Avoid `unless` branches without a body.
@@ -164,6 +195,38 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
     RUBY
   end
 
+  it 'registers an offense and corrects for missing `if` body with conditional `else` body' do
+    expect_offense(<<~RUBY)
+      if condition
+      ^^^^^^^^^^^^ Avoid `if` branches without a body.
+      else
+        do_something if x
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      unless condition
+        do_something if x
+      end
+    RUBY
+  end
+
+  it 'registers an offense and corrects for missing `unless` body with conditional `else` body' do
+    expect_offense(<<~RUBY)
+      unless condition
+      ^^^^^^^^^^^^^^^^ Avoid `unless` branches without a body.
+      else
+        do_something if x
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if condition
+        do_something if x
+      end
+    RUBY
+  end
+
   it 'registers an offense for missing `unless` and `else` body' do
     expect_offense(<<~RUBY)
       unless condition
@@ -172,7 +235,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction('')
+    expect_no_corrections
   end
 
   it 'registers an offense for missing `if` body with `elsif`' do
@@ -186,13 +249,29 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction(<<~RUBY)
-      if other_condition
-        do_something
-      elsif another_condition
-        do_something_else
-      end
+    expect_no_corrections
+  end
+
+  it 'registers an offense for missing `elsif` body with `end` on the same line' do
+    expect_offense(<<~RUBY)
+      if cond_a
+        do_a
+      elsif cond_b;end
+      ^^^^^^^^^^^^^ Avoid `elsif` branches without a body.
     RUBY
+
+    expect_no_corrections
+  end
+
+  it 'registers an offense for missing `elsif` and `else` bodies with `end` on the same line' do
+    expect_offense(<<~RUBY)
+      if cond_a
+        do_a
+      elsif cond_b;else;end
+      ^^^^^^^^^^^^^ Avoid `elsif` branches without a body.
+    RUBY
+
+    expect_no_corrections
   end
 
   it 'does not register an offense for missing `elsif` body with a comment' do
@@ -216,13 +295,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction(<<~RUBY)
-      if condition
-        do_something
-      else
-        # noop
-      end
-    RUBY
+    expect_no_corrections
   end
 
   it 'does not register an offense for missing `elsif` body with an inline comment' do
@@ -247,13 +320,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction(<<~RUBY)
-      if foo
-        do_foo
-      elsif bar
-        do_bar
-      end
-    RUBY
+    expect_no_corrections
   end
 
   it 'registers an offense for missing `unless` body' do
@@ -263,7 +330,27 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction('')
+    expect_no_corrections
+  end
+
+  it 'registers an offense when missing `if` body and using method call for return value' do
+    expect_offense(<<~RUBY)
+      if condition
+      ^^^^^^^^^^^^ Avoid `if` branches without a body.
+      end.do_something
+    RUBY
+
+    expect_no_corrections
+  end
+
+  it 'registers an offense when missing `if` body and using safe navigation method call for return value' do
+    expect_offense(<<~RUBY)
+      if condition
+      ^^^^^^^^^^^^ Avoid `if` branches without a body.
+      end&.do_something
+    RUBY
+
+    expect_no_corrections
   end
 
   it 'does not register an offense for missing `unless` body with a comment' do
@@ -274,7 +361,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
     RUBY
   end
 
-  it 'autocorrects properly when the if is assigned to a variable' do
+  it 'registers an offense when the if is assigned to a variable' do
     expect_offense(<<~RUBY)
       x = if foo
           ^^^^^^ Avoid `if` branches without a body.
@@ -283,14 +370,101 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
       end
     RUBY
 
-    expect_correction(<<~RUBY)
-      x = if bar
-        5
+    expect_no_corrections
+  end
+
+  it 'registers an offense when there is only one branch with assignment' do
+    expect_offense(<<~RUBY)
+      x = if foo
+          ^^^^^^ Avoid `if` branches without a body.
+      end
+    RUBY
+
+    expect_no_corrections
+  end
+
+  it 'registers an offense when there is only one branch after `||`' do
+    expect_offense(<<~RUBY)
+      x || if foo
+           ^^^^^^ Avoid `if` branches without a body.
+      end
+    RUBY
+
+    expect_no_corrections
+  end
+
+  it 'does not register an offense for an `if` with `nil` body' do
+    expect_no_offenses(<<~RUBY)
+      if condition
+        nil
       end
     RUBY
   end
 
-  context 'when AllowComments is false' do
+  it 'does not register an offense for an `unless` with `nil` body' do
+    expect_no_offenses(<<~RUBY)
+      unless condition
+        nil
+      end
+    RUBY
+  end
+
+  it 'does not register an offense for an `elsif` with `nil` body' do
+    expect_no_offenses(<<~RUBY)
+      if condition
+        do_something
+      elsif other_condition
+        nil
+      end
+    RUBY
+  end
+
+  context '>= Ruby 3.1', :ruby31 do
+    it 'registers an offense for multi-line value omission in `unless`' do
+      expect_offense(<<~RUBY)
+        var =
+          # This is the value of `other:`, like so: `other: condition || other_condition`
+          unless object.action value:, other:
+          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Avoid `unless` branches without a body.
+            condition || other_condition
+          end
+      RUBY
+
+      expect_no_corrections
+    end
+  end
+
+  context 'when `AllowComments` is `true`' do
+    let(:cop_config) { { 'AllowComments' => true } }
+
+    it 'does not register an offense for missing `if` body with a comment' do
+      expect_no_offenses(<<~RUBY)
+        if condition
+          # noop
+        end
+      RUBY
+    end
+
+    it 'does not register an offense for missing `elsif` body with a comment' do
+      expect_no_offenses(<<~RUBY)
+        if condition
+          do_something
+        elsif other_condition
+          # noop
+        end
+      RUBY
+    end
+
+    it 'does not register an offense for missing `unless` body with a comment' do
+      expect_no_offenses(<<~RUBY)
+        unless condition
+          # noop
+        end
+      RUBY
+    end
+  end
+
+  context 'when `AllowComments` is `false`' do
     let(:cop_config) { { 'AllowComments' => false } }
 
     it 'registers an offense for missing `if` body with a comment' do
@@ -301,7 +475,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
         end
       RUBY
 
-      expect_correction('')
+      expect_no_corrections
     end
 
     it 'registers an offense for missing `elsif` body with a comment' do
@@ -314,11 +488,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
         end
       RUBY
 
-      expect_correction(<<~RUBY)
-        if condition
-          do_something
-        end
-      RUBY
+      expect_no_corrections
     end
 
     it 'registers an offense for missing `unless` body with a comment' do
@@ -329,7 +499,7 @@ RSpec.describe RuboCop::Cop::Lint::EmptyConditionalBody, :config do
         end
       RUBY
 
-      expect_correction('')
+      expect_no_corrections
     end
   end
 end
