@@ -8,7 +8,7 @@ RSpec.describe RuboCop::Cop::Lint::MissingCopEnableDirective, :config do
     it 'registers an offense when a cop is disabled and never re-enabled' do
       expect_offense(<<~RUBY)
         # rubocop:disable Layout/SpaceAroundOperators
-        ^ Re-enable Layout/SpaceAroundOperators cop with `# rubocop:enable` after disabling it.
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Re-enable Layout/SpaceAroundOperators cop with `# rubocop:enable` after disabling it.
         x =   0
         # Some other code
       RUBY
@@ -26,7 +26,7 @@ RSpec.describe RuboCop::Cop::Lint::MissingCopEnableDirective, :config do
     it 'registers an offense when a department is disabled and never re-enabled' do
       expect_offense(<<~RUBY)
         # rubocop:disable Layout
-        ^ Re-enable Layout department with `# rubocop:enable` after disabling it.
+        ^^^^^^^^^^^^^^^^^^^^^^^^ Re-enable Layout department with `# rubocop:enable` after disabling it.
         x =   0
         # Some other code
       RUBY
@@ -48,7 +48,7 @@ RSpec.describe RuboCop::Cop::Lint::MissingCopEnableDirective, :config do
     it 'registers an offense when a cop is disabled for too many lines' do
       expect_offense(<<~RUBY)
         # rubocop:disable Layout/SpaceAroundOperators
-        ^ Re-enable Layout/SpaceAroundOperators cop within 2 lines after disabling it.
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Re-enable Layout/SpaceAroundOperators cop within 2 lines after disabling it.
         x =   0
         y = 1
         # Some other code
@@ -59,7 +59,7 @@ RSpec.describe RuboCop::Cop::Lint::MissingCopEnableDirective, :config do
     it 'registers an offense when a cop is disabled and never re-enabled' do
       expect_offense(<<~RUBY)
         # rubocop:disable Layout/SpaceAroundOperators
-        ^ Re-enable Layout/SpaceAroundOperators cop within 2 lines after disabling it.
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Re-enable Layout/SpaceAroundOperators cop within 2 lines after disabling it.
         x =   0
         # Some other code
       RUBY
@@ -78,7 +78,7 @@ RSpec.describe RuboCop::Cop::Lint::MissingCopEnableDirective, :config do
     it 'registers an offense when a department is disabled for too many lines' do
       expect_offense(<<~RUBY)
         # rubocop:disable Layout
-        ^ Re-enable Layout department within 2 lines after disabling it.
+        ^^^^^^^^^^^^^^^^^^^^^^^^ Re-enable Layout department within 2 lines after disabling it.
         x =   0
         y = 1
         # Some other code
@@ -89,7 +89,7 @@ RSpec.describe RuboCop::Cop::Lint::MissingCopEnableDirective, :config do
     it 'registers an offense when a department is disabled and never re-enabled' do
       expect_offense(<<~RUBY)
         # rubocop:disable Layout
-        ^ Re-enable Layout department within 2 lines after disabling it.
+        ^^^^^^^^^^^^^^^^^^^^^^^^ Re-enable Layout department within 2 lines after disabling it.
         x =   0
         # Some other code
       RUBY
