@@ -68,7 +68,7 @@ RSpec.describe RuboCop::Cop::Lint::RedundantSplatExpansion, :config do
         RUBY
 
         expect_correction(<<~RUBY)
-          array.push(#{as_array})
+          array.push(#{literal})
         RUBY
       end
     end
@@ -83,7 +83,7 @@ RSpec.describe RuboCop::Cop::Lint::RedundantSplatExpansion, :config do
   it_behaves_like 'splat expansion', '1.1', as_array: '[1.1]'
 
   context 'assignment to splat expansion' do
-    it 'registers an offense and corrects an array using a constructor' do
+    it 'registers an offense and corrects an array constructor in a local variable assignment' do
       expect_offense(<<~RUBY)
         a = *Array.new(3) { 42 }
             ^^^^^^^^^^^^^^^^^^^^ Replace splat expansion with comma separated values.
@@ -94,6 +94,50 @@ RSpec.describe RuboCop::Cop::Lint::RedundantSplatExpansion, :config do
       RUBY
     end
 
+    it 'registers an offense and corrects an array constructor in an instance variable assignment' do
+      expect_offense(<<~RUBY)
+        @a = *Array.new(3) { 42 }
+             ^^^^^^^^^^^^^^^^^^^^ Replace splat expansion with comma separated values.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        @a = Array.new(3) { 42 }
+      RUBY
+    end
+
+    it 'registers an offense and corrects an array constructor in a class variable assignment' do
+      expect_offense(<<~RUBY)
+        @@a = *Array.new(3) { 42 }
+              ^^^^^^^^^^^^^^^^^^^^ Replace splat expansion with comma separated values.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        @@a = Array.new(3) { 42 }
+      RUBY
+    end
+
+    it 'registers an offense and corrects an array constructor in a global variable assignment' do
+      expect_offense(<<~RUBY)
+        $a = *Array.new(3) { 42 }
+             ^^^^^^^^^^^^^^^^^^^^ Replace splat expansion with comma separated values.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        $a = Array.new(3) { 42 }
+      RUBY
+    end
+
+    it 'registers an offense and corrects an array constructor in a constant assignment' do
+      expect_offense(<<~RUBY)
+        A = *Array.new(3) { 42 }
+            ^^^^^^^^^^^^^^^^^^^^ Replace splat expansion with comma separated values.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        A = Array.new(3) { 42 }
+      RUBY
+    end
+
     it 'registers and corrects an array using top-level const' do
       expect_offense(<<~RUBY)
         a = *::Array.new(3) { 42 }
@@ -286,6 +330,17 @@ RSpec.describe RuboCop::Cop::Lint::RedundantSplatExpansion, :config do
         ["a", "b", "\#{one}", "two"]
       RUBY
     end
+
+    it 'registers an offense and corrects expansion of splatted string literal' do
+      expect_offense(<<~RUBY)
+        ["a", "b", *"c"]
+                   ^^^^ Replace splat expansion with comma separated values.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        ["a", "b", "c"]
+      RUBY
+    end
   end
 
   it 'allows expanding a method call on an array literal' do
@@ -371,13 +426,19 @@ RSpec.describe RuboCop::Cop::Lint::RedundantSplatExpansion, :config do
     let(:cop_config) { { 'AllowPercentLiteralArrayArgument' => true } }
 
     it 'does not register an offense when using percent string literal array' do
-      expect_no_offenses(<<~'RUBY')
+      expect_no_offenses(<<~RUBY)
         do_something(*%w[foo bar baz])
       RUBY
     end
 
+    it 'does not register an offense when using percent string literal array in safe navigation' do
+      expect_no_offenses(<<~RUBY)
+        maybe_nil&.do_something(*%w[foo bar baz])
+      RUBY
+    end
+
     it 'does not register an offense when using percent symbol literal array' do
-      expect_no_offenses(<<~'RUBY')
+      expect_no_offenses(<<~RUBY)
         do_something(*%i[foo bar baz])
       RUBY
     end
@@ -390,17 +451,32 @@ RSpec.describe RuboCop::Cop::Lint::RedundantSplatExpansion, :config do
     it_behaves_like 'array splat expansion', '%W(one #{two} three)', as_args: '"one", "#{two}", "three"'
 
     it 'registers an offense when using percent literal array' do
-      expect_offense(<<~'RUBY')
+      expect_offense(<<~RUBY)
         do_something(*%w[foo bar baz])
                      ^^^^^^^^^^^^^^^^ Pass array contents as separate arguments.
       RUBY
+
+      expect_correction(<<~RUBY)
+        do_something('foo', 'bar', 'baz')
+      RUBY
+    end
+
+    it 'registers an offense when using percent literal array in safe navigation' do
+      expect_offense(<<~RUBY)
+        maybe_nil&.do_something(*%w[foo bar baz])
+                                ^^^^^^^^^^^^^^^^ Pass array contents as separate arguments.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        maybe_nil&.do_something('foo', 'bar', 'baz')
+      RUBY
     end
 
     it_behaves_like 'array splat expansion', '%i(first second)', as_args: ':first, :second'
     it_behaves_like 'array splat expansion', '%I(first second #{third})', as_args: ':"first", :"second", :"#{third}"'
 
     it 'registers an offense when using percent symbol literal array' do
-      expect_offense(<<~'RUBY')
+      expect_offense(<<~RUBY)
         do_something(*%i[foo bar baz])
                      ^^^^^^^^^^^^^^^^ Pass array contents as separate arguments.
       RUBY
