@@ -28,7 +28,7 @@ RSpec.describe RuboCop::Cop::Lint::ShadowedException, :config do
       RUBY
     end
 
-    it 'rescue a exception without causing constant name deprecation warning' do
+    it 'rescue an exception without causing constant name deprecation warning' do
       expect do
         expect_no_offenses(<<~RUBY)
           def foo
@@ -87,7 +87,7 @@ RSpec.describe RuboCop::Cop::Lint::ShadowedException, :config do
 
     it 'registers an offense rescuing exceptions that are ancestors of each other' do
       expect_offense(<<~RUBY)
-        def
+        def foo
           something
         rescue StandardError, RuntimeError
         ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not shadow rescued Exceptions.
