@@ -2,10 +2,10 @@
 
 RSpec.describe RuboCop::Cop::Lint::UnifiedInteger, :config do
   shared_examples 'registers an offense' do |klass|
-    context 'target ruby version < 2.4', :ruby23 do
+    context 'target ruby version < 2.4', :ruby23, unsupported_on: :prism do
       context "when #{klass}" do
         context 'without any decorations' do
-          it 'registers an offense and autocorrects' do
+          it 'registers an offense but does not correct' do
             expect_offense(<<~RUBY, klass: klass)
               1.is_a?(%{klass})
                       ^{klass} Use `Integer` instead of `#{klass}`.
@@ -16,8 +16,6 @@ RSpec.describe RuboCop::Cop::Lint::UnifiedInteger, :config do
         end
 
         context 'when explicitly specified as toplevel constant' do
-          let(:source) { "1.is_a?(::#{klass})" }
-
           it 'registers an offense' do
             expect_offense(<<~RUBY, klass: klass)
               1.is_a?(::%{klass})
@@ -73,8 +71,8 @@ RSpec.describe RuboCop::Cop::Lint::UnifiedInteger, :config do
     end
   end
 
-  include_examples 'registers an offense', 'Fixnum'
-  include_examples 'registers an offense', 'Bignum'
+  it_behaves_like 'registers an offense', 'Fixnum'
+  it_behaves_like 'registers an offense', 'Bignum'
 
   context 'when Integer' do
     context 'without any decorations' do
