@@ -16,6 +16,12 @@ RSpec.describe RuboCop::Cop::Lint::UnmodifiedReduceAccumulator, :config do
       RUBY
     end
 
+    it "does not affect #{method} called with an empty block" do
+      expect_no_offenses(<<~RUBY)
+        values.#{method}(:+) { |result, value| }
+      RUBY
+    end
+
     context "given a #{method} block" do
       it 'does not register an offense when returning a literal' do
         expect_no_offenses(<<~RUBY)
@@ -45,6 +51,25 @@ RSpec.describe RuboCop::Cop::Lint::UnmodifiedReduceAccumulator, :config do
         end
       end
 
+      it 'registers an offense when returning the element in the block of safe navigation method call' do
+        aggregate_failures do
+          expect_offense(<<~RUBY)
+            (1..4)&.#{method}(0) do |acc, el|
+              el
+              ^^ Ensure the accumulator `acc` will be modified by `#{method}`.
+            end
+          RUBY
+
+          expect_offense(<<~RUBY)
+            values&.#{method}({}) do |acc, el|
+              acc[el] = true
+              el
+              ^^ Ensure the accumulator `acc` will be modified by `#{method}`.
+            end
+          RUBY
+        end
+      end
+
       it 'registers an offense when called with no argument' do
         expect_offense(<<~RUBY)
           (1..4).#{method} do |acc, el|
@@ -552,6 +577,28 @@ RSpec.describe RuboCop::Cop::Lint::UnmodifiedReduceAccumulator, :config do
         RUBY
       end
 
+      it 'does not look inside inner numblocks' do
+        expect_no_offenses(<<~RUBY)
+          foo.#{method}(bar) do |acc, el|
+            values.map do
+              next el if something?
+              _1
+            end
+          end
+        RUBY
+      end
+
+      it 'does not look inside inner itblocks', :ruby34 do
+        expect_no_offenses(<<~RUBY)
+          foo.#{method}(bar) do |acc, el|
+            values.map do
+              next el if something?
+              it
+            end
+          end
+        RUBY
+      end
+
       it 'allows break with no value' do
         expect_no_offenses(<<~RUBY)
           foo.#{method}([]) do |acc, el|
@@ -579,13 +626,13 @@ RSpec.describe RuboCop::Cop::Lint::UnmodifiedReduceAccumulator, :config do
 
       context 'argument count' do
         it 'ignores when there are not enough block arguments' do
-          expect_no_offenses(<<~RUBY, method: method)
+          expect_no_offenses(<<~RUBY)
             (1..4).#{method}(0) { |acc| acc.foo }
           RUBY
         end
 
         it 'ignores when there is a splat argument' do
-          expect_no_offenses(<<~RUBY, method: method)
+          expect_no_offenses(<<~RUBY)
             values.#{method}(0) { |*x| x[0] + x[1] }
           RUBY
         end
@@ -609,7 +656,14 @@ RSpec.describe RuboCop::Cop::Lint::UnmodifiedReduceAccumulator, :config do
           RUBY
         end
 
-        it 'does not register an offense when when returning the accumulator' do
+        it 'registers an offense when returning the element in the block of safe navigation method call' do
+          expect_offense(<<~RUBY, method: method)
+            (1..4)&.#{method}(0) { _2 }
+                    _{method}      ^^ Ensure the accumulator `_1` will be modified by `#{method}`.
+          RUBY
+        end
+
+        it 'does not register an offense when returning the accumulator' do
           expect_no_offenses(<<~RUBY)
             values.#{method}(0) { _1 + _2 }
           RUBY
