@@ -90,6 +90,46 @@ RSpec.describe RuboCop::Cop::Lint::UnreachableLoop, :config do
         end
       RUBY
     end
+
+    it 'registers an offense when using `case-in-else` with all break branches' do
+      expect_offense(<<~RUBY)
+        while x > 0
+        ^^^^^^^^^^^ This loop will have at most one iteration.
+          case x
+          in 1
+            break
+          else
+            raise MyError
+          end
+        end
+      RUBY
+    end
+
+    it 'does not register an offense when using `case` match without `else`' do
+      expect_no_offenses(<<~RUBY)
+        while x > 0
+          case x
+          in 1
+            break
+          end
+        end
+      RUBY
+    end
+
+    it 'does not register an offense when using `case-in-else` and not all branches are breaking' do
+      expect_no_offenses(<<~RUBY)
+        while x > 0
+          case x
+          in 1
+            break
+          in 2
+            do_something
+          else
+            raise MyError
+          end
+        end
+      RUBY
+    end
   end
 
   context 'with preceding continue statements' do
@@ -130,6 +170,21 @@ RSpec.describe RuboCop::Cop::Lint::UnreachableLoop, :config do
         end
       RUBY
     end
+
+    it 'does not register an offense when using `case-in-else` with all break branches' do
+      expect_no_offenses(<<~RUBY)
+        while x > 0
+          redo if x.odd?
+
+          case x
+          in 1
+            break
+          else
+            raise MyError
+          end
+        end
+      RUBY
+    end
   end
 
   context 'with an enumerator method' do
@@ -163,7 +218,7 @@ RSpec.describe RuboCop::Cop::Lint::UnreachableLoop, :config do
   context 'with AllowedPatterns' do
     let(:cop_config) { { 'AllowedPatterns' => [/exactly\(\d+\)\.times/] } }
 
-    context 'with a ignored method call' do
+    context 'with an ignored method call' do
       it 'does not register an offense' do
         expect_no_offenses(<<~RUBY)
           exactly(2).times { raise StandardError }
@@ -187,6 +242,15 @@ RSpec.describe RuboCop::Cop::Lint::UnreachableLoop, :config do
           RUBY
         end
       end
+
+      context 'Ruby 3.4', :ruby34 do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            2.times { raise it }
+            ^^^^^^^^^^^^^^^^^^^^ This loop will have at most one iteration.
+          RUBY
+        end
+      end
     end
   end
 
@@ -270,4 +334,15 @@ RSpec.describe RuboCop::Cop::Lint::UnreachableLoop, :config do
       RUBY
     end
   end
+
+  context 'Ruby 3.4', :ruby34 do
+    it 'registers an offense when using `return do_something(value) || break` in a loop' do
+      expect_offense(<<~RUBY)
+        [1, 2, 3].each do
+        ^^^^^^^^^^^^^^^^^ This loop will have at most one iteration.
+          return it.odd? || break
+        end
+      RUBY
+    end
+  end
 end
