@@ -29,6 +29,30 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier, :config do
     end
   end
 
+  context 'when an access modifier is used on top-level' do
+    it 'registers an offense and corrects' do
+      expect_offense(<<~RUBY)
+        def some_method
+          puts 10
+        end
+        private
+        ^^^^^^^ Useless `private` access modifier.
+        def other_method
+          puts 10
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        def some_method
+          puts 10
+        end
+        def other_method
+          puts 10
+        end
+      RUBY
+    end
+  end
+
   context 'when an access modifier has no methods' do
     it 'registers an offense and corrects' do
       expect_offense(<<~RUBY)
@@ -367,7 +391,7 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier, :config do
     end
   end
 
-  context 'when using ActiveSupport behavior when Rails is not eabled' do
+  context 'when using ActiveSupport behavior when Rails is not enabled' do
     it 'reports offenses and corrects' do
       expect_offense(<<~RUBY)
         module SomeModule
@@ -1019,6 +1043,58 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier, :config do
     end
   end
 
+  context '`def` in `Data.define` block', :ruby32 do
+    %w[protected private].each do |modifier|
+      it "doesn't register an offense if a method is defined in `Data.define` with block" do
+        expect_no_offenses(<<~RUBY)
+          Data.define do
+            #{modifier}
+            def foo
+            end
+          end
+        RUBY
+      end
+
+      it 'registers an offense if no method is defined in `Data.define` with block' do
+        expect_offense(<<~RUBY, modifier: modifier)
+          Data.define do
+            %{modifier}
+            ^{modifier} Useless `#{modifier}` access modifier.
+          end
+        RUBY
+      end
+
+      it 'registers an offense if no method is defined in `::Data.define` with block' do
+        expect_offense(<<~RUBY, modifier: modifier)
+          ::Data.define do
+            %{modifier}
+            ^{modifier} Useless `#{modifier}` access modifier.
+          end
+        RUBY
+      end
+
+      it 'registers an offense if no method is defined in `Data.define` with numblock' do
+        expect_offense(<<~RUBY, modifier: modifier)
+          Data.define do
+            %{modifier}
+            ^{modifier} Useless `#{modifier}` access modifier.
+            do_something(_1)
+          end
+        RUBY
+      end
+
+      it 'registers an offense if no method is defined in `Data.define` with itblock', :ruby34 do
+        expect_offense(<<~RUBY, modifier: modifier)
+          Data.define do
+            %{modifier}
+            ^{modifier} Useless `#{modifier}` access modifier.
+            do_something(it)
+          end
+        RUBY
+      end
+    end
+  end
+
   %w[module class].each do |keyword|
     it_behaves_like('at the top of the body', keyword)
     it_behaves_like('non-repeated visibility modifiers', keyword)
@@ -1039,4 +1115,113 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier, :config do
       it_behaves_like('nested modules', keyword, modifier)
     end
   end
+
+  context 'when `AllCops/ActiveSupportExtensionsEnabled: true`' do
+    let(:config) do
+      RuboCop::Config.new('AllCops' => { 'ActiveSupportExtensionsEnabled' => true })
+    end
+
+    context 'when using same access modifier inside and outside the included block' do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~RUBY)
+          class SomeClass
+            included do
+              private
+              def foo; end
+            end
+            private
+            def bar; end
+          end
+        RUBY
+      end
+
+      it 'registers an offense when using repeated access modifier inside/outside the included block' do
+        expect_offense(<<~RUBY)
+          class SomeClass
+            included do
+              private
+              private
+              ^^^^^^^ Useless `private` access modifier.
+              def foo; end
+            end
+            private
+            private
+            ^^^^^^^ Useless `private` access modifier.
+            def bar; end
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          class SomeClass
+            included do
+              private
+              def foo; end
+            end
+            private
+            def bar; end
+          end
+        RUBY
+      end
+    end
+  end
+
+  context 'when `AllCops/ActiveSupportExtensionsEnabled: false`' do
+    let(:config) do
+      RuboCop::Config.new('AllCops' => { 'ActiveSupportExtensionsEnabled' => false })
+    end
+
+    context 'when using same access modifier inside and outside the `included` block' do
+      it 'registers an offense' do
+        expect_offense(<<~RUBY)
+          class SomeClass
+            included do
+              private
+              def foo; end
+            end
+            private
+            ^^^^^^^ Useless `private` access modifier.
+            def bar; end
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          class SomeClass
+            included do
+              private
+              def foo; end
+            end
+            def bar; end
+          end
+        RUBY
+      end
+
+      it 'registers an offense when using repeated access modifier inside/outside the `included` block' do
+        expect_offense(<<~RUBY)
+          class SomeClass
+            included do
+              private
+              private
+              ^^^^^^^ Useless `private` access modifier.
+              def foo; end
+            end
+            private
+            ^^^^^^^ Useless `private` access modifier.
+            private
+            ^^^^^^^ Useless `private` access modifier.
+            def bar; end
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          class SomeClass
+            included do
+              private
+              def foo; end
+            end
+            def bar; end
+          end
+        RUBY
+      end
+    end
+  end
 end
