@@ -96,4 +96,50 @@ RSpec.describe RuboCop::Cop::Metrics::ParameterLists, :config do
       end
     RUBY
   end
+
+  it 'registers an offense when defining `initialize` in the `class` definition' do
+    expect_offense(<<~RUBY)
+      class Foo
+        def initialize(one:, two:, three:, four:, five:)
+                      ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Avoid parameter lists longer than 4 parameters. [5/4]
+        end
+      end
+    RUBY
+  end
+
+  it 'does not register an offense when defining `initialize` in the block of `Struct.new`' do
+    expect_no_offenses(<<~RUBY)
+      Struct.new(:one, :two, :three, :four, :five) do
+        def initialize(one:, two:, three:, four:, five:)
+        end
+      end
+    RUBY
+  end
+
+  it 'does not register an offense when defining `initialize` in the block of `::Struct.new`' do
+    expect_no_offenses(<<~RUBY)
+      ::Struct.new(:one, :two, :three, :four, :five) do
+        def initialize(one:, two:, three:, four:, five:)
+        end
+      end
+    RUBY
+  end
+
+  it 'does not register an offense when defining `initialize` in the block of `Data.define`' do
+    expect_no_offenses(<<~RUBY)
+      Data.define(:one, :two, :three, :four, :five) do
+        def initialize(one:, two:, three:, four:, five:)
+        end
+      end
+    RUBY
+  end
+
+  it 'does not register an offense when defining `initialize` in the block of `::Data.define`' do
+    expect_no_offenses(<<~RUBY)
+      ::Data.define(:one, :two, :three, :four, :five) do
+        def initialize(one:, two:, three:, four:, five:)
+        end
+      end
+    RUBY
+  end
 end
