@@ -42,7 +42,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for an if modifier' do
       expect_offense(<<~RUBY)
         def self.method_name
-        ^^^^^^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           call_foo if some_condition
         end
       RUBY
@@ -51,7 +51,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for an unless modifier' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           call_foo unless some_condition
         end
       RUBY
@@ -60,7 +60,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for elsif and else blocks' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [4/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [4/1]
           if first_condition then
             call_foo
           elsif second_condition then
@@ -75,7 +75,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for a ternary operator' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           value = some_condition ? 1 : 2
         end
       RUBY
@@ -84,7 +84,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for a while block' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           while some_condition do
             call_foo
           end
@@ -95,7 +95,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for an until block' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           until some_condition do
             call_foo
           end
@@ -106,7 +106,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for a for block' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           for i in 1..2 do
             call_method
           end
@@ -117,7 +117,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for a rescue block' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           begin
             call_foo
           rescue Exception
@@ -130,7 +130,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for a case/when block' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [3/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [3/1]
           case value
           when 1 then call_foo_1
           when 2 then call_foo_2
@@ -144,7 +144,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for a case/when block without an expression after case' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [3/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [3/1]
           case
           when value == 1
             call_foo
@@ -158,7 +158,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'counts else in a case with no argument' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [4/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [4/1]
           case
           when value == 1
             call_foo
@@ -174,7 +174,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for &&' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           call_foo && call_bar
         end
       RUBY
@@ -183,7 +183,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for and' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           call_foo and call_bar
         end
       RUBY
@@ -192,7 +192,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for ||' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           call_foo || call_bar
         end
       RUBY
@@ -201,7 +201,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for or' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           call_foo or call_bar
         end
       RUBY
@@ -210,7 +210,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'deals with nested if blocks containing && and ||' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [6/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [6/1]
           if first_condition then
             call_foo if second_condition && third_condition
             call_bar if fourth_condition || fifth_condition
@@ -222,12 +222,12 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'counts only a single method' do
       expect_offense(<<~RUBY)
         def method_name_1
-        ^^^^^^^^^^^^^^^^^ Perceived complexity for method_name_1 is too high. [2/1]
+        ^^^^^^^^^^^^^^^^^ Perceived complexity for `method_name_1` is too high. [2/1]
           call_foo if some_condition
         end
 
         def method_name_2
-        ^^^^^^^^^^^^^^^^^ Perceived complexity for method_name_2 is too high. [2/1]
+        ^^^^^^^^^^^^^^^^^ Perceived complexity for `method_name_2` is too high. [2/1]
           call_foo if some_condition
         end
       RUBY
@@ -236,7 +236,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'registers an offense for a `define_method`' do
       expect_offense(<<~RUBY)
         define_method :method_name do
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           call_foo if some_condition
         end
       RUBY
@@ -255,7 +255,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'counts known iterating block' do
       expect_offense(<<~RUBY)
         def method_name
-        ^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [2/1]
+        ^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [2/1]
           ary.each do |x|
             foo(x)
           end
@@ -326,7 +326,7 @@ RSpec.describe RuboCop::Cop::Metrics::PerceivedComplexity, :config do
     it 'counts stupid nested if and else blocks' do
       expect_offense(<<~RUBY)
         def method_name                   # 1
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Perceived complexity for method_name is too high. [7/2]
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Perceived complexity for `method_name` is too high. [7/2]
           if first_condition then         # 2
             call_foo
           else                            # 3
