@@ -19,6 +19,12 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
               ^^^^^^^ Memoized variable `@my_var` does not match method name `x`. Use `@x` instead.
             end
           RUBY
+
+          expect_correction(<<~RUBY)
+            def x
+              @x ||= :foo
+            end
+          RUBY
         end
       end
 
@@ -30,6 +36,12 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
               ^^^^^^^ Memoized variable `@my_var` does not match method name `x`. Use `@x` instead.
             end
           RUBY
+
+          expect_correction(<<~RUBY)
+            def self.x
+              @x ||= :foo
+            end
+          RUBY
         end
       end
 
@@ -41,6 +53,12 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
               ^^ Memoized variable `@y` does not match method name `x`. Use `@x` instead.
             end
           RUBY
+
+          expect_correction(<<~RUBY)
+            foo = def x
+              @x ||= :foo
+            end
+          RUBY
         end
       end
 
@@ -54,6 +72,14 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
               end
             end
           RUBY
+
+          expect_correction(<<~RUBY)
+            def x
+              @x ||= begin
+                :foo
+              end
+            end
+          RUBY
         end
       end
 
@@ -66,6 +92,13 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
               ^^^^ Memoized variable `@bar` does not match method name `foo`. Use `@foo` instead.
             end
           RUBY
+
+          expect_correction(<<~RUBY)
+            def foo
+              helper_variable = something_we_need_to_calculate_foo
+              @foo ||= calculate_expensive_thing(helper_variable)
+            end
+          RUBY
         end
 
         it 'registers an offense for a predicate method' do
@@ -76,6 +109,13 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
               ^^^^ Memoized variable `@bar` does not match method name `foo?`. Use `@foo` instead.
             end
           RUBY
+
+          expect_correction(<<~RUBY)
+            def foo?
+              helper_variable = something_we_need_to_calculate_foo
+              @foo ||= calculate_expensive_thing(helper_variable)
+            end
+          RUBY
         end
 
         it 'registers an offense for a bang method' do
@@ -86,6 +126,30 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
               ^^^^ Memoized variable `@bar` does not match method name `foo!`. Use `@foo` instead.
             end
           RUBY
+
+          expect_correction(<<~RUBY)
+            def foo!
+              helper_variable = something_we_need_to_calculate_foo
+              @foo ||= calculate_expensive_thing(helper_variable)
+            end
+          RUBY
+        end
+
+        it 'registers an offense for a assignment method' do
+          expect_offense(<<~RUBY)
+            def foo=(bar)
+              helper_variable = something_we_need_to_calculate(foo)
+              @bar ||= calculate_expensive_thing(helper_variable)
+              ^^^^ Memoized variable `@bar` does not match method name `foo=`. Use `@foo` instead.
+            end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            def foo=(bar)
+              helper_variable = something_we_need_to_calculate(foo)
+              @foo ||= calculate_expensive_thing(helper_variable)
+            end
+          RUBY
         end
       end
 
@@ -196,6 +260,36 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
               RUBY
             end
           end
+
+          context 'instance variables in `initialize_clone` method' do
+            it 'does not register an offense' do
+              expect_no_offenses(<<~RUBY)
+                def initialize_clone(obj)
+                  @files_with_offenses ||= {}
+                end
+              RUBY
+            end
+          end
+
+          context 'instance variables in `initialize_copy` method' do
+            it 'does not register an offense' do
+              expect_no_offenses(<<~RUBY)
+                def initialize_copy(obj)
+                  @files_with_offenses ||= {}
+                end
+              RUBY
+            end
+          end
+
+          context 'instance variables in `initialize_dup` method' do
+            it 'does not register an offense' do
+              expect_no_offenses(<<~RUBY)
+                def initialize_dup(obj)
+                  @files_with_offenses ||= {}
+                end
+              RUBY
+            end
+          end
         end
       end
 
@@ -218,6 +312,12 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                 ^^^^ Memoized variable `@foo` does not match method name `values`. Use `@values` instead.
               end
             RUBY
+
+            expect_correction(<<~RUBY)
+              define_method(:values) do
+                @values ||= do_something
+              end
+            RUBY
           end
         end
 
@@ -244,6 +344,14 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                   end
                 end
               RUBY
+
+              expect_correction(<<~RUBY)
+                def self.inherited(klass)
+                  klass.define_method(:values) do
+                    @values ||= do_something
+                  end
+                end
+              RUBY
             end
           end
         end
@@ -271,6 +379,14 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                   end
                 end
               RUBY
+
+              expect_correction(<<~RUBY)
+                def self.inherited(klass)
+                  klass.define_singleton_method(:values) do
+                    @values ||= do_something
+                  end
+                end
+              RUBY
             end
           end
         end
@@ -288,6 +404,13 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
             ^^^^^^^ Memoized variable `@my_var` does not match method name `x`. Use `@x` instead.
           end
         RUBY
+
+        expect_correction(<<~RUBY)
+          def x
+            return @x if defined?(@x)
+            @x = false
+          end
+        RUBY
       end
 
       it 'registers an offense when memoized variable does not match class method name' do
@@ -300,6 +423,13 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
             ^^^^^^^ Memoized variable `@my_var` does not match method name `x`. Use `@x` instead.
           end
         RUBY
+
+        expect_correction(<<~RUBY)
+          def self.x
+            return @x if defined?(@x)
+            @x = false
+          end
+        RUBY
       end
 
       context 'memoized variable matches method name' do
@@ -411,6 +541,13 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                 ^^^^ Memoized variable `@foo` does not match method name `values`. Use `@values` instead.
               end
             RUBY
+
+            expect_correction(<<~RUBY)
+              define_method(:values) do
+                return @values if defined?(@values)
+                @values = do_something
+              end
+            RUBY
           end
         end
 
@@ -441,6 +578,15 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                   end
                 end
               RUBY
+
+              expect_correction(<<~RUBY)
+                def self.inherited(klass)
+                  klass.define_method(:values) do
+                    return @values if defined?(@values)
+                    @values = do_something
+                  end
+                end
+              RUBY
             end
           end
         end
@@ -472,6 +618,15 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                   end
                 end
               RUBY
+
+              expect_correction(<<~RUBY)
+                def self.inherited(klass)
+                  klass.define_singleton_method(:values) do
+                    return @values if defined?(@values)
+                    @values = do_something
+                  end
+                end
+              RUBY
             end
           end
         end
@@ -490,6 +645,12 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
             ^^^^ Memoized variable `@foo` does not start with `_`. Use `@_foo` instead.
           end
         RUBY
+
+        expect_correction(<<~RUBY)
+          def foo
+            @_foo ||= :foo
+          end
+        RUBY
       end
 
       it 'registers an offense when it has leading `_` but names do not match' do
@@ -499,6 +660,12 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
             ^^^^^^^^ Memoized variable `@_my_var` does not match method name `foo`. Use `@_foo` instead.
           end
         RUBY
+
+        expect_correction(<<~RUBY)
+          def foo
+            @_foo ||= :foo
+          end
+        RUBY
       end
 
       it 'does not register an offense with a leading `_` for both names' do
@@ -528,6 +695,12 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                 ^^^^ Memoized variable `@foo` does not start with `_`. Use `@_values` instead.
               end
             RUBY
+
+            expect_correction(<<~RUBY)
+              define_method(:values) do
+                @_values ||= do_something
+              end
+            RUBY
           end
         end
 
@@ -554,6 +727,14 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                   end
                 end
               RUBY
+
+              expect_correction(<<~RUBY)
+                def self.inherited(klass)
+                  klass.define_method(:values) do
+                    @_values ||= do_something
+                  end
+                end
+              RUBY
             end
           end
         end
@@ -581,6 +762,14 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                   end
                 end
               RUBY
+
+              expect_correction(<<~RUBY)
+                def self.inherited(klass)
+                  klass.define_singleton_method(:values) do
+                    @_values ||= do_something
+                  end
+                end
+              RUBY
             end
           end
         end
@@ -598,6 +787,13 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
             ^^^^ Memoized variable `@foo` does not start with `_`. Use `@_foo` instead.
           end
         RUBY
+
+        expect_correction(<<~RUBY)
+          def foo
+            return @_foo if defined?(@_foo)
+            @_foo = false
+          end
+        RUBY
       end
 
       it 'registers an offense when it has leading `_` but names do not match' do
@@ -610,6 +806,13 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
             ^^^^^^^^ Memoized variable `@_my_var` does not match method name `foo`. Use `@_foo` instead.
           end
         RUBY
+
+        expect_correction(<<~RUBY)
+          def foo
+            return @_foo if defined?(@_foo)
+            @_foo = false
+          end
+        RUBY
       end
 
       it 'does not register an offense with a leading `_` for both names' do
@@ -644,6 +847,13 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                 ^^^^ Memoized variable `@foo` does not start with `_`. Use `@_values` instead.
               end
             RUBY
+
+            expect_correction(<<~RUBY)
+              define_method(:values) do
+                return @_values if defined?(@_values)
+                @_values = do_something
+              end
+            RUBY
           end
         end
 
@@ -674,6 +884,15 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                   end
                 end
               RUBY
+
+              expect_correction(<<~RUBY)
+                def self.inherited(klass)
+                  klass.define_method(:values) do
+                    return @_values if defined?(@_values)
+                    @_values = do_something
+                  end
+                end
+              RUBY
             end
           end
         end
@@ -705,6 +924,15 @@ RSpec.describe RuboCop::Cop::Naming::MemoizedInstanceVariableName, :config do
                   end
                 end
               RUBY
+
+              expect_correction(<<~RUBY)
+                def self.inherited(klass)
+                  klass.define_singleton_method(:values) do
+                    return @_values if defined?(@_values)
+                    @_values = do_something
+                  end
+                end
+              RUBY
             end
           end
         end
