@@ -16,8 +16,8 @@ RSpec.describe RuboCop::Cop::Offense do
     expect(offense.line).to eq(1)
     expect(offense.message).to eq('message')
     expect(offense.cop_name).to eq('CopName')
-    expect(offense.correctable?).to be_truthy
-    expect(offense.corrected?).to be_truthy
+    expect(offense).to be_correctable
+    expect(offense).to be_corrected
     expect(offense.highlighted_area.source).to eq('a')
   end
 
@@ -35,17 +35,17 @@ RSpec.describe RuboCop::Cop::Offense do
     o1 = described_class.new(:convention, location, 'message', 'CopName')
     o2 = described_class.new(:convention, location, 'message', 'CopName')
 
-    expect(o1 == o2).to be_truthy
+    expect(o1 == o2).to be(true)
   end
 
   it 'is frozen' do
-    expect(offense.frozen?).to be(true)
+    expect(offense).to be_frozen
   end
 
   %i[severity location message cop_name].each do |a|
     describe "##{a}" do
       it 'is frozen' do
-        expect(offense.public_send(a).frozen?).to be(true)
+        expect(offense.public_send(a)).to be_frozen
       end
     end
   end
@@ -58,6 +58,16 @@ RSpec.describe RuboCop::Cop::Offense do
     end
   end
 
+  describe '#highlighted_area' do
+    subject(:highlighted_area) { offense.highlighted_area }
+
+    it 'returns a range with correct column and length' do
+      expect(highlighted_area).to be_a Parser::Source::Range
+      expect(highlighted_area.column).to eq(0)
+      expect(highlighted_area.length).to eq(1)
+    end
+  end
+
   describe '#severity_level' do
     subject(:severity_level) do
       described_class.new(severity, location, 'message', 'CopName').severity.level
@@ -219,5 +229,11 @@ RSpec.describe RuboCop::Cop::Offense do
     it 'returns a real column' do
       expect(offense.real_column).to eq 1
     end
+
+    it 'returns a highlighted area' do
+      expect(offense.highlighted_area).to be_a Parser::Source::Range
+      expect(offense.highlighted_area.column).to eq 0
+      expect(offense.highlighted_area.length).to eq 0
+    end
   end
 end
