@@ -17,11 +17,11 @@ RSpec.describe RuboCop::Cop::Registry do
   let(:options) { {} }
 
   before do
-    stub_const('RuboCop::Cop::Test::FirstArrayElementIndentation', Class.new(RuboCop::Cop::Cop))
-    stub_const('RuboCop::Cop::RSpec::Foo', Class.new(RuboCop::Cop::Cop))
+    stub_const('RuboCop::Cop::Test::FirstArrayElementIndentation', Class.new(RuboCop::Cop::Base))
+    stub_const('RuboCop::Cop::RSpec::Foo', Class.new(RuboCop::Cop::Base))
   end
 
-  # `RuboCop::Cop::Cop` mutates its `registry` when inherited from.
+  # `RuboCop::Cop::Base` mutates its `registry` when inherited from.
   # This can introduce nondeterministic failures in other parts of the
   # specs if this mutation occurs before code that depends on this global cop
   # store. The workaround is to replace the global cop store with a temporary
@@ -29,7 +29,7 @@ RSpec.describe RuboCop::Cop::Registry do
   around { |test| described_class.with_temporary_global { test.run } }
 
   it 'can be cloned' do
-    klass = ::RuboCop::Cop::Metrics::AbcSize
+    klass = RuboCop::Cop::Metrics::AbcSize
     copy = registry.dup
     copy.enlist(klass)
     expect(copy.cops).to include(klass)
@@ -37,7 +37,7 @@ RSpec.describe RuboCop::Cop::Registry do
   end
 
   context 'when dismissing a cop class' do
-    let(:cop_class) { ::RuboCop::Cop::Metrics::AbcSize }
+    let(:cop_class) { RuboCop::Cop::Metrics::AbcSize }
 
     before { registry.enlist(cop_class) }
 
@@ -78,7 +78,7 @@ RSpec.describe RuboCop::Cop::Registry do
     end
 
     it 'returns false for cops not included in the store' do
-      expect(registry.contains_cop_matching?(['Style/NotReal'])).to be(false)
+      expect(registry).not_to be_contains_cop_matching(['Style/NotReal'])
     end
   end
 
@@ -114,7 +114,7 @@ RSpec.describe RuboCop::Cop::Registry do
 
     it 'emits a warning when namespace is incorrect' do
       warning = '/app/.rubocop.yml: Style/MethodLength has the wrong ' \
-                "namespace - should be Metrics\n"
+                "namespace - replace it with Metrics/MethodLength\n"
       qualified = nil
 
       expect do
@@ -124,18 +124,34 @@ RSpec.describe RuboCop::Cop::Registry do
       expect(qualified).to eql('Metrics/MethodLength')
     end
 
-    it 'raises an error when a cop name is ambiguous' do
-      cop_name = 'FirstArrayElementIndentation'
-      expect { registry.qualified_cop_name(cop_name, origin) }
-        .to raise_error(RuboCop::Cop::AmbiguousCopName)
-        .with_message(
-          'Ambiguous cop name `FirstArrayElementIndentation` used in ' \
-          '/app/.rubocop.yml needs department qualifier. Did you mean ' \
-          'Layout/FirstArrayElementIndentation or ' \
-          'Test/FirstArrayElementIndentation?'
-        )
-        .and output('/app/.rubocop.yml: Warning: no department given for ' \
-                    "FirstArrayElementIndentation.\n").to_stderr
+    context 'when cops share the same class name' do
+      let(:cops) do
+        [
+          RuboCop::Cop::Test::SameNameInMultipleNamespace,
+          RuboCop::Cop::Test::Foo::SameNameInMultipleNamespace,
+          RuboCop::Cop::Test::Bar::SameNameInMultipleNamespace
+        ]
+      end
+
+      it 'raises an error when a cop name is ambiguous' do
+        cop_name = 'SameNameInMultipleNamespace'
+        expect { registry.qualified_cop_name(cop_name, origin) }
+          .to raise_error(RuboCop::Cop::AmbiguousCopName)
+          .with_message(
+            'Ambiguous cop name `SameNameInMultipleNamespace` used in ' \
+            '/app/.rubocop.yml needs department qualifier. Did you mean ' \
+            'Test/SameNameInMultipleNamespace or ' \
+            'Test/Foo/SameNameInMultipleNamespace or ' \
+            'Test/Bar/SameNameInMultipleNamespace?'
+          )
+          .and output('/app/.rubocop.yml: Warning: no department given for ' \
+                      "SameNameInMultipleNamespace.\n").to_stderr
+      end
+
+      it 'qualifies names when the cop is unambiguous' do
+        qualified = registry.qualified_cop_name('Test/SameNameInMultipleNamespace', origin)
+        expect(qualified).to eql('Test/SameNameInMultipleNamespace')
+      end
     end
 
     it 'returns the provided name if no namespace is found' do
@@ -172,7 +188,9 @@ RSpec.describe RuboCop::Cop::Registry do
       end
 
       it 'exposes both cops' do
-        expect(registry.cops).to match_array([RuboCop::Cop::Foo::Bar, RuboCop::Cop::Baz::Foo::Bar])
+        expect(registry.cops).to contain_exactly(
+          RuboCop::Cop::Foo::Bar, RuboCop::Cop::Baz::Foo::Bar
+        )
       end
     end
   end
@@ -316,11 +334,11 @@ RSpec.describe RuboCop::Cop::Registry do
 
   describe '#department?' do
     it 'returns true for department name' do
-      expect(registry.department?('Lint')).to be true
+      expect(registry).to be_department('Lint')
     end
 
     it 'returns false for other names' do
-      expect(registry.department?('Foo')).to be false
+      expect(registry).not_to be_department('Foo')
     end
   end
 
