@@ -26,6 +26,17 @@ RSpec.describe RuboCop::Cop::Style::Alias, :config do
       RUBY
     end
 
+    it 'registers an offense for `alias` with interpolated symbol argument' do
+      expect_offense(<<~'RUBY')
+        alias :"string#{interpolation}" :symbol
+        ^^^^^ Use `alias_method` instead of `alias`.
+      RUBY
+
+      expect_correction(<<~'RUBY')
+        alias_method :"string#{interpolation}", :symbol
+      RUBY
+    end
+
     it 'does not register an offense for alias_method' do
       expect_no_offenses('alias_method :ala, :bala')
     end
@@ -45,6 +56,14 @@ RSpec.describe RuboCop::Cop::Style::Alias, :config do
         end
       RUBY
     end
+
+    it 'does not register an offense for alias_method when calling with no arguments' do
+      expect_no_offenses('alias_method')
+    end
+
+    it 'registers no offense for alias_method when calling with one argument' do
+      expect_no_offenses('alias_method :foo')
+    end
   end
 
   context 'when EnforcedStyle is prefer_alias' do
@@ -106,22 +125,67 @@ RSpec.describe RuboCop::Cop::Style::Alias, :config do
       RUBY
     end
 
-    it 'does not register an offense for alias_method with explicit receiver' do
+    it 'does not register an offense for alias in a def' do
       expect_no_offenses(<<~RUBY)
-        class C
-          receiver.alias_method :ala, :bala
+        def foo
+          alias :ala :bala
         end
       RUBY
     end
 
-    it 'does not register an offense for alias_method in a method def' do
+    it 'does not register an offense for multiple alias in a def' do
       expect_no_offenses(<<~RUBY)
-        def method
+        def foo
+          alias :foo :bar
+          alias :baz :qux
+        end
+      RUBY
+    end
+
+    it 'does not register an offense for `alias` with interpolated symbol argument' do
+      expect_no_offenses(<<~'RUBY')
+        alias :"string#{interpolation}" :symbol
+      RUBY
+    end
+
+    it 'registers an offense for alias in a defs' do
+      expect_offense(<<~RUBY)
+        def some_obj.foo
+          alias :ala :bala
+          ^^^^^ Use `alias_method` instead of `alias`.
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        def some_obj.foo
           alias_method :ala, :bala
         end
       RUBY
     end
 
+    it 'registers an offense for alias in a block' do
+      expect_offense(<<~RUBY)
+        included do
+          alias :ala :bala
+          ^^^^^ Use `alias_method` instead of `alias`.
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        included do
+          alias_method :ala, :bala
+        end
+      RUBY
+    end
+
+    it 'does not register an offense for alias_method with explicit receiver' do
+      expect_no_offenses(<<~RUBY)
+        class C
+          receiver.alias_method :ala, :bala
+        end
+      RUBY
+    end
+
     it 'does not register an offense for alias_method in self.method def' do
       expect_no_offenses(<<~RUBY)
         def self.method
@@ -161,5 +225,13 @@ RSpec.describe RuboCop::Cop::Style::Alias, :config do
         end
       RUBY
     end
+
+    it 'registers no offense for alias_method when calling with no arguments' do
+      expect_no_offenses('alias_method')
+    end
+
+    it 'registers no offense for alias_method when calling with one argument' do
+      expect_no_offenses('alias_method :foo')
+    end
   end
 end
