@@ -1,12 +1,161 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
+  shared_examples 'always accepted' do
+    context 'with blocks that need braces to be valid ruby' do
+      it 'accepts a multi-line block' do
+        expect_no_offenses(<<~RUBY)
+          puts [1, 2, 3].map { |n|
+            n * n
+          }
+        RUBY
+      end
+
+      it 'accepts a multi-line block followed by another argument' do
+        expect_no_offenses(<<~RUBY)
+          puts [1, 2, 3].map { |n|
+            n * n
+          }, 1
+        RUBY
+      end
+
+      it 'accepts a multi-line block inside a nested send' do
+        expect_no_offenses(<<~RUBY)
+          puts [0] + [1,2,3].map { |n|
+            n * n
+          }, 1
+        RUBY
+      end
+
+      it 'accepts a multi-line block inside a nested send when the block is the receiver' do
+        expect_no_offenses(<<~RUBY)
+          puts [1,2,3].map { |n|
+            n * n
+          } + [0], 1
+        RUBY
+      end
+
+      it 'accepts a multi-line block with chained method as an argument to an operator method' do
+        expect_no_offenses(<<~RUBY)
+          'Some text: %s' %
+            %w[foo bar].map { |v|
+              v.upcase
+            }.join(', ')
+        RUBY
+      end
+
+      it 'accepts a multi-line block with chained method as an argument to an operator method' \
+         'inside a kwarg' do
+        expect_no_offenses(<<~RUBY)
+          foo :bar, baz: 'Some text: %s' %
+                         %w[foo bar].map { |v|
+                          v.upcase
+                         }.join(', ')
+        RUBY
+      end
+
+      context 'Ruby >= 2.7', :ruby27 do
+        it 'accepts a multi-line numblock' do
+          expect_no_offenses(<<~RUBY)
+            puts [1, 2, 3].map {
+              _1 * _1
+            }, 1
+          RUBY
+        end
+
+        it 'accepts a multi-line numblock inside a nested send' do
+          expect_no_offenses(<<~RUBY)
+            puts [0] + [1,2,3].map {
+              _1 * _1
+            }, 1
+          RUBY
+        end
+
+        it 'accepts a multi-line numblock inside a nested send when the block is the receiver' do
+          expect_no_offenses(<<~RUBY)
+            puts [1,2,3].map {
+              _1 * _1
+            } + [0], 1
+          RUBY
+        end
+
+        it 'accepts a multi-line numblock with chained method as an argument to an operator method' do
+          expect_no_offenses(<<~RUBY)
+            foo %
+              %w[bar baz].map {
+                _1.upcase
+              }.join(', ')
+          RUBY
+        end
+
+        it 'accepts a multi-line numblock with chained method as an argument to an operator method' \
+           'inside a kwarg' do
+          expect_no_offenses(<<~RUBY)
+            foo :bar, baz: 'Some text: %s' %
+                           %w[foo bar].map {
+                            _1.upcase
+                           }.join(', ')
+          RUBY
+        end
+      end
+
+      context 'Ruby >= 3.4', :ruby34 do
+        it 'accepts a multi-line itblock' do
+          expect_no_offenses(<<~RUBY)
+            puts [1, 2, 3].map {
+              it * it
+            }, 1
+          RUBY
+        end
+
+        it 'accepts a multi-line itblock inside a nested send' do
+          expect_no_offenses(<<~RUBY)
+            puts [0] + [1,2,3].map {
+              it * it
+            }, 1
+          RUBY
+        end
+
+        it 'accepts a multi-line itblock inside a nested send when the block is the receiver' do
+          expect_no_offenses(<<~RUBY)
+            puts [1,2,3].map {
+              it * it
+            } + [0], 1
+          RUBY
+        end
+
+        it 'accepts a multi-line itblock with chained method as an argument to an operator method' do
+          expect_no_offenses(<<~RUBY)
+            foo %
+              %w[bar baz].map {
+                it.upcase
+              }.join(', ')
+          RUBY
+        end
+
+        it 'accepts a multi-line itblock with chained method as an argument to an operator method' \
+           'inside a kwarg' do
+          expect_no_offenses(<<~RUBY)
+            foo :bar, baz: 'Some text: %s' %
+                           %w[foo bar].map {
+                            it.upcase
+                           }.join(', ')
+          RUBY
+        end
+      end
+    end
+  end
+
   shared_examples 'syntactic styles' do
     it 'registers an offense for a single line block with do-end' do
       expect_offense(<<~RUBY)
         each do |x| end
              ^^ Prefer `{...}` over `do...end` for single-line blocks.
       RUBY
+
+      expect_correction(<<~RUBY)
+        each { |x| }
+      RUBY
     end
 
     it 'accepts a single line block with braces' do
@@ -20,20 +169,16 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
       RUBY
     end
 
-    it 'accepts a multi-line block that needs braces to be valid ruby' do
-      expect_no_offenses(<<~RUBY)
-        puts [1, 2, 3].map { |n|
-          n * n
-        }, 1
-      RUBY
-    end
-
     context 'Ruby >= 2.7', :ruby27 do
       it 'registers an offense for a single line numblock with do-end' do
         expect_offense(<<~RUBY)
           each do _1 end
                ^^ Prefer `{...}` over `do...end` for single-line blocks.
         RUBY
+
+        expect_correction(<<~RUBY)
+          each { _1 }
+        RUBY
       end
 
       it 'accepts a single line numblock with braces' do
@@ -47,14 +192,6 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
           end
         RUBY
       end
-
-      it 'accepts a multi-line numblock that needs braces to be valid ruby' do
-        expect_no_offenses(<<~RUBY)
-          puts [1, 2, 3].map {
-            _1 * _1
-          }, 1
-        RUBY
-      end
     end
   end
 
@@ -69,6 +206,8 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
 
     let(:cop_config) { cop_config }
 
+    it_behaves_like 'always accepted'
+
     it 'accepts a multi-line block with braces if the return value is assigned' do
       expect_no_offenses(<<~RUBY)
         foo = map { |x|
@@ -118,6 +257,12 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
           x
         }
       RUBY
+
+      expect_correction(<<~RUBY)
+        each do |x|
+          x
+        end
+      RUBY
     end
 
     it 'registers an offense for a multi-line block with do-end if the return value is assigned' do
@@ -127,6 +272,12 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
           x
         end
       RUBY
+
+      expect_correction(<<~RUBY)
+        foo = map { |x|
+          x
+        }
+      RUBY
     end
 
     it 'registers an offense for a multi-line block with do-end if the ' \
@@ -137,6 +288,12 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
           x
         end)
       RUBY
+
+      expect_correction(<<~RUBY)
+        puts (map { |x|
+          x
+        })
+      RUBY
     end
 
     it 'registers an offense for a multi-line block with do-end if the ' \
@@ -147,6 +304,12 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
           x
         end
       RUBY
+
+      expect_correction(<<~RUBY)
+        foo.bar = map { |x|
+          x
+        }
+      RUBY
     end
 
     it 'accepts a multi-line block with do-end if it is the return value of its scope' do
@@ -163,6 +326,52 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
       expect_no_offenses('return if any? { |x| x }')
     end
 
+    it 'accepts a single line block with {} if used in an `if` condition' do
+      expect_no_offenses(<<~RUBY)
+        if any? { |x| x }
+          return
+        end
+      RUBY
+    end
+
+    it 'accepts a single line block with {} if used in an `unless` condition' do
+      expect_no_offenses(<<~RUBY)
+        unless any? { |x| x }
+          return
+        end
+      RUBY
+    end
+
+    it 'accepts a single line block with {} if used in a `case` condition' do
+      expect_no_offenses(<<~RUBY)
+        case foo { |x| x }
+        when bar
+        end
+      RUBY
+    end
+
+    it 'accepts a single line block with {} if used in a `case` match condition' do
+      expect_no_offenses(<<~RUBY)
+        case foo { |x| x }
+        in bar
+        end
+      RUBY
+    end
+
+    it 'accepts a single line block with {} if used in a `while` condition' do
+      expect_no_offenses(<<~RUBY)
+        while foo { |x| x }
+        end
+      RUBY
+    end
+
+    it 'accepts a single line block with {} if used in an `until` condition' do
+      expect_no_offenses(<<~RUBY)
+        until foo { |x| x }
+        end
+      RUBY
+    end
+
     it 'accepts a single line block with {} if used in a logical or' do
       expect_no_offenses('any? { |c| c } || foo')
     end
@@ -290,21 +499,6 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
       RUBY
     end
 
-    it 'autocorrects do-end to {} if it is a functional block' do
-      expect_offense(<<~RUBY)
-        foo = map do |x|
-                  ^^ Prefer `{...}` over `do...end` for functional blocks.
-          x
-        end
-      RUBY
-
-      expect_correction(<<~RUBY)
-        foo = map { |x|
-          x
-        }
-      RUBY
-    end
-
     it 'autocorrects do-end to {} with appropriate spacing' do
       expect_offense(<<~RUBY)
         foo = map do|x|
@@ -320,21 +514,6 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
       RUBY
     end
 
-    it 'autocorrects do-end to {} if it is a functional block and does not change the meaning' do
-      expect_offense(<<~RUBY)
-        puts (map do |x|
-                  ^^ Prefer `{...}` over `do...end` for functional blocks.
-          x
-        end)
-      RUBY
-
-      expect_correction(<<~RUBY)
-        puts (map { |x|
-          x
-        })
-      RUBY
-    end
-
     it 'autocorrects do-end with `rescue` to {} if it is a functional block' do
       expect_offense(<<~RUBY)
         x = map do |a|
@@ -387,7 +566,8 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
 
     let(:cop_config) { cop_config }
 
-    include_examples 'syntactic styles'
+    it_behaves_like 'always accepted'
+    it_behaves_like 'syntactic styles'
 
     it 'autocorrects do-end for single line blocks to { and }' do
       expect_offense(<<~RUBY)
@@ -424,6 +604,11 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
                ^ Avoid using `{...}` for multi-line blocks.
           }
         RUBY
+
+        expect_correction(<<~RUBY)
+          each do |x|
+          end
+        RUBY
       end
 
       it 'registers an offense when combined with attribute assignment' do
@@ -432,6 +617,22 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
                             ^ Avoid using `{...}` for multi-line blocks.
           }
         RUBY
+
+        expect_correction(<<~RUBY)
+          foo.bar = baz.map do |x|
+          end
+        RUBY
+      end
+
+      it 'registers an offense for nested multi-line blocks with trailing comment' do
+        expect_offense(<<~RUBY)
+          blcck {
+                ^ Avoid using `{...}` for multi-line blocks.
+          }
+          block { foo {
+                ^ Avoid using `{...}` for multi-line blocks.
+          } }.bar # comment
+        RUBY
       end
 
       it 'registers an offense when there is a comment after the closing brace and block body is not empty' do
@@ -448,6 +649,20 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
         RUBY
       end
 
+      it 'registers an offense when there is a comment after the closing brace and bracket' do
+        expect_offense(<<~RUBY)
+          [foo {
+               ^ Avoid using `{...}` for multi-line blocks.
+          }] # comment
+        RUBY
+
+        expect_correction(<<~RUBY)
+          [# comment
+          foo do
+          end]
+        RUBY
+      end
+
       it 'registers an offense and keep chained block when there is a comment after the closing brace and block body is not empty' do
         expect_offense(<<~RUBY)
           baz.map { |x|
@@ -512,6 +727,22 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
         RUBY
       end
 
+      it 'accepts braces with safe navigation if do-end would change the meaning' do
+        expect_no_offenses(<<~RUBY)
+          foo&.bar baz {
+            y
+          }
+        RUBY
+      end
+
+      it 'accepts braces with chained safe navigation if do-end would change the meaning' do
+        expect_no_offenses(<<~RUBY)
+          foo.bar baz {
+            y
+          }&.quux
+        RUBY
+      end
+
       it 'accepts a multi-line functional block with {} if it is an ignored method' do
         expect_no_offenses(<<~RUBY)
           foo = proc {
@@ -540,6 +771,16 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
             # ...
           })
         RUBY
+
+        expect_correction(<<~RUBY)
+          scope :foo, (lambda do |f|
+            where(condition: "value")
+          end)
+
+          expect { something }.to(raise_error(ErrorClass) do |error|
+            # ...
+          end)
+        RUBY
       end
 
       it 'can handle special method names such as []= and done?' do
@@ -553,6 +794,16 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
             e.nil?
           }
         RUBY
+
+        expect_correction(<<~RUBY)
+          h2[k2] = Hash.new do |h3,k3|
+            h3[k3] = 0
+          end
+
+          x = done? list.reject { |e|
+            e.nil?
+          }
+        RUBY
       end
 
       it 'autocorrects { and } to do and end' do
@@ -575,16 +826,36 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
       it 'autocorrects adjacent curly braces correctly' do
         expect_offense(<<~RUBY)
           (0..3).each { |a| a.times {
-                                    ^ Avoid using `{...}` for multi-line blocks.
                       ^ Avoid using `{...}` for multi-line blocks.
             puts a
           }}
         RUBY
 
         expect_correction(<<~RUBY)
-          (0..3).each do |a| a.times do
+          (0..3).each do |a| a.times {
             puts a
-          end end
+          } end
+        RUBY
+      end
+
+      it 'does not register an offense for a multi-line block with `{` and `}` with method chain' do
+        expect_no_offenses(<<~RUBY)
+          foo bar + baz {
+          }.qux.quux
+        RUBY
+      end
+
+      it 'does not register an offense for a multi-line block with `{` and `}` with method chain and safe navigation' do
+        expect_no_offenses(<<~RUBY)
+          foo x&.bar + baz {
+          }.qux.quux
+        RUBY
+      end
+
+      it 'does not register an offense when multi-line blocks to `{` and `}` with arithmetic operation method chain' do
+        expect_no_offenses(<<~RUBY)
+          foo bar + baz {
+          }.qux + quux
         RUBY
       end
 
@@ -595,6 +866,20 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
           }, arg3: :another_value
         RUBY
       end
+
+      it 'handles a multiline {} block with trailing comment' do
+        expect_offense(<<~RUBY)
+          my_method { |x|
+                    ^ Avoid using `{...}` for multi-line blocks.
+            x.foo } unless bar   # comment
+        RUBY
+
+        expect_correction(<<~RUBY)
+          # comment
+          my_method do |x|
+            x.foo end unless bar
+        RUBY
+      end
     end
 
     context 'with a single line do-end block with an inline `rescue`' do
@@ -609,6 +894,28 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
         RUBY
       end
     end
+
+    context 'with a single line do-end block with an inline `rescue` without a semicolon before `rescue`' do
+      it 'registers an offense' do
+        expect_offense(<<~RUBY)
+          foo do next unless bar rescue StandardError; end
+              ^^ Prefer `{...}` over `do...end` for single-line blocks.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo { next unless bar rescue StandardError; }
+        RUBY
+      end
+    end
+
+    context 'with a single line do-end block with an inline `rescue` with a semicolon before `rescue`' do
+      it 'does not register an offense' do
+        # NOTE: `foo { next unless bar; rescue StandardError; }` is a syntax error.
+        expect_no_offenses(<<~RUBY)
+          foo do next unless bar; rescue StandardError; end
+        RUBY
+      end
+    end
   end
 
   context 'EnforcedStyle: braces_for_chaining' do
@@ -620,7 +927,8 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
 
     let(:cop_config) { cop_config }
 
-    include_examples 'syntactic styles'
+    it_behaves_like 'always accepted'
+    it_behaves_like 'syntactic styles'
 
     it 'registers an offense for multi-line chained do-end blocks' do
       expect_offense(<<~RUBY)
@@ -688,6 +996,14 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
           }
         ]
       RUBY
+
+      expect_correction(<<~RUBY)
+        Hash[
+          {foo: :bar}.map do |k, v|
+            [k, v]
+          end
+        ]
+      RUBY
     end
 
     context 'when there are braces around a multi-line block' do
@@ -697,6 +1013,11 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
                ^ Prefer `do...end` for multi-line blocks without chaining.
           }
         RUBY
+
+        expect_correction(<<~RUBY)
+          each do |x|
+          end
+        RUBY
       end
 
       it 'registers an offense when combined with attribute assignment' do
@@ -705,6 +1026,11 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
                             ^ Prefer `do...end` for multi-line blocks without chaining.
           }
         RUBY
+
+        expect_correction(<<~RUBY)
+          foo.bar = baz.map do |x|
+          end
+        RUBY
       end
 
       it 'allows when the block is being chained' do
@@ -789,6 +1115,8 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
 
     let(:cop_config) { cop_config }
 
+    it_behaves_like 'always accepted'
+
     it 'registers an offense for a single line block with do-end' do
       expect_offense(<<~RUBY)
         each do |x| end
@@ -810,6 +1138,11 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
              ^^ Prefer `{...}` over `do...end` for blocks.
         end
       RUBY
+
+      expect_correction(<<~RUBY)
+        each { |x|
+        }
+      RUBY
     end
 
     it 'does not autocorrect do-end if {} would change the meaning' do
@@ -849,6 +1182,11 @@ RSpec.describe RuboCop::Cop::Style::BlockDelimiters, :config do
                           ^^ Prefer `{...}` over `do...end` for blocks.
         end
       RUBY
+
+      expect_correction(<<~RUBY)
+        foo.bar = baz.map { |x|
+        }
+      RUBY
     end
 
     it 'accepts a multi-line functional block with do-end if it is an ignored method' do
