@@ -14,14 +14,11 @@ RSpec.describe RuboCop::Cop::Style::CaseEquality, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects for === when the receiver is a regexp' do
-      expect_offense(<<~RUBY)
+    it 'does not register an offense for === when the receiver is a regexp' do
+      # This detection is expected to be supported by `Performance/RegexpMatch`.
+      expect_no_offenses(<<~RUBY)
         /OMG/ === var
-              ^^^ Avoid the use of the case equality operator `===`.
       RUBY
-
-      # This correction is expected to be supported by `Performance/Regexp`.
-      expect_no_corrections
     end
 
     it 'registers an offense and corrects for === when the receiver is a range' do
@@ -59,7 +56,7 @@ RSpec.describe RuboCop::Cop::Style::CaseEquality, :config do
       RUBY
     end
 
-    include_examples 'offenses'
+    it_behaves_like 'offenses'
   end
 
   context 'when AllowOnConstant is true' do
@@ -71,7 +68,7 @@ RSpec.describe RuboCop::Cop::Style::CaseEquality, :config do
       RUBY
     end
 
-    include_examples 'offenses'
+    it_behaves_like 'offenses'
   end
 
   context 'when AllowOnSelfClass is false' do
@@ -88,7 +85,7 @@ RSpec.describe RuboCop::Cop::Style::CaseEquality, :config do
       RUBY
     end
 
-    include_examples 'offenses'
+    it_behaves_like 'offenses'
   end
 
   context 'when AllowOnSelfClass is true' do
@@ -100,7 +97,7 @@ RSpec.describe RuboCop::Cop::Style::CaseEquality, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects for === when the receiver is self.klass' do
+    it 'registers an offense but does not correct for === when the receiver is self.klass' do
       expect_offense(<<~RUBY)
         self.klass === var
                    ^^^ Avoid the use of the case equality operator `===`.
@@ -109,6 +106,6 @@ RSpec.describe RuboCop::Cop::Style::CaseEquality, :config do
       expect_no_corrections
     end
 
-    include_examples 'offenses'
+    it_behaves_like 'offenses'
   end
 end
