@@ -5,7 +5,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense assigning any variable type to ternary' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = foo? ? 1 : 2
-        ^{variable}^^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -16,7 +16,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense assigning any variable type to if else' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = if foo
-        ^{variable}^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^^^^^^^ Assign variables inside of conditionals.
                         1
                       else
                         2
@@ -35,7 +35,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense assigning any variable type to if elsif else' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = if foo
-        ^{variable}^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^^^^^^^ Assign variables inside of conditionals.
                         1
                       elsif baz
                         2
@@ -55,10 +55,10 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
       RUBY
     end
 
-    it 'registers an offense assigning any variable type to if elsewith multiple assignment' do
+    it 'registers an offense assigning any variable type to if else with multiple assignment' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable}, %{variable} = if foo
-        ^{variable}^^^{variable}^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^{variable}^^^^^^^^^ Assign variables inside of conditionals.
                         something
                       else
                         something_else
@@ -85,7 +85,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense assigning any variable type to unless else' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = unless foo
-        ^{variable}^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^^^^^^^^^^^ Assign variables inside of conditionals.
                         1
                       else
                         2
@@ -104,7 +104,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense for assigning any variable type to case when' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = case foo
-        ^{variable}^^^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^^^^^^^^^ Assign variables inside of conditionals.
                       when "a"
                         1
                       when "b"
@@ -130,7 +130,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
       it 'registers an offense for assigning any variable type to case in' do
         expect_offense(<<~RUBY, variable: variable)
           %{variable} = case foo
-          ^{variable}^^^^^^^^^^^ Assign variables inside of conditionals
+          ^{variable}^^^^^^^^^^^ Assign variables inside of conditionals.
                         in "a"
                           1
                         in "b"
@@ -168,7 +168,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense for any assignment to ternary' do
       expect_offense(<<~RUBY, assignment: assignment)
         bar %{assignment} (foo? ? 1 : 2)
-        ^^^^^{assignment}^^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^{assignment}^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -179,7 +179,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense any assignment to if else' do
       expect_offense(<<~RUBY, assignment: assignment)
         bar %{assignment} if foo
-        ^^^^^{assignment}^^^^^^^ Assign variables inside of conditionals
+        ^^^^^{assignment}^^^^^^^ Assign variables inside of conditionals.
                         1
                       else
                         2
@@ -206,7 +206,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense for any assignment to unless else' do
       expect_offense(<<~RUBY, assignment: assignment)
         bar %{assignment} unless foo
-        ^^^^^{assignment}^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^{assignment}^^^^^^^^^^^ Assign variables inside of conditionals.
                         1
                       else
                         2
@@ -225,7 +225,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense any assignment to case when' do
       expect_offense(<<~RUBY, assignment: assignment)
         bar %{assignment} case foo
-        ^^^^^{assignment}^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^{assignment}^^^^^^^^^ Assign variables inside of conditionals.
                       when "a"
                         1
                       else
@@ -258,7 +258,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'assigning any variable type to a multiline if else' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = if foo
-        ^{variable}^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^^^^^^^ Assign variables inside of conditionals.
                         something
                         1
                       else
@@ -281,7 +281,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'assigning any variable type to an if else with multiline in one branch' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = if foo
-        ^{variable}^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^^^^^^^ Assign variables inside of conditionals.
                         1
                       else
                         something_else
@@ -302,7 +302,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'assigning any variable type to a multiline if elsif else' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = if foo
-        ^{variable}^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^^^^^^^ Assign variables inside of conditionals.
                         something
                         1
                       elsif bar
@@ -337,7 +337,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'assigning any variable type to a multiline unless else' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = unless foo
-        ^{variable}^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^^^^^^^^^^^ Assign variables inside of conditionals.
                         something
                         1
                       else
@@ -360,7 +360,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'assigning any variable type to a multiline case when' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = case foo
-        ^{variable}^^^^^^^^^^^ Assign variables inside of conditionals
+        ^{variable}^^^^^^^^^^^ Assign variables inside of conditionals.
                       when "a"
                         something
                         1
@@ -455,7 +455,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'any assignment to a multiline if else' do
       expect_offense(<<~RUBY, assignment: assignment)
         bar %{assignment} if foo
-        ^^^^^{assignment}^^^^^^^ Assign variables inside of conditionals
+        ^^^^^{assignment}^^^^^^^ Assign variables inside of conditionals.
                         something
                         1
                       else
@@ -478,7 +478,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'any assignment to a multiline unless else' do
       expect_offense(<<~RUBY, assignment: assignment)
         bar %{assignment} unless foo
-        ^^^^^{assignment}^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^{assignment}^^^^^^^^^^^ Assign variables inside of conditionals.
                         something
                         1
                       else
@@ -501,7 +501,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'any assignment to a multiline case when' do
       expect_offense(<<~RUBY, assignment: assignment)
         bar %{assignment} case foo
-        ^^^^^{assignment}^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^{assignment}^^^^^^^^^ Assign variables inside of conditionals.
                       when "a"
                         something
                         1
@@ -567,7 +567,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to an if else condition' do
       expect_offense(<<~RUBY)
         bar = if foo
-        ^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
                 1
               else
                 2
@@ -586,7 +586,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to an if elsif else condition' do
       expect_offense(<<~RUBY)
         bar = if foo
-        ^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
                 1
               elsif foobar
                 2
@@ -609,7 +609,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to an if elsif else with multiple elsifs' do
       expect_offense(<<~RUBY)
         bar = if foo
-        ^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
                 1
               elsif foobar
                 2
@@ -633,10 +633,25 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
       RUBY
     end
 
+    it 'corrects assignment to an unless condition' do
+      expect_offense(<<~RUBY)
+        value = unless condition
+        ^^^^^^^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
+                      1
+                    end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        unless condition
+          value = 1
+        end
+      RUBY
+    end
+
     it 'corrects assignment to an unless else condition' do
       expect_offense(<<~RUBY)
         bar = unless foo
-        ^^^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
                 1
               else
                 2
@@ -655,7 +670,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to a case when else condition' do
       expect_offense(<<~RUBY)
         bar = case foo
-        ^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^ Assign variables inside of conditionals.
               when foobar
                 1
               else
@@ -676,7 +691,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to a case when else with multiple whens' do
       expect_offense(<<~RUBY)
         bar = case foo
-        ^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^ Assign variables inside of conditionals.
               when foobar
                 1
               when baz
@@ -701,7 +716,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to a ternary operator' do
       expect_offense(<<~RUBY)
         bar = foo? ? 1 : 2
-        ^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -710,6 +725,114 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     end
   end
 
+  shared_examples 'with `dstr` node in branch' do
+    it 'registers an offense for heredoc inside branch' do
+      expect_offense(<<~RUBY)
+        value = if a
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
+          239
+        else
+          raise(ArgumentError, <<~ANSWER)
+            4
+
+            2
+          ANSWER
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        if a
+          value = 239
+        else
+          value = raise(ArgumentError, <<~ANSWER)
+            4
+
+            2
+          ANSWER
+        end
+      RUBY
+    end
+
+    it 'registers an offense for string interpolation inside branch' do
+      expect_offense(<<~'RUBY')
+        value = if a
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
+          239
+        else
+          "#{foo} \
+            #{bar} \
+          "
+        end
+      RUBY
+
+      expect_correction(<<~'RUBY')
+        if a
+          value = 239
+        else
+          value = "#{foo} \
+            #{bar} \
+          "
+        end
+      RUBY
+    end
+  end
+
+  shared_examples 'with multiline regex in branch' do
+    it 'registers an offense for a multiline %r{} regex' do
+      expect_offense(<<~RUBY)
+        x = if condition
+        ^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
+          %r{a
+            b}x
+        else
+          %r{c
+            d}x
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        if condition
+          x = %r{a
+            b}x
+        else
+          x = %r{c
+            d}x
+        end
+      RUBY
+    end
+
+    it 'registers an offense for a multiline regex assignment with interpolation and comments' do
+      expect_offense(<<~'RUBY')
+        x = if condition
+        ^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
+          %r{#{foo}
+            b}x
+        else
+          %r{#{bar}
+            d}x
+        end
+      RUBY
+
+      expect_correction(<<~'RUBY')
+        if condition
+          x = %r{#{foo}
+            b}x
+        else
+          x = %r{#{bar}
+            d}x
+        end
+      RUBY
+    end
+  end
+
+  shared_examples 'with indexed assignment without arguments' do
+    it 'does not register an offense' do
+      expect_no_offenses(<<~RUBY)
+        foo.[]=()
+      RUBY
+    end
+  end
+
   context 'SingleLineConditionsOnly true' do
     let(:config) do
       RuboCop::Config.new('Style/ConditionalAssignment' => {
@@ -786,6 +909,10 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it_behaves_like('multiline all assignment types allow', '&&=')
     it_behaves_like('multiline all assignment types allow', '<<')
 
+    it_behaves_like('with `dstr` node in branch')
+    it_behaves_like('with multiline regex in branch')
+    it_behaves_like('with indexed assignment without arguments')
+
     it 'allows a method call in the subject of a ternary operator' do
       expect_no_offenses('bar << foo? ? 1 : 2')
     end
@@ -793,7 +920,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense for assignment using a method that ends with an equal sign' do
       expect_offense(<<~RUBY)
         self.attributes = foo? ? 1 : 2
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -804,7 +931,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense for assignment using []=' do
       expect_offense(<<~RUBY)
         foo[:a] = if bar?
-        ^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
                     1
                   else
                     2
@@ -823,7 +950,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'registers an offense for assignment to an if then else' do
       expect_offense(<<~RUBY)
         bar = if foo then 1
-        ^^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
               else 2
               end
       RUBY
@@ -835,10 +962,78 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
       RUBY
     end
 
+    it 'registers an offense for assignment to an one-line if then else' do
+      expect_offense(<<~RUBY)
+        bar = if foo then 1 else 2 end
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        if foo then bar = 1 else bar = 2 end
+      RUBY
+    end
+
+    it 'registers an offense for assignment with one-line `else` and `end`' do
+      expect_offense(<<~RUBY)
+        bar = if foo
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
+                    1
+              else 2 end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        if foo
+          bar = 1
+        else bar = 2 end
+      RUBY
+    end
+
+    it 'registers an offense for assignment with one-line `else` and `end` with nested branch' do
+      expect_offense(<<~RUBY)
+        bar = if foo
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
+                    1
+              elsif baz
+                2
+              else 3 end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        if foo
+          bar = 1
+        elsif baz
+          bar = 2
+        else bar = 3 end
+      RUBY
+    end
+
+    it 'registers an offense for an assignment that uses if branch bodies including a block' do
+      expect_offense(<<~RUBY)
+        result = if condition
+        ^^^^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
+          foo do
+          end
+        else
+          bar do
+          end
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        if condition
+          result = foo do
+          end
+        else
+          result = bar do
+          end
+        end
+      RUBY
+    end
+
     it 'registers an offense for assignment to case when then else' do
       expect_offense(<<~RUBY)
         baz = case foo
-        ^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^ Assign variables inside of conditionals.
               when bar then 1
               else 2
               end
@@ -852,6 +1047,27 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
       RUBY
     end
 
+    it 'registers an offense when empty `case` condition' do
+      expect_offense(<<~RUBY)
+        var = case
+        ^^^^^^^^^^ Assign variables inside of conditionals.
+        when foo
+          bar
+        else
+          baz
+        end
+      RUBY
+
+      expect_correction(<<~RUBY)
+        case
+        when foo
+          var = bar
+        else
+          var = baz
+        end
+      RUBY
+    end
+
     context 'for loop' do
       it 'ignores pseudo assignments in a for loop' do
         expect_no_offenses('for i in [1, 2, 3]; puts i; end')
@@ -863,7 +1079,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to a namespaced constant' do
       expect_offense(<<~RUBY)
         FOO::BAR = if baz?
-        ^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
                       1
                     else
                       2
@@ -882,7 +1098,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment when without `else` branch' do
       expect_offense(<<~RUBY)
         var = if foo
-        ^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
           bar
         elsif baz
           qux
@@ -976,11 +1192,14 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it_behaves_like('multiline all assignment types offense', '<<')
 
     it_behaves_like('single line condition autocorrect')
+    it_behaves_like('with `dstr` node in branch')
+    it_behaves_like('with multiline regex in branch')
+    it_behaves_like('with indexed assignment without arguments')
 
     it 'corrects assignment to a multiline if else condition' do
       expect_offense(<<~RUBY)
         bar = if foo
-        ^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
                 something
                 1
               else
@@ -1003,7 +1222,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to a multiline if elsif else condition' do
       expect_offense(<<~RUBY)
         bar = if foo
-        ^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
                 something
                 1
               elsif foobar
@@ -1032,7 +1251,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to an if elsif else with multiple elsifs' do
       expect_offense(<<~RUBY)
         bar = if foo
-        ^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^ Assign variables inside of conditionals.
                 something
                 1
               elsif foobar
@@ -1067,7 +1286,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to an unless else condition' do
       expect_offense(<<~RUBY)
         bar = unless foo
-        ^^^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^^^ Assign variables inside of conditionals.
                 something
                 1
               else
@@ -1090,7 +1309,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to a case when else condition' do
       expect_offense(<<~RUBY)
         bar = case foo
-        ^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^ Assign variables inside of conditionals.
               when foobar
                 something
                 1
@@ -1115,7 +1334,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
     it 'corrects assignment to a case when else with multiple whens' do
       expect_offense(<<~RUBY)
         bar = case foo
-        ^^^^^^^^^^^^^^ Assign variables inside of conditionals
+        ^^^^^^^^^^^^^^ Assign variables inside of conditionals.
               when foobar
                 something
                 1
