@@ -6,7 +6,7 @@ RSpec.describe RuboCop::Cop::Style::DateTime, :config do
   it 'registers an offense when using DateTime for current time' do
     expect_offense(<<~RUBY)
       DateTime.now
-      ^^^^^^^^^^^^ Prefer Time over DateTime.
+      ^^^^^^^^^^^^ Prefer `Time` over `DateTime`.
     RUBY
 
     expect_correction(<<~RUBY)
@@ -14,10 +14,21 @@ RSpec.describe RuboCop::Cop::Style::DateTime, :config do
     RUBY
   end
 
+  it 'registers an offense when using DateTime for current time with safe navigation operator' do
+    expect_offense(<<~RUBY)
+      DateTime&.now
+      ^^^^^^^^^^^^^ Prefer `Time` over `DateTime`.
+    RUBY
+
+    expect_correction(<<~RUBY)
+      Time&.now
+    RUBY
+  end
+
   it 'registers an offense when using ::DateTime for current time' do
     expect_offense(<<~RUBY)
       ::DateTime.now
-      ^^^^^^^^^^^^^^ Prefer Time over DateTime.
+      ^^^^^^^^^^^^^^ Prefer `Time` over `DateTime`.
     RUBY
 
     expect_correction(<<~RUBY)
@@ -28,7 +39,7 @@ RSpec.describe RuboCop::Cop::Style::DateTime, :config do
   it 'registers an offense when using DateTime for modern date' do
     expect_offense(<<~RUBY)
       DateTime.iso8601('2016-06-29')
-      ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Prefer Time over DateTime.
+      ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Prefer `Time` over `DateTime`.
     RUBY
 
     expect_correction(<<~RUBY)
@@ -62,7 +73,14 @@ RSpec.describe RuboCop::Cop::Style::DateTime, :config do
     it 'registers an offense' do
       expect_offense(<<~RUBY)
         thing.to_datetime
-        ^^^^^^^^^^^^^^^^^ Do not use #to_datetime.
+        ^^^^^^^^^^^^^^^^^ Do not use `#to_datetime`.
+      RUBY
+    end
+
+    it 'registers an offense when using safe navigation operator' do
+      expect_offense(<<~RUBY)
+        thing&.to_datetime
+        ^^^^^^^^^^^^^^^^^^ Do not use `#to_datetime`.
       RUBY
     end
   end
