@@ -52,6 +52,15 @@ RSpec.describe RuboCop::Cop::Style::DocumentationMethod, :config do
         end
       end
 
+      context 'when `initialize` method' do
+        it 'does not register an offense' do
+          expect_no_offenses(<<~RUBY)
+            def initialize
+            end
+          RUBY
+        end
+      end
+
       context 'when method is private' do
         it 'does not register an offense' do
           expect_no_offenses(<<~RUBY)
@@ -83,6 +92,14 @@ RSpec.describe RuboCop::Cop::Style::DocumentationMethod, :config do
           expect_no_offenses('private def method; end')
         end
 
+        it 'does not register an offense with inline `private_class_method`' do
+          expect_no_offenses(<<~RUBY)
+            private_class_method def self.foo
+              puts 'bar'
+            end
+          RUBY
+        end
+
         context 'when required for non-public methods' do
           let(:require_for_non_public_methods) { true }
 
@@ -121,6 +138,15 @@ RSpec.describe RuboCop::Cop::Style::DocumentationMethod, :config do
                       ^^^^^^^^^^^^^^^ Missing method documentation comment.
             RUBY
           end
+
+          it 'registers an offense with inline `private_class_method`' do
+            expect_offense(<<~RUBY)
+              private_class_method def self.foo
+                                   ^^^^^^^^^^^^ Missing method documentation comment.
+                puts 'bar'
+              end
+            RUBY
+          end
         end
       end
 
@@ -361,7 +387,7 @@ RSpec.describe RuboCop::Cop::Style::DocumentationMethod, :config do
       context 'with documentation comment' do
         context 'when method is public' do
           it 'does not register an offense' do
-            expect_no_offenses(<<-RUBY)
+            expect_no_offenses(<<~RUBY)
               class Foo
                 # Documentation
                 def bar
@@ -610,6 +636,16 @@ RSpec.describe RuboCop::Cop::Style::DocumentationMethod, :config do
             RUBY
           end
         end
+
+        it 'registers an offense for inline def with ruby2_keywords' do
+          expect_offense(<<~RUBY)
+            module Foo
+              ruby2_keywords def bar
+              ^^^^^^^^^^^^^^^^^^^^^^ Missing method documentation comment.
+              end
+            end
+          RUBY
+        end
       end
 
       context 'with documentation comment' do
@@ -656,6 +692,16 @@ RSpec.describe RuboCop::Cop::Style::DocumentationMethod, :config do
             RUBY
           end
         end
+
+        it 'does not register an offense for inline def with ruby2_keywords' do
+          expect_no_offenses(<<~RUBY)
+            module Foo
+              # Documentation
+              ruby2_keywords def bar
+              end
+            end
+          RUBY
+        end
       end
 
       context 'with both public and private methods' do
@@ -947,6 +993,19 @@ RSpec.describe RuboCop::Cop::Style::DocumentationMethod, :config do
           end
         end
       end
+
+      describe 'when AllowedMethods is configured' do
+        before { config['Style/DocumentationMethod'] = { 'AllowedMethods' => ['method_missing'] } }
+
+        it 'ignores the methods in the config' do
+          expect_no_offenses(<<~RUBY)
+            class Foo
+              def method_missing(name, *args)
+              end
+            end
+          RUBY
+        end
+      end
     end
   end
 end
