@@ -46,7 +46,7 @@ RSpec.describe RuboCop::Cop::Style::DoubleNegation, :config do
   context 'when `EnforcedStyle: allowed_in_returns`' do
     let(:enforced_style) { 'allowed_in_returns' }
 
-    include_examples 'common'
+    it_behaves_like 'common'
 
     it 'registers an offense and corrects for `!!` when not return location and using `unless`' do
       expect_offense(<<~RUBY)
@@ -493,6 +493,17 @@ RSpec.describe RuboCop::Cop::Style::DoubleNegation, :config do
       RUBY
     end
 
+    it 'does not register an offense for a line-broken `!!` expression when using `return` keyword' do
+      expect_no_offenses(<<~RUBY)
+        def foo?
+          return !!bar.do_something if condition
+          baz
+          !!qux &&
+            quux
+        end
+      RUBY
+    end
+
     it 'does not register an offense for `!!` when return location by `define_method`' do
       expect_no_offenses(<<~RUBY)
         define_method :foo? do
@@ -502,6 +513,15 @@ RSpec.describe RuboCop::Cop::Style::DoubleNegation, :config do
       RUBY
     end
 
+    it 'does not register an offense for `!!` when return location by `define_method` with numblock' do
+      expect_no_offenses(<<~RUBY)
+        define_method :foo? do
+          do_something(_1)
+          !!qux
+        end
+      RUBY
+    end
+
     it 'does not register an offense for `!!` when return location by `define_singleton_method`' do
       expect_no_offenses(<<~RUBY)
         define_singleton_method :foo? do
@@ -783,7 +803,7 @@ RSpec.describe RuboCop::Cop::Style::DoubleNegation, :config do
   context 'when `EnforcedStyle: forbidden`' do
     let(:enforced_style) { 'forbidden' }
 
-    include_examples 'common'
+    it_behaves_like 'common'
 
     it 'registers an offense and corrects for `!!` when return location' do
       expect_offense(<<~RUBY)
