@@ -8,7 +8,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyCaseCondition, :config do
       expect_correction(corrected_source)
     end
 
-    let(:source_with_case) { source.sub(/case/, 'case :a').sub(/^\s*\^.*\n/, '') }
+    let(:source_with_case) { source.sub('case', 'case :a').sub(/^\s*\^.*\n/, '') }
 
     it 'accepts the source with case' do
       expect_no_offenses(source_with_case)
@@ -240,22 +240,22 @@ RSpec.describe RuboCop::Cop::Style::EmptyCaseCondition, :config do
     context 'when used as an argument of a method without comment' do
       let(:source) do
         <<~RUBY
-          do_some_work case
-                       ^^^^ Do not use empty `case` condition, instead use an `if` expression.
-                       when object.nil?
-                         Object.new
-                       else
-                         object
-                       end
+          case
+          ^^^^ Do not use empty `case` condition, instead use an `if` expression.
+          when object.nil?
+            Object.new
+          else
+            object
+          end
         RUBY
       end
       let(:corrected_source) do
         <<~RUBY
-          do_some_work if object.nil?
-                         Object.new
-                       else
-                         object
-                       end
+          if object.nil?
+            Object.new
+          else
+            object
+          end
         RUBY
       end
 
@@ -266,67 +266,23 @@ RSpec.describe RuboCop::Cop::Style::EmptyCaseCondition, :config do
       let(:source) do
         <<~RUBY
           # example.rb
-          do_some_work case
-                       ^^^^ Do not use empty `case` condition, instead use an `if` expression.
-                       when object.nil?
-                         Object.new
-                       else
-                         object
-                       end
+          case
+          ^^^^ Do not use empty `case` condition, instead use an `if` expression.
+          when object.nil?
+            Object.new
+          else
+            object
+          end
         RUBY
       end
       let(:corrected_source) do
         <<~RUBY
           # example.rb
-          do_some_work if object.nil?
-                         Object.new
-                       else
-                         object
-                       end
-        RUBY
-      end
-
-      it_behaves_like 'detect/correct empty case, accept non-empty case'
-    end
-
-    context 'when using `when ... then` in `case` in `return`' do
-      let(:source) do
-        <<~RUBY
-          return case
-                 ^^^^ Do not use empty `case` condition, instead use an `if` expression.
-                 when object.nil? then Object.new
-                 else object
-                 end
-        RUBY
-      end
-      let(:corrected_source) do
-        <<~RUBY
-          return if object.nil?
-           Object.new
-                 else object
-                 end
-        RUBY
-      end
-
-      it_behaves_like 'detect/correct empty case, accept non-empty case'
-    end
-
-    context 'when using `when ... then` in `case` in a method call' do
-      let(:source) do
-        <<~RUBY
-          do_some_work case
-                       ^^^^ Do not use empty `case` condition, instead use an `if` expression.
-                       when object.nil? then Object.new
-                       else object
-                       end
-        RUBY
-      end
-      let(:corrected_source) do
-        <<~RUBY
-          do_some_work if object.nil?
-           Object.new
-                       else object
-                       end
+          if object.nil?
+            Object.new
+          else
+            object
+          end
         RUBY
       end
 
@@ -386,5 +342,70 @@ RSpec.describe RuboCop::Cop::Style::EmptyCaseCondition, :config do
         RUBY
       end
     end
+
+    context 'when using `return` before empty case condition' do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~RUBY)
+          return case
+                 when foo
+                   1
+                 else
+                   2
+                 end
+        RUBY
+      end
+    end
+
+    context 'when using `break` before empty case condition', :ruby32, unsupported_on: :prism do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~RUBY)
+          break case
+                when foo
+                  1
+                else
+                  2
+                end
+        RUBY
+      end
+    end
+
+    context 'when using `next` before empty case condition', :ruby32, unsupported_on: :prism do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~RUBY)
+          next case
+               when foo
+                 1
+               else
+                 2
+               end
+        RUBY
+      end
+    end
+
+    context 'when using method call before empty case condition' do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~RUBY)
+          do_something case
+                       when foo
+                         1
+                       else
+                         2
+                       end
+        RUBY
+      end
+    end
+
+    context 'when using safe navigation method call before empty case condition' do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~RUBY)
+          obj&.do_something case
+                            when foo
+                              1
+                            else
+                              2
+                            end
+        RUBY
+      end
+    end
   end
 end
