@@ -553,7 +553,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse, :config do
         end
       end
 
-      context 'with not comment and nil else-clause' do
+      context 'with no comment and nil else-clause' do
         it 'registers an offense' do
           expect_offense(<<~RUBY)
             if condition
@@ -589,10 +589,77 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse, :config do
           RUBY
         end
       end
+
+      context 'with no comment and empty else-clause after `elsif`' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            if condition
+              foo
+            elsif condition2
+              bar
+            else
+            ^^^^ Redundant `else`-clause.
+            end
+          RUBY
+        end
+      end
+
+      context 'with no comment and nil else-clause after `elsif`' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            if condition
+              foo
+            elsif condition2
+              bar
+            else
+            ^^^^ Redundant `else`-clause.
+              nil
+            end
+          RUBY
+        end
+      end
+
+      context 'with comment and empty else-clause after `elsif`' do
+        it "doesn't register an offense" do
+          expect_no_offenses(<<~RUBY)
+            if condition
+              foo
+            elsif condition2
+              bar
+            else
+              # some comment
+            end
+          RUBY
+        end
+      end
+
+      context 'with comment and nil else-clause after `elsif`' do
+        it "doesn't register an offense" do
+          expect_no_offenses(<<~RUBY)
+            if condition
+              foo
+            elsif condition2
+              bar
+            else
+              nil # some comment
+            end
+          RUBY
+        end
+      end
+
+      context 'without an else' do
+        it 'does not register an offense' do
+          expect_no_offenses(<<~RUBY)
+            if condition
+              statement
+            end
+          RUBY
+        end
+      end
     end
 
     context 'given an unless-statement' do
-      context 'with not comment and empty else-clause' do
+      context 'with no comment and empty else-clause' do
         it 'registers an offense' do
           expect_offense(<<~RUBY)
             unless condition
@@ -604,7 +671,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse, :config do
         end
       end
 
-      context 'with not comment and nil else-clause' do
+      context 'with no comment and nil else-clause' do
         it 'registers an offense' do
           expect_offense(<<~RUBY)
             unless condition
@@ -640,10 +707,20 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse, :config do
           RUBY
         end
       end
+
+      context 'without an else' do
+        it 'does not register an offense' do
+          expect_no_offenses(<<~RUBY)
+            unless condition
+              statement
+            end
+          RUBY
+        end
+      end
     end
 
     context 'given a case statement' do
-      context 'with not comment and empty else-clause' do
+      context 'with no comment and empty else-clause' do
         it 'registers an offense' do
           expect_offense(<<~RUBY)
             case a
@@ -656,7 +733,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse, :config do
         end
       end
 
-      context 'with not comment and nil else-clause' do
+      context 'with no comment and nil else-clause' do
         it 'registers an offense' do
           expect_offense(<<~RUBY)
             case a
@@ -695,6 +772,17 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse, :config do
           RUBY
         end
       end
+
+      context 'without an else' do
+        it 'does not register an offense' do
+          expect_no_offenses(<<~RUBY)
+            case a
+            when condition
+              statement
+            end
+          RUBY
+        end
+      end
     end
   end
 
