@@ -4,7 +4,7 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
   context 'EnforcedStyle is left_coerce' do
     let(:cop_config) { { 'EnforcedStyle' => 'left_coerce' } }
 
-    it 'registers offense and corrects for right coerce' do
+    it 'registers an offense and corrects for right coerce' do
       expect_offense(<<~RUBY)
         a / b.to_f
         ^^^^^^^^^^ Prefer using `.to_f` on the left side.
@@ -15,7 +15,19 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
       RUBY
     end
 
-    it 'registers offense and corrects for both coerce' do
+    it 'does not register an offense for right coerce with `nth_ref`' do
+      expect_no_offenses(<<~RUBY)
+        a / $1.to_f
+      RUBY
+    end
+
+    it 'does not register an offense for right coerce with `Regexp.last_match(1)`' do
+      expect_no_offenses(<<~RUBY)
+        a / Regexp.last_match(1).to_f
+      RUBY
+    end
+
+    it 'registers an offense and corrects for both coerce' do
       expect_offense(<<~RUBY)
         a.to_f / b.to_f
         ^^^^^^^^^^^^^^^ Prefer using `.to_f` on the left side.
@@ -26,7 +38,25 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
       RUBY
     end
 
-    it 'registers offense and corrects for right coerce with calculations' do
+    it 'does not register an offense for both coerce with `nth_ref`' do
+      expect_no_offenses(<<~RUBY)
+        $1.to_f / $2.to_f
+      RUBY
+    end
+
+    it 'does not register an offense for both coerce with `Regexp.last_match`' do
+      expect_no_offenses(<<~RUBY)
+        Regexp.last_match(1).to_f / Regexp.last_match(1).to_f
+      RUBY
+    end
+
+    it 'does not register an offense for both coerce with `::Regexp.last_match`' do
+      expect_no_offenses(<<~RUBY)
+        ::Regexp.last_match(1).to_f / ::Regexp.last_match(1).to_f
+      RUBY
+    end
+
+    it 'registers an offense and corrects for right coerce with calculations' do
       expect_offense(<<~RUBY)
         (a * b) / (c - d / 2).to_f
         ^^^^^^^^^^^^^^^^^^^^^^^^^^ Prefer using `.to_f` on the left side.
@@ -37,6 +67,10 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
       RUBY
     end
 
+    it 'does not register offense for right coerce with implicit receiver' do
+      expect_no_offenses('a / to_f')
+    end
+
     it 'does not register offense for left coerce' do
       expect_no_offenses('a.to_f / b')
     end
@@ -45,7 +79,7 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
   context 'EnforcedStyle is right_coerce' do
     let(:cop_config) { { 'EnforcedStyle' => 'right_coerce' } }
 
-    it 'registers offense and corrects for left coerce' do
+    it 'registers an offense and corrects for left coerce' do
       expect_offense(<<~RUBY)
         a.to_f / b
         ^^^^^^^^^^ Prefer using `.to_f` on the right side.
@@ -56,7 +90,19 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
       RUBY
     end
 
-    it 'registers offense and corrects for both coerce' do
+    it 'does not register an offense for left coerce with `nth_ref`' do
+      expect_no_offenses(<<~RUBY)
+        $1.to_f / b
+      RUBY
+    end
+
+    it 'does not register an offense for left coerce with `Regexp.last_match(1)`' do
+      expect_no_offenses(<<~RUBY)
+        Regexp.last_match(1).to_f / b
+      RUBY
+    end
+
+    it 'registers an offense and corrects for both coerce' do
       expect_offense(<<~RUBY)
         a.to_f / b.to_f
         ^^^^^^^^^^^^^^^ Prefer using `.to_f` on the right side.
@@ -67,7 +113,7 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
       RUBY
     end
 
-    it 'registers offense and corrects for left coerce with calculations' do
+    it 'registers an offense and corrects for left coerce with calculations' do
       expect_offense(<<~RUBY)
         (a - b).to_f / (c * 3 * d / 2)
         ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Prefer using `.to_f` on the right side.
@@ -78,6 +124,10 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
       RUBY
     end
 
+    it 'does not register offense for left coerce with implicit receiver' do
+      expect_no_offenses('to_f / b')
+    end
+
     it 'does not register offense for right coerce' do
       expect_no_offenses('a / b.to_f')
     end
@@ -86,7 +136,7 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
   context 'EnforcedStyle is single_coerce' do
     let(:cop_config) { { 'EnforcedStyle' => 'single_coerce' } }
 
-    it 'registers offense and corrects for both coerce' do
+    it 'registers an offense and corrects for both coerce' do
       expect_offense(<<~RUBY)
         a.to_f / b.to_f
         ^^^^^^^^^^^^^^^ Prefer using `.to_f` on one side only.
@@ -97,7 +147,7 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
       RUBY
     end
 
-    it 'registers offense and corrects for left coerce with calculations' do
+    it 'registers an offense and corrects for left coerce with calculations' do
       expect_offense(<<~RUBY)
         (a - b).to_f / (3 * d / 2).to_f
         ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Prefer using `.to_f` on one side only.
@@ -115,12 +165,24 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
     it 'does not register offense for right coerce only' do
       expect_no_offenses('a / b.to_f')
     end
+
+    it 'does not register offense for left coerce with implicit receiver' do
+      expect_no_offenses('a / to_f')
+    end
+
+    it 'does not register offense for rigjt coerce with implicit receiver' do
+      expect_no_offenses('to_f / b')
+    end
+
+    it 'does not register offense for coercions with implicit receivers' do
+      expect_no_offenses('to_f / to_f')
+    end
   end
 
   context 'EnforcedStyle is fdiv' do
     let(:cop_config) { { 'EnforcedStyle' => 'fdiv' } }
 
-    it 'registers offense and corrects for right coerce' do
+    it 'registers an offense and corrects for right coerce' do
       expect_offense(<<~RUBY)
         a / b.to_f
         ^^^^^^^^^^ Prefer using `fdiv` for float divisions.
@@ -131,7 +193,7 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
       RUBY
     end
 
-    it 'registers offense and corrects for both coerce' do
+    it 'registers an offense and corrects for both coerce' do
       expect_offense(<<~RUBY)
         a.to_f / b.to_f
         ^^^^^^^^^^^^^^^ Prefer using `fdiv` for float divisions.
@@ -142,7 +204,7 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
       RUBY
     end
 
-    it 'registers offense and corrects for left coerce' do
+    it 'registers an offense and corrects for left coerce' do
       expect_offense(<<~RUBY)
         a.to_f / b
         ^^^^^^^^^^ Prefer using `fdiv` for float divisions.
@@ -153,7 +215,7 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
       RUBY
     end
 
-    it 'registers offense and corrects for left coerce with calculations' do
+    it 'registers an offense and corrects for left coerce with calculations' do
       expect_offense(<<~RUBY)
         (a - b).to_f / (c * 3 * d / 2)
         ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Prefer using `fdiv` for float divisions.
@@ -167,5 +229,13 @@ RSpec.describe RuboCop::Cop::Style::FloatDivision, :config do
     it 'does not register offense on usage of fdiv' do
       expect_no_offenses('a.fdiv(b)')
     end
+
+    it 'does not register offense for left coerce with implicit receiver' do
+      expect_no_offenses('to_f / b')
+    end
+
+    it 'does not register offense for right coerce with implicit receiver' do
+      expect_no_offenses('a / to_f')
+    end
   end
 end
