@@ -370,6 +370,19 @@ RSpec.describe RuboCop::Cop::Style::For, :config do
           end
         RUBY
       end
+
+      it 'corrects to `each` with safe navigation if collection ends with safe navigation' do
+        expect_offense(<<~RUBY)
+          for item in foo&.items
+          ^^^^^^^^^^^^^^^^^^^^^^ Prefer `each` over `for`.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo&.items&.each do |item|
+          end
+        RUBY
+      end
     end
 
     it 'accepts multiline each' do
@@ -463,6 +476,27 @@ RSpec.describe RuboCop::Cop::Style::For, :config do
       end
     end
 
+    context 'Ruby 3.4', :ruby34 do
+      it 'registers an offense for each without an item and uses _ as the item' do
+        expect_offense(<<~RUBY)
+          def func
+            [1, 2, 3].each do
+            ^^^^^^^^^^^^^^^^^ Prefer `for` over `each`.
+              puts it
+            end
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def func
+            for _ in [1, 2, 3] do
+              puts it
+            end
+          end
+        RUBY
+      end
+    end
+
     it 'registers an offense for correct + opposite style' do
       expect_offense(<<~RUBY)
         def func
@@ -488,6 +522,14 @@ RSpec.describe RuboCop::Cop::Style::For, :config do
       RUBY
     end
 
+    it 'registers no offense when there is no receiver' do
+      expect_no_offenses(<<~RUBY)
+        each do |n|
+          puts n
+        end
+      RUBY
+    end
+
     it 'registers multiple offenses' do
       expect_offense(<<~RUBY)
         for n in [1, 2, 3] do
