@@ -4,6 +4,7 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
   let(:enforced_style) { :annotated }
   let(:allowed_methods) { [] }
   let(:allowed_patterns) { [] }
+  let(:mode) { :aggressive }
 
   let(:cop_config) do
     {
@@ -11,7 +12,8 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
       'SupportedStyles' => %i[annotated template unannotated],
       'MaxUnannotatedPlaceholdersAllowed' => 0,
       'AllowedMethods' => allowed_methods,
-      'AllowedPatterns' => allowed_patterns
+      'AllowedPatterns' => allowed_patterns,
+      'Mode' => mode
     }
   end
 
@@ -24,7 +26,7 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
       end
 
       if correctable_sequence
-        it 'registers offense for dual unannotated' do
+        it 'registers an offense for dual unannotated' do
           expect_offense(<<~RUBY)
             format('%#{token} %s', foo, bar)
                     ^^ Prefer [...]
@@ -77,14 +79,14 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
 
       it 'registers offenses for template style' do
         expect_offense(<<~RUBY, annotated: annotated, template: template)
-          <<-HEREDOC
+          format(<<-HEREDOC, foo: bar)
           foo %{annotated} + bar %{template}
               _{annotated}       ^{template} Prefer annotated tokens [...]
           HEREDOC
         RUBY
 
         expect_correction(<<~RUBY)
-          <<-HEREDOC
+          format(<<-HEREDOC, foo: bar)
           foo #{annotated} + bar #{template_to_annotated}
           HEREDOC
         RUBY
@@ -92,29 +94,29 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
 
       it 'supports dynamic string with interpolation' do
         expect_offense(<<~'RUBY', annotated: annotated, template: template)
-          "a#{b}%{annotated} c#{d}%{template} e#{f}"
-                _{annotated}      ^{template} Prefer annotated tokens [...]
+          format("a#{b}%{annotated} c#{d}%{template} e#{f}")
+                       _{annotated}      ^{template} Prefer annotated tokens [...]
         RUBY
 
         expect_correction(<<~RUBY)
-          "a\#{b}#{annotated} c\#{d}#{template_to_annotated} e\#{f}"
+          format("a\#{b}#{annotated} c\#{d}#{template_to_annotated} e\#{f}")
         RUBY
       end
 
       it 'sets the enforced style to annotated after inspecting "%<a>s"' do
-        expect_no_offenses('"%<a>s"')
+        expect_no_offenses('format("%<a>s", a: foo)')
 
         expect(cop.config_to_allow_offenses).to eq('EnforcedStyle' => 'annotated')
       end
 
       it 'detects when the cop must be disabled to avoid offenses' do
         expect_offense(<<~RUBY)
-          "%{a}"
-           ^^^^ Prefer annotated tokens [...]
+          format("%{a}", a: foo)
+                  ^^^^ Prefer annotated tokens [...]
         RUBY
 
         expect_correction(<<~RUBY)
-          "%<a>s"
+          format("%<a>s", a: foo)
         RUBY
 
         expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
@@ -133,22 +135,22 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
       if template_correction
         it 'registers offenses for annotated style' do
           expect_offense(<<~RUBY, annotated: annotated, template: template)
-            <<-HEREDOC
+            format(<<-HEREDOC, foo: bar)
             foo %{template} + bar %{annotated}
                 _{template}       ^{annotated} Prefer template tokens [...]
             HEREDOC
           RUBY
 
           expect_correction(<<~RUBY)
-            <<-HEREDOC
+            format(<<-HEREDOC, foo: bar)
             foo #{template} + bar #{annotated_to_template}
             HEREDOC
           RUBY
         end
       else
         it 'does not register offenses for annotated style' do
-          expect_no_offenses(<<~RUBY, annotated: annotated, template: template)
-            <<-HEREDOC
+          expect_no_offenses(<<~RUBY)
+            format(<<-HEREDOC, foo: bar)
             foo %{template} + bar %{annotated}
             HEREDOC
           RUBY
@@ -158,35 +160,35 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
       it 'supports dynamic string with interpolation' do
         if template_correction
           expect_offense(<<~'RUBY', annotated: annotated, template: template)
-            "a#{b}%{template} c#{d}%{annotated} e#{f}"
-                  _{template}      ^{annotated} Prefer template tokens [...]
+            format("a#{b}%{template} c#{d}%{annotated} e#{f}")
+                         _{template}      ^{annotated} Prefer template tokens [...]
           RUBY
 
           expect_correction(<<~RUBY)
-            "a\#{b}#{template} c\#{d}#{annotated_to_template} e\#{f}"
+            format("a\#{b}#{template} c\#{d}#{annotated_to_template} e\#{f}")
           RUBY
         else
-          expect_no_offenses(<<~'RUBY', annotated: annotated, template: template)
-            "a#{b}%{template} c#{d}%{annotated} e#{f}"
+          expect_no_offenses(<<~'RUBY')
+            format("a#{b}%{template} c#{d}%{annotated} e#{f}")
           RUBY
         end
       end
 
       it 'detects when the cop must be disabled to avoid offenses' do
         expect_offense(<<~RUBY)
-          "%<a>s"
-           ^^^^^ Prefer template tokens [...]
+          format("%<a>s", a: foo)
+                  ^^^^^ Prefer template tokens [...]
         RUBY
 
         expect_correction(<<~RUBY)
-          "%{a}"
+          format("%{a}", a: foo)
         RUBY
 
         expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
       end
 
       it 'configures the enforced style to template after inspecting "%{a}"' do
-        expect_no_offenses('"%{a}"')
+        expect_no_offenses('format("%{a}", a: foo)')
 
         expect(cop.config_to_allow_offenses).to eq('EnforcedStyle' => 'template')
       end
@@ -239,8 +241,122 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
             ^^^^^^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
     RUBY
 
+    expect_no_corrections
+  end
+
+  it 'handles dstrs in format context' do
+    expect_offense(<<~'RUBY')
+      format("c#{b}%{template}")
+                   ^^^^^^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+    RUBY
+
     expect_correction(<<~'RUBY')
-      "c#{b}%<template>s"
+      format("c#{b}%<template>s")
+    RUBY
+  end
+
+  it 'autocorrects in sprintf context' do
+    expect_offense(<<~RUBY)
+      sprintf('%{foo}', foo: 'bar')
+               ^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+    RUBY
+
+    expect_correction(<<~RUBY)
+      sprintf('%<foo>s', foo: 'bar')
+    RUBY
+  end
+
+  it 'autocorrects in printf context' do
+    expect_offense(<<~RUBY)
+      printf('%{foo}', foo: 'bar')
+              ^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+    RUBY
+
+    expect_correction(<<~RUBY)
+      printf('%<foo>s', foo: 'bar')
+    RUBY
+  end
+
+  it 'autocorrects with the percent operator' do
+    expect_offense(<<~RUBY)
+      '%{foo}' % { foo: 'bar' }
+       ^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+    RUBY
+
+    expect_correction(<<~RUBY)
+      '%<foo>s' % { foo: 'bar' }
+    RUBY
+  end
+
+  it 'autocorrects dstr with the percent operator' do
+    expect_offense(<<~'RUBY')
+      "c#{b}%{foo}" % { foo: 'bar' }
+            ^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+    RUBY
+
+    expect_correction(<<~'RUBY')
+      "c#{b}%<foo>s" % { foo: 'bar' }
+    RUBY
+  end
+
+  it 'does not autocorrect when passed to a non-format method' do
+    expect_offense(<<~RUBY)
+      foo('%{bar}')
+           ^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+    RUBY
+
+    expect_no_corrections
+  end
+
+  it 'does not autocorrect a bare string outside of format context' do
+    expect_offense(<<~RUBY)
+      'https://gitlab.com/%{project_path}/-/blob/%{default_branch}/file'
+                          ^^^^^^^^^^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+                                                 ^^^^^^^^^^^^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+    RUBY
+
+    expect_no_corrections
+  end
+
+  it 'does not autocorrect a string in a hash value' do
+    expect_offense(<<~RUBY)
+      validates :colour, format: { message: '%{colour} is not a valid hex colour' }
+                                             ^^^^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+    RUBY
+
+    expect_no_corrections
+  end
+
+  it 'does not autocorrect a bare heredoc' do
+    expect_offense(<<~RUBY)
+      <<-MSG
+        %{colour} is not valid
+        ^^^^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+      MSG
+    RUBY
+
+    expect_no_corrections
+  end
+
+  it 'autocorrects with an explicit receiver on format' do
+    expect_offense(<<~RUBY)
+      Kernel.format('%{foo}', foo: 'bar')
+                     ^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+    RUBY
+
+    expect_correction(<<~RUBY)
+      Kernel.format('%<foo>s', foo: 'bar')
+    RUBY
+  end
+
+  it 'autocorrects with an explicit receiver on sprintf' do
+    expect_offense(<<~RUBY)
+      Kernel.sprintf('%{foo}', foo: 'bar')
+                      ^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
+    RUBY
+
+    expect_correction(<<~RUBY)
+      Kernel.sprintf('%<foo>s', foo: 'bar')
     RUBY
   end
 
@@ -315,9 +431,7 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
          ^^^^^^ Prefer annotated tokens (like `%<foo>s`) over template tokens (like `%{foo}`).
       RUBY
 
-      expect_correction(<<~RUBY)
-        "%<foo>s"
-      RUBY
+      expect_no_corrections
     end
 
     context 'when AllowedMethods is enabled' do
@@ -398,9 +512,7 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
          ^^^^^^^ Prefer template tokens (like `%{foo}`) over annotated tokens (like `%<foo>s`).
       RUBY
 
-      expect_correction(<<~RUBY)
-        "%{foo}"
-      RUBY
+      expect_no_corrections
     end
   end
 
@@ -416,4 +528,60 @@ RSpec.describe RuboCop::Cop::Style::FormatStringToken, :config do
       expect_no_corrections
     end
   end
+
+  context 'with `Mode: conservative`' do
+    let(:mode) { :conservative }
+
+    %i[annotated template unannotated].each do |style|
+      context "when enforced style is #{style}" do
+        let(:enforced_style) { style }
+
+        shared_examples 'conservative' do |given_style, string|
+          context "with `#{string}`" do
+            context 'with a bare string' do
+              it 'does not register an offense' do
+                expect_no_offenses(<<~RUBY)
+                  '#{string}'
+                RUBY
+              end
+            end
+
+            if style != given_style
+              %i[printf sprintf format].each do |method|
+                context "as an argument to `#{method}`" do
+                  it 'registers an offense' do
+                    expect_offense(<<~RUBY, string: string, method: method)
+                      %{method}('%{string}', *vars)
+                      _{method}  ^{string} Prefer [...]
+                    RUBY
+                  end
+                end
+              end
+
+              context 'as an argument to `%`' do
+                it 'registers an offense' do
+                  expect_offense(<<~RUBY, string: string)
+                    '#{string}' % vars
+                     ^{string} Prefer [...]
+                  RUBY
+                end
+              end
+            end
+
+            context 'as an argument to another method' do
+              it 'does not register an offense' do
+                expect_no_offenses(<<~RUBY)
+                  foo('#{string}')
+                RUBY
+              end
+            end
+          end
+        end
+
+        it_behaves_like 'conservative', :annotated, '%<greetings>s'
+        it_behaves_like 'conservative', :template, '%{greetings}'
+        it_behaves_like 'conservative', :unannotated, '%s'
+      end
+    end
+  end
 end
