@@ -26,7 +26,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
 
       let(:cop_config_overrides) { {} }
 
-      it 'registers offense for hash rocket syntax when new is possible' do
+      it 'registers an offense for hash rocket syntax when new is possible' do
         expect_offense(<<~RUBY)
           x = { :a => 0, :b   =>  2}
                 ^^^^^ Use the new Ruby 1.9 hash syntax.
@@ -68,13 +68,13 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         expect_no_offenses('{}')
       end
 
-      context 'ruby < 2.2', :ruby21 do
+      context 'ruby < 2.2', :ruby21, unsupported_on: :prism do
         it 'accepts hash rockets when symbol keys have string in them' do
           expect_no_offenses('x = { :"string" => 0 }')
         end
       end
 
-      it 'registers an offense when symbol keys have strings in them' do
+      it 'registers an offense when symbol keys have strings in them', :ruby22 do
         expect_offense(<<~RUBY)
           x = { :"string" => 0 }
                 ^^^^^^^^^^^^ Use the new Ruby 1.9 hash syntax.
@@ -140,7 +140,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         expect_no_offenses('x = { :[] => 0 }')
       end
 
-      it 'registers offense when keys start with an uppercase letter' do
+      it 'registers an offense when keys start with an uppercase letter' do
         expect_offense(<<~RUBY)
           x = { :A => 0 }
                 ^^^^^ Use the new Ruby 1.9 hash syntax.
@@ -208,6 +208,85 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
           RUBY
         end
       end
+
+      it 'registers an offense for implicit `call` method' do
+        expect_offense(<<~RUBY)
+          method(:puts).(:key => value)
+                         ^^^^^^^ Use the new Ruby 1.9 hash syntax.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          method(:puts).(key: value)
+        RUBY
+      end
+
+      context 'Ruby >= 3.1', :ruby31 do
+        it 'registers an offense and adds parentheses for `if` condition' do
+          expect_offense(<<~RUBY)
+            if foo bar: bar
+                        ^^^ Omit the hash value.
+              baz
+            end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            if foo(bar:)
+              baz
+            end
+          RUBY
+        end
+
+        it 'registers an offense and adds parentheses for `unless` condition' do
+          expect_offense(<<~RUBY)
+            unless foo bar: bar
+                            ^^^ Omit the hash value.
+              baz
+            end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            unless foo(bar:)
+              baz
+            end
+          RUBY
+        end
+
+        it 'registers an offense and adds parentheses for `while` condition' do
+          expect_offense(<<~RUBY)
+            while foo bar: bar
+                           ^^^ Omit the hash value.
+              baz
+            end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            while foo(bar:)
+              baz
+            end
+          RUBY
+        end
+
+        it 'registers an offense and adds parentheses for `until` condition' do
+          expect_offense(<<~RUBY)
+            until foo bar: bar
+                           ^^^ Omit the hash value.
+              baz
+            end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            until foo(bar:)
+              baz
+            end
+          RUBY
+        end
+
+        it 'does not register an offense for modifier form' do
+          expect_no_offenses(<<~RUBY)
+            baz if foo bar: bar
+          RUBY
+        end
+      end
     end
 
     context 'with SpaceAroundOperators disabled' do
@@ -336,6 +415,17 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         RUBY
       end
     end
+
+    it 'registers an offense for implicit `call` method' do
+      expect_offense(<<~RUBY)
+        method(:puts).(:key=>value)
+                       ^^^^^^ Use the new Ruby 1.9 hash syntax.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        method(:puts).(key: value)
+      RUBY
+    end
   end
 
   context 'configured to enforce hash rockets style' do
@@ -347,7 +437,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
       }
     end
 
-    it 'registers offense for Ruby 1.9 style' do
+    it 'registers an offense for Ruby 1.9 style' do
       expect_offense(<<~RUBY)
         x = { a: 0, b: 2}
               ^^ Use hash rockets syntax.
@@ -406,6 +496,17 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         expect_no_offenses('{ :a => :b, :c => :d }')
       end
     end
+
+    it 'registers an offense for implicit `call` method' do
+      expect_offense(<<~RUBY)
+        method(:puts).(a: 0)
+                       ^^ Use hash rockets syntax.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        method(:puts).(:a => 0)
+      RUBY
+    end
   end
 
   context 'configured to enforce ruby 1.9 style with no mixed keys' do
@@ -421,7 +522,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         expect_no_offenses('x = { a: 0, b: 1 }')
       end
 
-      it 'registers offense for hash rocket syntax when new is possible' do
+      it 'registers an offense for hash rocket syntax when new is possible' do
         expect_offense(<<~RUBY)
           x = { :a => 0, :b => 2 }
                 ^^^^^ Use the new Ruby 1.9 hash syntax.
@@ -478,7 +579,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         RUBY
       end
 
-      context 'ruby < 2.2', :ruby21 do
+      context 'ruby < 2.2', :ruby21, unsupported_on: :prism do
         it 'accepts hash rockets when keys have whitespaces in them' do
           expect_no_offenses('x = { :"t o" => 0, :b => 1 }')
         end
@@ -601,7 +702,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         expect_no_offenses('x = { a: 0, b: 1 }')
       end
 
-      it 'registers offense for hash rocket syntax when new is possible' do
+      it 'registers an offense for hash rocket syntax when new is possible' do
         expect_offense(<<~RUBY)
           x = { :a => 0, :b => 2 }
                 ^^^^^ Use the new Ruby 1.9 hash syntax.
@@ -658,7 +759,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         RUBY
       end
 
-      context 'ruby < 2.2', :ruby21 do
+      context 'ruby < 2.2', :ruby21, unsupported_on: :prism do
         it 'accepts hash rockets when keys have whitespaces in them' do
           expect_no_offenses('x = { :"t o" => 0, :b => 1 }')
         end
@@ -788,6 +889,19 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
       expect_no_offenses('x = { :"t o" => 0, :b => 1 }')
     end
 
+    context 'Ruby >= 3.1', :ruby31 do
+      it 'registers hash rockets when keys have whitespaces in them and using hash value omission' do
+        expect_offense(<<~RUBY)
+          {:"t o" => 0, b:}
+                        ^^ Don't mix styles in the same hash.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          {:"t o" => 0, :b => b}
+        RUBY
+      end
+    end
+
     it 'registers an offense when keys have whitespaces and mix styles' do
       expect_offense(<<~RUBY)
         x = { :"t o" => 0, b: 1 }
@@ -925,6 +1039,25 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         RUBY
       end
 
+      it 'registers and corrects an offense when braced hash key and value are the same and it is used in `if`...`else`' do
+        expect_offense(<<~RUBY)
+          if condition
+            template % {value: value}
+                               ^^^^^ Omit the hash value.
+          else
+            do_something
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          if condition
+            template % {value:}
+          else
+            do_something
+          end
+        RUBY
+      end
+
       it 'registers and corrects an offense when hash key and hash value are the same and it in the method body' do
         expect_offense(<<~RUBY)
           def do_something
@@ -1016,7 +1149,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
       it 'does not register an offense when hash key and hash value are the same but the value ends `!`' do
         # Prevents the following syntax error:
         #
-        # % ruby -cve 'def foo! = puts("hi"); {foo!:}'
+        # $ ruby -cve 'def foo! = puts("hi"); {foo!:}'
         # ruby 3.1.0dev (2021-12-05T10:23:42Z master 19f037e452) [x86_64-darwin19]
         # -e:1: identifier foo! is not valid to get
         expect_no_offenses(<<~RUBY)
@@ -1027,7 +1160,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
       it 'does not register an offense when hash key and hash value are the same but the value ends `?`' do
         # Prevents the following syntax error:
         #
-        # % ruby -cve 'def foo? = puts("hi"); {foo?:}'
+        # $ ruby -cve 'def foo? = puts("hi"); {foo?:}'
         # ruby 3.1.0dev (2021-12-05T10:23:42Z master 19f037e452) [x86_64-darwin19]
         # -e:1: identifier foo? is not valid to get
         expect_no_offenses(<<~RUBY)
@@ -1054,24 +1187,109 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         RUBY
       end
 
-      it 'does not register an offense when without parentheses call expr follows' do
-        # Prevent syntax errors shown in the URL: https://bugs.ruby-lang.org/issues/18396
-        expect_no_offenses(<<~RUBY)
+      it 'registers an offense when without parentheses call expr follows' do
+        # Add parentheses to prevent syntax errors shown in the URL: https://bugs.ruby-lang.org/issues/18396
+        expect_offense(<<~RUBY)
           foo value: value
+                     ^^^^^ Omit the hash value.
           foo arg
 
           value = 'a'
           foo value: value
+                     ^^^^^ Omit the hash value.
+          foo arg
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo(value:)
+          foo arg
+
+          value = 'a'
+          foo(value:)
           foo arg
         RUBY
       end
 
-      it 'does not register an offense when without parentheses call expr follows after nested method call' do
-        # Prevent syntax errors shown in the URL: https://bugs.ruby-lang.org/issues/18396
-        expect_no_offenses(<<~RUBY)
+      it 'registers an offense in chained calls' do
+        expect_offense(<<~RUBY)
+          create(:foo, bar: bar).baz
+                            ^^^ Omit the hash value.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          create(:foo, bar:).baz
+        RUBY
+      end
+
+      it 'registers an offense when without parentheses call expr follows after nested method call' do
+        # Add parentheses to prevent syntax errors shown in the URL: https://bugs.ruby-lang.org/issues/18396
+        expect_offense(<<~RUBY)
           foo bar value: value
+                         ^^^^^ Omit the hash value.
           baz
         RUBY
+
+        expect_correction(<<~RUBY)
+          foo bar(value:)
+          baz
+        RUBY
+      end
+
+      it 'registers an offense when without parentheses call expr follows after multiple keyword arguments method call' do
+        # Add parentheses to prevent syntax errors shown in the URL: https://bugs.ruby-lang.org/issues/18396
+        expect_offense(<<~RUBY)
+          foo baz: baz, qux: qux
+                             ^^^ Omit the hash value.
+                   ^^^ Omit the hash value.
+          baz
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo(baz:, qux:)
+          baz
+        RUBY
+      end
+
+      it 'registers an offense when expression follows hash key assignment' do
+        expect_offense(<<~RUBY)
+          hash[:key] = { foo: foo }
+                              ^^^ Omit the hash value.
+          bar
+        RUBY
+
+        expect_correction(<<~RUBY)
+          hash[:key] = { foo: }
+          bar
+        RUBY
+      end
+
+      it 'registers an offense when expression follows attribute assignment' do
+        expect_offense(<<~RUBY)
+          object.attr = {foo: foo}
+                              ^^^ Omit the hash value.
+          pass
+        RUBY
+
+        expect_correction(<<~RUBY)
+          object.attr = {foo:}
+          pass
+        RUBY
+      end
+
+      it 'registers an offense when expression follows multiple assignments' do
+        expect_offense(<<~RUBY)
+          foo = bar = do_stuff arg, opt1: opt1,
+                                          ^^^^ Omit the hash value.
+                                    opt2: opt2
+                                          ^^^^ Omit the hash value.
+          pass
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo = bar = do_stuff(arg, opt1:,
+                                    opt2:)
+          pass
+        RUBY
       end
 
       it 'registers an offense when one line `if` condition follows (with parentheses)' do
@@ -1085,9 +1303,114 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         RUBY
       end
 
+      it 'registers an offense when one line `if` condition follows super (with parentheses)' do
+        expect_offense(<<~RUBY)
+          super(value: value) unless foo
+                       ^^^^^ Omit the hash value.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          super(value:) unless foo
+        RUBY
+      end
+
+      it 'registers an offense in super followed by ivar assignment (without parentheses)' do
+        expect_offense(<<~RUBY)
+          super value: value, other: other
+                                     ^^^^^ Omit the hash value.
+                       ^^^^^ Omit the hash value.
+          @ivar = ivar
+        RUBY
+
+        expect_correction(<<~RUBY)
+          super(value:, other:)
+          @ivar = ivar
+        RUBY
+      end
+
+      it 'registers an offense in super followed by expr without parentheses' do
+        expect_offense(<<~RUBY)
+          super value: value, other: other
+                                     ^^^^^ Omit the hash value.
+                       ^^^^^ Omit the hash value.
+          foo baz
+        RUBY
+
+        expect_correction(<<~RUBY)
+          super(value:, other:)
+          foo baz
+        RUBY
+      end
+
+      context 'Ruby <= 3.2', :ruby32, unsupported_on: :prism do
+        it 'registers an offense in chained calls with dispatch keywords' do
+          expect_offense(<<~RUBY)
+            yield(:foo, bar: bar).baz
+                             ^^^ Omit the hash value.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            yield(:foo, bar:).baz
+          RUBY
+        end
+
+        it 'registers an offense when one line `if` condition follows yield (with parentheses)' do
+          expect_offense(<<~RUBY)
+            yield(value: value) unless foo
+                         ^^^^^ Omit the hash value.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            yield(value:) unless foo
+          RUBY
+        end
+
+        it 'registers an offense in yield followed by ivar assignment (without parentheses)' do
+          expect_offense(<<~RUBY)
+            yield value: value, other: other
+                                       ^^^^^ Omit the hash value.
+                         ^^^^^ Omit the hash value.
+            @ivar = ivar
+          RUBY
+
+          expect_correction(<<~RUBY)
+            yield(value:, other:)
+            @ivar = ivar
+          RUBY
+        end
+
+        it 'registers an offense in yield followed by expr without parentheses' do
+          expect_offense(<<~RUBY)
+            yield value: value, other: other
+                                       ^^^^^ Omit the hash value.
+                         ^^^^^ Omit the hash value.
+            foo baz
+          RUBY
+
+          expect_correction(<<~RUBY)
+            yield(value:, other:)
+            foo baz
+          RUBY
+        end
+      end
+
       it 'does not register an offense when one line `if` condition follows (without parentheses)' do
         expect_no_offenses(<<~RUBY)
-          foo value: value if bar
+          foo x, value: value if bar
+        RUBY
+      end
+
+      it 'does not register an offense when one line `if` condition follows super (without parentheses)' do
+        expect_no_offenses(<<~RUBY)
+          super x, value: value unless foo
+        RUBY
+      end
+
+      it 'does not register an offense when one line `if` condition follows (without parentheses) in methods' do
+        expect_no_offenses(<<~RUBY)
+          def method
+            foo x, other:, value: value if bar
+          end
         RUBY
       end
 
@@ -1114,51 +1437,224 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
         RUBY
       end
 
-      it 'does not register an offense when call expr with argument and a block follows' do
-        expect_no_offenses(<<~RUBY)
+      it 'registers an offense when call expr with argument and a block follows' do
+        expect_offense(<<~RUBY)
           foo value: value
+                     ^^^^^ Omit the hash value.
+          foo arg do
+            value
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo(value:)
           foo arg do
             value
           end
         RUBY
       end
 
-      it 'does not register an offense when call expr without arguments and with a block follows' do
-        # Prevent syntax semantic changes shown in the URL: https://bugs.ruby-lang.org/issues/18396
-        expect_no_offenses(<<~RUBY)
+      it 'registers an offense when call expr without arguments and with a block follows' do
+        # Add parentheses to prevent syntax semantic changes shown in the URL: https://bugs.ruby-lang.org/issues/18396
+        expect_offense(<<~RUBY)
           foo value: value
+                     ^^^^^ Omit the hash value.
+          bar do
+            value
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo(value:)
           bar do
             value
           end
         RUBY
       end
 
-      it 'does not register an offense when with parentheses call expr follows' do
-        # Prevent syntax semantic changes shown in the URL: https://bugs.ruby-lang.org/issues/18396
-        expect_no_offenses(<<~RUBY)
+      it 'registers an offense when with parentheses call expr follows' do
+        # Add parentheses to prevent syntax semantic changes shown in the URL: https://bugs.ruby-lang.org/issues/18396
+        expect_offense(<<~RUBY)
           foo value: value
+                     ^^^^^ Omit the hash value.
+          foo(arg)
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo(value:)
           foo(arg)
         RUBY
       end
 
-      it 'does not register an offense when with parentheses call expr follows assignment expr' do
-        # Prevent syntax semantic changes shown in the URL: https://bugs.ruby-lang.org/issues/18396
-        expect_no_offenses(<<~RUBY)
+      it 'registers an offense when with parentheses safe navigation call expr follows' do
+        # Add parentheses to prevent syntax semantic changes shown in the URL: https://bugs.ruby-lang.org/issues/18396
+        expect_offense(<<~RUBY)
+          x&.foo value: value
+                        ^^^^^ Omit the hash value.
+          foo(arg)
+        RUBY
+
+        expect_correction(<<~RUBY)
+          x&.foo(value:)
+          foo(arg)
+        RUBY
+      end
+
+      it 'registers an offense when with parentheses call expr follows assignment expr' do
+        # Add parentheses to prevent syntax semantic changes shown in the URL: https://bugs.ruby-lang.org/issues/18396
+        expect_offense(<<~RUBY)
           var = foo value: value
+                           ^^^^^ Omit the hash value.
+          foo(arg)
+        RUBY
+
+        expect_correction(<<~RUBY)
+          var = foo(value:)
           foo(arg)
         RUBY
       end
 
-      it 'does not register an offense when hash key and hash value are partially the same' do
-        expect_no_offenses(<<~RUBY)
+      it 'registers an offense when hash key and hash value are partially the same' do
+        expect_offense(<<~RUBY)
           def do_something
             do_something foo: foo
+                              ^^^ Omit the hash value.
+            do_something(arg)
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def do_something
+            do_something(foo:)
             do_something(arg)
           end
         RUBY
       end
 
-      context 'when hash roket syntax' do
+      it 'registers an offense when hash first arg key and hash value only are the same which has a method call on the next line' do
+        expect_offense(<<~RUBY)
+          buz foo: foo, bar: 'bar'
+                   ^^^ Omit the hash value.
+
+          def buz(foo:, bar:); end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          buz foo:, bar: 'bar'
+
+          def buz(foo:, bar:); end
+        RUBY
+      end
+
+      it 'registers an offense in method receiving hash literals' do
+        expect_offense(<<~RUBY)
+          foo = {bar: bar, baz: :baz, quux: quux}.merge foo
+                                            ^^^^ Omit the hash value.
+                      ^^^ Omit the hash value.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo = {bar:, baz: :baz, quux:}.merge foo
+        RUBY
+      end
+
+      it 'registers an offense in arguments as method calls with hash omissions' do
+        expect_offense(<<~RUBY)
+          if condition?
+            raise LongLongLongLongError.new 'A long, long, long, long, really long message', foo: foo
+                                                                                                  ^^^ Omit the hash value.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          if condition?
+            raise LongLongLongLongError.new('A long, long, long, long, really long message', foo:)
+          end
+        RUBY
+      end
+
+      it 'registers an offense in calls without parentheses but inside parentheses' do
+        expect_offense(<<~RUBY)
+          (create :foo, bar: bar)
+                             ^^^ Omit the hash value.
+
+          pass
+        RUBY
+
+        expect_correction(<<~RUBY)
+          (create :foo, bar:)
+
+          pass
+        RUBY
+      end
+
+      it 'registers an offense and adds parentheses for `if` condition' do
+        expect_offense(<<~RUBY)
+          if foo bar: bar
+                      ^^^ Omit the hash value.
+            baz
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          if foo(bar:)
+            baz
+          end
+        RUBY
+      end
+
+      it 'registers an offense and adds parentheses for `unless` condition' do
+        expect_offense(<<~RUBY)
+          unless foo bar: bar
+                          ^^^ Omit the hash value.
+            baz
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          unless foo(bar:)
+            baz
+          end
+        RUBY
+      end
+
+      it 'registers an offense and adds parentheses for `while` condition' do
+        expect_offense(<<~RUBY)
+          while foo bar: bar
+                         ^^^ Omit the hash value.
+            baz
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          while foo(bar:)
+            baz
+          end
+        RUBY
+      end
+
+      it 'registers an offense and adds parentheses for `until` condition' do
+        expect_offense(<<~RUBY)
+          until foo bar: bar
+                         ^^^ Omit the hash value.
+            baz
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          until foo(bar:)
+            baz
+          end
+        RUBY
+      end
+
+      it 'does not register an offense for modifier form' do
+        expect_no_offenses(<<~RUBY)
+          baz if foo bar: bar
+        RUBY
+      end
+
+      context 'when hash rocket syntax' do
         let(:enforced_style) { 'hash_rockets' }
 
         it 'does not register an offense' do
@@ -1169,7 +1665,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
       end
     end
 
-    context 'Ruby <= 3.0', :ruby30 do
+    context 'Ruby <= 3.0', :ruby30, unsupported_on: :prism do
       it 'does not register an offense when hash key and hash value are the same' do
         expect_no_offenses(<<~RUBY)
           {foo: foo, bar: bar}
@@ -1277,7 +1773,7 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
     end
   end
 
-  context 'configured to disallow mixing of implicit and explicit hash literal value' do
+  context 'configured to disallow mixing of implicit and explicit hash literal value, but prefers shorthand syntax whenever possible' do
     let(:cop_config) do
       {
         'EnforcedStyle' => 'ruby19',
@@ -1338,9 +1834,75 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
           {foo:, bar:}
         RUBY
       end
+
+      it 'registers an offense and adds parentheses for `if` condition' do
+        expect_offense(<<~RUBY)
+          if foo bar: bar
+                      ^^^ Omit the hash value.
+            baz
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          if foo(bar:)
+            baz
+          end
+        RUBY
+      end
+
+      it 'registers an offense and adds parentheses for `unless` condition' do
+        expect_offense(<<~RUBY)
+          unless foo bar: bar
+                          ^^^ Omit the hash value.
+            baz
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          unless foo(bar:)
+            baz
+          end
+        RUBY
+      end
+
+      it 'registers an offense and adds parentheses for `while` condition' do
+        expect_offense(<<~RUBY)
+          while foo bar: bar
+                         ^^^ Omit the hash value.
+            baz
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          while foo(bar:)
+            baz
+          end
+        RUBY
+      end
+
+      it 'registers an offense and adds parentheses for `until` condition' do
+        expect_offense(<<~RUBY)
+          until foo bar: bar
+                         ^^^ Omit the hash value.
+            baz
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          until foo(bar:)
+            baz
+          end
+        RUBY
+      end
+
+      it 'does not register an offense for modifier form' do
+        expect_no_offenses(<<~RUBY)
+          baz if foo bar: bar
+        RUBY
+      end
     end
 
-    context 'Ruby <= 3.0', :ruby30 do
+    context 'Ruby <= 3.0', :ruby30, unsupported_on: :prism do
       it 'does not register an offense when all hash key and hash values are the same' do
         expect_no_offenses(<<~RUBY)
           {foo: foo, bar: bar}
@@ -1348,4 +1910,70 @@ RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
       end
     end
   end
+
+  context 'configured to disallow mixing of implicit and explicit hash literal value' do
+    let(:cop_config) do
+      {
+        'EnforcedStyle' => 'ruby19',
+        'SupportedStyles' => %w[ruby19 hash_rockets],
+        'EnforcedShorthandSyntax' => 'either_consistent'
+      }
+    end
+
+    context 'Ruby >= 3.1', :ruby31 do
+      it 'does not register an offense when all hash values are omitted' do
+        expect_no_offenses(<<~RUBY)
+          {foo:, bar:}
+        RUBY
+      end
+
+      it 'registers an offense when some hash values are omitted but they can all be omitted' do
+        expect_offense(<<~RUBY)
+          {foo:, bar: bar}
+                      ^^^ Do not mix explicit and implicit hash values. Omit the hash value.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          {foo:, bar:}
+        RUBY
+      end
+
+      it 'registers an offense when some hash values are omitted but they cannot all be omitted' do
+        expect_offense(<<~RUBY)
+          {foo:, bar: baz}
+           ^^^ Do not mix explicit and implicit hash values. Include the hash value.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          {foo: foo, bar: baz}
+        RUBY
+      end
+
+      it 'does not register an offense when all hash values are present, but no values can be omitted' do
+        expect_no_offenses(<<~RUBY)
+          {foo: bar, bar: foo}
+        RUBY
+      end
+
+      it 'does not register an offense when all hash values are present, but only some values can be omitted' do
+        expect_no_offenses(<<~RUBY)
+          {foo: baz, bar: bar}
+        RUBY
+      end
+
+      it 'does not register an offense when all hash values are present, but can all be omitted' do
+        expect_no_offenses(<<~RUBY)
+          {foo: foo, bar: bar}
+        RUBY
+      end
+    end
+
+    context 'Ruby <= 3.0', :ruby30, unsupported_on: :prism do
+      it 'does not register an offense when hash key and hash value are the same' do
+        expect_no_offenses(<<~RUBY)
+          {foo: foo, bar: bar}
+        RUBY
+      end
+    end
+  end
 end
