@@ -74,6 +74,35 @@ RSpec.describe RuboCop::Cop::Style::IfInsideElse, :config do
     RUBY
   end
 
+  it 'catches an `if..else` nested inside an `else` with comments in both branches' do
+    expect_offense(<<~RUBY)
+      if a
+        foo
+      else
+        if b
+        ^^ Convert `if` nested inside `else` to `elsif`.
+          # this is very important
+          bar # this too
+        else
+          # this three
+          baz # this four
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if a
+        foo
+      elsif b
+        # this is very important
+          bar # this too
+        else
+          # this three
+          baz # this four
+      end
+    RUBY
+  end
+
   it 'catches an if..elsif..else nested inside an else' do
     expect_offense(<<~RUBY)
       if a
@@ -114,7 +143,8 @@ RSpec.describe RuboCop::Cop::Style::IfInsideElse, :config do
       elsif b
         foo
       else
-        bar if condition
+        # important info
+        bar if condition # blabla
             ^^ Convert `if` nested inside `else` to `elsif`.
       end
     RUBY
@@ -125,7 +155,8 @@ RSpec.describe RuboCop::Cop::Style::IfInsideElse, :config do
       elsif b
         foo
       elsif condition
-        bar
+        # important info
+        bar # blabla
       end
     RUBY
   end
@@ -143,9 +174,11 @@ RSpec.describe RuboCop::Cop::Style::IfInsideElse, :config do
     expect_correction(<<~RUBY)
       if x
         'x'
-      elsif y
+      else
+        if y
         'y'
       end
+      end
     RUBY
   end
 
@@ -183,11 +216,13 @@ RSpec.describe RuboCop::Cop::Style::IfInsideElse, :config do
     expect_correction(<<~RUBY)
       if x
         'x'
-      elsif y
+      else
+        if y
         'y'
         elsif z
         'z'
       end
+      end
     RUBY
   end
 
@@ -229,12 +264,49 @@ RSpec.describe RuboCop::Cop::Style::IfInsideElse, :config do
     expect_correction(<<~RUBY)
       if x
         'x'
-      elsif y
+      else
+        if y
         'y'
         elsif z
         'z'
         else
         'a'
+        end
+      end
+    RUBY
+  end
+
+  it 'handles a deep nested multiline `if...then...elsif...else...end`' do
+    expect_offense(<<~RUBY)
+      if cond
+      else
+        if nested_one
+        ^^ Convert `if` nested inside `else` to `elsif`.
+        else
+          if c
+          ^^ Convert `if` nested inside `else` to `elsif`.
+            if d
+            else
+              if e
+              ^^ Convert `if` nested inside `else` to `elsif`.
+              end
+            end
+          end
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if cond
+      elsif nested_one
+        else
+          if c
+            if d
+            else
+              if e
+              end
+            end
+          end
       end
     RUBY
   end
