@@ -88,7 +88,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for method call without parens' do
+    it 'registers an offense for method call without parens' do
       expect_offense(<<~RUBY)
         top.test a, b
         ^^^^^^^^^^^^^ Use parentheses for method calls with arguments.
@@ -100,7 +100,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
     end
 
     context 'when using safe navigation operator' do
-      it 'register an offense for method call without parens' do
+      it 'registers an offense for method call without parens' do
         expect_offense(<<~RUBY)
           top&.test a, b
           ^^^^^^^^^^^^^^ Use parentheses for method calls with arguments.
@@ -112,7 +112,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       end
     end
 
-    it 'register an offense for non-receiver method call without parens' do
+    it 'registers an offense for non-receiver method call without parens' do
       expect_offense(<<~RUBY)
         def foo
           test a, b
@@ -127,7 +127,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for methods starting with capital without parens' do
+    it 'registers an offense for methods starting with capital without parens' do
       expect_offense(<<~RUBY)
         def foo
           Test a, b
@@ -142,34 +142,27 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for superclass call without parens' do
-      expect_offense(<<~RUBY)
+    it 'does not register an offense for superclass call without parens' do
+      expect_no_offenses(<<~RUBY)
         def foo
           super a
-          ^^^^^^^ Use parentheses for method calls with arguments.
-        end
-      RUBY
-
-      expect_correction(<<~RUBY)
-        def foo
-          super(a)
         end
       RUBY
     end
 
-    it 'register no offense for superclass call without args' do
+    it 'registers no offense for superclass call without args' do
       expect_no_offenses('super')
     end
 
-    it 'register no offense for yield without args' do
+    it 'registers no offense for yield without args' do
       expect_no_offenses('yield')
     end
 
-    it 'register no offense for superclass call with parens' do
+    it 'registers no offense for superclass call with parens' do
       expect_no_offenses('super(a)')
     end
 
-    it 'register an offense for yield without parens' do
+    it 'registers an offense for yield without parens' do
       expect_offense(<<~RUBY)
         def foo
           yield a
@@ -466,9 +459,87 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
           foo arg
         RUBY
       end
+
+      it 'does not register an offense in conditionals' do
+        expect_no_offenses(<<~RUBY)
+          var =
+            unless object.action(value:, other:)
+              condition || other_condition
+            end
+        RUBY
+      end
+
+      it 'registers an offense in case_match multi-line branches' do
+        expect_offense(<<~RUBY)
+          case match
+          in :pattern1
+            foo(value:)
+               ^^^^^^^^ Omit parentheses for method calls with arguments.
+          in :pattern2
+            bar(value:)
+               ^^^^^^^^ Omit parentheses for method calls with arguments.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case match
+          in :pattern1
+            foo value:
+          in :pattern2
+            bar value:
+          end
+        RUBY
+      end
+
+      it 'does not register an offense in case_match single-line branches' do
+        expect_no_offenses(<<~RUBY)
+          case match
+          in :pattern1 then foo(value:)
+          in :pattern2 then bar(value:)
+          end
+        RUBY
+      end
+
+      it 'does not register an offense in case single-line branches' do
+        expect_no_offenses(<<~RUBY)
+          case match
+          when /pattern1/ then foo(value:)
+          when /pattern2/ then bar(value:)
+          end
+        RUBY
+      end
     end
 
-    it 'register an offense for parens in method call without args' do
+    context 'anonymous rest arguments in 3.2', :ruby32 do
+      it 'does not register an offense when method calls to have parens' do
+        expect_no_offenses(<<~RUBY)
+          def foo(*)
+            foo(*)
+            do_something
+          end
+        RUBY
+      end
+    end
+
+    context 'anonymous keyword rest arguments in 3.2', :ruby32 do
+      it 'does not register an offense when method calls to have parens' do
+        expect_no_offenses(<<~RUBY)
+          def foo(**)
+            foo(**)
+          end
+        RUBY
+      end
+
+      it 'does not register an offense when forwarded keyword argument has additional nodes' do
+        expect_no_offenses(<<~RUBY)
+          def foo(**)
+            foo(name: value, **)
+          end
+        RUBY
+      end
+    end
+
+    it 'registers an offense for parens in method call without args' do
       trailing_whitespace = ' '
 
       expect_offense(<<~RUBY)
@@ -481,7 +552,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for multi-line method calls' do
+    it 'registers an offense for multi-line method calls' do
       expect_offense(<<~RUBY)
         test(
             ^ Omit parentheses for method calls with arguments.
@@ -496,22 +567,15 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for superclass call with parens' do
-      expect_offense(<<~RUBY)
+    it 'does not register an offense for superclass call with parens' do
+      expect_no_offenses(<<~RUBY)
         def foo
           super(a)
-               ^^^ Omit parentheses for method calls with arguments.
-        end
-      RUBY
-
-      expect_correction(<<~RUBY)
-        def foo
-          super a
         end
       RUBY
     end
 
-    it 'register an offense for yield call with parens' do
+    it 'registers an offense for yield call with parens' do
       expect_offense(<<~RUBY)
         def foo
           yield(a)
@@ -526,7 +590,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for parens in the last chain' do
+    it 'registers an offense for parens in the last chain' do
       expect_offense(<<~RUBY)
         foo().bar(3).wait(4)
                          ^^^ Omit parentheses for method calls with arguments.
@@ -537,7 +601,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for parens in do-end blocks' do
+    it 'registers an offense for parens in do-end blocks' do
       expect_offense(<<~RUBY)
         foo(:arg) do
            ^^^^^^ Omit parentheses for method calls with arguments.
@@ -552,7 +616,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for hashes in keyword values' do
+    it 'registers an offense for hashes in keyword values' do
       expect_offense(<<~RUBY)
         method_call(hash: {foo: :bar})
                    ^^^^^^^^^^^^^^^^^^^ Omit parentheses for method calls with arguments.
@@ -563,7 +627,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for %r regex literal as arguments' do
+    it 'registers an offense for %r regex literal as arguments' do
       expect_offense(<<~RUBY)
         method_call(%r{foo})
                    ^^^^^^^^^ Omit parentheses for method calls with arguments.
@@ -574,7 +638,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for parens in string interpolation' do
+    it 'registers an offense for parens in string interpolation' do
       expect_offense(<<~'RUBY')
         "#{t('no.parens')}"
             ^^^^^^^^^^^^^ Omit parentheses for method calls with arguments.
@@ -585,7 +649,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense in complex conditionals' do
+    it 'registers an offense in complex conditionals' do
       expect_offense(<<~RUBY)
         def foo
           if cond.present? && verify?(:something)
@@ -614,7 +678,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense in assignments' do
+    it 'registers an offense in assignments' do
       expect_offense(<<~RUBY)
         foo = A::B.new(c)
                       ^^^ Omit parentheses for method calls with arguments.
@@ -641,7 +705,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense for camel-case methods with arguments' do
+    it 'registers an offense for camel-case methods with arguments' do
       expect_offense(<<~RUBY)
         Array(:arg)
              ^^^^^^ Omit parentheses for method calls with arguments.
@@ -652,7 +716,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'register an offense in multi-line inheritance' do
+    it 'registers an offense in multi-line inheritance' do
       expect_offense(<<~RUBY)
         class Point < Struct.new(:x, :y)
                                 ^^^^^^^^ Omit parentheses for method calls with arguments.
@@ -665,6 +729,34 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
+    it 'registers an offense in calls inside braced blocks' do
+      expect_offense(<<~RUBY)
+        client.images(page: page) { |resource| Image.new(resource) }
+                                                        ^^^^^^^^^^ Omit parentheses for method calls with arguments.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        client.images(page: page) { |resource| Image.new resource }
+      RUBY
+    end
+
+    it 'registers an offense in calls inside braced numblocks', :ruby27 do
+      expect_offense(<<~RUBY)
+        client.images(page: page) { Image.new(_1) }
+                                             ^^^^ Omit parentheses for method calls with arguments.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        client.images(page: page) { Image.new _1 }
+      RUBY
+    end
+
+    it 'accepts parenthesized method calls before constant resolution' do
+      expect_no_offenses(<<~RUBY)
+        do_something(arg)::CONST
+      RUBY
+    end
+
     it 'accepts parens in single-line inheritance' do
       expect_no_offenses(<<-RUBY)
         class Point < Struct.new(:x, :y); end
@@ -733,6 +825,38 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       expect_no_offenses('foo(1) { 2 }')
     end
 
+    it 'accepts parens around argument values with blocks' do
+      expect_no_offenses(<<~RUBY)
+        Foo::Bar.find(pending.things.map { |t| t['code'] }.first)
+      RUBY
+    end
+
+    it 'accepts parens around argument values with numblocks', :ruby27 do
+      expect_no_offenses(<<~RUBY)
+        Foo::Bar.find(pending.things.map { _1['code'] })
+      RUBY
+    end
+
+    it 'accepts parens in array literal calls with blocks' do
+      expect_no_offenses(<<~RUBY)
+        [
+          foo.bar.quux(:args) do
+            pass
+          end,
+        ]
+      RUBY
+    end
+
+    it 'accepts parens in array literal calls with numblocks' do
+      expect_no_offenses(<<~RUBY)
+        [
+          foo.bar.quux(:args) do
+            pass _1
+          end,
+        ]
+      RUBY
+    end
+
     it 'accepts parens in calls with logical operators' do
       expect_no_offenses('foo(a) && bar(b)')
       expect_no_offenses('foo(a) || bar(b)')
@@ -743,6 +867,14 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
+    it 'accepts parens in calls with logical operator and numblock' do
+      expect_no_offenses(<<~RUBY)
+        foo(a) || bar(b) do
+          pass _1
+        end
+      RUBY
+    end
+
     it 'accepts parens in calls with args with logical operators' do
       expect_no_offenses('foo(a, b || c)')
       expect_no_offenses('foo a, b || c')
@@ -754,6 +886,12 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       expect_no_offenses('foo(+1)')
       expect_no_offenses('foo(+"")')
       expect_no_offenses('foo(-"")')
+      expect_no_offenses('foo(-1 + 3i)')
+      expect_no_offenses('foo(+1 + 3i)')
+      expect_no_offenses('foo(-3i)')
+      expect_no_offenses('foo(+3i)')
+      expect_no_offenses('foo(-1.3i)')
+      expect_no_offenses('foo(+1.3i)')
     end
 
     it 'accepts parens in args splat' do
@@ -781,6 +919,10 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       expect_no_offenses('yield path, File.basepath(path)')
     end
 
+    it 'accepts parens in super calls with braced blocks' do
+      expect_no_offenses('super(foo(bar)) { yield }')
+    end
+
     it 'accepts parens in super without args' do
       expect_no_offenses('super()')
     end
@@ -789,10 +931,6 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       expect_no_offenses('super foo(bar)')
     end
 
-    it 'accepts parens in super calls with braced blocks' do
-      expect_no_offenses('super(foo(bar)) { yield }')
-    end
-
     it 'accepts parens in camel case method without args' do
       expect_no_offenses('Array()')
     end
@@ -829,6 +967,44 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
+    context 'range literals' do
+      it 'accepts parens when no end node and last argument' do
+        expect_no_offenses(<<~RUBY)
+          foo(2..)
+          foo(1, 2...)
+        RUBY
+      end
+
+      it 'registers an offense no end node and not last argument' do
+        expect_offense(<<~RUBY)
+          foo(2.., 1)
+             ^^^^^^^^ Omit parentheses for method calls with arguments.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo 2.., 1
+        RUBY
+      end
+
+      it 'accepts parens when no begin node and first argument' do
+        expect_no_offenses(<<~RUBY)
+          foo(..2, 1)
+          foo(...2)
+        RUBY
+      end
+
+      it 'registers an offense no begin node and not first argument' do
+        expect_offense(<<~RUBY)
+          foo(1, ..2)
+             ^^^^^^^^ Omit parentheses for method calls with arguments.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo 1, ..2
+        RUBY
+      end
+    end
+
     it 'accepts parens in assignment in conditions' do
       expect_no_offenses(<<-RUBY)
         case response = get("server/list")
@@ -842,6 +1018,14 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
+    it 'accepts parens in `when` clause is used to pass an argument' do
+      expect_no_offenses(<<-RUBY)
+        case condition
+          when do_something(arg)
+        end
+      RUBY
+    end
+
     it 'autocorrects single-line calls' do
       expect_offense(<<~RUBY)
         top.test(1, 2, foo: bar(3))
@@ -864,7 +1048,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
 
       expect_correction(<<~RUBY)
-        foo \\#{trailing_whitespace}
+        foo \\
           bar: 3
 
       RUBY
@@ -899,6 +1083,27 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
+    # Ruby 2.7's one-line `in` pattern node type is `match-pattern`.
+    it 'accepts parens in one-line `in` pattern matching', :ruby27 do
+      expect_no_offenses(<<~RUBY)
+        execute(query) in {elapsed:, sql_count:}
+      RUBY
+    end
+
+    # Ruby 3.0's one-line `in` pattern node type is `match-pattern-p`.
+    it 'accepts parens in one-line `in` pattern matching', :ruby30 do
+      expect_no_offenses(<<~RUBY)
+        execute(query) in {elapsed:, sql_count:}
+      RUBY
+    end
+
+    # Ruby 3.0's one-line `=>` pattern node type is `match-pattern`.
+    it 'accepts parens in one-line `=>` pattern matching', :ruby30 do
+      expect_no_offenses(<<~RUBY)
+        execute(query) => {elapsed:, sql_count:}
+      RUBY
+    end
+
     context 'allowing parenthesis in chaining' do
       let(:cop_config) do
         {
@@ -907,7 +1112,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
         }
       end
 
-      it 'register offense for single-line chaining without previous parens' do
+      it 'registers an offense for single-line chaining without previous parens' do
         expect_offense(<<~RUBY)
           Rails.convoluted.example.logger.error("something")
                                                ^^^^^^^^^^^^^ Omit parentheses for method calls with arguments.
@@ -918,7 +1123,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
         RUBY
       end
 
-      it 'register offense for multi-line chaining without previous parens' do
+      it 'registers an offense for multi-line chaining without previous parens' do
         expect_offense(<<~RUBY)
           Rails
             .convoluted
@@ -941,9 +1146,21 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
         expect_no_offenses('foo().bar(3).wait 4')
       end
 
+      it 'accepts parens when previously chained sends have numblocks', :ruby27 do
+        expect_no_offenses(<<~RUBY)
+          [a, b].map { _1.call 'something' }.uniq.join(' - ')
+        RUBY
+      end
+
       it 'accepts parens in the last call if any previous calls with parentheses' do
         expect_no_offenses('foo().bar(3).quux.wait(4)')
       end
+
+      it 'accepts parens in empty hashes for arguments calls' do
+        expect_no_offenses(<<~RUBY)
+          params.should eq({})
+        RUBY
+      end
     end
 
     context 'allowing parens in multi-line calls' do
@@ -961,6 +1178,56 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
           )
         RUBY
       end
+
+      it 'accepts parens in argument calls with blocks' do
+        expect_no_offenses(<<~RUBY)
+          foo(
+            bar.new(quux) do
+              pass
+            end
+          )
+        RUBY
+      end
+
+      it 'accepts parens in argument calls with numblocks' do
+        expect_no_offenses(<<~RUBY)
+          foo(
+            bar.new(quux) do
+              pass _1
+            end
+          )
+        RUBY
+      end
+
+      it 'accepts parens in argument csend with blocks' do
+        expect_no_offenses(<<~RUBY)
+          foo(
+            bar&.new(quux) do
+              pass
+            end
+          )
+        RUBY
+      end
+
+      it 'accepts parens in super argument call with blocks' do
+        expect_no_offenses(<<~RUBY)
+          super(
+            bar.new(quux) do
+              pass
+            end
+          )
+        RUBY
+      end
+
+      it 'accepts parens in yield argument call with blocks' do
+        expect_no_offenses(<<~RUBY)
+          yield(
+            bar.new(quux) do
+              pass
+            end
+          )
+        RUBY
+      end
     end
 
     context 'allowing parens in camel-case methods' do
@@ -1042,6 +1309,29 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       end
     end
 
+    context 'for macros called within a block' do
+      let(:cop_config) { { 'IgnoreMacros' => 'true', 'IncludedMacros' => ['assert_equal'] } }
+
+      it 'finds offense' do
+        expect_offense(<<~RUBY)
+          class Foo
+            test "description" do
+              assert_equal 1, 1
+              ^^^^^^^^^^^^^^^^^ Use parentheses for method calls with arguments.
+            end
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          class Foo
+            test "description" do
+              assert_equal(1, 1)
+            end
+          end
+        RUBY
+      end
+    end
+
     context 'for a macro in both IncludedMacros and AllowedMethods' do
       let(:cop_config) do
         {
@@ -1060,4 +1350,79 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       end
     end
   end
+
+  context 'when inspecting macro methods with IncludedMacroPatterns' do
+    let(:cop_config) do
+      { 'IgnoreMacros' => 'true', 'IncludedMacroPatterns' => ['^assert', '^refute'] }
+    end
+
+    context 'in a class body' do
+      it 'finds offense for methods matching patterns' do
+        expect_offense(<<~RUBY)
+          class Foo
+            assert_equal 'expected', actual
+            ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use parentheses for method calls with arguments.
+            refute_nil value
+            ^^^^^^^^^^^^^^^^ Use parentheses for method calls with arguments.
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          class Foo
+            assert_equal('expected', actual)
+            refute_nil(value)
+          end
+        RUBY
+      end
+    end
+
+    context 'for macros called within a block' do
+      it 'finds offense' do
+        expect_offense(<<~RUBY)
+          class Foo
+            test "description" do
+              assert_equal 1, 1
+              ^^^^^^^^^^^^^^^^^ Use parentheses for method calls with arguments.
+            end
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          class Foo
+            test "description" do
+              assert_equal(1, 1)
+            end
+          end
+        RUBY
+      end
+    end
+
+    context 'for a macro not matching included patterns' do
+      it 'allows' do
+        expect_no_offenses(<<~RUBY)
+          class Foo
+            has_many :posts
+          end
+        RUBY
+      end
+    end
+
+    context 'for a macro in both IncludedMacroPatterns and AllowedMethods' do
+      let(:cop_config) do
+        {
+          'IgnoreMacros' => 'true',
+          'IncludedMacroPatterns' => ['^assert'],
+          'AllowedMethods' => ['assert_equal']
+        }
+      end
+
+      it 'allows' do
+        expect_no_offenses(<<~RUBY)
+          class Foo
+            assert_equal 'test', result
+          end
+        RUBY
+      end
+    end
+  end
 end
