@@ -83,10 +83,10 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
   shared_examples 'string literal' do
     # TODO : It is not yet decided when frozen string will be the default.
     # It has been abandoned in the Ruby 3.0 period, but may default in
-    # the long run. So these tests are left with a provisional value of 4.0.
-    if RuboCop::TargetRuby.supported_versions.include?(4.0)
-      context 'when the target ruby version >= 4.0' do
-        let(:ruby_version) { 4.0 }
+    # the long run. So these tests are left with a provisional value of 5.0.
+    if RuboCop::TargetRuby.supported_versions.include?(5.0)
+      context 'when the target ruby version >= 5.0' do
+        let(:ruby_version) { 5.0 }
 
         context 'when the frozen string literal comment is missing' do
           it_behaves_like 'immutable objects', '"#{a}"'
@@ -115,7 +115,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
         let(:prefix) { '# frozen_string_literal: true' }
 
         it_behaves_like 'mutable objects', '"#{a}"'
-        it_behaves_like 'immutable objects', <<~'RUBY'
+        it_behaves_like 'immutable objects', <<~RUBY
           <<~HERE
             foo
             bar
@@ -160,7 +160,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
       end
     end
 
-    context 'Ruby 2.7 or lower', :ruby27 do
+    context 'Ruby 2.7 or lower', :ruby27, unsupported_on: :prism do
       context 'when the frozen string literal comment is missing' do
         it_behaves_like 'mutable objects', '"#{a}"'
       end
@@ -169,7 +169,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
         let(:prefix) { '# frozen_string_literal: true' }
 
         it_behaves_like 'immutable objects', '"#{a}"'
-        it_behaves_like 'immutable objects', <<~'RUBY'
+        it_behaves_like 'immutable objects', <<~RUBY
           <<~HERE
             foo
             bar
@@ -348,7 +348,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
       end
     end
 
-    context 'Ruby 2.7 or lower', :ruby27 do
+    context 'Ruby 2.7 or lower', :ruby27, unsupported_on: :prism do
       context 'when assigning a regexp' do
         it 'registers an offense' do
           expect_offense(<<~RUBY)
@@ -536,7 +536,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
         RUBY
       end
 
-      it 'accepts operating on a constant and an interger' do
+      it 'accepts operating on a constant and an integer' do
         expect_no_offenses(<<~RUBY)
           CONST = FOO + 2
         RUBY
