@@ -37,7 +37,7 @@ RSpec.describe RuboCop::Cop::Style::NestedFileDirname, :config do
     end
   end
 
-  context 'Ruby <= 3.0', :ruby30 do
+  context 'Ruby <= 3.0', :ruby30, unsupported_on: :prism do
     it 'does not register an offense when using `File.dirname(path)` nested two times' do
       expect_no_offenses(<<~RUBY)
         File.dirname(File.dirname(path))
