@@ -10,14 +10,6 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
       }
     }
   end
-  let(:if_offense_message) do
-    'Favor the ternary operator (`?:`) or multi-line constructs over single-line ' \
-      '`if/then/else/end` constructs.'
-  end
-  let(:unless_offense_message) do
-    'Favor the ternary operator (`?:`) or multi-line constructs over single-line ' \
-      '`unless/then/else/end` constructs.'
-  end
 
   context 'when AlwaysCorrectToMultiline is false' do
     let(:always_correct_to_multiline) { false }
@@ -25,7 +17,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
     it 'registers and corrects an offense with ternary operator for if/then/else/end' do
       expect_offense(<<~RUBY)
         if cond then run else dont end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -41,7 +33,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        '`then` without body' do
       expect_offense(<<~RUBY)
         if cond then else dont end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -53,10 +45,16 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
       expect_no_offenses('if cond then run end')
     end
 
+    it 'does not register an offense when using if/then/else/end with multiple expressions in the `then` body' do
+      expect_no_offenses(<<~RUBY)
+        if cond then x; y else z end
+      RUBY
+    end
+
     it 'registers and corrects an offense with ternary operator for unless/then/else/end' do
       expect_offense(<<~RUBY)
         unless cond then run else dont end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{unless_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `unless/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -64,6 +62,33 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
       RUBY
     end
 
+    it 'registers and corrects an offense with ternary operator for nested if/then/else/end' do
+      expect_offense(<<~RUBY)
+        if cond then foo else if cond2; bar else baz end; end
+                              ^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        cond ? foo : (if cond2; bar else baz end)
+      RUBY
+    end
+
+    it 'registers and corrects an offense when the else branch of a ternary operator has multiple expressions' do
+      expect_offense(<<~RUBY)
+        if cond; foo; else bar; baz; end
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        if cond
+          foo
+        else
+          bar; baz
+        end
+      RUBY
+    end
+
     it 'does not register an offense for unless/then/else/end with empty else' do
       expect_no_offenses('unless cond then run else end')
     end
@@ -77,7 +102,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
          'when if/then/else/end is preceded by an operator' do
         expect_offense(<<~RUBY, operator: operator)
           a %{operator} if cond then run else dont end
-            _{operator} ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+            _{operator} ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
         RUBY
 
         expect_correction(<<~RUBY)
@@ -91,7 +116,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
          "for if/then/else/end with `#{expr}` constructs inside inner branches" do
         expect_offense(<<~RUBY, expr: expr)
           if %{expr} then %{expr} else %{expr} end
-          ^^^^{expr}^^^^^^^{expr}^^^^^^^{expr}^^^^ #{if_offense_message}
+          ^^^^{expr}^^^^^^^{expr}^^^^^^^{expr}^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
         RUBY
 
         expect_correction(<<~RUBY)
@@ -103,6 +128,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'puts 1'
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'defined? :A'
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'yield a'
+
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'super b'
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'not a'
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'a and b'
@@ -114,7 +140,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if/then/else/end that contains method calls with unparenthesized arguments' do
       expect_offense(<<~RUBY)
         if check 1 then run 2 else dont_run 3 end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -126,7 +152,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if/then/else/end that contains method calls with parenthesized arguments' do
       expect_offense(<<~RUBY)
         if a(0) then puts(1) else yield(2) end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -138,7 +164,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if/then/else/end that contains unparenthesized operator method calls' do
       expect_offense(<<~RUBY)
         if 0 + 0 then 1 + 1 else 2 + 2 end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -146,12 +172,12 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
       RUBY
     end
 
-    shared_examples 'if/then/else/end with keyword' do |keyword|
+    shared_examples 'if/then/else/end with keyword' do |keyword, options|
       it 'registers and corrects an offense with ternary operator when one of the branches of ' \
-         "if/then/else/end contains `#{keyword}` keyword" do
+         "if/then/else/end contains `#{keyword}` keyword", *options do
         expect_offense(<<~RUBY, keyword: keyword)
           if true then %{keyword} else 7 end
-          ^^^^^^^^^^^^^^{keyword}^^^^^^^^^^^ #{if_offense_message}
+          ^^^^^^^^^^^^^^{keyword}^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
         RUBY
 
         expect_correction(<<~RUBY)
@@ -160,8 +186,12 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
       end
     end
 
-    it_behaves_like 'if/then/else/end with keyword', 'retry'
-    it_behaves_like 'if/then/else/end with keyword', 'break'
+    context 'Ruby <= 3.2', :ruby32, unsupported_on: :prism do
+      it_behaves_like 'if/then/else/end with keyword', 'retry'
+    end
+
+    it_behaves_like 'if/then/else/end with keyword', 'break', [:ruby32, { unsupported_on: :prism }]
+
     it_behaves_like 'if/then/else/end with keyword', 'self'
     it_behaves_like 'if/then/else/end with keyword', 'raise'
 
@@ -169,7 +199,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if/then/else/end contains `next` keyword' do
       expect_offense(<<~RUBY)
         map { |line| if line.match(/^\s*#/) || line.strip.empty? then next else line end }
-                     ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+                     ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor the ternary operator (`?:`) over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -180,7 +210,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
     it 'registers and corrects an offense with multi-line construct for if-then-elsif-then-end' do
       expect_offense(<<~RUBY)
         if cond1 then run elsif cond2 then maybe end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -196,7 +226,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if-then-elsif-then-else-end' do
       expect_offense(<<~RUBY)
         if cond1 then run elsif cond2 then maybe else dont end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -214,7 +244,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if-then-elsif-then-elsif-then-else-end' do
       expect_offense(<<~RUBY)
         if cond1 then run elsif cond2 then maybe elsif cond3 then perhaps else dont end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -237,7 +267,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
     it 'registers and corrects an offense with multi-line construct for if/then/else/end' do
       expect_offense(<<~RUBY)
         if cond then run else dont end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -257,7 +287,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        '`then` without body' do
       expect_offense(<<~RUBY)
         if cond then else dont end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -276,7 +306,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
     it 'registers and corrects an offense with multi-line construct for unless/then/else/end' do
       expect_offense(<<~RUBY)
         unless cond then run else dont end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{unless_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `unless` over single-line `unless/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -288,6 +318,22 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
       RUBY
     end
 
+    it 'registers and corrects an offense with ternary operator for nested if/then/else/end' do
+      expect_offense(<<~RUBY)
+        if cond then foo else if cond2; bar else baz end; end
+                              ^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        if cond
+          foo
+        else
+          if cond2; bar else baz end
+        end
+      RUBY
+    end
+
     it 'does not register an offense for unless/then/else/end with empty else' do
       expect_no_offenses('unless cond then run else end')
     end
@@ -301,7 +347,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
          'when if/then/else/end is preceded by an operator' do
         expect_offense(<<~RUBY, operator: operator)
           a %{operator} if cond then run else dont end
-            _{operator} ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+            _{operator} ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
         RUBY
 
         expect_correction(<<~RUBY)
@@ -319,7 +365,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
          "parentheses for if/then/else/end with `#{expr}` constructs inside inner branches" do
         expect_offense(<<~RUBY, expr: expr)
           if %{expr} then %{expr} else %{expr} end
-          ^^^^{expr}^^^^^^^{expr}^^^^^^^{expr}^^^^ #{if_offense_message}
+          ^^^^{expr}^^^^^^^{expr}^^^^^^^{expr}^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
         RUBY
 
         expect_correction(<<~RUBY)
@@ -334,7 +380,9 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
 
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'puts 1'
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'defined? :A'
+
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'yield a'
+
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'super b'
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'not a'
     it_behaves_like 'if/then/else/end with constructs changing precedence', 'a and b'
@@ -346,7 +394,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'for if/then/else/end that contains method calls with unparenthesized arguments' do
       expect_offense(<<~RUBY)
         if check 1 then run 2 else dont_run 3 end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -362,7 +410,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if/then/else/end that contains method calls with parenthesized arguments' do
       expect_offense(<<~RUBY)
         if a(0) then puts(1) else yield(2) end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -378,7 +426,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if/then/else/end that contains unparenthesized operator method calls' do
       expect_offense(<<~RUBY)
         if 0 + 0 then 1 + 1 else 2 + 2 end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -390,12 +438,12 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
       RUBY
     end
 
-    shared_examples 'if/then/else/end with keyword' do |keyword|
+    shared_examples 'if/then/else/end with keyword' do |keyword, options|
       it 'registers and corrects an offense with multi-line construct when one of the branches ' \
-         "of if/then/else/end contains `#{keyword}` keyword" do
+         "of if/then/else/end contains `#{keyword}` keyword", *options do
         expect_offense(<<~RUBY, keyword: keyword)
           if true then %{keyword} else 7 end
-          ^^^^^^^^^^^^^^{keyword}^^^^^^^^^^^ #{if_offense_message}
+          ^^^^^^^^^^^^^^{keyword}^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
         RUBY
 
         expect_correction(<<~RUBY)
@@ -408,8 +456,12 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
       end
     end
 
-    it_behaves_like 'if/then/else/end with keyword', 'retry'
-    it_behaves_like 'if/then/else/end with keyword', 'break'
+    context 'Ruby <= 3.2', :ruby32, unsupported_on: :prism do
+      it_behaves_like 'if/then/else/end with keyword', 'retry'
+    end
+
+    it_behaves_like 'if/then/else/end with keyword', 'break', [:ruby32, { unsupported_on: :prism }]
+
     it_behaves_like 'if/then/else/end with keyword', 'self'
     it_behaves_like 'if/then/else/end with keyword', 'raise'
 
@@ -417,7 +469,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if/then/else/end contains `next` keyword' do
       expect_offense(<<~RUBY)
         map { |line| if line.match(/^\s*#/) || line.strip.empty? then next else line end }
-                     ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+                     ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -433,7 +485,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if-then-elsif-then-else-end' do
       expect_offense(<<~RUBY)
         if cond1 then run elsif cond2 then maybe else dont end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -451,7 +503,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
        'if-then-elsif-then-elsif-then-else-end' do
       expect_offense(<<~RUBY)
         if cond1 then run elsif cond2 then maybe elsif cond3 then perhaps else dont end
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -473,7 +525,7 @@ RSpec.describe RuboCop::Cop::Style::OneLineConditional, :config do
       it 'registers and corrects an offense with multi-line construct for if/then/else/end' do
         expect_offense(<<~RUBY)
           if cond then run else dont end
-          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ #{if_offense_message}
+          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Favor multi-line `if` over single-line `if/then/else/end` constructs.
         RUBY
 
         expect_correction(<<~RUBY)
