@@ -43,4 +43,17 @@ RSpec.describe RuboCop::Cop::Style::Proc, :config do
       RUBY
     end
   end
+
+  context 'Ruby 3.4', :ruby34 do
+    it 'registers an offense for a Proc.new call' do
+      expect_offense(<<~RUBY)
+        f = Proc.new { puts it }
+            ^^^^^^^^ Use `proc` instead of `Proc.new`.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        f = proc { puts it }
+      RUBY
+    end
+  end
 end
