@@ -57,6 +57,36 @@ RSpec.describe RuboCop::Cop::Style::RedundantConditional, :config do
     RUBY
   end
 
+  it 'registers an offense for unless/else with boolean results' do
+    expect_offense(<<~RUBY)
+      unless x == y
+      ^^^^^^^^^^^^^ This conditional expression can just be replaced by `!(x == y)`.
+        true
+      else
+        false
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      !(x == y)
+    RUBY
+  end
+
+  it 'registers an offense for unless/else with negated boolean results' do
+    expect_offense(<<~RUBY)
+      unless x == y
+      ^^^^^^^^^^^^^ This conditional expression can just be replaced by `x == y`.
+        false
+      else
+        true
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      x == y
+    RUBY
+  end
+
   it 'registers an offense for if/elsif/else with boolean results' do
     expect_offense(<<~RUBY)
       if cond
