@@ -105,35 +105,86 @@ RSpec.describe RuboCop::Cop::Style::RedundantRegexpEscape, :config do
                    ^^ Redundant escape inside regexp literal
         RUBY
 
-        expect_correction(<<~'RUBY')
+        expect_correction(<<~RUBY)
           foo = /[:.]/
         RUBY
       end
     end
 
     context "with an escaped '-' character being the last character inside a character class" do
-      it 'registers an offense and corrects' do
-        expect_offense(<<~'RUBY')
-          foo = /[0-9\-]/
-                     ^^ Redundant escape inside regexp literal
-        RUBY
+      context 'with a regexp %r{...} literal' do
+        it 'registers an offense and corrects' do
+          expect_offense(<<~'RUBY')
+            foo = %r{[0-9\-]}
+                         ^^ Redundant escape inside regexp literal
+          RUBY
 
-        expect_correction(<<~RUBY)
-          foo = /[0-9-]/
-        RUBY
+          expect_correction(<<~RUBY)
+            foo = %r{[0-9-]}
+          RUBY
+        end
+      end
+
+      context 'with a regexp /.../ literal' do
+        it 'registers an offense and corrects' do
+          expect_offense(<<~'RUBY')
+            foo = /[0-9\-]/
+                       ^^ Redundant escape inside regexp literal
+          RUBY
+
+          expect_correction(<<~RUBY)
+            foo = /[0-9-]/
+          RUBY
+        end
+      end
+
+      context "with an escaped opening square bracket before an escaped '-' character" do
+        it 'registers an offense and corrects' do
+          expect_offense(<<~'RUBY')
+            foo = /[\[\-]/
+                      ^^ Redundant escape inside regexp literal
+          RUBY
+
+          expect_correction(<<~'RUBY')
+            foo = /[\[-]/
+          RUBY
+        end
       end
     end
 
     context "with an escaped '-' character being the first character inside a character class" do
-      it 'registers an offense and corrects' do
-        expect_offense(<<~'RUBY')
-          foo = /[\-0-9]/
-                  ^^ Redundant escape inside regexp literal
-        RUBY
+      context 'with a regexp %r{...} literal' do
+        it 'registers an offense and corrects' do
+          expect_offense(<<~'RUBY')
+            foo = %r{[\-0-9]}
+                      ^^ Redundant escape inside regexp literal
+          RUBY
 
-        expect_correction(<<~RUBY)
-          foo = /[-0-9]/
-        RUBY
+          expect_correction(<<~RUBY)
+            foo = %r{[-0-9]}
+          RUBY
+        end
+      end
+
+      context 'with a regexp /.../ literal' do
+        it 'registers an offense and corrects' do
+          expect_offense(<<~'RUBY')
+            foo = /[\-0-9]/
+                    ^^ Redundant escape inside regexp literal
+          RUBY
+
+          expect_correction(<<~RUBY)
+            foo = /[-0-9]/
+          RUBY
+        end
+      end
+    end
+
+    context "with an escaped '-' character being neither first nor last inside a character class" do
+      it 'does not register an offense' do
+        expect_no_offenses('foo = %r{[\w\-\#]}')
+        expect_no_offenses('foo = /[\w\-\#]/')
+        expect_no_offenses('foo = /[\[\-\]]/')
       end
     end
 
@@ -162,7 +213,7 @@ RSpec.describe RuboCop::Cop::Style::RedundantRegexpEscape, :config do
                                ^^ Redundant escape inside regexp literal
         RUBY
 
-        expect_correction(<<~'RUBY')
+        expect_correction(<<~RUBY)
           foo = /[[:punct:]&&[^.]]/
         RUBY
       end
@@ -181,7 +232,7 @@ RSpec.describe RuboCop::Cop::Style::RedundantRegexpEscape, :config do
                            ^^ Redundant escape inside regexp literal
         RUBY
 
-        expect_correction(<<~'RUBY')
+        expect_correction(<<~RUBY)
           foo = /[[:alnum:].]/
         RUBY
       end
@@ -206,6 +257,30 @@ RSpec.describe RuboCop::Cop::Style::RedundantRegexpEscape, :config do
       end
     end
 
+    context 'with an escaped instance variable after `#`' do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~'RUBY')
+          foo = /[#\@not_ivar]/
+        RUBY
+      end
+    end
+
+    context 'with an escaped class variable after `#`' do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~'RUBY')
+          foo = /[#\@@not_cvar]/
+        RUBY
+      end
+    end
+
+    context 'with an escaped global variable after `#`' do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~'RUBY')
+          foo = /[#\$not_gvar]/
+        RUBY
+      end
+    end
+
     context 'with an escape inside an interpolated string' do
       it 'does not register an offense' do
         expect_no_offenses('foo = /#{"\""}/')
@@ -290,7 +365,7 @@ RSpec.describe RuboCop::Cop::Style::RedundantRegexpEscape, :config do
                ^^ Redundant escape inside regexp literal
         RUBY
 
-        expect_correction(<<~'RUBY')
+        expect_correction(<<~RUBY)
           r = /-/i
         RUBY
       end
@@ -560,10 +635,23 @@ RSpec.describe RuboCop::Cop::Style::RedundantRegexpEscape, :config do
         p x
       RUBY
 
-      expect_correction(<<~'RUBY')
+      expect_correction(<<~RUBY)
         x = s[/[一二三四.]+/]
         p x
       RUBY
     end
   end
+
+  context 'with escaping invalid byte sequence in UTF-8' do
+    it 'registers an offense and corrects' do
+      expect_offense(<<~'RUBY')
+        r = /[\§]/
+              ^^ Redundant escape inside regexp literal
+      RUBY
+
+      expect_correction(<<~RUBY)
+        r = /[§]/
+      RUBY
+    end
+  end
 end
