@@ -89,6 +89,197 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
     RUBY
   end
 
+  it 'registers an offense and corrects when using nested `if` within `if foo = bar` as the LHS of an `and`' do
+    # `and` is used in the source code for precedence without parentheses
+    expect_offense(<<~RUBY)
+      if foo = bar and baz
+        if quux
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo = bar and baz && quux
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested `if` within `if foo = bar` as the RHS of an `and`' do
+    expect_offense(<<~RUBY)
+      if baz && foo = bar
+        if quux
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if baz && (foo = bar) && quux
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested `if` within `if foo = bar` in a multiline `and`' do
+    expect_offense(<<~RUBY)
+      if baz &&
+         foo = bar
+        if quux
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if baz &&
+         (foo = bar) && quux
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested `if` within `if foo = bar` in a nested `and`' do
+    expect_offense(<<~RUBY)
+      if baz && foo = bar and fred = garply
+        if corge
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if baz && foo = bar and (fred = garply) && corge
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested `if` within `if (foo = bar)` in an `and`' do
+    expect_offense(<<~RUBY)
+      if baz && (foo = bar)
+        if quux
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if baz && (foo = bar) && quux
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects assignment within nested `if`' do
+    expect_offense(<<~RUBY)
+      if foo
+        if bar = baz
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo && (bar = baz)
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects assignment within `and` within nested `if`' do
+    expect_offense(<<~RUBY)
+      if foo
+        if quux && bar = baz
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo && quux && (bar = baz)
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested `if` within `if foo = bar` as the LHS of an `or`' do
+    # `or` is used in the source code for precedence without parentheses
+    expect_offense(<<~RUBY)
+      if foo = bar or baz
+        if quux
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if (foo = bar or baz) && quux
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested `if` within `if foo = bar` as the RHS of an `or`' do
+    expect_offense(<<~RUBY)
+      if baz || foo = bar
+        if quux
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if (baz || foo = bar) && quux
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested `if` within `unless foo & bar`' do
+    expect_offense(<<~RUBY)
+      unless foo & bar
+        if baz
+        ^^ Consider merging nested conditions into outer `unless` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if !(foo & bar) && baz
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested `if` within `if foo & bar`' do
+    expect_offense(<<~RUBY)
+      if foo & bar
+        if baz
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if (foo & bar) && baz
+          do_something
+        end
+    RUBY
+  end
+
   it 'registers an offense and corrects when using nested `unless` within `unless`' do
     expect_offense(<<~RUBY)
       unless foo
@@ -158,10 +349,11 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
       end
     RUBY
 
+    # INFO: parentheses are removed by Style/RedundantParentheses
     expect_correction(<<~RUBY)
       class A
         def foo
-          if h[:a] && !h.has_key?(:b)
+          if (h[:a]) && !h.has_key?(:b)
             h[:b] = true
           end
         end
@@ -280,6 +472,22 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
     RUBY
   end
 
+  it 'registers an offense and corrects when using `unless` and `===` without parens in the outer condition ' \
+     'and nested modifier condition' do
+    expect_offense(<<~RUBY)
+      if result
+        do_something unless foo === bar
+                     ^^^^^^ Consider merging nested conditions into outer `if` conditions.
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if result && !(foo === bar)
+        do_something
+      end
+    RUBY
+  end
+
   it 'registers an offense and corrects when using `unless` and `&&` without parens in the outer condition ' \
      'and nested modifier condition' do
     expect_offense(<<~RUBY)
@@ -290,7 +498,7 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
     RUBY
 
     expect_correction(<<~RUBY)
-      if !foo && !bar && !baz && !qux
+      if !(foo && bar && baz) && !qux
         do_something
       end
     RUBY
@@ -376,7 +584,7 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
     RUBY
 
     expect_correction(<<~RUBY)
-      if foo.is_a?(Foo) && (bar && baz) && quux
+      if foo.is_a?(Foo) && bar && baz && quux
           do_something
         end
     RUBY
@@ -422,6 +630,68 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
     RUBY
   end
 
+  it 'registers an offense and corrects when using nested `if` and `not` in the inner condition' do
+    expect_offense(<<~RUBY)
+      if foo
+        if not bar
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo && (not bar)
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested `if` and `not` in the outer condition' do
+    expect_offense(<<~RUBY)
+      if not foo
+        if bar
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if (not foo) && bar
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested `if` and `!` in the inner condition' do
+    expect_offense(<<~RUBY)
+      if foo
+        if !bar
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo && !bar
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense and corrects when using nested single line `if`' do
+    expect_offense(<<~RUBY)
+      if foo; if bar; end; end
+              ^^ Consider merging nested conditions into outer `if` conditions.
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo && bar; end;#{' '}
+    RUBY
+  end
+
   context 'when disabling `Style/IfUnlessModifier`' do
     let(:config) { RuboCop::Config.new('Style/IfUnlessModifier' => { 'Enabled' => false }) }
 
@@ -483,6 +753,23 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
     RUBY
   end
 
+  it 'registers an offense and corrects when comment is in an empty nested `if` body' do
+    expect_offense(<<~RUBY)
+      if foo
+        if bar
+        ^^ Consider merging nested conditions into outer `if` conditions.
+          # Comments.
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo && bar
+          # Comments.
+        end
+    RUBY
+  end
+
   it 'registers an offense and corrects when `if` foo do_something end `if` bar' do
     expect_offense(<<~RUBY)
       if foo
@@ -537,7 +824,7 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
     RUBY
 
     expect_correction(<<~RUBY)
-      if (bar && baz) && foo
+      if bar && baz && foo
         do_something
       end
     RUBY
@@ -603,6 +890,55 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
     RUBY
   end
 
+  it 'registers an offense when inner condition is an & operator' do
+    expect_offense(<<~RUBY)
+      if foo
+        unless bar & baz
+        ^^^^^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo && !(bar & baz)
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense when inner condition is an || operator' do
+    expect_offense(<<~RUBY)
+      if foo
+        unless bar || baz
+        ^^^^^^ Consider merging nested conditions into outer `if` conditions.
+          do_something
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo && !(bar || baz)
+          do_something
+        end
+    RUBY
+  end
+
+  it 'registers an offense when inner condition is an operator as a guard clause' do
+    expect_offense(<<~RUBY)
+      if foo
+        do_something unless bar & baz
+                     ^^^^^^ Consider merging nested conditions into outer `if` conditions.
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo && !(bar & baz)
+        do_something
+      end
+    RUBY
+  end
+
   it 'does not register an offense when using nested ternary within conditional' do
     expect_no_offenses(<<~RUBY)
       if foo
@@ -679,11 +1015,28 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
         RUBY
 
         expect_correction(<<~RUBY)
-          if foo && (ok? bar)
+          if foo && ok?(bar)
             do_something
           end
         RUBY
       end
+
+      context 'with a `csend` node' do
+        it 'registers an offense and corrects' do
+          expect_offense(<<~RUBY)
+            if foo
+              do_something if obj&.ok? bar
+                           ^^ Consider merging nested conditions into outer `if` conditions.
+            end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            if foo && obj&.ok?(bar)
+              do_something
+            end
+          RUBY
+        end
+      end
     end
 
     context 'in modifier style' do
@@ -698,7 +1051,7 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
         RUBY
 
         expect_correction(<<~RUBY)
-          if foo && (ok? bar)
+          if foo && ok?(bar)
               do_something
             end
         RUBY
@@ -716,7 +1069,7 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
           RUBY
 
           expect_correction(<<~RUBY)
-            if foo && (bar&.baz quux)
+            if foo && bar&.baz(quux)
                 do_something
               end
           RUBY
@@ -743,6 +1096,27 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
           RUBY
         end
       end
+
+      context 'with a numblock' do
+        it 'registers an offense and corrects' do
+          expect_offense(<<~RUBY)
+            if foo
+              if ok? bar do
+              ^^ Consider merging nested conditions into outer `if` conditions.
+                  _1
+                end
+              end
+            end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            if foo && (ok? bar do
+                  _1
+                end)
+              end
+          RUBY
+        end
+      end
     end
   end
 
@@ -795,4 +1169,24 @@ RSpec.describe RuboCop::Cop::Style::SoleNestedConditional, :config do
       RUBY
     end
   end
+
+  it 'registers an offense and corrects when using nested `unless` within `if` followed by another `if`' do
+    expect_offense(<<~RUBY)
+      if foo
+        unless bar
+        ^^^^^^ Consider merging nested conditions into outer `if` conditions.
+          if baz
+          ^^ Consider merging nested conditions into outer `unless` conditions.
+            do_something
+          end
+        end
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if foo && !bar && baz
+            do_something
+          end
+    RUBY
+  end
 end
