@@ -79,17 +79,6 @@ RSpec.describe RuboCop::Cop::Style::SymbolArray, :config do
       RUBY
     end
 
-    it "doesn't break when a symbol contains )" do
-      expect_offense(<<~RUBY)
-        [:one, :")", :three, :"(", :"]", :"["]
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use `%i` or `%I` for an array of symbols.
-      RUBY
-
-      expect_correction(<<~'RUBY')
-        %i(one \) three \( ] [)
-      RUBY
-    end
-
     it 'does not register an offense for array with non-syms' do
       expect_no_offenses('[:one, :two, "three"]')
     end
@@ -98,10 +87,26 @@ RSpec.describe RuboCop::Cop::Style::SymbolArray, :config do
       expect_no_offenses('%i(one two three)')
     end
 
+    it 'does not register an offense for array containing delimiters without spaces' do
+      expect_no_offenses('%i[zero (one) [two] three[4] five[six] seven(8) nine(ten) ([]) [] ()]')
+    end
+
+    it 'does not register an offense for a percent array with interpolations' do
+      expect_no_offenses('%I[one_#{two} three #{four}_five six#{seven}eight [nine_#{ten}]]')
+    end
+
     it 'does not register an offense if symbol contains whitespace' do
       expect_no_offenses('[:one, :two, :"space here"]')
     end
 
+    it 'does not register an offense if a symbol contains unclosed delimiters' do
+      expect_no_offenses('[:one, :")", :two, :"(", :"]"]')
+    end
+
+    it 'does not register an offense if a symbol contains a delimiter with spaces' do
+      expect_no_offenses('[:one, :two, :"[ ]", :"( )"]')
+    end
+
     it 'registers an offense in a non-ambiguous block context' do
       expect_offense(<<~RUBY)
         foo([:bar, :baz]) { qux }
@@ -133,6 +138,84 @@ RSpec.describe RuboCop::Cop::Style::SymbolArray, :config do
       expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
     end
 
+    it 'registers an offense for a %i array containing escaped [ ]' do
+      expect_offense(<<~'RUBY')
+        %i[one \[ \] two]
+        ^^^^^^^^^^^^^^^^^ Use `[:one, :'[', :']', :two]` for an array of symbols.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        [:one, :'[', :']', :two]
+      RUBY
+    end
+
+    it 'does not register an offense for a %i array containing unescaped [ ]' do
+      expect_no_offenses(<<~RUBY)
+        %i(one [ ] two)
+      RUBY
+    end
+
+    it 'registers an offense for a %i array containing whitespace between brackets' do
+      expect_offense(<<~'RUBY')
+        %i[one two \[three\ four\ five\]]
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use `[:one, :two, :'[three four five]']` for an array of symbols.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        [:one, :two, :'[three four five]']
+      RUBY
+    end
+
+    it 'registers an offense for a %i array containing brackets between brackets' do
+      expect_offense(<<~'RUBY')
+        %i[one two \[\[\]]
+        ^^^^^^^^^^^^^^^^^^ Use `[:one, :two, :'[[]']` for an array of symbols.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        [:one, :two, :'[[]']
+      RUBY
+    end
+
+    it 'registers an offense for a %i array containing escaped ( )' do
+      expect_offense(<<~'RUBY')
+        %i(one \( \) two)
+        ^^^^^^^^^^^^^^^^^ Use `[:one, :'(', :')', :two]` for an array of symbols.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        [:one, :'(', :')', :two]
+      RUBY
+    end
+
+    it 'does not register an offense for a %i array containing unescaped ( )' do
+      expect_no_offenses(<<~RUBY)
+        %i[one ( ) two]
+      RUBY
+    end
+
+    it 'registers an offense for a %i array containing parentheses between parentheses' do
+      expect_offense(<<~'RUBY')
+        %i(one two \(\(\))
+        ^^^^^^^^^^^^^^^^^^ Use `[:one, :two, :'(()']` for an array of symbols.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        [:one, :two, :'(()']
+      RUBY
+    end
+
+    it 'registers an offense for a %i array containing whitespace between parentheses' do
+      expect_offense(<<~'RUBY')
+        %i(one two \(three\ four\ five\))
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use `[:one, :two, :'(three four five)']` for an array of symbols.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        [:one, :two, :'(three four five)']
+      RUBY
+    end
+
     context 'when PreferredDelimiters is specified' do
       let(:other_cops) do
         {
@@ -144,19 +227,8 @@ RSpec.describe RuboCop::Cop::Style::SymbolArray, :config do
         }
       end
 
-      it 'autocorrects an array with delimiters' do
-        expect_offense(<<~RUBY)
-          [:one, :")", :three, :"(", :"]", :"["]
-          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use `%i` or `%I` for an array of symbols.
-        RUBY
-
-        expect_correction(<<~'RUBY')
-          %i[one ) three ( \] \[]
-        RUBY
-      end
-
       it 'autocorrects an array in multiple lines' do
-        expect_offense(<<-RUBY)
+        expect_offense(<<~RUBY)
           [
           ^ Use `%i` or `%I` for an array of symbols.
           :foo,
@@ -165,7 +237,7 @@ RSpec.describe RuboCop::Cop::Style::SymbolArray, :config do
           ]
         RUBY
 
-        expect_correction(<<-RUBY)
+        expect_correction(<<~RUBY)
           %i[
           foo
           bar
@@ -175,19 +247,30 @@ RSpec.describe RuboCop::Cop::Style::SymbolArray, :config do
       end
 
       it 'autocorrects an array using partial newlines' do
-        expect_offense(<<-RUBY)
+        expect_offense(<<~RUBY)
           [:foo, :bar, :baz,
           ^^^^^^^^^^^^^^^^^^ Use `%i` or `%I` for an array of symbols.
           :boz, :buz,
           :biz]
         RUBY
 
-        expect_correction(<<-RUBY)
+        expect_correction(<<~RUBY)
           %i[foo bar baz
           boz buz
           biz]
         RUBY
       end
+
+      it 'autocorrects balanced pairs of delimiters without excessive escaping' do
+        expect_offense(<<~RUBY)
+          [:a, :'b[]', :'c[][]']
+          ^^^^^^^^^^^^^^^^^^^^^^ Use `%i` or `%I` for an array of symbols.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          %i[a b[] c[][]]
+        RUBY
+      end
     end
   end
 
