@@ -40,19 +40,25 @@ RSpec.describe RuboCop::Cop::Style::TrailingCommaInArrayLiteral, :config do
     context 'when EnforcedStyleForMultiline is no_comma' do
       let(:cop_config) { { 'EnforcedStyleForMultiline' => 'no_comma' } }
 
-      include_examples 'single line lists', ''
+      it_behaves_like 'single line lists', ''
     end
 
     context 'when EnforcedStyleForMultiline is comma' do
       let(:cop_config) { { 'EnforcedStyleForMultiline' => 'comma' } }
 
-      include_examples 'single line lists', ', unless each item is on its own line'
+      it_behaves_like 'single line lists', ', unless each item is on its own line'
+    end
+
+    context 'when EnforcedStyleForMultiline is diff_comma' do
+      let(:cop_config) { { 'EnforcedStyleForMultiline' => 'diff_comma' } }
+
+      it_behaves_like 'single line lists', ', unless that item immediately precedes a newline'
     end
 
     context 'when EnforcedStyleForMultiline is consistent_comma' do
       let(:cop_config) { { 'EnforcedStyleForMultiline' => 'consistent_comma' } }
 
-      include_examples 'single line lists', ', unless items are split onto multiple lines'
+      it_behaves_like 'single line lists', ', unless items are split onto multiple lines'
     end
   end
 
@@ -193,6 +199,107 @@ RSpec.describe RuboCop::Cop::Style::TrailingCommaInArrayLiteral, :config do
       end
     end
 
+    context 'when EnforcedStyleForMultiline is diff_comma' do
+      let(:cop_config) { { 'EnforcedStyleForMultiline' => 'diff_comma' } }
+
+      context 'when closing bracket is on same line as last value' do
+        it 'accepts no trailing comma' do
+          expect_no_offenses(<<~RUBY)
+            VALUES = [
+                       1001,
+                       2020,
+                       3333]
+          RUBY
+        end
+      end
+
+      it 'accepts two values on the same line' do
+        expect_no_offenses(<<~RUBY)
+          VALUES = [
+                     1001, 2020,
+                     3333,
+                   ]
+        RUBY
+      end
+
+      it 'registers an offense for literal with two of the values ' \
+         'on the same line and no trailing comma' do
+        expect_offense(<<~RUBY)
+          VALUES = [
+                     1001, 2020,
+                     3333
+                     ^^^^ Put a comma after the last item of a multiline array.
+                   ]
+        RUBY
+
+        expect_correction(<<~RUBY)
+          VALUES = [
+                     1001, 2020,
+                     3333,
+                   ]
+        RUBY
+      end
+
+      it 'accepts trailing comma' do
+        expect_no_offenses(<<~RUBY)
+          VALUES = [1001,
+                    2020,
+                    3333,
+                   ]
+        RUBY
+      end
+
+      it 'accepts trailing comma with comment' do
+        expect_no_offenses(<<~RUBY)
+          VALUES = [1001,
+                    2020,
+                    3333, # comment
+                   ]
+        RUBY
+      end
+
+      it 'registers an offense for a trailing comma on same line as closing bracket' do
+        expect_offense(<<~RUBY)
+          VALUES = [1001,
+                    2020,
+                    3333,]
+                        ^ Avoid comma after the last item of an array, unless that item immediately precedes a newline.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          VALUES = [1001,
+                    2020,
+                    3333]
+        RUBY
+      end
+
+      it 'accepts a multiline word array' do
+        expect_no_offenses(<<~RUBY)
+          ingredients = %w(
+            sausage
+            anchovies
+            olives
+          )
+        RUBY
+      end
+
+      it 'accepts a multiline array with a single item and trailing comma' do
+        expect_no_offenses(<<~RUBY)
+          foo = [
+            1,
+          ]
+        RUBY
+      end
+
+      it 'accepts a multiline array with items on a single line and trailing comma' do
+        expect_no_offenses(<<~RUBY)
+          foo = [
+            1, 2,
+          ]
+        RUBY
+      end
+    end
+
     context 'when EnforcedStyleForMultiline is consistent_comma' do
       let(:cop_config) { { 'EnforcedStyleForMultiline' => 'consistent_comma' } }
 
@@ -251,6 +358,21 @@ RSpec.describe RuboCop::Cop::Style::TrailingCommaInArrayLiteral, :config do
         RUBY
       end
 
+      it 'registers an offense for no trailing comma on same line as closing bracket' do
+        expect_offense(<<~RUBY)
+          VALUES = [1001,
+                    2020,
+                    3333]
+                    ^^^^ Put a comma after the last item of a multiline array.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          VALUES = [1001,
+                    2020,
+                    3333,]
+        RUBY
+      end
+
       it 'accepts a multiline word array' do
         expect_no_offenses(<<~RUBY)
           ingredients = %w(
@@ -269,7 +391,7 @@ RSpec.describe RuboCop::Cop::Style::TrailingCommaInArrayLiteral, :config do
         RUBY
       end
 
-      it 'accepts a multiline array with items on a single line andtrailing comma' do
+      it 'accepts a multiline array with items on a single line and trailing comma' do
         expect_no_offenses(<<~RUBY)
           foo = [
             1, 2,
