@@ -1,6 +1,10 @@
 # frozen_string_literal: true
 
+require 'timeout'
+
 RSpec.describe RuboCop::Cop::Style::WordArray, :config do
+  include EncodingHelper
+
   before do
     # Reset data which is shared by all instances of WordArray
     described_class.largest_brackets = -Float::INFINITY
@@ -58,10 +62,7 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
 
     context 'when the default external encoding is UTF-8' do
       around do |example|
-        orig_encoding = Encoding.default_external
-        Encoding.default_external = Encoding::UTF_8
-        example.run
-        Encoding.default_external = orig_encoding
+        with_default_external_encoding(Encoding::UTF_8) { example.run }
       end
 
       it 'registers an offense for arrays of unicode word characters' do
@@ -78,10 +79,7 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
 
     context 'when the default external encoding is US-ASCII' do
       around do |example|
-        orig_encoding = Encoding.default_external
-        Encoding.default_external = Encoding::US_ASCII
-        example.run
-        Encoding.default_external = orig_encoding
+        with_default_external_encoding(Encoding::US_ASCII) { example.run }
       end
 
       it 'registers an offense for arrays of unicode word characters' do
@@ -242,7 +240,7 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
     end
 
     it 'autocorrects an array of words in multiple lines' do
-      expect_offense(<<-RUBY)
+      expect_offense(<<~RUBY)
         [
         ^ Use `%w` or `%W` for an array of words.
         "foo",
@@ -251,7 +249,7 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
         ]
       RUBY
 
-      expect_correction(<<-RUBY)
+      expect_correction(<<~RUBY)
         %w(
         foo
         bar
@@ -261,14 +259,14 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
     end
 
     it 'autocorrects an array of words using partial newlines' do
-      expect_offense(<<-RUBY)
+      expect_offense(<<~RUBY)
         ["foo", "bar", "baz",
         ^^^^^^^^^^^^^^^^^^^^^ Use `%w` or `%W` for an array of words.
         "boz", "buz",
         "biz"]
       RUBY
 
-      expect_correction(<<-RUBY)
+      expect_correction(<<~RUBY)
         %w(foo bar baz
         boz buz
         biz)
@@ -347,6 +345,60 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
         A = %w(one two)
       RUBY
     end
+
+    it 'registers an offense and corrects for array within 2d array' do
+      expect_offense(<<~RUBY)
+        [
+          ['one', 'One'],
+          ^^^^^^^^^^^^^^ Use `%w` or `%W` for an array of words.
+          ['two', 'Two']
+          ^^^^^^^^^^^^^^ Use `%w` or `%W` for an array of words.
+        ]
+      RUBY
+
+      expect_correction(<<~RUBY)
+        [
+          %w(one One),
+          %w(two Two)
+        ]
+      RUBY
+    end
+
+    it 'does not register an offense for array within 2d array containing subarrays with complex content' do
+      expect_no_offenses(<<~RUBY)
+        [
+          ['one', 'One'],
+          ['two', 'Two'],
+          ['forty two', 'Forty Two']
+        ]
+      RUBY
+    end
+
+    it 'investigates a large matrix in a reasonable amount of time' do
+      expect do
+        Timeout.timeout(5) do # Should take under a second, but 5 seconds is plenty of margin
+          expect_no_offenses(<<~RUBY)
+            [
+              #{Array.new(999) do |n|
+                "['#{n}', 'simple_content'],"
+              end.join("\n  ")}
+              ['100', 'complex content'],
+            ]
+          RUBY
+        end
+      end.not_to raise_error, 'did not complete investigation in reasonable time'
+    end
+
+    it 'registers an offense and corrects for nested arrays' do
+      expect_offense(<<~RUBY)
+        [['one', 'One'], 2, 3]
+         ^^^^^^^^^^^^^^ Use `%w` or `%W` for an array of words.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        [%w(one One), 2, 3]
+      RUBY
+    end
   end
 
   context 'when EnforcedStyle is array' do
@@ -383,6 +435,34 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
       RUBY
     end
 
+    it 'registers an offense when assigning `%w()` array' do
+      expect_offense(<<~RUBY)
+        FOO = %w(one@example.com two@example.com)
+              ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use `['one@example.com', 'two@example.com']` for an array of words.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        FOO = ['one@example.com', 'two@example.com']
+      RUBY
+    end
+
+    it 'registers an offense when assigning multiline `%w()` array' do
+      expect_offense(<<~RUBY)
+        FOO = %w(
+              ^^^ Use an array literal `[...]` for an array of words.
+          one@example.com
+          two@example.com
+        )
+      RUBY
+
+      expect_correction(<<~RUBY)
+        FOO = [
+          'one@example.com',
+          'two@example.com'
+        ]
+      RUBY
+    end
+
     it 'registers an offense for an empty %w() array' do
       expect_offense(<<~RUBY)
         %w()
@@ -428,7 +508,7 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
     end
 
     it 'autocorrects multiline %w() array' do
-      expect_offense(<<~'RUBY')
+      expect_offense(<<~RUBY)
         %w(
         ^^^ Use an array literal `[...]` for an array of words.
           foo
@@ -436,7 +516,7 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
         )
       RUBY
 
-      expect_correction(<<~'RUBY')
+      expect_correction(<<~RUBY)
         [
           'foo',
           'bar'
@@ -479,7 +559,7 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
       RUBY
     end
 
-    it "doesn't fail with `encoding: binary" do
+    it "doesn't fail with `encoding: binary`" do
       expect_no_offenses(<<~'RUBY')
         # -*- encoding: binary -*-
         ["\xC0"] # Invalid as UTF-8
@@ -579,6 +659,17 @@ RSpec.describe RuboCop::Cop::Style::WordArray, :config do
           %w[) \] ( \[]
         RUBY
       end
+
+      it 'autocorrects balanced pairs of delimiters without excessive escaping' do
+        expect_offense(<<~RUBY)
+          ['a', 'b[]', 'c[][]']
+          ^^^^^^^^^^^^^^^^^^^^^ Use `%w` or `%W` for an array of words.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          %w[a b[] c[][]]
+        RUBY
+      end
     end
   end
 
