@@ -32,6 +32,10 @@ RSpec.describe RuboCop::Cop::Style::YodaCondition, :config do
       expect_no_offenses('foo == "bar"')
     end
 
+    it 'accepts constant on right' do
+      expect_no_offenses('foo == BAR')
+    end
+
     it 'accepts interpolated string on left' do
       expect_no_offenses('"#{interpolation}" == foo')
     end
@@ -138,6 +142,17 @@ RSpec.describe RuboCop::Cop::Style::YodaCondition, :config do
       RUBY
     end
 
+    it 'registers an offense constant on left of comparison' do
+      expect_offense(<<~RUBY)
+        FOO < bar
+        ^^^^^^^^^ Reverse the order of the operands `FOO < bar`.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        bar > FOO
+      RUBY
+    end
+
     context 'within an if or ternary statement' do
       it 'registers an offense for number on left in if condition' do
         expect_offense(<<~RUBY)
@@ -309,6 +324,10 @@ RSpec.describe RuboCop::Cop::Style::YodaCondition, :config do
       expect_no_offenses('bar === "foo"')
     end
 
+    it 'accepts equality check method is used without the first argument' do
+      expect_no_offenses('foo.==')
+    end
+
     it 'registers an offense for string literal on right' do
       expect_offense(<<~RUBY)
         bar == "foo"
