@@ -11,8 +11,7 @@ RSpec.describe RuboCop::Cop::VariableForce::Variable do
         name = :foo
         declaration_node = s(:def)
         scope = RuboCop::Cop::VariableForce::Scope.new(s(:class))
-        expect { described_class.new(name, declaration_node, scope) }
-          .to raise_error(ArgumentError)
+        expect { described_class.new(name, declaration_node, scope) }.to raise_error(ArgumentError)
       end
     end
   end
@@ -22,38 +21,30 @@ RSpec.describe RuboCop::Cop::VariableForce::Variable do
 
     let(:name) { :foo }
     let(:declaration_node) { s(:arg, name) }
-    let(:scope) do
-      instance_double(RuboCop::Cop::VariableForce::Scope).as_null_object
-    end
+    let(:scope) { instance_double(RuboCop::Cop::VariableForce::Scope).as_null_object }
     let(:variable) { described_class.new(name, declaration_node, scope) }
 
     context 'when the variable is not assigned' do
-      it { is_expected.to be_falsey }
+      it { is_expected.to be(false) }
 
       context 'and the variable is referenced' do
-        before do
-          variable.reference!(s(:lvar, name))
-        end
+        before { variable.reference!(s(:lvar, name)) }
 
-        it { is_expected.to be_truthy }
+        it { is_expected.to be(true) }
       end
     end
 
     context 'when the variable has an assignment' do
-      before do
-        variable.assign(s(:lvasgn, name))
-      end
+      before { variable.assign(s(:lvasgn, name)) }
 
       context 'and the variable is not yet referenced' do
-        it { is_expected.to be_falsey }
+        it { is_expected.to be(false) }
       end
 
       context 'and the variable is referenced' do
-        before do
-          variable.reference!(s(:lvar, name))
-        end
+        before { variable.reference!(s(:lvar, name)) }
 
-        it { is_expected.to be_truthy }
+        it { is_expected.to be(true) }
       end
     end
   end
