@@ -3,7 +3,7 @@
 RSpec.describe RuboCop::Formatter::ClangStyleFormatter, :config do
   subject(:formatter) { described_class.new(output) }
 
-  let(:cop_class) { RuboCop::Cop::Cop }
+  let(:cop_class) { RuboCop::Cop::Base }
   let(:output) { StringIO.new }
 
   before { cop.send(:begin_investigation, processed_source) }
@@ -12,26 +12,20 @@ RSpec.describe RuboCop::Formatter::ClangStyleFormatter, :config do
     let(:file) { '/path/to/file' }
 
     let(:offense) do
-      RuboCop::Cop::Offense.new(:convention, location, 'This is a message.', 'CopName', status)
+      RuboCop::Cop::Offense.new(:convention, range, 'This is a message.', 'CopName', status)
     end
 
     let(:source) { ('aa'..'az').to_a.join($RS) }
 
-    let(:location) { source_range(0...1) }
+    let(:range) { source_range(0...1) }
 
     it 'displays text containing the offending source line' do
-      cop.add_offense(
-        nil,
-        location: Parser::Source::Range.new(source_buffer, 0, 2),
-        message: 'message 1'
-      )
-      cop.add_offense(
-        nil,
-        location: Parser::Source::Range.new(source_buffer, 30, 32),
-        message: 'message 2'
+      cop.add_offense(Parser::Source::Range.new(source_buffer, 0, 2), message: 'message 1')
+      offenses = cop.add_offense(
+        Parser::Source::Range.new(source_buffer, 30, 32), message: 'message 2'
       )
 
-      formatter.report_file('test', cop.offenses)
+      formatter.report_file('test', offenses)
       expect(output.string).to eq <<~OUTPUT
         test:1:1: C: message 1
         aa
@@ -46,18 +40,12 @@ RSpec.describe RuboCop::Formatter::ClangStyleFormatter, :config do
       let(:source) { ['     ', 'yaba'].join($RS) }
 
       it 'does not display offending source line' do
-        cop.add_offense(
-          nil,
-          location: Parser::Source::Range.new(source_buffer, 0, 2),
-          message: 'message 1'
-        )
-        cop.add_offense(
-          nil,
-          location: Parser::Source::Range.new(source_buffer, 6, 10),
-          message: 'message 2'
+        cop.add_offense(Parser::Source::Range.new(source_buffer, 0, 2), message: 'message 1')
+        offenses = cop.add_offense(
+          Parser::Source::Range.new(source_buffer, 6, 10), message: 'message 2'
         )
 
-        formatter.report_file('test', cop.offenses)
+        formatter.report_file('test', offenses)
         expect(output.string).to eq <<~OUTPUT
           test:1:1: C: message 1
           test:2:1: C: message 2
@@ -77,11 +65,11 @@ RSpec.describe RuboCop::Formatter::ClangStyleFormatter, :config do
       end
 
       it 'displays the first line with ellipses' do
-        location = source_range(source.index('[')..source.index(']'))
+        range = source_range(source.index('[')..source.index(']'))
 
-        cop.add_offense(nil, location: location, message: 'message 1')
+        offenses = cop.add_offense(range, message: 'message 1')
 
-        formatter.report_file('test', cop.offenses)
+        formatter.report_file('test', offenses)
         expect(output.string)
           .to eq <<~OUTPUT
             test:1:14: C: message 1
@@ -126,10 +114,10 @@ RSpec.describe RuboCop::Formatter::ClangStyleFormatter, :config do
       end
 
       it 'displays text containing the offending source line' do
-        location = source_range(source.index('[')..source.index(']'))
+        range = source_range(source.index('[')..source.index(']'))
 
-        cop.add_offense(nil, location: location, message: 'message 1')
-        formatter.report_file('test', cop.offenses)
+        offenses = cop.add_offense(range, message: 'message 1')
+        formatter.report_file('test', offenses)
 
         expect(output.string)
           .to eq <<~OUTPUT
@@ -139,5 +127,27 @@ RSpec.describe RuboCop::Formatter::ClangStyleFormatter, :config do
         OUTPUT
       end
     end
+
+    context 'when the source contains tabs' do
+      let(:source) do
+        <<~RUBY
+          \t\t\tdo_something("[123]")
+        RUBY
+      end
+
+      it 'preserves tabs in highlighted area' do
+        range = source_range(source.index('[')..source.index(']'))
+
+        offenses = cop.add_offense(range, message: 'message 1')
+        formatter.report_file('test', offenses)
+
+        expect(output.string)
+          .to eq <<~OUTPUT
+            test:1:18: C: message 1
+            \t\t\tdo_something("[123]")
+            \t\t\t              ^^^^^
+        OUTPUT
+      end
+    end
   end
 end
