@@ -6,6 +6,8 @@ RSpec.describe RuboCop::Formatter::DisabledConfigFormatter, :isolated_environmen
 
   subject(:formatter) { described_class.new(output) }
 
+  include_context 'mock console output'
+
   let(:output) do
     io = StringIO.new
 
@@ -34,19 +36,8 @@ RSpec.describe RuboCop::Formatter::DisabledConfigFormatter, :isolated_environmen
   let(:expected_heading_command) { 'rubocop --auto-gen-config' }
 
   let(:expected_heading_timestamp) { "on #{Time.now} " }
-
-  around do |example|
-    original_stdout = $stdout
-    original_stderr = $stderr
-
-    $stdout = StringIO.new
-    $stderr = StringIO.new
-
-    example.run
-
-    $stdout = original_stdout
-    $stderr = original_stderr
-  end
+  let(:config_store) { instance_double(RuboCop::ConfigStore) }
+  let(:options) { { config_store: config_store } }
 
   before do
     stub_cop_class('Test::Cop1')
@@ -55,14 +46,15 @@ RSpec.describe RuboCop::Formatter::DisabledConfigFormatter, :isolated_environmen
     RuboCop::ConfigLoader.clear_options
 
     allow(Time).to receive(:now).and_return(Time.now)
+    allow(config_store).to receive(:for_pwd).and_return(instance_double(RuboCop::Config))
   end
 
   context 'when any offenses are detected' do
     before do
       formatter.started(['test_a.rb', 'test_b.rb'])
-      formatter.file_started('test_a.rb', {})
+      formatter.file_started('test_a.rb', options)
       formatter.file_finished('test_a.rb', offenses)
-      formatter.file_started('test_b.rb', {})
+      formatter.file_started('test_b.rb', options)
       formatter.file_finished('test_b.rb', [offenses.first])
       formatter.finished(['test_a.rb', 'test_b.rb'])
     end
@@ -101,9 +93,9 @@ RSpec.describe RuboCop::Formatter::DisabledConfigFormatter, :isolated_environmen
       YAML
 
       formatter.started(['test_a.rb', 'test_b.rb'])
-      formatter.file_started('test_a.rb', {})
+      formatter.file_started('test_a.rb', options)
       formatter.file_finished('test_a.rb', offenses)
-      formatter.file_started('test_b.rb', {})
+      formatter.file_started('test_b.rb', options)
       formatter.file_finished('test_b.rb', [offenses.first])
 
       allow(RuboCop::ConfigLoader.default_configuration).to receive(:[]).and_return({})
@@ -138,7 +130,7 @@ RSpec.describe RuboCop::Formatter::DisabledConfigFormatter, :isolated_environmen
       formatter.started(filenames)
 
       filenames.each do |filename|
-        formatter.file_started(filename, {})
+        formatter.file_started(filename, options)
 
         if filename == filenames.last
           formatter.file_finished(filename, [offenses.first])
@@ -189,7 +181,7 @@ RSpec.describe RuboCop::Formatter::DisabledConfigFormatter, :isolated_environmen
       formatter.started(filenames)
 
       filenames.each do |filename|
-        formatter.file_started(filename, {})
+        formatter.file_started(filename, options)
 
         if filename == filenames.last
           formatter.file_finished(filename, [offenses.first])
@@ -245,7 +237,7 @@ RSpec.describe RuboCop::Formatter::DisabledConfigFormatter, :isolated_environmen
       stub_cop_class('Test::Cop3') { extend RuboCop::Cop::AutoCorrector }
 
       formatter.started(['test_autocorrect.rb'])
-      formatter.file_started('test_autocorrect.rb', {})
+      formatter.file_started('test_autocorrect.rb', options)
       formatter.file_finished('test_autocorrect.rb', offenses)
       formatter.finished(['test_autocorrect.rb'])
     end
