@@ -77,6 +77,8 @@ RSpec.describe RuboCop::Formatter::FormatterSet do
   end
 
   describe '#close_output_files' do
+    include_context 'mock console output'
+
     before do
       2.times do
         output_path = Tempfile.new('').path
@@ -85,21 +87,14 @@ RSpec.describe RuboCop::Formatter::FormatterSet do
       formatter_set.add_formatter('simple')
     end
 
-    around do |example|
-      $stdout = StringIO.new
-      example.run
-    ensure
-      $stdout = STDOUT
-    end
-
     it 'closes all output files' do
       formatter_set.close_output_files
-      formatter_set[0..1].each { |formatter| expect(formatter.output.closed?).to be(true) }
+      formatter_set[0..1].each { |formatter| expect(formatter.output).to be_closed }
       win_close.call(formatter_set) if RuboCop::Platform.windows?
     end
 
     it 'does not close non file output' do
-      expect(formatter_set[2].output.closed?).to be(false)
+      expect(formatter_set[2].output).not_to be_closed
       win_close.call(formatter_set) if RuboCop::Platform.windows?
     end
   end
