@@ -77,18 +77,18 @@ RSpec.describe RuboCop::Formatter::QuietFormatter do
     context 'when no files inspected' do
       it 'handles pluralization correctly' do
         formatter.report_summary(0, 0, 0, 0)
-        expect(output.string.empty?).to be(true)
+        expect(output.string).to be_empty
       end
     end
 
     context 'when a file inspected and no offenses detected' do
       it 'handles pluralization correctly' do
         formatter.report_summary(1, 0, 0, 0)
-        expect(output.string.empty?).to be(true)
+        expect(output.string).to be_empty
       end
     end
 
-    context 'when a offense detected' do
+    context 'when an offense detected' do
       it 'handles pluralization correctly' do
         formatter.report_summary(1, 1, 0, 0)
         expect(output.string).to eq(<<~OUTPUT)
@@ -98,7 +98,7 @@ RSpec.describe RuboCop::Formatter::QuietFormatter do
       end
     end
 
-    context 'when a offense detected and a offense correctable' do
+    context 'when an offense detected and an offense correctable' do
       it 'handles pluralization correctly' do
         formatter.report_summary(1, 1, 0, 1)
         expect(output.string).to eq(<<~OUTPUT)
