@@ -1,6 +1,7 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::ResultCache, :isolated_environment do
+  include EncodingHelper
   include FileHelper
 
   subject(:cache) { described_class.new(file, team, options, config_store, cache_root) }
@@ -13,7 +14,8 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
   let(:file) { 'example.rb' }
   let(:options) { {} }
   let(:config_store) { instance_double(RuboCop::ConfigStore, for_pwd: RuboCop::Config.new) }
-  let(:cache_root) { "#{Dir.pwd}/rubocop_cache" }
+  let(:cache_root) { "#{Dir.pwd}/.cache" }
+  let(:rubocop_cache_dir) { "#{Dir.pwd}/.cache/rubocop_cache" }
   let(:offenses) do
     [RuboCop::Cop::Offense.new(:warning, location, 'unused var', 'Lint/UselessAssignment')]
   end
@@ -41,7 +43,7 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
       it 'is valid and can be loaded' do
         cache.save(offenses)
         cache2 = described_class.new(file, team, options2, config_store, cache_root)
-        expect(cache2.valid?).to be(true)
+        expect(cache2).to be_valid
         saved_offenses = cache2.load
         expect(saved_offenses).to eq(offenses)
       end
@@ -113,19 +115,49 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
           expect(cache.load[0].status).to eq(:new_status)
         end
       end
+
+      context 'a global offense' do
+        let(:no_location) { RuboCop::Cop::Offense::NO_LOCATION }
+        let(:global_offense) do
+          RuboCop::Cop::Offense.new(:warning, no_location, 'empty file', 'Lint/EmptyFile',
+                                    :unsupported)
+        end
+
+        it 'serializes the range correctly' do
+          cache.save([global_offense])
+          expect(cache.load[0].location).to eq(no_location)
+        end
+      end
+
+      context 'a global Lint/Syntax offense, caused by a parser error' do
+        before do
+          create_file('example.rb', ['# encoding: unknown'])
+        end
+
+        let(:no_location) { RuboCop::Cop::Offense::NO_LOCATION }
+        let(:global_offense) do
+          RuboCop::Cop::Offense.new(:warning, no_location, 'empty file', 'Lint/Syntax',
+                                    :unsupported)
+        end
+
+        it 'serializes the range correctly' do
+          cache.save([global_offense])
+          expect(cache.load[0].location).to eq(no_location)
+        end
+      end
     end
 
     context 'when no option is given' do
       let(:options2) { {} }
 
-      include_examples 'valid'
+      it_behaves_like 'valid'
 
       context 'when file contents have changed' do
         it 'is invalid' do
           cache.save(offenses)
           create_file('example.rb', ['x = 2'])
           cache2 = described_class.new(file, team, options, config_store, cache_root)
-          expect(cache2.valid?).to be(false)
+          expect(cache2).not_to be_valid
         end
       end
 
@@ -135,7 +167,7 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
             cache.save(offenses)
             FileUtils.chmod('+x', file)
             cache2 = described_class.new(file, team, options, config_store, cache_root)
-            expect(cache2.valid?).to be(false)
+            expect(cache2).not_to be_valid
           end
         end
       end
@@ -148,11 +180,11 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
             if contents.include?("\r")
               f.write(contents.delete("\r"))
             else
-              f.write(contents.gsub(/\n/, "\r\n"))
+              f.write(contents.gsub("\n", "\r\n"))
             end
           end
           cache2 = described_class.new(file, team, options, config_store, cache_root)
-          expect(cache2.valid?).to be(false)
+          expect(cache2).not_to be_valid
         end
       end
 
@@ -161,7 +193,7 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
           cache.save(offenses)
           allow(team).to(receive(:external_dependency_checksum).and_return('bar'))
           cache2 = described_class.new(file, team, options, config_store, cache_root)
-          expect(cache2.valid?).to be(false)
+          expect(cache2).not_to be_valid
         end
       end
 
@@ -170,11 +202,13 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
           cache.save(offenses)
           allow(team).to(receive(:external_dependency_checksum).and_return('foo'))
           cache2 = described_class.new(file, team, options, config_store, cache_root)
-          expect(cache2.valid?).to be(true)
+          expect(cache2).to be_valid
         end
       end
 
       context 'when a symlink is present in the cache location' do
+        include_context 'mock console output'
+
         let(:cache2) { described_class.new(file, team, options, config_store, cache_root) }
 
         let(:attack_target_dir) { Dir.mktmpdir }
@@ -189,12 +223,10 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
           path = result.first
           FileUtils.rm_rf(path)
           FileUtils.ln_s(attack_target_dir, path)
-          $stderr = StringIO.new
         end
 
         after do
           FileUtils.rm_rf(attack_target_dir)
-          $stderr = STDERR
         end
 
         context 'and symlink attack protection is enabled' do
@@ -202,7 +234,7 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
             cache2.save(offenses)
             # The cache file has not been created because there was a symlink in
             # its path.
-            expect(cache2.valid?).to be(false)
+            expect(cache2).not_to be_valid
             expect($stderr.string).to match(/Warning: .* is a symlink, which is not allowed.\n/)
           end
         end
@@ -221,7 +253,7 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
           it 'permits caching and prints no warning' do
             cache2.save(offenses)
 
-            expect(cache2.valid?).to be(true)
+            expect(cache2).to be_valid
             expect($stderr.string).not_to match(/Warning: .* is a symlink, which is not allowed.\n/)
           end
         end
@@ -232,14 +264,14 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
       it 'takes the cache_root from the options' do
         cache2 = described_class.new(file, team, { cache_root: 'some/path' }, config_store)
 
-        expect(cache2.path).to start_with('some/path')
+        expect(cache2.path).to start_with('some/path/rubocop_cache')
       end
     end
 
     context 'when --format is given' do
       let(:options2) { { format: 'simple' } }
 
-      include_examples 'valid'
+      it_behaves_like 'valid'
     end
 
     context 'when --only is given' do
@@ -248,7 +280,7 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
         cache2 = described_class.new(file, team,
                                      { only: ['Layout/LineLength'] },
                                      config_store, cache_root)
-        expect(cache2.valid?).to be(false)
+        expect(cache2).not_to be_valid
       end
     end
 
@@ -257,7 +289,7 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
         cache.save(offenses)
         cache2 = described_class.new(file, team, { display_cop_names: true },
                                      config_store, cache_root)
-        expect(cache2.valid?).to be(false)
+        expect(cache2).not_to be_valid
       end
     end
 
@@ -277,15 +309,15 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
       let(:offenses) do
         [
           "unused var \xF0",
-          (+'unused var あ').force_encoding(::Encoding::ASCII_8BIT)
+          (+'unused var あ').force_encoding(Encoding::ASCII_8BIT)
         ].map do |message|
           RuboCop::Cop::Offense.new(:warning, location, message, 'Lint/UselessAssignment')
         end
       end
 
-      before { Encoding.default_internal = Encoding::UTF_8 }
-
-      after { Encoding.default_internal = nil }
+      around do |example|
+        with_default_internal_encoding(Encoding::UTF_8) { example.run }
+      end
 
       it 'writes non UTF-8 encodable data to file with no exception' do
         expect { cache.save(offenses) }.not_to raise_error
@@ -293,7 +325,7 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
     end
 
     shared_examples 'invalid cache location' do |error, message|
-      before { $stderr = StringIO.new }
+      include_context 'mock console output'
 
       it 'doesn\'t raise an exception' do
         allow(FileUtils).to receive(:mkdir_p).with(start_with(cache_root)).and_raise(error)
@@ -303,8 +335,6 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
             #{message}
         WARN
       end
-
-      after { $stderr = STDERR }
     end
 
     context 'when the @path is not writable' do
@@ -316,29 +346,46 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
   end
 
   describe '.cleanup' do
+    include_context 'mock console output'
+
     before do
       cfg = RuboCop::Config.new('AllCops' => { 'MaxFilesInCache' => 1 })
       allow(config_store).to receive(:for_pwd).and_return(cfg)
       allow(config_store).to receive(:for_file).with('other.rb').and_return(cfg)
       create_file('other.rb', ['x = 1'])
-      $stdout = StringIO.new
     end
 
-    after { $stdout = STDOUT }
-
-    it 'removes the oldest files in the cache if needed' do
+    it 'removes the oldest files in the standard cache_root if needed' do
       cache.save(offenses)
-      cache2 = described_class.new('other.rb', team, options, config_store, cache_root)
-      expect(Dir["#{cache_root}/*/*/*"].size).to eq(1)
+      underscore_dir = Dir["#{rubocop_cache_dir}/*/*"].first
+      expect(Dir["#{underscore_dir}/*"].size).to eq(1)
       cache.class.cleanup(config_store, :verbose, cache_root)
       expect($stdout.string).to eq('')
 
+      cache2 = described_class.new('other.rb', team, options, config_store, cache_root)
       cache2.save(offenses)
-      underscore_dir = Dir["#{cache_root}/*/*"].first
+      underscore_dir = Dir["#{rubocop_cache_dir}/*/*"].first
       expect(Dir["#{underscore_dir}/*"].size).to eq(2)
+
       cache.class.cleanup(config_store, :verbose, cache_root)
-      expect(File.exist?(underscore_dir)).to be_falsey
-      expect($stdout.string).to eq("Removing the 2 oldest files from #{cache_root}\n")
+      expect(File).not_to exist(underscore_dir)
+      expect($stdout.string).to eq("Removing the 2 oldest files from #{rubocop_cache_dir}\n")
+    end
+
+    it 'removes the oldest files in a custom cache_root if needed' do
+      custom_cache_root = "#{Dir.pwd}/.custom_cache"
+      custom_rubocop_cache_dir = "#{Dir.pwd}/.custom_cache/rubocop_cache"
+
+      custom_cache = described_class.new('other.rb', team, options, config_store, custom_cache_root)
+      custom_cache.save(offenses)
+      custom_cache2 = described_class.new('some.rb', team, options, config_store, custom_cache_root)
+      custom_cache2.save(offenses)
+      underscore_dir = Dir["#{custom_rubocop_cache_dir}/*/*"].first
+      expect(Dir["#{underscore_dir}/*"].size).to eq(2)
+
+      custom_cache.class.cleanup(config_store, :verbose, custom_cache_root)
+      expect(File).not_to exist(underscore_dir)
+      expect($stdout.string).to eq("Removing the 2 oldest files from #{custom_rubocop_cache_dir}\n")
     end
   end
 
@@ -362,6 +409,14 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
           cacheroot = described_class.cache_root(config_store)
           expect(cacheroot).to eq(File.join(Dir.home, '.cache', 'rubocop_cache'))
         end
+
+        it 'contains the root in path only once' do
+          cache = described_class.new(file, team, options, config_store)
+          expect(cache.path).to start_with(File.join(Dir.home, '.cache', 'rubocop_cache'))
+
+          count = cache.path.scan('rubocop_cache').count
+          expect(count).to eq(1)
+        end
       end
 
       context 'and XDG_CACHE_HOME is set' do
@@ -378,6 +433,16 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
           cacheroot = described_class.cache_root(config_store)
           expect(cacheroot).to eq(File.join(ENV.fetch('XDG_CACHE_HOME'), puid, 'rubocop_cache'))
         end
+
+        it 'contains the root in path only once' do
+          cache = described_class.new(file, team, options, config_store)
+          expect(cache.path).to start_with(
+            File.join(ENV.fetch('XDG_CACHE_HOME'), puid, 'rubocop_cache')
+          )
+
+          count = cache.path.scan('rubocop_cache').count
+          expect(count).to eq(1)
+        end
       end
     end
 
@@ -403,6 +468,14 @@ RSpec.describe RuboCop::ResultCache, :isolated_environment do
           cacheroot = described_class.cache_root(config_store)
           expect(cacheroot).to eq(File.join('/tmp/cache-from-env', 'rubocop_cache'))
         end
+
+        it 'contains the root in path only once' do
+          cache = described_class.new(file, team, options, config_store)
+          expect(cache.path).to start_with(File.join('/tmp/cache-from-env', 'rubocop_cache'))
+
+          count = cache.path.scan('rubocop_cache').count
+          expect(count).to eq(1)
+        end
       end
     end
   end
