@@ -42,7 +42,7 @@ RSpec.describe RuboCop::Runner, :isolated_environment do
 
     context 'with SIGINT' do
       it 'returns false' do
-        skip unless Process.respond_to?(:fork)
+        skip '`Process` does not respond to `fork` method.' unless Process.respond_to?(:fork)
 
         # Make sure the runner works slowly and thus is interruptible
         allow(runner).to receive(:process_file) do
@@ -121,6 +121,136 @@ RSpec.describe RuboCop::Runner, :isolated_environment do
       end
     end
 
+    context 'custom ruby extractors' do
+      around do |example|
+        described_class.ruby_extractors.unshift(custom_ruby_extractor)
+
+        # Ignore platform differences.
+        create_file('.rubocop.yml', <<~YAML)
+          Layout/EndOfLine:
+            Enabled: false
+        YAML
+
+        example.call
+      ensure
+        described_class.ruby_extractors.shift
+      end
+
+      context 'when the extractor matches' do
+        # rubocop:disable Layout/LineLength
+        let(:custom_ruby_extractor) do
+          lambda do |_processed_source|
+            [
+              {
+                offset: 1,
+                processed_source: RuboCop::ProcessedSource.new(<<~RUBY, 3.3, 'dummy.rb', parser_engine: parser_engine)
+                  # frozen_string_literal: true
+
+                  def valid_code; end
+                RUBY
+              },
+              {
+                offset: 2,
+                processed_source: RuboCop::ProcessedSource.new(source, 3.3, 'dummy.rb', parser_engine: parser_engine)
+              }
+            ]
+          end
+        end
+        # rubocop:enable Layout/LineLength
+
+        let(:source) do
+          <<~RUBY
+            # frozen_string_literal: true
+
+            def INVALID_CODE; end
+          RUBY
+        end
+
+        it 'sends the offense to a formatter' do
+          runner.run([])
+          expect(formatter_output).to eq <<~RESULT
+            Inspecting 1 file
+            C
+
+            Offenses:
+
+            example.rb:3:7: C: Naming/MethodName: Use snake_case for method names.
+            def INVALID_CODE; end
+                  ^^^^^^^^^^^^
+
+            1 file inspected, 1 offense detected
+          RESULT
+        end
+      end
+
+      context 'when the extractor does not match' do
+        let(:custom_ruby_extractor) do
+          lambda do |_processed_source|
+          end
+        end
+
+        let(:source) { <<~RUBY }
+          # frozen_string_literal: true
+
+          def INVALID_CODE; end
+        RUBY
+
+        it 'sends the offense to a formatter' do
+          runner.run([])
+          expect(formatter_output).to eq <<~RESULT
+            Inspecting 1 file
+            C
+
+            Offenses:
+
+            example.rb:3:5: C: Naming/MethodName: Use snake_case for method names.
+            def INVALID_CODE; end
+                ^^^^^^^^^^^^
+
+            1 file inspected, 1 offense detected
+          RESULT
+        end
+      end
+
+      context 'when the extractor crashes' do
+        let(:source) { <<~RUBY }
+          # frozen_string_literal: true
+
+          def foo; end
+        RUBY
+
+        shared_examples 'error handling' do
+          it 'raises an error with the crashing extractor/file' do
+            expect do
+              runner.run([])
+            end.to raise_error(RuboCop::Error, /runner_spec\.rb failed to process .*example\.rb/)
+          end
+        end
+
+        context 'and it is a Proc' do
+          let(:custom_ruby_extractor) do
+            lambda do |_processed_source|
+              raise 'Oh no!'
+            end
+          end
+
+          it_behaves_like 'error handling'
+        end
+
+        context 'and it responds to `call`' do
+          let(:custom_ruby_extractor) do
+            Class.new do
+              def self.call(_processed_source)
+                raise 'Oh no!'
+              end
+            end
+          end
+
+          it_behaves_like 'error handling'
+        end
+      end
+    end
+
     context 'if a cop crashes' do
       before do
         # The cache responds that it's not valid, which means that new results
@@ -185,9 +315,11 @@ RSpec.describe RuboCop::Runner, :isolated_environment do
   end
 
   describe '#run with cops autocorrecting each-other' do
-    let(:source_file_path) { create_file('example.rb', source) }
+    include_context 'mock console output'
 
-    let(:options) { { autocorrect: true, formatters: [['progress', formatter_output_path]] } }
+    let!(:source_file_path) { create_file('example.rb', source) }
+
+    let(:options) { { autocorrect: true } }
 
     context 'with two conflicting cops' do
       subject(:runner) do
@@ -211,15 +343,28 @@ RSpec.describe RuboCop::Runner, :isolated_environment do
           end
         RUBY
 
-        it 'aborts because of an infinite loop' do
-          expect do
-            runner.run([])
-          end.to raise_error(
-            RuboCop::Runner::InfiniteCorrectionLoop,
+        it 'records the infinite loop error' do
+          runner.run([])
+          expect(runner.errors.size).to be(1)
+          expect(runner.errors[0].message).to eq(
             "Infinite loop detected in #{source_file_path} and caused by " \
             'Test/ClassMustBeAModuleCop -> Test/ModuleMustBeAClassCop'
           )
         end
+
+        context 'when `raise_cop_error` is set' do
+          let(:options) { { autocorrect: true, raise_cop_error: true } }
+
+          it 'raises the infinite loop error' do
+            expect do
+              runner.run([])
+            end.to raise_error(
+              described_class::InfiniteCorrectionLoop,
+              "Infinite loop detected in #{source_file_path} and caused by " \
+              'Test/ClassMustBeAModuleCop -> Test/ModuleMustBeAClassCop'
+            )
+          end
+        end
       end
 
       context 'if there are multiple offenses in an inspected file' do
@@ -231,11 +376,11 @@ RSpec.describe RuboCop::Runner, :isolated_environment do
           end
         RUBY
 
-        it 'aborts because of an infinite loop' do
-          expect do
-            runner.run([])
-          end.to raise_error(
-            RuboCop::Runner::InfiniteCorrectionLoop,
+        it 'records the infinite loop error' do
+          runner.run([])
+
+          expect(runner.errors.size).to be(1)
+          expect(runner.errors[0].message).to eq(
             "Infinite loop detected in #{source_file_path} and caused by " \
             'Test/ClassMustBeAModuleCop -> Test/ModuleMustBeAClassCop'
           )
@@ -267,14 +412,13 @@ RSpec.describe RuboCop::Runner, :isolated_environment do
           end
         RUBY
 
-        it 'aborts because of an infinite loop' do
-          expect do
-            runner.run([])
-          end.to raise_error(
-            RuboCop::Runner::InfiniteCorrectionLoop,
+        it 'records the infinite loop error' do
+          runner.run([])
+
+          expect(runner.errors.size).to be(1)
+          expect(runner.errors[0].message).to eq(
             "Infinite loop detected in #{source_file_path} and caused by " \
-            'Test/ClassMustBeAModuleCop, Test/AtoB ' \
-            '-> Test/ModuleMustBeAClassCop, Test/BtoA'
+            'Test/ClassMustBeAModuleCop, Test/AtoB -> Test/ModuleMustBeAClassCop, Test/BtoA'
           )
         end
       end
@@ -302,11 +446,11 @@ RSpec.describe RuboCop::Runner, :isolated_environment do
             end
           RUBY
 
-          it 'aborts because of an infinite loop' do
-            expect do
-              runner.run([])
-            end.to raise_error(
-              RuboCop::Runner::InfiniteCorrectionLoop,
+          it 'records the infinite correction error' do
+            runner.run([])
+
+            expect(runner.errors.size).to be(1)
+            expect(runner.errors[0].message).to eq(
               "Infinite loop detected in #{source_file_path} and caused by " \
               'Test/AtoB -> Test/BtoC -> Test/CtoA'
             )
@@ -336,7 +480,7 @@ RSpec.describe RuboCop::Runner, :isolated_environment do
             expect(runner.run([])).to be false
           end
 
-          it 'ommits unsafe correctable `Style/FrozenStringLiteral`' do
+          it 'omits unsafe correctable `Style/FrozenStringLiteral`' do
             runner.run([])
             expect(formatter_output).to eq <<~RESULT
               Inspecting 1 file
@@ -379,7 +523,7 @@ RSpec.describe RuboCop::Runner, :isolated_environment do
             expect(runner.run([])).to be false
           end
 
-          it 'ommits uncorrectable `Layout/LineLength`' do
+          it 'omits uncorrectable `Layout/LineLength`' do
             runner.run([])
             expect(formatter_output).to eq <<~RESULT
               Inspecting 1 file
