@@ -24,6 +24,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
                        .rbx
                        .ru
                        .ruby
+                       .schema
                        .spec
                        .thor
                        .watchr]
@@ -50,6 +51,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
                       Puppetfile
                       Rakefile
                       rakefile
+                      Schemafile
                       Snapfile
                       Steepfile
                       Thorfile
@@ -60,8 +62,15 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
   subject(:target_finder) { described_class.new(config_store, options) }
 
   let(:config_store) { RuboCop::ConfigStore.new }
-  let(:options) { { force_exclusion: force_exclusion, debug: debug } }
+  let(:options) do
+    {
+      force_exclusion: force_exclusion,
+      ignore_parent_exclusion: ignore_parent_exclusion,
+      debug: debug
+    }
+  end
   let(:force_exclusion) { false }
+  let(:ignore_parent_exclusion) { false }
   let(:debug) { false }
 
   before do
@@ -69,9 +78,11 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
     create_empty_file('dir1/ruby2.rb')
     create_empty_file('dir1/file.txt')
     create_empty_file('dir1/file')
-    create_file('dir1/executable',  '#!/usr/bin/env ruby')
+    create_file('dir1/executable', '#!/usr/bin/env ruby')
     create_empty_file('dir2/ruby3.rb')
     create_empty_file('.hidden/ruby4.rb')
+
+    RuboCop::ConfigLoader.clear_options
   end
 
   shared_examples 'common behavior for #find' do
@@ -105,6 +116,16 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
       end
     end
 
+    context 'when a pattern with matching folders is passed' do
+      before { create_empty_file('app/dir.rb/ruby.rb') }
+
+      let(:args) { ['app/**/*.rb'] }
+
+      it 'finds only files which match the pattern' do
+        expect(found_basenames).to eq(['ruby.rb'])
+      end
+    end
+
     context 'when same paths are passed' do
       let(:args) { %w[dir1 dir1] }
 
@@ -142,15 +163,33 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
       context "when it's forced to adhere file exclusion configuration" do
         let(:force_exclusion) { true }
 
-        it 'excludes them' do
-          expect(found_basenames).to eq(['ruby2.rb'])
+        context 'when parent exclusion is in effect' do
+          before do
+            create_file('dir2/.rubocop.yml', <<~YAML)
+              require:
+                - unloadable_extension
+            YAML
+          end
+
+          it 'excludes only files that are excluded on top level and does not load ' \
+             'other configuration files unnecessarily' do
+            expect(found_basenames).to eq(['ruby2.rb', 'executable'])
+          end
+        end
+
+        context 'when parent exclusion is ignored' do
+          let(:ignore_parent_exclusion) { true }
+
+          it 'excludes files that are excluded on any level' do
+            expect(found_basenames).to eq(['ruby2.rb'])
+          end
         end
       end
     end
 
     it 'returns absolute paths' do
-      expect(found_files.empty?).to be(false)
-      found_files.each { |file| expect(Pathname.new(file).absolute?).to be(true) }
+      expect(found_files).not_to be_empty
+      found_files.each { |file| expect(Pathname.new(file)).to be_absolute }
     end
 
     it 'does not find hidden files' do
@@ -162,7 +201,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
 
       it 'finds files under the current directory' do
         Dir.chdir('dir1') do
-          expect(found_files.empty?).to be(false)
+          expect(found_files).not_to be_empty
           found_files.each do |file|
             expect(file).to include('/dir1/')
             expect(file).not_to include('/dir2/')
@@ -176,7 +215,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
 
       it 'finds files under the specified directory' do
         Dir.chdir('dir1') do
-          expect(found_files.empty?).to be(false)
+          expect(found_files).not_to be_empty
           found_files.each do |file|
             expect(file).to include('/dir2/')
             expect(file).not_to include('/dir1/')
@@ -248,7 +287,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
       let(:args) { ['dir2/file'] }
 
       it "doesn't pick the file" do
-        expect(found_basenames.empty?).to be(true)
+        expect(found_basenames).to be_empty
       end
     end
 
@@ -261,7 +300,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
 
       context 'when local AllCops/Include lists two patterns' do
         before do
-          create_file('.rubocop.yml', <<-YAML)
+          create_file('.rubocop.yml', <<~YAML)
             AllCops:
               Include:
                 - '**/*.rb'
@@ -275,7 +314,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
 
         context 'when a subdirectory AllCops/Include only lists one pattern' do
           before do
-            create_file('dir2/.rubocop.yml', <<-YAML)
+            create_file('dir2/.rubocop.yml', <<~YAML)
               AllCops:
                 Include:
                   - '**/*.ruby'
@@ -291,7 +330,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
       end
     end
 
-    include_examples 'common behavior for #find'
+    it_behaves_like 'common behavior for #find'
 
     context 'when some non-known Ruby files are specified in the ' \
             'configuration Include and they are not explicitly passed ' \
@@ -312,7 +351,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
       end
     end
 
-    include_examples 'when input is passed on stdin'
+    it_behaves_like 'when input is passed on stdin'
   end
 
   describe '#find(..., :all_file_types)' do
@@ -320,7 +359,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
     let(:found_basenames) { found_files.map { |f| File.basename(f) } }
     let(:args) { [] }
 
-    include_examples 'common behavior for #find'
+    it_behaves_like 'common behavior for #find'
 
     context 'when a non-ruby file is passed' do
       let(:args) { ['dir2/file'] }
@@ -339,11 +378,11 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
 
       let(:args) { ruby_extensions.map { |ext| "dir2/file#{ext}" } }
 
-      include_examples 'picks all the ruby files'
+      it_behaves_like 'picks all the ruby files'
 
       context 'when local AllCops/Include lists two patterns' do
         before do
-          create_file('.rubocop.yml', <<-YAML)
+          create_file('.rubocop.yml', <<~YAML)
             AllCops:
               Include:
                 - '**/*.rb'
@@ -351,18 +390,18 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
           YAML
         end
 
-        include_examples 'picks all the ruby files'
+        it_behaves_like 'picks all the ruby files'
 
         context 'when a subdirectory AllCops/Include only lists one pattern' do
           before do
-            create_file('dir2/.rubocop.yml', <<-YAML)
+            create_file('dir2/.rubocop.yml', <<~YAML)
               AllCops:
                 Include:
                   - '**/*.ruby'
             YAML
           end
 
-          include_examples 'picks all the ruby files'
+          it_behaves_like 'picks all the ruby files'
         end
       end
     end
@@ -388,7 +427,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
       end
     end
 
-    include_examples 'when input is passed on stdin'
+    it_behaves_like 'when input is passed on stdin'
   end
 
   describe '#find_files' do
@@ -433,6 +472,47 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
       expect(found_basenames).to include('ruby4.rb')
     end
 
+    it 'works also if a folder is named "{foo}"' do
+      create_empty_file('{foo}/ruby4.rb')
+
+      config = instance_double(RuboCop::Config)
+      exclude_property = { 'Exclude' => [File.expand_path('dir1/**/*')] }
+      allow(config).to receive(:for_all_cops).and_return(exclude_property)
+      allow(config_store).to receive(:for).and_return(config)
+
+      expect(found_basenames).not_to include('ruby1.rb')
+      expect(found_basenames).to include('ruby3.rb')
+      expect(found_basenames).to include('ruby4.rb')
+    end
+
+    it 'works also if a folder is named "[...something]"' do
+      create_empty_file('[...something]/ruby4.rb')
+
+      config = instance_double(RuboCop::Config)
+      exclude_property = { 'Exclude' => [File.expand_path('dir1/**/*')] }
+      allow(config).to receive(:for_all_cops).and_return(exclude_property)
+      allow(config_store).to receive(:for).and_return(config)
+
+      expect(found_basenames).not_to include('ruby1.rb')
+      expect(found_basenames).to include('ruby3.rb')
+      expect(found_basenames).to include('ruby4.rb')
+    end
+
+    it 'works if patterns are empty' do
+      allow(Dir).to receive(:glob).and_call_original
+      allow_any_instance_of(described_class).to receive(:wanted_dir_patterns).and_return([])
+
+      expect(Dir).to receive(:glob).with([File.join(base_dir, '**/*')], flags)
+      expect(found_basenames).to include(
+        'executable',
+        'file.txt',
+        'file',
+        'ruby1.rb',
+        'ruby2.rb',
+        'ruby3.rb'
+      )
+    end
+
     # Cannot create a directory with containing `*` character on Windows.
     # https://docs.microsoft.com/en-us/windows/win32/fileio/naming-a-file#naming-conventions
     unless RuboCop::Platform.windows?
@@ -467,18 +547,16 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
     end
 
     it 'can exclude symlinks as well as directories' do
-      Dir.mktmpdir do |tmpdir|
-        create_empty_file(File.join(tmpdir, 'ruby5.rb'))
-        create_link('link', tmpdir)
+      create_empty_file(File.join(Dir.home, 'ruby5.rb'))
+      create_link('link', Dir.home)
 
-        config = instance_double(RuboCop::Config)
-        exclude_property = { 'Exclude' => [File.expand_path('link/**/*')] }
-        allow(config).to receive(:for_all_cops).and_return(exclude_property)
-        allow(config_store).to receive(:for).and_return(config)
+      config = instance_double(RuboCop::Config)
+      exclude_property = { 'Exclude' => [File.expand_path('link/**/*')] }
+      allow(config).to receive(:for_all_cops).and_return(exclude_property)
+      allow(config_store).to receive(:for).and_return(config)
 
-        expect(found_basenames).not_to include('ruby5.rb')
-        expect(found_basenames).to include('ruby3.rb')
-      end
+      expect(found_basenames).not_to include('ruby5.rb')
+      expect(found_basenames).to include('ruby3.rb')
     end
   end
 
@@ -511,12 +589,12 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
       allow(config).to receive(:file_to_include?) do |file|
         File.basename(file) == 'file'
       end
-      allow(config)
-        .to receive(:for_all_cops).and_return('Exclude' => [],
-                                              'Include' => [],
-                                              'RubyInterpreters' => [])
-      allow(config).to receive(:[]).and_return([])
-      allow(config).to receive(:file_to_exclude?).and_return(false)
+      allow(config).to receive_messages(
+        for_all_cops: { 'Exclude' => [], 'Include' => [], 'RubyInterpreters' => [] },
+        :[] => [],
+        file_to_exclude?: false
+      )
+
       allow(config_store).to receive(:for).and_return(config)
 
       expect(found_basenames).to include('file')
@@ -524,11 +602,11 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
 
     it 'does not pick files specified to be excluded in config' do
       config = instance_double(RuboCop::Config).as_null_object
-      allow(config)
-        .to receive(:for_all_cops).and_return('Exclude' => [],
-                                              'Include' => [],
-                                              'RubyInterpreters' => [])
-      allow(config).to receive(:file_to_include?).and_return(false)
+      allow(config).to receive_messages(
+        for_all_cops: { 'Exclude' => [], 'Include' => [], 'RubyInterpreters' => [] },
+        file_to_include?: false
+      )
+
       allow(config).to receive(:file_to_exclude?) do |file|
         File.basename(file) == 'ruby2.rb'
       end
@@ -538,15 +616,7 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
     end
 
     context 'when an exception is raised while reading file' do
-      around do |example|
-        original_stderr = $stderr
-        $stderr = StringIO.new
-        begin
-          example.run
-        ensure
-          $stderr = original_stderr
-        end
-      end
+      include_context 'mock console output'
 
       before { allow_any_instance_of(File).to receive(:readline).and_raise(EOFError) }
 
@@ -564,7 +634,53 @@ RSpec.describe RuboCop::TargetFinder, :isolated_environment do
 
         it 'outputs nothing' do
           found_files
-          expect($stderr.string.empty?).to be(true)
+          expect($stderr.string).to be_empty
+        end
+      end
+    end
+
+    context 'when file is zero-sized' do
+      include_context 'mock console output'
+
+      before do
+        create_file('dir1/flag', nil)
+      end
+
+      context 'and debug mode is enabled' do
+        let(:debug) { true }
+
+        it 'outputs error message' do
+          found_files
+          expect($stderr.string).to be_empty
+        end
+      end
+
+      context 'and debug mode is disabled' do
+        let(:debug) { false }
+
+        it 'outputs nothing' do
+          found_files
+          expect($stderr.string).to be_empty
+        end
+      end
+    end
+
+    context 'when provided directory contains hidden segments' do
+      let(:base_dir) { File.expand_path('.hidden') }
+
+      it 'picks relevant files within provided directory' do
+        expect(found_basenames).to match_array(%w[ruby4.rb])
+      end
+
+      context 'with nested hidden directory' do
+        before do
+          create_empty_file('.hidden/.nested-hidden/ruby5.rb')
+          create_file('.hidden/shebang-ruby', '#! /usr/bin/env ruby')
+          create_file('.hidden/shebang-zsh', '#! /usr/bin/env zsh')
+        end
+
+        it 'picks relevant files within provided directory' do
+          expect(found_basenames).to match_array(%w[ruby4.rb ruby5.rb shebang-ruby])
         end
       end
     end
