@@ -1,12 +1,10 @@
 # frozen_string_literal: true
 
-RSpec.shared_examples_for 'multiline literal brace layout' do
+RSpec.shared_examples 'multiline literal brace layout' do
   include MultilineLiteralBraceHelper
 
   let(:prefix) { '' } # A prefix before the opening brace.
   let(:suffix) { '' } # A suffix for the line after the closing brace.
-  let(:open) { nil } # The opening brace.
-  let(:close) { nil } # The closing brace.
   let(:a) { 'a' } # The first element.
   let(:b) { 'b' } # The second element.
   let(:b_comment) { '' } # Comment after the second element.
